'''OpenGL extension REND.screen_coordinates

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_REND_screen_coordinates'
_DEPRECATED = False
GL_SCREEN_COORDINATES_REND = constant.Constant( 'GL_SCREEN_COORDINATES_REND', 0x8490 )
GL_INVERTED_SCREEN_W_REND = constant.Constant( 'GL_INVERTED_SCREEN_W_REND', 0x8491 )


def glInitScreenCoordinatesREND():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
