'''OpenGL extension MESA.resize_buffers

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_MESA_resize_buffers'
_DEPRECATED = False

glResizeBuffersMESA = platform.createExtensionFunction( 
'glResizeBuffersMESA',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(),
doc='glResizeBuffersMESA() -> None',
argNames=(),
deprecated=_DEPRECATED,
)


def glInitResizeBuffersMESA():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
