'''OpenGL extension EXT.bgra

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_bgra'
_DEPRECATED = False
GL_BGR_EXT = constant.Constant( 'GL_BGR_EXT', 0x80E0 )
GL_BGRA_EXT = constant.Constant( 'GL_BGRA_EXT', 0x80E1 )


def glInitBgraEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
