'''OpenGL extension NV.vertex_array_range

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_vertex_array_range'
_DEPRECATED = False
GL_VERTEX_ARRAY_RANGE_NV = constant.Constant( 'GL_VERTEX_ARRAY_RANGE_NV', 0x851D )
GL_VERTEX_ARRAY_RANGE_LENGTH_NV = constant.Constant( 'GL_VERTEX_ARRAY_RANGE_LENGTH_NV', 0x851E )
glget.addGLGetConstant( GL_VERTEX_ARRAY_RANGE_LENGTH_NV, (1,) )
GL_VERTEX_ARRAY_RANGE_VALID_NV = constant.Constant( 'GL_VERTEX_ARRAY_RANGE_VALID_NV', 0x851F )
glget.addGLGetConstant( GL_VERTEX_ARRAY_RANGE_VALID_NV, (1,) )
GL_MAX_VERTEX_ARRAY_RANGE_ELEMENT_NV = constant.Constant( 'GL_MAX_VERTEX_ARRAY_RANGE_ELEMENT_NV', 0x8520 )
glget.addGLGetConstant( GL_MAX_VERTEX_ARRAY_RANGE_ELEMENT_NV, (1,) )
GL_VERTEX_ARRAY_RANGE_POINTER_NV = constant.Constant( 'GL_VERTEX_ARRAY_RANGE_POINTER_NV', 0x8521 )
glFlushVertexArrayRangeNV = platform.createExtensionFunction( 
'glFlushVertexArrayRangeNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(),
doc='glFlushVertexArrayRangeNV() -> None',
argNames=(),
deprecated=_DEPRECATED,
)

glVertexArrayRangeNV = platform.createExtensionFunction( 
'glVertexArrayRangeNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsizei,ctypes.c_void_p,),
doc='glVertexArrayRangeNV(GLsizei(length), c_void_p(pointer)) -> None',
argNames=('length','pointer',),
deprecated=_DEPRECATED,
)


def glInitVertexArrayRangeNV():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
