'''OpenGL extension NV.video_capture

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_video_capture'
_DEPRECATED = False
GL_VIDEO_BUFFER_NV = constant.Constant( 'GL_VIDEO_BUFFER_NV', 0x9020 )
GL_VIDEO_BUFFER_BINDING_NV = constant.Constant( 'GL_VIDEO_BUFFER_BINDING_NV', 0x9021 )
glget.addGLGetConstant( GL_VIDEO_BUFFER_BINDING_NV, (1,) )
GL_FIELD_UPPER_NV = constant.Constant( 'GL_FIELD_UPPER_NV', 0x9022 )
GL_FIELD_LOWER_NV = constant.Constant( 'GL_FIELD_LOWER_NV', 0x9023 )
GL_NUM_VIDEO_CAPTURE_STREAMS_NV = constant.Constant( 'GL_NUM_VIDEO_CAPTURE_STREAMS_NV', 0x9024 )
GL_NEXT_VIDEO_CAPTURE_BUFFER_STATUS_NV = constant.Constant( 'GL_NEXT_VIDEO_CAPTURE_BUFFER_STATUS_NV', 0x9025 )
GL_VIDEO_CAPTURE_TO_422_SUPPORTED_NV = constant.Constant( 'GL_VIDEO_CAPTURE_TO_422_SUPPORTED_NV', 0x9026 )
GL_LAST_VIDEO_CAPTURE_STATUS_NV = constant.Constant( 'GL_LAST_VIDEO_CAPTURE_STATUS_NV', 0x9027 )
GL_VIDEO_BUFFER_PITCH_NV = constant.Constant( 'GL_VIDEO_BUFFER_PITCH_NV', 0x9028 )
GL_VIDEO_COLOR_CONVERSION_MATRIX_NV = constant.Constant( 'GL_VIDEO_COLOR_CONVERSION_MATRIX_NV', 0x9029 )
GL_VIDEO_COLOR_CONVERSION_MAX_NV = constant.Constant( 'GL_VIDEO_COLOR_CONVERSION_MAX_NV', 0x902A )
GL_VIDEO_COLOR_CONVERSION_MIN_NV = constant.Constant( 'GL_VIDEO_COLOR_CONVERSION_MIN_NV', 0x902B )
GL_VIDEO_COLOR_CONVERSION_OFFSET_NV = constant.Constant( 'GL_VIDEO_COLOR_CONVERSION_OFFSET_NV', 0x902C )
GL_VIDEO_BUFFER_INTERNAL_FORMAT_NV = constant.Constant( 'GL_VIDEO_BUFFER_INTERNAL_FORMAT_NV', 0x902D )
GL_PARTIAL_SUCCESS_NV = constant.Constant( 'GL_PARTIAL_SUCCESS_NV', 0x902E )
GL_SUCCESS_NV = constant.Constant( 'GL_SUCCESS_NV', 0x902F )
GL_FAILURE_NV = constant.Constant( 'GL_FAILURE_NV', 0x9030 )
GL_YCBYCR8_422_NV = constant.Constant( 'GL_YCBYCR8_422_NV', 0x9031 )
GL_YCBAYCR8A_4224_NV = constant.Constant( 'GL_YCBAYCR8A_4224_NV', 0x9032 )
GL_Z6Y10Z6CB10Z6Y10Z6CR10_422_NV = constant.Constant( 'GL_Z6Y10Z6CB10Z6Y10Z6CR10_422_NV', 0x9033 )
GL_Z6Y10Z6CB10Z6A10Z6Y10Z6CR10Z6A10_4224_NV = constant.Constant( 'GL_Z6Y10Z6CB10Z6A10Z6Y10Z6CR10Z6A10_4224_NV', 0x9034 )
GL_Z4Y12Z4CB12Z4Y12Z4CR12_422_NV = constant.Constant( 'GL_Z4Y12Z4CB12Z4Y12Z4CR12_422_NV', 0x9035 )
GL_Z4Y12Z4CB12Z4A12Z4Y12Z4CR12Z4A12_4224_NV = constant.Constant( 'GL_Z4Y12Z4CB12Z4A12Z4Y12Z4CR12Z4A12_4224_NV', 0x9036 )
GL_Z4Y12Z4CB12Z4CR12_444_NV = constant.Constant( 'GL_Z4Y12Z4CB12Z4CR12_444_NV', 0x9037 )
GL_VIDEO_CAPTURE_FRAME_WIDTH_NV = constant.Constant( 'GL_VIDEO_CAPTURE_FRAME_WIDTH_NV', 0x9038 )
GL_VIDEO_CAPTURE_FRAME_HEIGHT_NV = constant.Constant( 'GL_VIDEO_CAPTURE_FRAME_HEIGHT_NV', 0x9039 )
GL_VIDEO_CAPTURE_FIELD_UPPER_HEIGHT_NV = constant.Constant( 'GL_VIDEO_CAPTURE_FIELD_UPPER_HEIGHT_NV', 0x903A )
GL_VIDEO_CAPTURE_FIELD_LOWER_HEIGHT_NV = constant.Constant( 'GL_VIDEO_CAPTURE_FIELD_LOWER_HEIGHT_NV', 0x903B )
GL_VIDEO_CAPTURE_SURFACE_ORIGIN_NV = constant.Constant( 'GL_VIDEO_CAPTURE_SURFACE_ORIGIN_NV', 0x903C )
glBeginVideoCaptureNV = platform.createExtensionFunction( 
'glBeginVideoCaptureNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,),
doc='glBeginVideoCaptureNV(GLuint(video_capture_slot)) -> None',
argNames=('video_capture_slot',),
deprecated=_DEPRECATED,
)

glBindVideoCaptureStreamBufferNV = platform.createExtensionFunction( 
'glBindVideoCaptureStreamBufferNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLuint,constants.GLenum,constants.GLintptrARB,),
doc='glBindVideoCaptureStreamBufferNV(GLuint(video_capture_slot), GLuint(stream), GLenum(frame_region), GLintptrARB(offset)) -> None',
argNames=('video_capture_slot','stream','frame_region','offset',),
deprecated=_DEPRECATED,
)

glBindVideoCaptureStreamTextureNV = platform.createExtensionFunction( 
'glBindVideoCaptureStreamTextureNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLuint,constants.GLenum,constants.GLenum,constants.GLuint,),
doc='glBindVideoCaptureStreamTextureNV(GLuint(video_capture_slot), GLuint(stream), GLenum(frame_region), GLenum(target), GLuint(texture)) -> None',
argNames=('video_capture_slot','stream','frame_region','target','texture',),
deprecated=_DEPRECATED,
)

glEndVideoCaptureNV = platform.createExtensionFunction( 
'glEndVideoCaptureNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,),
doc='glEndVideoCaptureNV(GLuint(video_capture_slot)) -> None',
argNames=('video_capture_slot',),
deprecated=_DEPRECATED,
)

glGetVideoCaptureivNV = platform.createExtensionFunction( 
'glGetVideoCaptureivNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLintArray,),
doc='glGetVideoCaptureivNV(GLuint(video_capture_slot), GLenum(pname), GLintArray(params)) -> None',
argNames=('video_capture_slot','pname','params',),
deprecated=_DEPRECATED,
)

glGetVideoCaptureStreamivNV = platform.createExtensionFunction( 
'glGetVideoCaptureStreamivNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLuint,constants.GLenum,arrays.GLintArray,),
doc='glGetVideoCaptureStreamivNV(GLuint(video_capture_slot), GLuint(stream), GLenum(pname), GLintArray(params)) -> None',
argNames=('video_capture_slot','stream','pname','params',),
deprecated=_DEPRECATED,
)

glGetVideoCaptureStreamfvNV = platform.createExtensionFunction( 
'glGetVideoCaptureStreamfvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLuint,constants.GLenum,arrays.GLfloatArray,),
doc='glGetVideoCaptureStreamfvNV(GLuint(video_capture_slot), GLuint(stream), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('video_capture_slot','stream','pname','params',),
deprecated=_DEPRECATED,
)

glGetVideoCaptureStreamdvNV = platform.createExtensionFunction( 
'glGetVideoCaptureStreamdvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLuint,constants.GLenum,arrays.GLdoubleArray,),
doc='glGetVideoCaptureStreamdvNV(GLuint(video_capture_slot), GLuint(stream), GLenum(pname), GLdoubleArray(params)) -> None',
argNames=('video_capture_slot','stream','pname','params',),
deprecated=_DEPRECATED,
)

glVideoCaptureNV = platform.createExtensionFunction( 
'glVideoCaptureNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLenum, 
argTypes=(constants.GLuint,arrays.GLuintArray,arrays.GLuint64Array,),
doc='glVideoCaptureNV(GLuint(video_capture_slot), GLuintArray(sequence_num), GLuint64Array(capture_time)) -> constants.GLenum',
argNames=('video_capture_slot','sequence_num','capture_time',),
deprecated=_DEPRECATED,
)

glVideoCaptureStreamParameterivNV = platform.createExtensionFunction( 
'glVideoCaptureStreamParameterivNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLuint,constants.GLenum,arrays.GLintArray,),
doc='glVideoCaptureStreamParameterivNV(GLuint(video_capture_slot), GLuint(stream), GLenum(pname), GLintArray(params)) -> None',
argNames=('video_capture_slot','stream','pname','params',),
deprecated=_DEPRECATED,
)

glVideoCaptureStreamParameterfvNV = platform.createExtensionFunction( 
'glVideoCaptureStreamParameterfvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLuint,constants.GLenum,arrays.GLfloatArray,),
doc='glVideoCaptureStreamParameterfvNV(GLuint(video_capture_slot), GLuint(stream), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('video_capture_slot','stream','pname','params',),
deprecated=_DEPRECATED,
)

glVideoCaptureStreamParameterdvNV = platform.createExtensionFunction( 
'glVideoCaptureStreamParameterdvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLuint,constants.GLenum,arrays.GLdoubleArray,),
doc='glVideoCaptureStreamParameterdvNV(GLuint(video_capture_slot), GLuint(stream), GLenum(pname), GLdoubleArray(params)) -> None',
argNames=('video_capture_slot','stream','pname','params',),
deprecated=_DEPRECATED,
)


def glInitVideoCaptureNV():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
