'''OpenGL extension EXT.texture_compression_s3tc

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_texture_compression_s3tc'
_DEPRECATED = False
GL_COMPRESSED_RGB_S3TC_DXT1_EXT = constant.Constant( 'GL_COMPRESSED_RGB_S3TC_DXT1_EXT', 0x83F0 )
GL_COMPRESSED_RGBA_S3TC_DXT1_EXT = constant.Constant( 'GL_COMPRESSED_RGBA_S3TC_DXT1_EXT', 0x83F1 )
GL_COMPRESSED_RGBA_S3TC_DXT3_EXT = constant.Constant( 'GL_COMPRESSED_RGBA_S3TC_DXT3_EXT', 0x83F2 )
GL_COMPRESSED_RGBA_S3TC_DXT5_EXT = constant.Constant( 'GL_COMPRESSED_RGBA_S3TC_DXT5_EXT', 0x83F3 )


def glInitTextureCompressionS3TcEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
