'''OpenGL extension MESA.pack_invert

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_MESA_pack_invert'
_DEPRECATED = False
GL_PACK_INVERT_MESA = constant.Constant( 'GL_PACK_INVERT_MESA', 0x8758 )
glget.addGLGetConstant( GL_PACK_INVERT_MESA, (1,) )


def glInitPackInvertMESA():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
