'''OpenGL extension NV.primitive_restart

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_primitive_restart'
_DEPRECATED = False
GL_PRIMITIVE_RESTART_NV = constant.Constant( 'GL_PRIMITIVE_RESTART_NV', 0x8558 )
glget.addGLGetConstant( GL_PRIMITIVE_RESTART_NV, (1,) )
GL_PRIMITIVE_RESTART_INDEX_NV = constant.Constant( 'GL_PRIMITIVE_RESTART_INDEX_NV', 0x8559 )
glget.addGLGetConstant( GL_PRIMITIVE_RESTART_INDEX_NV, (1,) )
glPrimitiveRestartNV = platform.createExtensionFunction( 
'glPrimitiveRestartNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(),
doc='glPrimitiveRestartNV() -> None',
argNames=(),
deprecated=_DEPRECATED,
)

glPrimitiveRestartIndexNV = platform.createExtensionFunction( 
'glPrimitiveRestartIndexNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,),
doc='glPrimitiveRestartIndexNV(GLuint(index)) -> None',
argNames=('index',),
deprecated=_DEPRECATED,
)


def glInitPrimitiveRestartNV():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
