'''OpenGL extension EXT.pixel_buffer_object

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_pixel_buffer_object'
_DEPRECATED = False
GL_PIXEL_PACK_BUFFER_EXT = constant.Constant( 'GL_PIXEL_PACK_BUFFER_EXT', 0x88EB )
GL_PIXEL_UNPACK_BUFFER_EXT = constant.Constant( 'GL_PIXEL_UNPACK_BUFFER_EXT', 0x88EC )
GL_PIXEL_PACK_BUFFER_BINDING_EXT = constant.Constant( 'GL_PIXEL_PACK_BUFFER_BINDING_EXT', 0x88ED )
glget.addGLGetConstant( GL_PIXEL_PACK_BUFFER_BINDING_EXT, (1,) )
GL_PIXEL_UNPACK_BUFFER_BINDING_EXT = constant.Constant( 'GL_PIXEL_UNPACK_BUFFER_BINDING_EXT', 0x88EF )
glget.addGLGetConstant( GL_PIXEL_UNPACK_BUFFER_BINDING_EXT, (1,) )


def glInitPixelBufferObjectEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
