'''OpenGL extension IBM.texture_mirrored_repeat

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_IBM_texture_mirrored_repeat'
_DEPRECATED = False
GL_MIRRORED_REPEAT_IBM = constant.Constant( 'GL_MIRRORED_REPEAT_IBM', 0x8370 )


def glInitTextureMirroredRepeatIBM():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
