'''OpenGL extension EXT.blend_equation_separate

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_blend_equation_separate'
_DEPRECATED = False
GL_BLEND_EQUATION_RGB_EXT = constant.Constant( 'GL_BLEND_EQUATION_RGB_EXT', 0x8009 )
GL_BLEND_EQUATION_ALPHA_EXT = constant.Constant( 'GL_BLEND_EQUATION_ALPHA_EXT', 0x883D )
glget.addGLGetConstant( GL_BLEND_EQUATION_ALPHA_EXT, (1,) )
glBlendEquationSeparateEXT = platform.createExtensionFunction( 
'glBlendEquationSeparateEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,),
doc='glBlendEquationSeparateEXT(GLenum(modeRGB), GLenum(modeAlpha)) -> None',
argNames=('modeRGB','modeAlpha',),
deprecated=_DEPRECATED,
)


def glInitBlendEquationSeparateEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
