'''OpenGL extension EXT.polygon_offset

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_polygon_offset'
_DEPRECATED = False
GL_POLYGON_OFFSET_EXT = constant.Constant( 'GL_POLYGON_OFFSET_EXT', 0x8037 )
glget.addGLGetConstant( GL_POLYGON_OFFSET_EXT, (1,) )
GL_POLYGON_OFFSET_FACTOR_EXT = constant.Constant( 'GL_POLYGON_OFFSET_FACTOR_EXT', 0x8038 )
glget.addGLGetConstant( GL_POLYGON_OFFSET_FACTOR_EXT, (1,) )
GL_POLYGON_OFFSET_BIAS_EXT = constant.Constant( 'GL_POLYGON_OFFSET_BIAS_EXT', 0x8039 )
glget.addGLGetConstant( GL_POLYGON_OFFSET_BIAS_EXT, (1,) )
glPolygonOffsetEXT = platform.createExtensionFunction( 
'glPolygonOffsetEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLfloat,constants.GLfloat,),
doc='glPolygonOffsetEXT(GLfloat(factor), GLfloat(bias)) -> None',
argNames=('factor','bias',),
deprecated=_DEPRECATED,
)


def glInitPolygonOffsetEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
