'''OpenGL extension EXT.clip_volume_hint

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_clip_volume_hint'
_DEPRECATED = False
GL_CLIP_VOLUME_CLIPPING_HINT_EXT = constant.Constant( 'GL_CLIP_VOLUME_CLIPPING_HINT_EXT', 0x80F0 )
glget.addGLGetConstant( GL_CLIP_VOLUME_CLIPPING_HINT_EXT, (1,) )


def glInitClipVolumeHintEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
