'''OpenGL extension EXT.draw_buffers2

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_draw_buffers2'
_DEPRECATED = False

glColorMaskIndexedEXT = platform.createExtensionFunction( 
'glColorMaskIndexedEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLboolean,constants.GLboolean,constants.GLboolean,constants.GLboolean,),
doc='glColorMaskIndexedEXT(GLuint(index), GLboolean(r), GLboolean(g), GLboolean(b), GLboolean(a)) -> None',
argNames=('index','r','g','b','a',),
deprecated=_DEPRECATED,
)

glGetBooleanIndexedvEXT = platform.createExtensionFunction( 
'glGetBooleanIndexedvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,arrays.GLbooleanArray,),
doc='glGetBooleanIndexedvEXT(GLenum(target), GLuint(index), GLbooleanArray(data)) -> None',
argNames=('target','index','data',),
deprecated=_DEPRECATED,
)

glGetIntegerIndexedvEXT = platform.createExtensionFunction( 
'glGetIntegerIndexedvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,arrays.GLintArray,),
doc='glGetIntegerIndexedvEXT(GLenum(target), GLuint(index), GLintArray(data)) -> None',
argNames=('target','index','data',),
deprecated=_DEPRECATED,
)

glEnableIndexedEXT = platform.createExtensionFunction( 
'glEnableIndexedEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,),
doc='glEnableIndexedEXT(GLenum(target), GLuint(index)) -> None',
argNames=('target','index',),
deprecated=_DEPRECATED,
)

glDisableIndexedEXT = platform.createExtensionFunction( 
'glDisableIndexedEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,),
doc='glDisableIndexedEXT(GLenum(target), GLuint(index)) -> None',
argNames=('target','index',),
deprecated=_DEPRECATED,
)

glIsEnabledIndexedEXT = platform.createExtensionFunction( 
'glIsEnabledIndexedEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLboolean, 
argTypes=(constants.GLenum,constants.GLuint,),
doc='glIsEnabledIndexedEXT(GLenum(target), GLuint(index)) -> constants.GLboolean',
argNames=('target','index',),
deprecated=_DEPRECATED,
)


def glInitDrawBuffers2EXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
