'''OpenGL extension IBM.multimode_draw_arrays

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_IBM_multimode_draw_arrays'
_DEPRECATED = False

glMultiModeDrawArraysIBM = platform.createExtensionFunction( 
'glMultiModeDrawArraysIBM',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLuintArray,arrays.GLintArray,arrays.GLsizeiArray,constants.GLsizei,constants.GLint,),
doc='glMultiModeDrawArraysIBM(GLuintArray(mode), GLintArray(first), GLsizeiArray(count), GLsizei(primcount), GLint(modestride)) -> None',
argNames=('mode','first','count','primcount','modestride',),
deprecated=_DEPRECATED,
)

glMultiModeDrawElementsIBM = platform.createExtensionFunction( 
'glMultiModeDrawElementsIBM',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLuintArray,arrays.GLsizeiArray,constants.GLenum,ctypes.POINTER(ctypes.c_void_p),constants.GLsizei,constants.GLint,),
doc='glMultiModeDrawElementsIBM(GLuintArray(mode), GLsizeiArray(count), GLenum(type), POINTER(ctypes.c_void_p)(indices), GLsizei(primcount), GLint(modestride)) -> None',
argNames=('mode','count','type','indices','primcount','modestride',),
deprecated=_DEPRECATED,
)


def glInitMultimodeDrawArraysIBM():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
