'''OpenGL extension EXT.vertex_array

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_vertex_array'
_DEPRECATED = False
GL_VERTEX_ARRAY_EXT = constant.Constant( 'GL_VERTEX_ARRAY_EXT', 0x8074 )
glget.addGLGetConstant( GL_VERTEX_ARRAY_EXT, (1,) )
GL_NORMAL_ARRAY_EXT = constant.Constant( 'GL_NORMAL_ARRAY_EXT', 0x8075 )
glget.addGLGetConstant( GL_NORMAL_ARRAY_EXT, (1,) )
GL_COLOR_ARRAY_EXT = constant.Constant( 'GL_COLOR_ARRAY_EXT', 0x8076 )
GL_INDEX_ARRAY_EXT = constant.Constant( 'GL_INDEX_ARRAY_EXT', 0x8077 )
glget.addGLGetConstant( GL_INDEX_ARRAY_EXT, (1,) )
GL_TEXTURE_COORD_ARRAY_EXT = constant.Constant( 'GL_TEXTURE_COORD_ARRAY_EXT', 0x8078 )
glget.addGLGetConstant( GL_TEXTURE_COORD_ARRAY_EXT, (1,) )
GL_EDGE_FLAG_ARRAY_EXT = constant.Constant( 'GL_EDGE_FLAG_ARRAY_EXT', 0x8079 )
glget.addGLGetConstant( GL_EDGE_FLAG_ARRAY_EXT, (1,) )
GL_VERTEX_ARRAY_SIZE_EXT = constant.Constant( 'GL_VERTEX_ARRAY_SIZE_EXT', 0x807A )
glget.addGLGetConstant( GL_VERTEX_ARRAY_SIZE_EXT, (1,) )
GL_VERTEX_ARRAY_TYPE_EXT = constant.Constant( 'GL_VERTEX_ARRAY_TYPE_EXT', 0x807B )
glget.addGLGetConstant( GL_VERTEX_ARRAY_TYPE_EXT, (1,) )
GL_VERTEX_ARRAY_STRIDE_EXT = constant.Constant( 'GL_VERTEX_ARRAY_STRIDE_EXT', 0x807C )
glget.addGLGetConstant( GL_VERTEX_ARRAY_STRIDE_EXT, (1,) )
GL_VERTEX_ARRAY_COUNT_EXT = constant.Constant( 'GL_VERTEX_ARRAY_COUNT_EXT', 0x807D )
glget.addGLGetConstant( GL_VERTEX_ARRAY_COUNT_EXT, (1,) )
GL_NORMAL_ARRAY_TYPE_EXT = constant.Constant( 'GL_NORMAL_ARRAY_TYPE_EXT', 0x807E )
glget.addGLGetConstant( GL_NORMAL_ARRAY_TYPE_EXT, (1,) )
GL_NORMAL_ARRAY_STRIDE_EXT = constant.Constant( 'GL_NORMAL_ARRAY_STRIDE_EXT', 0x807F )
glget.addGLGetConstant( GL_NORMAL_ARRAY_STRIDE_EXT, (1,) )
GL_NORMAL_ARRAY_COUNT_EXT = constant.Constant( 'GL_NORMAL_ARRAY_COUNT_EXT', 0x8080 )
glget.addGLGetConstant( GL_NORMAL_ARRAY_COUNT_EXT, (1,) )
GL_COLOR_ARRAY_SIZE_EXT = constant.Constant( 'GL_COLOR_ARRAY_SIZE_EXT', 0x8081 )
glget.addGLGetConstant( GL_COLOR_ARRAY_SIZE_EXT, (1,) )
GL_COLOR_ARRAY_TYPE_EXT = constant.Constant( 'GL_COLOR_ARRAY_TYPE_EXT', 0x8082 )
glget.addGLGetConstant( GL_COLOR_ARRAY_TYPE_EXT, (1,) )
GL_COLOR_ARRAY_STRIDE_EXT = constant.Constant( 'GL_COLOR_ARRAY_STRIDE_EXT', 0x8083 )
glget.addGLGetConstant( GL_COLOR_ARRAY_STRIDE_EXT, (1,) )
GL_COLOR_ARRAY_COUNT_EXT = constant.Constant( 'GL_COLOR_ARRAY_COUNT_EXT', 0x8084 )
glget.addGLGetConstant( GL_COLOR_ARRAY_COUNT_EXT, (1,) )
GL_INDEX_ARRAY_TYPE_EXT = constant.Constant( 'GL_INDEX_ARRAY_TYPE_EXT', 0x8085 )
glget.addGLGetConstant( GL_INDEX_ARRAY_TYPE_EXT, (1,) )
GL_INDEX_ARRAY_STRIDE_EXT = constant.Constant( 'GL_INDEX_ARRAY_STRIDE_EXT', 0x8086 )
glget.addGLGetConstant( GL_INDEX_ARRAY_STRIDE_EXT, (1,) )
GL_INDEX_ARRAY_COUNT_EXT = constant.Constant( 'GL_INDEX_ARRAY_COUNT_EXT', 0x8087 )
glget.addGLGetConstant( GL_INDEX_ARRAY_COUNT_EXT, (1,) )
GL_TEXTURE_COORD_ARRAY_SIZE_EXT = constant.Constant( 'GL_TEXTURE_COORD_ARRAY_SIZE_EXT', 0x8088 )
glget.addGLGetConstant( GL_TEXTURE_COORD_ARRAY_SIZE_EXT, (1,) )
GL_TEXTURE_COORD_ARRAY_TYPE_EXT = constant.Constant( 'GL_TEXTURE_COORD_ARRAY_TYPE_EXT', 0x8089 )
glget.addGLGetConstant( GL_TEXTURE_COORD_ARRAY_TYPE_EXT, (1,) )
GL_TEXTURE_COORD_ARRAY_STRIDE_EXT = constant.Constant( 'GL_TEXTURE_COORD_ARRAY_STRIDE_EXT', 0x808A )
glget.addGLGetConstant( GL_TEXTURE_COORD_ARRAY_STRIDE_EXT, (1,) )
GL_TEXTURE_COORD_ARRAY_COUNT_EXT = constant.Constant( 'GL_TEXTURE_COORD_ARRAY_COUNT_EXT', 0x808B )
glget.addGLGetConstant( GL_TEXTURE_COORD_ARRAY_COUNT_EXT, (1,) )
GL_EDGE_FLAG_ARRAY_STRIDE_EXT = constant.Constant( 'GL_EDGE_FLAG_ARRAY_STRIDE_EXT', 0x808C )
glget.addGLGetConstant( GL_EDGE_FLAG_ARRAY_STRIDE_EXT, (1,) )
GL_EDGE_FLAG_ARRAY_COUNT_EXT = constant.Constant( 'GL_EDGE_FLAG_ARRAY_COUNT_EXT', 0x808D )
glget.addGLGetConstant( GL_EDGE_FLAG_ARRAY_COUNT_EXT, (1,) )
GL_VERTEX_ARRAY_POINTER_EXT = constant.Constant( 'GL_VERTEX_ARRAY_POINTER_EXT', 0x808E )
GL_NORMAL_ARRAY_POINTER_EXT = constant.Constant( 'GL_NORMAL_ARRAY_POINTER_EXT', 0x808F )
GL_COLOR_ARRAY_POINTER_EXT = constant.Constant( 'GL_COLOR_ARRAY_POINTER_EXT', 0x8090 )
GL_INDEX_ARRAY_POINTER_EXT = constant.Constant( 'GL_INDEX_ARRAY_POINTER_EXT', 0x8091 )
GL_TEXTURE_COORD_ARRAY_POINTER_EXT = constant.Constant( 'GL_TEXTURE_COORD_ARRAY_POINTER_EXT', 0x8092 )
GL_EDGE_FLAG_ARRAY_POINTER_EXT = constant.Constant( 'GL_EDGE_FLAG_ARRAY_POINTER_EXT', 0x8093 )
glArrayElementEXT = platform.createExtensionFunction( 
'glArrayElementEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,),
doc='glArrayElementEXT(GLint(i)) -> None',
argNames=('i',),
deprecated=_DEPRECATED,
)

glColorPointerEXT = platform.createExtensionFunction( 
'glColorPointerEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLenum,constants.GLsizei,constants.GLsizei,ctypes.c_void_p,),
doc='glColorPointerEXT(GLint(size), GLenum(type), GLsizei(stride), GLsizei(count), c_void_p(pointer)) -> None',
argNames=('size','type','stride','count','pointer',),
deprecated=_DEPRECATED,
)

glDrawArraysEXT = platform.createExtensionFunction( 
'glDrawArraysEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,constants.GLsizei,),
doc='glDrawArraysEXT(GLenum(mode), GLint(first), GLsizei(count)) -> None',
argNames=('mode','first','count',),
deprecated=_DEPRECATED,
)

glEdgeFlagPointerEXT = platform.createExtensionFunction( 
'glEdgeFlagPointerEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsizei,constants.GLsizei,arrays.GLbooleanArray,),
doc='glEdgeFlagPointerEXT(GLsizei(stride), GLsizei(count), GLbooleanArray(pointer)) -> None',
argNames=('stride','count','pointer',),
deprecated=_DEPRECATED,
)

glGetPointervEXT = platform.createExtensionFunction( 
'glGetPointervEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,ctypes.POINTER(ctypes.c_void_p),),
doc='glGetPointervEXT(GLenum(pname), POINTER(ctypes.c_void_p)(params)) -> None',
argNames=('pname','params',),
deprecated=_DEPRECATED,
)

glIndexPointerEXT = platform.createExtensionFunction( 
'glIndexPointerEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLsizei,constants.GLsizei,ctypes.c_void_p,),
doc='glIndexPointerEXT(GLenum(type), GLsizei(stride), GLsizei(count), c_void_p(pointer)) -> None',
argNames=('type','stride','count','pointer',),
deprecated=_DEPRECATED,
)

glNormalPointerEXT = platform.createExtensionFunction( 
'glNormalPointerEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLsizei,constants.GLsizei,ctypes.c_void_p,),
doc='glNormalPointerEXT(GLenum(type), GLsizei(stride), GLsizei(count), c_void_p(pointer)) -> None',
argNames=('type','stride','count','pointer',),
deprecated=_DEPRECATED,
)

glTexCoordPointerEXT = platform.createExtensionFunction( 
'glTexCoordPointerEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLenum,constants.GLsizei,constants.GLsizei,ctypes.c_void_p,),
doc='glTexCoordPointerEXT(GLint(size), GLenum(type), GLsizei(stride), GLsizei(count), c_void_p(pointer)) -> None',
argNames=('size','type','stride','count','pointer',),
deprecated=_DEPRECATED,
)

glVertexPointerEXT = platform.createExtensionFunction( 
'glVertexPointerEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLenum,constants.GLsizei,constants.GLsizei,ctypes.c_void_p,),
doc='glVertexPointerEXT(GLint(size), GLenum(type), GLsizei(stride), GLsizei(count), c_void_p(pointer)) -> None',
argNames=('size','type','stride','count','pointer',),
deprecated=_DEPRECATED,
)


def glInitVertexArrayEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
