'''OpenGL extension SGIX.convolution_accuracy

This module customises the behaviour of the 
OpenGL.raw.GL.SGIX.convolution_accuracy to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension adds an accuracy hint for convolution.  It
	allows the program to trade off precision for speed.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGIX/convolution_accuracy.txt
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions, wrapper
from OpenGL.GL import glget
import ctypes
from OpenGL.raw.GL.SGIX.convolution_accuracy import *
### END AUTOGENERATED SECTION