'''OpenGL extension EXT.compiled_vertex_array

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_compiled_vertex_array'
_DEPRECATED = False
GL_ARRAY_ELEMENT_LOCK_FIRST_EXT = constant.Constant( 'GL_ARRAY_ELEMENT_LOCK_FIRST_EXT', 0x81A8 )
glget.addGLGetConstant( GL_ARRAY_ELEMENT_LOCK_FIRST_EXT, (1,) )
GL_ARRAY_ELEMENT_LOCK_COUNT_EXT = constant.Constant( 'GL_ARRAY_ELEMENT_LOCK_COUNT_EXT', 0x81A9 )
glget.addGLGetConstant( GL_ARRAY_ELEMENT_LOCK_COUNT_EXT, (1,) )
glLockArraysEXT = platform.createExtensionFunction( 
'glLockArraysEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLsizei,),
doc='glLockArraysEXT(GLint(first), GLsizei(count)) -> None',
argNames=('first','count',),
deprecated=_DEPRECATED,
)

glUnlockArraysEXT = platform.createExtensionFunction( 
'glUnlockArraysEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(),
doc='glUnlockArraysEXT() -> None',
argNames=(),
deprecated=_DEPRECATED,
)


def glInitCompiledVertexArrayEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
