'''OpenGL extension SGIX.subsample

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SGIX_subsample'
_DEPRECATED = False
GL_PACK_SUBSAMPLE_RATE_SGIX = constant.Constant( 'GL_PACK_SUBSAMPLE_RATE_SGIX', 0x85A0 )
GL_UNPACK_SUBSAMPLE_RATE_SGIX = constant.Constant( 'GL_UNPACK_SUBSAMPLE_RATE_SGIX', 0x85A1 )
GL_PIXEL_SUBSAMPLE_4444_SGIX = constant.Constant( 'GL_PIXEL_SUBSAMPLE_4444_SGIX', 0x85A2 )
GL_PIXEL_SUBSAMPLE_2424_SGIX = constant.Constant( 'GL_PIXEL_SUBSAMPLE_2424_SGIX', 0x85A3 )
GL_PIXEL_SUBSAMPLE_4242_SGIX = constant.Constant( 'GL_PIXEL_SUBSAMPLE_4242_SGIX', 0x85A4 )


def glInitSubsampleSGIX():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
