'''OpenGL extension SGIX.FfdMask

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SGIX_FfdMask'
_DEPRECATED = False
GL_TEXTURE_DEFORMATION_BIT_SGIX = constant.Constant( 'GL_TEXTURE_DEFORMATION_BIT_SGIX', 0x1 )
GL_GEOMETRY_DEFORMATION_BIT_SGIX = constant.Constant( 'GL_GEOMETRY_DEFORMATION_BIT_SGIX', 0x2 )


def glInitFfdmaskSGIX():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
