'''OpenGL extension HP.texture_lighting

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_HP_texture_lighting'
_DEPRECATED = False
GL_TEXTURE_LIGHTING_MODE_HP = constant.Constant( 'GL_TEXTURE_LIGHTING_MODE_HP', 0x8167 )
GL_TEXTURE_POST_SPECULAR_HP = constant.Constant( 'GL_TEXTURE_POST_SPECULAR_HP', 0x8168 )
GL_TEXTURE_PRE_SPECULAR_HP = constant.Constant( 'GL_TEXTURE_PRE_SPECULAR_HP', 0x8169 )


def glInitTextureLightingHP():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
