'''OpenGL extension EXT.texture_swizzle

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_texture_swizzle'
_DEPRECATED = False
GL_TEXTURE_SWIZZLE_R_EXT = constant.Constant( 'GL_TEXTURE_SWIZZLE_R_EXT', 0x8E42 )
GL_TEXTURE_SWIZZLE_G_EXT = constant.Constant( 'GL_TEXTURE_SWIZZLE_G_EXT', 0x8E43 )
GL_TEXTURE_SWIZZLE_B_EXT = constant.Constant( 'GL_TEXTURE_SWIZZLE_B_EXT', 0x8E44 )
GL_TEXTURE_SWIZZLE_A_EXT = constant.Constant( 'GL_TEXTURE_SWIZZLE_A_EXT', 0x8E45 )
GL_TEXTURE_SWIZZLE_RGBA_EXT = constant.Constant( 'GL_TEXTURE_SWIZZLE_RGBA_EXT', 0x8E46 )


def glInitTextureSwizzleEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
