'''OpenGL extension NV.gpu_program4

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_gpu_program4'
_DEPRECATED = False
GL_MIN_PROGRAM_TEXEL_OFFSET_NV = constant.Constant( 'GL_MIN_PROGRAM_TEXEL_OFFSET_NV', 0x8904 )
GL_MAX_PROGRAM_TEXEL_OFFSET_NV = constant.Constant( 'GL_MAX_PROGRAM_TEXEL_OFFSET_NV', 0x8905 )
GL_PROGRAM_ATTRIB_COMPONENTS_NV = constant.Constant( 'GL_PROGRAM_ATTRIB_COMPONENTS_NV', 0x8906 )
GL_PROGRAM_RESULT_COMPONENTS_NV = constant.Constant( 'GL_PROGRAM_RESULT_COMPONENTS_NV', 0x8907 )
GL_MAX_PROGRAM_ATTRIB_COMPONENTS_NV = constant.Constant( 'GL_MAX_PROGRAM_ATTRIB_COMPONENTS_NV', 0x8908 )
GL_MAX_PROGRAM_RESULT_COMPONENTS_NV = constant.Constant( 'GL_MAX_PROGRAM_RESULT_COMPONENTS_NV', 0x8909 )
GL_MAX_PROGRAM_GENERIC_ATTRIBS_NV = constant.Constant( 'GL_MAX_PROGRAM_GENERIC_ATTRIBS_NV', 0x8DA5 )
GL_MAX_PROGRAM_GENERIC_RESULTS_NV = constant.Constant( 'GL_MAX_PROGRAM_GENERIC_RESULTS_NV', 0x8DA6 )
glProgramLocalParameterI4iNV = platform.createExtensionFunction( 
'glProgramLocalParameterI4iNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLint,constants.GLint,constants.GLint,constants.GLint,),
doc='glProgramLocalParameterI4iNV(GLenum(target), GLuint(index), GLint(x), GLint(y), GLint(z), GLint(w)) -> None',
argNames=('target','index','x','y','z','w',),
deprecated=_DEPRECATED,
)

glProgramLocalParameterI4ivNV = platform.createExtensionFunction( 
'glProgramLocalParameterI4ivNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,arrays.GLintArray,),
doc='glProgramLocalParameterI4ivNV(GLenum(target), GLuint(index), GLintArray(params)) -> None',
argNames=('target','index','params',),
deprecated=_DEPRECATED,
)

glProgramLocalParametersI4ivNV = platform.createExtensionFunction( 
'glProgramLocalParametersI4ivNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLsizei,arrays.GLintArray,),
doc='glProgramLocalParametersI4ivNV(GLenum(target), GLuint(index), GLsizei(count), GLintArray(params)) -> None',
argNames=('target','index','count','params',),
deprecated=_DEPRECATED,
)

glProgramLocalParameterI4uiNV = platform.createExtensionFunction( 
'glProgramLocalParameterI4uiNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,),
doc='glProgramLocalParameterI4uiNV(GLenum(target), GLuint(index), GLuint(x), GLuint(y), GLuint(z), GLuint(w)) -> None',
argNames=('target','index','x','y','z','w',),
deprecated=_DEPRECATED,
)

glProgramLocalParameterI4uivNV = platform.createExtensionFunction( 
'glProgramLocalParameterI4uivNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,arrays.GLuintArray,),
doc='glProgramLocalParameterI4uivNV(GLenum(target), GLuint(index), GLuintArray(params)) -> None',
argNames=('target','index','params',),
deprecated=_DEPRECATED,
)

glProgramLocalParametersI4uivNV = platform.createExtensionFunction( 
'glProgramLocalParametersI4uivNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLsizei,arrays.GLuintArray,),
doc='glProgramLocalParametersI4uivNV(GLenum(target), GLuint(index), GLsizei(count), GLuintArray(params)) -> None',
argNames=('target','index','count','params',),
deprecated=_DEPRECATED,
)

glProgramEnvParameterI4iNV = platform.createExtensionFunction( 
'glProgramEnvParameterI4iNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLint,constants.GLint,constants.GLint,constants.GLint,),
doc='glProgramEnvParameterI4iNV(GLenum(target), GLuint(index), GLint(x), GLint(y), GLint(z), GLint(w)) -> None',
argNames=('target','index','x','y','z','w',),
deprecated=_DEPRECATED,
)

glProgramEnvParameterI4ivNV = platform.createExtensionFunction( 
'glProgramEnvParameterI4ivNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,arrays.GLintArray,),
doc='glProgramEnvParameterI4ivNV(GLenum(target), GLuint(index), GLintArray(params)) -> None',
argNames=('target','index','params',),
deprecated=_DEPRECATED,
)

glProgramEnvParametersI4ivNV = platform.createExtensionFunction( 
'glProgramEnvParametersI4ivNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLsizei,arrays.GLintArray,),
doc='glProgramEnvParametersI4ivNV(GLenum(target), GLuint(index), GLsizei(count), GLintArray(params)) -> None',
argNames=('target','index','count','params',),
deprecated=_DEPRECATED,
)

glProgramEnvParameterI4uiNV = platform.createExtensionFunction( 
'glProgramEnvParameterI4uiNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,),
doc='glProgramEnvParameterI4uiNV(GLenum(target), GLuint(index), GLuint(x), GLuint(y), GLuint(z), GLuint(w)) -> None',
argNames=('target','index','x','y','z','w',),
deprecated=_DEPRECATED,
)

glProgramEnvParameterI4uivNV = platform.createExtensionFunction( 
'glProgramEnvParameterI4uivNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,arrays.GLuintArray,),
doc='glProgramEnvParameterI4uivNV(GLenum(target), GLuint(index), GLuintArray(params)) -> None',
argNames=('target','index','params',),
deprecated=_DEPRECATED,
)

glProgramEnvParametersI4uivNV = platform.createExtensionFunction( 
'glProgramEnvParametersI4uivNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLsizei,arrays.GLuintArray,),
doc='glProgramEnvParametersI4uivNV(GLenum(target), GLuint(index), GLsizei(count), GLuintArray(params)) -> None',
argNames=('target','index','count','params',),
deprecated=_DEPRECATED,
)

glGetProgramLocalParameterIivNV = platform.createExtensionFunction( 
'glGetProgramLocalParameterIivNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,arrays.GLintArray,),
doc='glGetProgramLocalParameterIivNV(GLenum(target), GLuint(index), GLintArray(params)) -> None',
argNames=('target','index','params',),
deprecated=_DEPRECATED,
)

glGetProgramLocalParameterIuivNV = platform.createExtensionFunction( 
'glGetProgramLocalParameterIuivNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,arrays.GLuintArray,),
doc='glGetProgramLocalParameterIuivNV(GLenum(target), GLuint(index), GLuintArray(params)) -> None',
argNames=('target','index','params',),
deprecated=_DEPRECATED,
)

glGetProgramEnvParameterIivNV = platform.createExtensionFunction( 
'glGetProgramEnvParameterIivNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,arrays.GLintArray,),
doc='glGetProgramEnvParameterIivNV(GLenum(target), GLuint(index), GLintArray(params)) -> None',
argNames=('target','index','params',),
deprecated=_DEPRECATED,
)

glGetProgramEnvParameterIuivNV = platform.createExtensionFunction( 
'glGetProgramEnvParameterIuivNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,arrays.GLuintArray,),
doc='glGetProgramEnvParameterIuivNV(GLenum(target), GLuint(index), GLuintArray(params)) -> None',
argNames=('target','index','params',),
deprecated=_DEPRECATED,
)


def glInitGpuProgram4NV():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
