'''OpenGL extension EXT.cmyka

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_cmyka'
_DEPRECATED = False
GL_CMYK_EXT = constant.Constant( 'GL_CMYK_EXT', 0x800C )
GL_CMYKA_EXT = constant.Constant( 'GL_CMYKA_EXT', 0x800D )
GL_PACK_CMYK_HINT_EXT = constant.Constant( 'GL_PACK_CMYK_HINT_EXT', 0x800E )
glget.addGLGetConstant( GL_PACK_CMYK_HINT_EXT, (1,) )
GL_UNPACK_CMYK_HINT_EXT = constant.Constant( 'GL_UNPACK_CMYK_HINT_EXT', 0x800F )
glget.addGLGetConstant( GL_UNPACK_CMYK_HINT_EXT, (1,) )


def glInitCmykaEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
