'''OpenGL extension OML.interlace

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_OML_interlace'
_DEPRECATED = False
GL_INTERLACE_OML = constant.Constant( 'GL_INTERLACE_OML', 0x8980 )
glget.addGLGetConstant( GL_INTERLACE_OML, (1,) )
GL_INTERLACE_READ_OML = constant.Constant( 'GL_INTERLACE_READ_OML', 0x8981 )
glget.addGLGetConstant( GL_INTERLACE_READ_OML, (1,) )


def glInitInterlaceOML():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
