'''OpenGL extension EXT.timer_query

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_timer_query'
_DEPRECATED = False
GL_TIME_ELAPSED_EXT = constant.Constant( 'GL_TIME_ELAPSED_EXT', 0x88BF )
glGetQueryObjecti64vEXT = platform.createExtensionFunction( 
'glGetQueryObjecti64vEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLint64Array,),
doc='glGetQueryObjecti64vEXT(GLuint(id), GLenum(pname), GLint64Array(params)) -> None',
argNames=('id','pname','params',),
deprecated=_DEPRECATED,
)

glGetQueryObjectui64vEXT = platform.createExtensionFunction( 
'glGetQueryObjectui64vEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLuint64Array,),
doc='glGetQueryObjectui64vEXT(GLuint(id), GLenum(pname), GLuint64Array(params)) -> None',
argNames=('id','pname','params',),
deprecated=_DEPRECATED,
)


def glInitTimerQueryEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
