'''OpenGL extension SGIS.sharpen_texture

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SGIS_sharpen_texture'
_DEPRECATED = False
GL_LINEAR_SHARPEN_SGIS = constant.Constant( 'GL_LINEAR_SHARPEN_SGIS', 0x80AD )
GL_LINEAR_SHARPEN_ALPHA_SGIS = constant.Constant( 'GL_LINEAR_SHARPEN_ALPHA_SGIS', 0x80AE )
GL_LINEAR_SHARPEN_COLOR_SGIS = constant.Constant( 'GL_LINEAR_SHARPEN_COLOR_SGIS', 0x80AF )
GL_SHARPEN_TEXTURE_FUNC_POINTS_SGIS = constant.Constant( 'GL_SHARPEN_TEXTURE_FUNC_POINTS_SGIS', 0x80B0 )
glSharpenTexFuncSGIS = platform.createExtensionFunction( 
'glSharpenTexFuncSGIS',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLsizei,arrays.GLfloatArray,),
doc='glSharpenTexFuncSGIS(GLenum(target), GLsizei(n), GLfloatArray(points)) -> None',
argNames=('target','n','points',),
deprecated=_DEPRECATED,
)

glGetSharpenTexFuncSGIS = platform.createExtensionFunction( 
'glGetSharpenTexFuncSGIS',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLfloatArray,),
doc='glGetSharpenTexFuncSGIS(GLenum(target), GLfloatArray(points)) -> None',
argNames=('target','points',),
deprecated=_DEPRECATED,
)


def glInitSharpenTextureSGIS():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
