'''OpenGL extension SGIX.convolution_accuracy

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SGIX_convolution_accuracy'
_DEPRECATED = False
GL_CONVOLUTION_HINT_SGIX = constant.Constant( 'GL_CONVOLUTION_HINT_SGIX', 0x8316 )


def glInitConvolutionAccuracySGIX():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
