'''OpenGL extension ARB.seamless_cube_map

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ARB_seamless_cube_map'
_DEPRECATED = False
GL_TEXTURE_CUBE_MAP_SEAMLESS = constant.Constant( 'GL_TEXTURE_CUBE_MAP_SEAMLESS', 0x884F )


def glInitSeamlessCubeMapARB():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
