'''OpenGL extension IBM.rasterpos_clip

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_IBM_rasterpos_clip'
_DEPRECATED = False
GL_RASTER_POSITION_UNCLIPPED_IBM = constant.Constant( 'GL_RASTER_POSITION_UNCLIPPED_IBM', 0x19262 )
glget.addGLGetConstant( GL_RASTER_POSITION_UNCLIPPED_IBM, (1,) )


def glInitRasterposClipIBM():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
