'''OpenGL extension EXT.packed_pixels

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_packed_pixels'
_DEPRECATED = False
GL_UNSIGNED_BYTE_3_3_2_EXT = constant.Constant( 'GL_UNSIGNED_BYTE_3_3_2_EXT', 0x8032 )
GL_UNSIGNED_SHORT_4_4_4_4_EXT = constant.Constant( 'GL_UNSIGNED_SHORT_4_4_4_4_EXT', 0x8033 )
GL_UNSIGNED_SHORT_5_5_5_1_EXT = constant.Constant( 'GL_UNSIGNED_SHORT_5_5_5_1_EXT', 0x8034 )
GL_UNSIGNED_INT_8_8_8_8_EXT = constant.Constant( 'GL_UNSIGNED_INT_8_8_8_8_EXT', 0x8035 )
GL_UNSIGNED_INT_10_10_10_2_EXT = constant.Constant( 'GL_UNSIGNED_INT_10_10_10_2_EXT', 0x8036 )


def glInitPackedPixelsEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
