'''OpenGL extension DFX.tbuffer

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_DFX_tbuffer'
_DEPRECATED = False

glTbufferMask3DFX = platform.createExtensionFunction( 
'glTbufferMask3DFX',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,),
doc='glTbufferMask3DFX(GLuint(mask)) -> None',
argNames=('mask',),
deprecated=_DEPRECATED,
)


def glInitTbufferDFX():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
