'''OpenGL extension EXT.texture_filter_anisotropic

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_texture_filter_anisotropic'
_DEPRECATED = False
GL_TEXTURE_MAX_ANISOTROPY_EXT = constant.Constant( 'GL_TEXTURE_MAX_ANISOTROPY_EXT', 0x84FE )
GL_MAX_TEXTURE_MAX_ANISOTROPY_EXT = constant.Constant( 'GL_MAX_TEXTURE_MAX_ANISOTROPY_EXT', 0x84FF )
glget.addGLGetConstant( GL_MAX_TEXTURE_MAX_ANISOTROPY_EXT, (1,) )


def glInitTextureFilterAnisotropicEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
