'''OpenGL extension NV.texgen_reflection

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_texgen_reflection'
_DEPRECATED = False
GL_NORMAL_MAP_NV = constant.Constant( 'GL_NORMAL_MAP_NV', 0x8511 )
GL_REFLECTION_MAP_NV = constant.Constant( 'GL_REFLECTION_MAP_NV', 0x8512 )


def glInitTexgenReflectionNV():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
