'''OpenGL extension ARB.transpose_matrix

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ARB_transpose_matrix'
_DEPRECATED = False
GL_TRANSPOSE_MODELVIEW_MATRIX_ARB = constant.Constant( 'GL_TRANSPOSE_MODELVIEW_MATRIX_ARB', 0x84E3 )
glget.addGLGetConstant( GL_TRANSPOSE_MODELVIEW_MATRIX_ARB, (4,4) )
GL_TRANSPOSE_PROJECTION_MATRIX_ARB = constant.Constant( 'GL_TRANSPOSE_PROJECTION_MATRIX_ARB', 0x84E4 )
glget.addGLGetConstant( GL_TRANSPOSE_PROJECTION_MATRIX_ARB, (4,4) )
GL_TRANSPOSE_TEXTURE_MATRIX_ARB = constant.Constant( 'GL_TRANSPOSE_TEXTURE_MATRIX_ARB', 0x84E5 )
glget.addGLGetConstant( GL_TRANSPOSE_TEXTURE_MATRIX_ARB, (4,4) )
GL_TRANSPOSE_COLOR_MATRIX_ARB = constant.Constant( 'GL_TRANSPOSE_COLOR_MATRIX_ARB', 0x84E6 )
glget.addGLGetConstant( GL_TRANSPOSE_COLOR_MATRIX_ARB, (4,4) )
glLoadTransposeMatrixfARB = platform.createExtensionFunction( 
'glLoadTransposeMatrixfARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLfloatArray,),
doc='glLoadTransposeMatrixfARB(GLfloatArray(m)) -> None',
argNames=('m',),
deprecated=_DEPRECATED,
)

glLoadTransposeMatrixdARB = platform.createExtensionFunction( 
'glLoadTransposeMatrixdARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLdoubleArray,),
doc='glLoadTransposeMatrixdARB(GLdoubleArray(m)) -> None',
argNames=('m',),
deprecated=_DEPRECATED,
)

glMultTransposeMatrixfARB = platform.createExtensionFunction( 
'glMultTransposeMatrixfARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLfloatArray,),
doc='glMultTransposeMatrixfARB(GLfloatArray(m)) -> None',
argNames=('m',),
deprecated=_DEPRECATED,
)

glMultTransposeMatrixdARB = platform.createExtensionFunction( 
'glMultTransposeMatrixdARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLdoubleArray,),
doc='glMultTransposeMatrixdARB(GLdoubleArray(m)) -> None',
argNames=('m',),
deprecated=_DEPRECATED,
)


def glInitTransposeMatrixARB():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
