'''OpenGL extension SUN.slice_accum

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SUN_slice_accum'
_DEPRECATED = False
GL_SLICE_ACCUM_SUN = constant.Constant( 'GL_SLICE_ACCUM_SUN', 0x85CC )


def glInitSliceAccumSUN():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
