'''OpenGL extension OML.resample

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_OML_resample'
_DEPRECATED = False
GL_PACK_RESAMPLE_OML = constant.Constant( 'GL_PACK_RESAMPLE_OML', 0x8984 )
glget.addGLGetConstant( GL_PACK_RESAMPLE_OML, (1,) )
GL_UNPACK_RESAMPLE_OML = constant.Constant( 'GL_UNPACK_RESAMPLE_OML', 0x8985 )
glget.addGLGetConstant( GL_UNPACK_RESAMPLE_OML, (1,) )
GL_RESAMPLE_REPLICATE_OML = constant.Constant( 'GL_RESAMPLE_REPLICATE_OML', 0x8986 )
GL_RESAMPLE_ZERO_FILL_OML = constant.Constant( 'GL_RESAMPLE_ZERO_FILL_OML', 0x8987 )
GL_RESAMPLE_AVERAGE_OML = constant.Constant( 'GL_RESAMPLE_AVERAGE_OML', 0x8988 )
GL_RESAMPLE_DECIMATE_OML = constant.Constant( 'GL_RESAMPLE_DECIMATE_OML', 0x8989 )


def glInitResampleOML():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
