'''OpenGL extension NV.depth_buffer_float

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_depth_buffer_float'
_DEPRECATED = False
GL_DEPTH_COMPONENT32F_NV = constant.Constant( 'GL_DEPTH_COMPONENT32F_NV', 0x8DAB )
GL_DEPTH32F_STENCIL8_NV = constant.Constant( 'GL_DEPTH32F_STENCIL8_NV', 0x8DAC )
GL_FLOAT_32_UNSIGNED_INT_24_8_REV_NV = constant.Constant( 'GL_FLOAT_32_UNSIGNED_INT_24_8_REV_NV', 0x8DAD )
GL_DEPTH_BUFFER_FLOAT_MODE_NV = constant.Constant( 'GL_DEPTH_BUFFER_FLOAT_MODE_NV', 0x8DAF )
glDepthRangedNV = platform.createExtensionFunction( 
'glDepthRangedNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLdouble,constants.GLdouble,),
doc='glDepthRangedNV(GLdouble(zNear), GLdouble(zFar)) -> None',
argNames=('zNear','zFar',),
deprecated=_DEPRECATED,
)

glClearDepthdNV = platform.createExtensionFunction( 
'glClearDepthdNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLdouble,),
doc='glClearDepthdNV(GLdouble(depth)) -> None',
argNames=('depth',),
deprecated=_DEPRECATED,
)

glDepthBoundsdNV = platform.createExtensionFunction( 
'glDepthBoundsdNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLdouble,constants.GLdouble,),
doc='glDepthBoundsdNV(GLdouble(zmin), GLdouble(zmax)) -> None',
argNames=('zmin','zmax',),
deprecated=_DEPRECATED,
)


def glInitDepthBufferFloatNV():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
