'''OpenGL extension SGIX.depth_texture

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SGIX_depth_texture'
_DEPRECATED = False
GL_DEPTH_COMPONENT16_SGIX = constant.Constant( 'GL_DEPTH_COMPONENT16_SGIX', 0x81A5 )
GL_DEPTH_COMPONENT24_SGIX = constant.Constant( 'GL_DEPTH_COMPONENT24_SGIX', 0x81A6 )
GL_DEPTH_COMPONENT32_SGIX = constant.Constant( 'GL_DEPTH_COMPONENT32_SGIX', 0x81A7 )


def glInitDepthTextureSGIX():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
