'''OpenGL extension EXT.draw_instanced

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_draw_instanced'
_DEPRECATED = False

glDrawArraysInstancedEXT = platform.createExtensionFunction( 
'glDrawArraysInstancedEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,constants.GLsizei,constants.GLsizei,),
doc='glDrawArraysInstancedEXT(GLenum(mode), GLint(start), GLsizei(count), GLsizei(primcount)) -> None',
argNames=('mode','start','count','primcount',),
deprecated=_DEPRECATED,
)

glDrawElementsInstancedEXT = platform.createExtensionFunction( 
'glDrawElementsInstancedEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLsizei,constants.GLenum,ctypes.c_void_p,constants.GLsizei,),
doc='glDrawElementsInstancedEXT(GLenum(mode), GLsizei(count), GLenum(type), c_void_p(indices), GLsizei(primcount)) -> None',
argNames=('mode','count','type','indices','primcount',),
deprecated=_DEPRECATED,
)


def glInitDrawInstancedEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
