'''OpenGL extension EXT.texture_env_dot3

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_texture_env_dot3'
_DEPRECATED = False
GL_DOT3_RGB_EXT = constant.Constant( 'GL_DOT3_RGB_EXT', 0x8740 )
GL_DOT3_RGBA_EXT = constant.Constant( 'GL_DOT3_RGBA_EXT', 0x8741 )


def glInitTextureEnvDot3EXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
