'''OpenGL extension EXT.texture_array

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_texture_array'
_DEPRECATED = False
GL_TEXTURE_1D_ARRAY_EXT = constant.Constant( 'GL_TEXTURE_1D_ARRAY_EXT', 0x8C18 )
GL_PROXY_TEXTURE_1D_ARRAY_EXT = constant.Constant( 'GL_PROXY_TEXTURE_1D_ARRAY_EXT', 0x8C19 )
GL_TEXTURE_2D_ARRAY_EXT = constant.Constant( 'GL_TEXTURE_2D_ARRAY_EXT', 0x8C1A )
GL_PROXY_TEXTURE_2D_ARRAY_EXT = constant.Constant( 'GL_PROXY_TEXTURE_2D_ARRAY_EXT', 0x8C1B )
GL_TEXTURE_BINDING_1D_ARRAY_EXT = constant.Constant( 'GL_TEXTURE_BINDING_1D_ARRAY_EXT', 0x8C1C )
glget.addGLGetConstant( GL_TEXTURE_BINDING_1D_ARRAY_EXT, (1,) )
GL_TEXTURE_BINDING_2D_ARRAY_EXT = constant.Constant( 'GL_TEXTURE_BINDING_2D_ARRAY_EXT', 0x8C1D )
glget.addGLGetConstant( GL_TEXTURE_BINDING_2D_ARRAY_EXT, (1,) )
GL_MAX_ARRAY_TEXTURE_LAYERS_EXT = constant.Constant( 'GL_MAX_ARRAY_TEXTURE_LAYERS_EXT', 0x88FF )
glget.addGLGetConstant( GL_MAX_ARRAY_TEXTURE_LAYERS_EXT, (1,) )
GL_COMPARE_REF_DEPTH_TO_TEXTURE_EXT = constant.Constant( 'GL_COMPARE_REF_DEPTH_TO_TEXTURE_EXT', 0x884E )


def glInitTextureArrayEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
