'''OpenGL extension GLEXT.GL_64_TYPES_DEFINED

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_GLEXT_GL_64_TYPES_DEFINED'
_DEPRECATED = False



def glInitGl64TypesDefinedGLEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
