'''OpenGL extension ATI.text_fragment_shader

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ATI_text_fragment_shader'
_DEPRECATED = False
GL_TEXT_FRAGMENT_SHADER_ATI = constant.Constant( 'GL_TEXT_FRAGMENT_SHADER_ATI', 0x8200 )
glget.addGLGetConstant( GL_TEXT_FRAGMENT_SHADER_ATI, (1,) )


def glInitTextFragmentShaderATI():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
