'''OpenGL extension GREMEDY.string_marker

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_GREMEDY_string_marker'
_DEPRECATED = False

glStringMarkerGREMEDY = platform.createExtensionFunction( 
'glStringMarkerGREMEDY',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsizei,ctypes.c_void_p,),
doc='glStringMarkerGREMEDY(GLsizei(len), c_void_p(string)) -> None',
argNames=('len','string',),
deprecated=_DEPRECATED,
)


def glInitStringMarkerGREMEDY():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
