'''OpenGL extension NV.vertex_array_range2

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_vertex_array_range2'
_DEPRECATED = False
GL_VERTEX_ARRAY_RANGE_WITHOUT_FLUSH_NV = constant.Constant( 'GL_VERTEX_ARRAY_RANGE_WITHOUT_FLUSH_NV', 0x8533 )


def glInitVertexArrayRange2NV():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
