'''OpenGL extension EXT.abgr

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.abgr to provide a more 
Python-friendly API

Overview (from the spec)
	
	EXT_abgr extends the list of host-memory color formats.  Specifically,
	it provides a reverse-order alternative to image format RGBA.  The ABGR
	component order matches the cpack Iris GL format on big-endian machines.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/abgr.txt
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions, wrapper
from OpenGL.GL import glget
import ctypes
from OpenGL.raw.GL.EXT.abgr import *
### END AUTOGENERATED SECTION