'''OpenGL extension EXT.stencil_two_side

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_stencil_two_side'
_DEPRECATED = False
GL_STENCIL_TEST_TWO_SIDE_EXT = constant.Constant( 'GL_STENCIL_TEST_TWO_SIDE_EXT', 0x8910 )
glget.addGLGetConstant( GL_STENCIL_TEST_TWO_SIDE_EXT, (1,) )
GL_ACTIVE_STENCIL_FACE_EXT = constant.Constant( 'GL_ACTIVE_STENCIL_FACE_EXT', 0x8911 )
glget.addGLGetConstant( GL_ACTIVE_STENCIL_FACE_EXT, (1,) )
glActiveStencilFaceEXT = platform.createExtensionFunction( 
'glActiveStencilFaceEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,),
doc='glActiveStencilFaceEXT(GLenum(face)) -> None',
argNames=('face',),
deprecated=_DEPRECATED,
)


def glInitStencilTwoSideEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
