'''OpenGL extension EXT.color_matrix

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.color_matrix to provide a more 
Python-friendly API
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions, wrapper
from OpenGL.GL import glget
import ctypes
from OpenGL.raw.GL.EXT.color_matrix import *
### END AUTOGENERATED SECTION