'''OpenGL extension SGIX.ycrcba

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SGIX_ycrcba'
_DEPRECATED = False
GL_YCRCB_SGIX = constant.Constant( 'GL_YCRCB_SGIX', 0x8318 )
GL_YCRCBA_SGIX = constant.Constant( 'GL_YCRCBA_SGIX', 0x8319 )


def glInitYcrcbaSGIX():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
