'''OpenGL extension ARB.instanced_arrays

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ARB_instanced_arrays'
_DEPRECATED = False
GL_VERTEX_ATTRIB_ARRAY_DIVISOR_ARB = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY_DIVISOR_ARB', 0x88FE )
glVertexAttribDivisorARB = platform.createExtensionFunction( 
'glVertexAttribDivisorARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLuint,),
doc='glVertexAttribDivisorARB(GLuint(index), GLuint(divisor)) -> None',
argNames=('index','divisor',),
deprecated=_DEPRECATED,
)


def glInitInstancedArraysARB():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
