'''OpenGL extension VERSION.GL_2_1_DEPRECATED

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_VERSION_GL_2_1'
_DEPRECATED = True
GL_CURRENT_RASTER_SECONDARY_COLOR = constant.Constant( 'GL_CURRENT_RASTER_SECONDARY_COLOR', 0x845F )
GL_SLUMINANCE_ALPHA = constant.Constant( 'GL_SLUMINANCE_ALPHA', 0x8C44 )
GL_SLUMINANCE8_ALPHA8 = constant.Constant( 'GL_SLUMINANCE8_ALPHA8', 0x8C45 )
GL_SLUMINANCE = constant.Constant( 'GL_SLUMINANCE', 0x8C46 )
GL_SLUMINANCE8 = constant.Constant( 'GL_SLUMINANCE8', 0x8C47 )
GL_COMPRESSED_SLUMINANCE = constant.Constant( 'GL_COMPRESSED_SLUMINANCE', 0x8C4A )
GL_COMPRESSED_SLUMINANCE_ALPHA = constant.Constant( 'GL_COMPRESSED_SLUMINANCE_ALPHA', 0x8C4B )

