'''OpenGL extension ATI.map_object_buffer

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ATI_map_object_buffer'
_DEPRECATED = False

glMapObjectBufferATI = platform.createExtensionFunction( 
'glMapObjectBufferATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=ctypes.c_void_p, 
argTypes=(constants.GLuint,),
doc='glMapObjectBufferATI(GLuint(buffer)) -> ctypes.c_void_p',
argNames=('buffer',),
deprecated=_DEPRECATED,
)

glUnmapObjectBufferATI = platform.createExtensionFunction( 
'glUnmapObjectBufferATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,),
doc='glUnmapObjectBufferATI(GLuint(buffer)) -> None',
argNames=('buffer',),
deprecated=_DEPRECATED,
)


def glInitMapObjectBufferATI():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
