'''OpenGL extension NV.multisample_filter_hint

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_multisample_filter_hint'
_DEPRECATED = False
GL_MULTISAMPLE_FILTER_HINT_NV = constant.Constant( 'GL_MULTISAMPLE_FILTER_HINT_NV', 0x8534 )
glget.addGLGetConstant( GL_MULTISAMPLE_FILTER_HINT_NV, (1,) )


def glInitMultisampleFilterHintNV():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
