'''OpenGL extension ARB.provoking_vertex

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ARB_provoking_vertex'
_DEPRECATED = False
GL_QUADS_FOLLOW_PROVOKING_VERTEX_CONVENTION = constant.Constant( 'GL_QUADS_FOLLOW_PROVOKING_VERTEX_CONVENTION', 0x8E4C )
glget.addGLGetConstant( GL_QUADS_FOLLOW_PROVOKING_VERTEX_CONVENTION, (1,) )
GL_FIRST_VERTEX_CONVENTION = constant.Constant( 'GL_FIRST_VERTEX_CONVENTION', 0x8E4D )
GL_LAST_VERTEX_CONVENTION = constant.Constant( 'GL_LAST_VERTEX_CONVENTION', 0x8E4E )
GL_PROVOKING_VERTEX = constant.Constant( 'GL_PROVOKING_VERTEX', 0x8E4F )
glget.addGLGetConstant( GL_PROVOKING_VERTEX, (1,) )
glProvokingVertex = platform.createExtensionFunction( 
'glProvokingVertex',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,),
doc='glProvokingVertex(GLenum(mode)) -> None',
argNames=('mode',),
deprecated=_DEPRECATED,
)


def glInitProvokingVertexARB():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
