'''OpenGL extension EXT.blend_subtract

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_blend_subtract'
_DEPRECATED = False
GL_FUNC_SUBTRACT_EXT = constant.Constant( 'GL_FUNC_SUBTRACT_EXT', 0x800A )
GL_FUNC_REVERSE_SUBTRACT_EXT = constant.Constant( 'GL_FUNC_REVERSE_SUBTRACT_EXT', 0x800B )


def glInitBlendSubtractEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
