'''OpenGL extension PGI.vertex_hints

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_PGI_vertex_hints'
_DEPRECATED = False
GL_VERTEX_DATA_HINT_PGI = constant.Constant( 'GL_VERTEX_DATA_HINT_PGI', 0x1A22A )
GL_VERTEX_CONSISTENT_HINT_PGI = constant.Constant( 'GL_VERTEX_CONSISTENT_HINT_PGI', 0x1A22B )
GL_MATERIAL_SIDE_HINT_PGI = constant.Constant( 'GL_MATERIAL_SIDE_HINT_PGI', 0x1A22C )
GL_MAX_VERTEX_HINT_PGI = constant.Constant( 'GL_MAX_VERTEX_HINT_PGI', 0x1A22D )
GL_COLOR3_BIT_PGI = constant.Constant( 'GL_COLOR3_BIT_PGI', 0x10000 )
GL_COLOR4_BIT_PGI = constant.Constant( 'GL_COLOR4_BIT_PGI', 0x20000 )
GL_EDGEFLAG_BIT_PGI = constant.Constant( 'GL_EDGEFLAG_BIT_PGI', 0x40000 )
GL_INDEX_BIT_PGI = constant.Constant( 'GL_INDEX_BIT_PGI', 0x80000 )
GL_MAT_AMBIENT_BIT_PGI = constant.Constant( 'GL_MAT_AMBIENT_BIT_PGI', 0x100000 )
GL_MAT_AMBIENT_AND_DIFFUSE_BIT_PGI = constant.Constant( 'GL_MAT_AMBIENT_AND_DIFFUSE_BIT_PGI', 0x200000 )
GL_MAT_DIFFUSE_BIT_PGI = constant.Constant( 'GL_MAT_DIFFUSE_BIT_PGI', 0x400000 )
GL_MAT_EMISSION_BIT_PGI = constant.Constant( 'GL_MAT_EMISSION_BIT_PGI', 0x800000 )
GL_MAT_COLOR_INDEXES_BIT_PGI = constant.Constant( 'GL_MAT_COLOR_INDEXES_BIT_PGI', 0x1000000 )
GL_MAT_SHININESS_BIT_PGI = constant.Constant( 'GL_MAT_SHININESS_BIT_PGI', 0x2000000 )
GL_MAT_SPECULAR_BIT_PGI = constant.Constant( 'GL_MAT_SPECULAR_BIT_PGI', 0x4000000 )
GL_NORMAL_BIT_PGI = constant.Constant( 'GL_NORMAL_BIT_PGI', 0x8000000 )
GL_TEXCOORD1_BIT_PGI = constant.Constant( 'GL_TEXCOORD1_BIT_PGI', 0x10000000 )
GL_TEXCOORD2_BIT_PGI = constant.Constant( 'GL_TEXCOORD2_BIT_PGI', 0x20000000 )
GL_TEXCOORD3_BIT_PGI = constant.Constant( 'GL_TEXCOORD3_BIT_PGI', 0x40000000 )
GL_TEXCOORD4_BIT_PGI = constant.Constant( 'GL_TEXCOORD4_BIT_PGI', 0x80000000 )
GL_VERTEX23_BIT_PGI = constant.Constant( 'GL_VERTEX23_BIT_PGI', 0x4 )
GL_VERTEX4_BIT_PGI = constant.Constant( 'GL_VERTEX4_BIT_PGI', 0x8 )


def glInitVertexHintsPGI():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
