'''OpenGL extension NV.copy_depth_to_color

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_copy_depth_to_color'
_DEPRECATED = False
GL_DEPTH_STENCIL_TO_RGBA_NV = constant.Constant( 'GL_DEPTH_STENCIL_TO_RGBA_NV', 0x886E )
GL_DEPTH_STENCIL_TO_BGRA_NV = constant.Constant( 'GL_DEPTH_STENCIL_TO_BGRA_NV', 0x886F )


def glInitCopyDepthToColorNV():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
