'''OpenGL extension SGIX.vertex_preclip

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SGIX_vertex_preclip'
_DEPRECATED = False
GL_VERTEX_PRECLIP_SGIX = constant.Constant( 'GL_VERTEX_PRECLIP_SGIX', 0x83EE )
GL_VERTEX_PRECLIP_HINT_SGIX = constant.Constant( 'GL_VERTEX_PRECLIP_HINT_SGIX', 0x83EF )


def glInitVertexPreclipSGIX():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
