'''OpenGL extension SGIX.framezoom

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SGIX_framezoom'
_DEPRECATED = False
GL_FRAMEZOOM_SGIX = constant.Constant( 'GL_FRAMEZOOM_SGIX', 0x818B )
GL_FRAMEZOOM_FACTOR_SGIX = constant.Constant( 'GL_FRAMEZOOM_FACTOR_SGIX', 0x818C )
GL_MAX_FRAMEZOOM_FACTOR_SGIX = constant.Constant( 'GL_MAX_FRAMEZOOM_FACTOR_SGIX', 0x818D )
glFrameZoomSGIX = platform.createExtensionFunction( 
'glFrameZoomSGIX',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,),
doc='glFrameZoomSGIX(GLint(factor)) -> None',
argNames=('factor',),
deprecated=_DEPRECATED,
)


def glInitFramezoomSGIX():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
