'''OpenGL extension EXT.transform_feedback

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_transform_feedback'
_DEPRECATED = False
GL_TRANSFORM_FEEDBACK_BUFFER_EXT = constant.Constant( 'GL_TRANSFORM_FEEDBACK_BUFFER_EXT', 0x8C8E )
GL_TRANSFORM_FEEDBACK_BUFFER_START_EXT = constant.Constant( 'GL_TRANSFORM_FEEDBACK_BUFFER_START_EXT', 0x8C84 )
GL_TRANSFORM_FEEDBACK_BUFFER_SIZE_EXT = constant.Constant( 'GL_TRANSFORM_FEEDBACK_BUFFER_SIZE_EXT', 0x8C85 )
GL_TRANSFORM_FEEDBACK_BUFFER_BINDING_EXT = constant.Constant( 'GL_TRANSFORM_FEEDBACK_BUFFER_BINDING_EXT', 0x8C8F )
GL_INTERLEAVED_ATTRIBS_EXT = constant.Constant( 'GL_INTERLEAVED_ATTRIBS_EXT', 0x8C8C )
GL_SEPARATE_ATTRIBS_EXT = constant.Constant( 'GL_SEPARATE_ATTRIBS_EXT', 0x8C8D )
GL_PRIMITIVES_GENERATED_EXT = constant.Constant( 'GL_PRIMITIVES_GENERATED_EXT', 0x8C87 )
GL_TRANSFORM_FEEDBACK_PRIMITIVES_WRITTEN_EXT = constant.Constant( 'GL_TRANSFORM_FEEDBACK_PRIMITIVES_WRITTEN_EXT', 0x8C88 )
GL_RASTERIZER_DISCARD_EXT = constant.Constant( 'GL_RASTERIZER_DISCARD_EXT', 0x8C89 )
GL_MAX_TRANSFORM_FEEDBACK_INTERLEAVED_COMPONENTS_EXT = constant.Constant( 'GL_MAX_TRANSFORM_FEEDBACK_INTERLEAVED_COMPONENTS_EXT', 0x8C8A )
GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_ATTRIBS_EXT = constant.Constant( 'GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_ATTRIBS_EXT', 0x8C8B )
GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_COMPONENTS_EXT = constant.Constant( 'GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_COMPONENTS_EXT', 0x8C80 )
GL_TRANSFORM_FEEDBACK_VARYINGS_EXT = constant.Constant( 'GL_TRANSFORM_FEEDBACK_VARYINGS_EXT', 0x8C83 )
GL_TRANSFORM_FEEDBACK_BUFFER_MODE_EXT = constant.Constant( 'GL_TRANSFORM_FEEDBACK_BUFFER_MODE_EXT', 0x8C7F )
GL_TRANSFORM_FEEDBACK_VARYING_MAX_LENGTH_EXT = constant.Constant( 'GL_TRANSFORM_FEEDBACK_VARYING_MAX_LENGTH_EXT', 0x8C76 )
glBeginTransformFeedbackEXT = platform.createExtensionFunction( 
'glBeginTransformFeedbackEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,),
doc='glBeginTransformFeedbackEXT(GLenum(primitiveMode)) -> None',
argNames=('primitiveMode',),
deprecated=_DEPRECATED,
)

glEndTransformFeedbackEXT = platform.createExtensionFunction( 
'glEndTransformFeedbackEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(),
doc='glEndTransformFeedbackEXT() -> None',
argNames=(),
deprecated=_DEPRECATED,
)

glBindBufferRangeEXT = platform.createExtensionFunction( 
'glBindBufferRangeEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLuint,constants.GLintptr,constants.GLsizeiptr,),
doc='glBindBufferRangeEXT(GLenum(target), GLuint(index), GLuint(buffer), GLintptr(offset), GLsizeiptr(size)) -> None',
argNames=('target','index','buffer','offset','size',),
deprecated=_DEPRECATED,
)

glBindBufferOffsetEXT = platform.createExtensionFunction( 
'glBindBufferOffsetEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLuint,constants.GLintptr,),
doc='glBindBufferOffsetEXT(GLenum(target), GLuint(index), GLuint(buffer), GLintptr(offset)) -> None',
argNames=('target','index','buffer','offset',),
deprecated=_DEPRECATED,
)

glBindBufferBaseEXT = platform.createExtensionFunction( 
'glBindBufferBaseEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLuint,),
doc='glBindBufferBaseEXT(GLenum(target), GLuint(index), GLuint(buffer)) -> None',
argNames=('target','index','buffer',),
deprecated=_DEPRECATED,
)

glTransformFeedbackVaryingsEXT = platform.createExtensionFunction( 
'glTransformFeedbackVaryingsEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLsizei,ctypes.POINTER( ctypes.POINTER( constants.GLchar )),constants.GLenum,),
doc='glTransformFeedbackVaryingsEXT(GLuint(program), GLsizei(count), POINTER( ctypes.POINTER( constants.GLchar ))(varyings), GLenum(bufferMode)) -> None',
argNames=('program','count','varyings','bufferMode',),
deprecated=_DEPRECATED,
)

glGetTransformFeedbackVaryingEXT = platform.createExtensionFunction( 
'glGetTransformFeedbackVaryingEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLuint,constants.GLsizei,arrays.GLsizeiArray,arrays.GLsizeiArray,arrays.GLuintArray,arrays.GLcharArray,),
doc='glGetTransformFeedbackVaryingEXT(GLuint(program), GLuint(index), GLsizei(bufSize), GLsizeiArray(length), GLsizeiArray(size), GLuintArray(type), GLcharArray(name)) -> None',
argNames=('program','index','bufSize','length','size','type','name',),
deprecated=_DEPRECATED,
)


def glInitTransformFeedbackEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
