'''OpenGL extension NV.fragment_program

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_fragment_program'
_DEPRECATED = False
GL_MAX_FRAGMENT_PROGRAM_LOCAL_PARAMETERS_NV = constant.Constant( 'GL_MAX_FRAGMENT_PROGRAM_LOCAL_PARAMETERS_NV', 0x8868 )
glget.addGLGetConstant( GL_MAX_FRAGMENT_PROGRAM_LOCAL_PARAMETERS_NV, (1,) )
GL_FRAGMENT_PROGRAM_NV = constant.Constant( 'GL_FRAGMENT_PROGRAM_NV', 0x8870 )
glget.addGLGetConstant( GL_FRAGMENT_PROGRAM_NV, (1,) )
GL_MAX_TEXTURE_COORDS_NV = constant.Constant( 'GL_MAX_TEXTURE_COORDS_NV', 0x8871 )
glget.addGLGetConstant( GL_MAX_TEXTURE_COORDS_NV, (1,) )
GL_MAX_TEXTURE_IMAGE_UNITS_NV = constant.Constant( 'GL_MAX_TEXTURE_IMAGE_UNITS_NV', 0x8872 )
glget.addGLGetConstant( GL_MAX_TEXTURE_IMAGE_UNITS_NV, (1,) )
GL_FRAGMENT_PROGRAM_BINDING_NV = constant.Constant( 'GL_FRAGMENT_PROGRAM_BINDING_NV', 0x8873 )
glget.addGLGetConstant( GL_FRAGMENT_PROGRAM_BINDING_NV, (1,) )
GL_PROGRAM_ERROR_STRING_NV = constant.Constant( 'GL_PROGRAM_ERROR_STRING_NV', 0x8874 )
glProgramNamedParameter4fNV = platform.createExtensionFunction( 
'glProgramNamedParameter4fNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLsizei,arrays.GLubyteArray,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glProgramNamedParameter4fNV(GLuint(id), GLsizei(len), GLubyteArray(name), GLfloat(x), GLfloat(y), GLfloat(z), GLfloat(w)) -> None',
argNames=('id','len','name','x','y','z','w',),
deprecated=_DEPRECATED,
)

glProgramNamedParameter4dNV = platform.createExtensionFunction( 
'glProgramNamedParameter4dNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLsizei,arrays.GLubyteArray,constants.GLdouble,constants.GLdouble,constants.GLdouble,constants.GLdouble,),
doc='glProgramNamedParameter4dNV(GLuint(id), GLsizei(len), GLubyteArray(name), GLdouble(x), GLdouble(y), GLdouble(z), GLdouble(w)) -> None',
argNames=('id','len','name','x','y','z','w',),
deprecated=_DEPRECATED,
)

glProgramNamedParameter4fvNV = platform.createExtensionFunction( 
'glProgramNamedParameter4fvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLsizei,arrays.GLubyteArray,arrays.GLfloatArray,),
doc='glProgramNamedParameter4fvNV(GLuint(id), GLsizei(len), GLubyteArray(name), GLfloatArray(v)) -> None',
argNames=('id','len','name','v',),
deprecated=_DEPRECATED,
)

glProgramNamedParameter4dvNV = platform.createExtensionFunction( 
'glProgramNamedParameter4dvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLsizei,arrays.GLubyteArray,arrays.GLdoubleArray,),
doc='glProgramNamedParameter4dvNV(GLuint(id), GLsizei(len), GLubyteArray(name), GLdoubleArray(v)) -> None',
argNames=('id','len','name','v',),
deprecated=_DEPRECATED,
)

glGetProgramNamedParameterfvNV = platform.createExtensionFunction( 
'glGetProgramNamedParameterfvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLsizei,arrays.GLubyteArray,arrays.GLfloatArray,),
doc='glGetProgramNamedParameterfvNV(GLuint(id), GLsizei(len), GLubyteArray(name), GLfloatArray(params)) -> None',
argNames=('id','len','name','params',),
deprecated=_DEPRECATED,
)

glGetProgramNamedParameterdvNV = platform.createExtensionFunction( 
'glGetProgramNamedParameterdvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLsizei,arrays.GLubyteArray,arrays.GLdoubleArray,),
doc='glGetProgramNamedParameterdvNV(GLuint(id), GLsizei(len), GLubyteArray(name), GLdoubleArray(params)) -> None',
argNames=('id','len','name','params',),
deprecated=_DEPRECATED,
)


def glInitFragmentProgramNV():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
