'''OpenGL extension NV.fragment_program2

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_fragment_program2'
_DEPRECATED = False
GL_MAX_PROGRAM_EXEC_INSTRUCTIONS_NV = constant.Constant( 'GL_MAX_PROGRAM_EXEC_INSTRUCTIONS_NV', 0x88F4 )
GL_MAX_PROGRAM_CALL_DEPTH_NV = constant.Constant( 'GL_MAX_PROGRAM_CALL_DEPTH_NV', 0x88F5 )
GL_MAX_PROGRAM_IF_DEPTH_NV = constant.Constant( 'GL_MAX_PROGRAM_IF_DEPTH_NV', 0x88F6 )
GL_MAX_PROGRAM_LOOP_DEPTH_NV = constant.Constant( 'GL_MAX_PROGRAM_LOOP_DEPTH_NV', 0x88F7 )
GL_MAX_PROGRAM_LOOP_COUNT_NV = constant.Constant( 'GL_MAX_PROGRAM_LOOP_COUNT_NV', 0x88F8 )


def glInitFragmentProgram2NV():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
