'''OpenGL extension SGIS.sharpen_texture

This module customises the behaviour of the 
OpenGL.raw.GL.SGIS.sharpen_texture to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension introduces texture magnification filters that sharpen
	the resulting image by extrapolating from the level 1 image to the
	level 0 image.  Sharpening can be enabled for all color channels, for
	the alpha channel only, or for the red, green, and blue channels only.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGIS/sharpen_texture.txt
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions, wrapper
from OpenGL.GL import glget
import ctypes
from OpenGL.raw.GL.SGIS.sharpen_texture import *
### END AUTOGENERATED SECTION