'''OpenGL extension EXT.texture_sRGB

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_texture_sRGB'
_DEPRECATED = False
GL_SRGB_EXT = constant.Constant( 'GL_SRGB_EXT', 0x8C40 )
GL_SRGB8_EXT = constant.Constant( 'GL_SRGB8_EXT', 0x8C41 )
GL_SRGB_ALPHA_EXT = constant.Constant( 'GL_SRGB_ALPHA_EXT', 0x8C42 )
GL_SRGB8_ALPHA8_EXT = constant.Constant( 'GL_SRGB8_ALPHA8_EXT', 0x8C43 )
GL_SLUMINANCE_ALPHA_EXT = constant.Constant( 'GL_SLUMINANCE_ALPHA_EXT', 0x8C44 )
GL_SLUMINANCE8_ALPHA8_EXT = constant.Constant( 'GL_SLUMINANCE8_ALPHA8_EXT', 0x8C45 )
GL_SLUMINANCE_EXT = constant.Constant( 'GL_SLUMINANCE_EXT', 0x8C46 )
GL_SLUMINANCE8_EXT = constant.Constant( 'GL_SLUMINANCE8_EXT', 0x8C47 )
GL_COMPRESSED_SRGB_EXT = constant.Constant( 'GL_COMPRESSED_SRGB_EXT', 0x8C48 )
GL_COMPRESSED_SRGB_ALPHA_EXT = constant.Constant( 'GL_COMPRESSED_SRGB_ALPHA_EXT', 0x8C49 )
GL_COMPRESSED_SLUMINANCE_EXT = constant.Constant( 'GL_COMPRESSED_SLUMINANCE_EXT', 0x8C4A )
GL_COMPRESSED_SLUMINANCE_ALPHA_EXT = constant.Constant( 'GL_COMPRESSED_SLUMINANCE_ALPHA_EXT', 0x8C4B )
GL_COMPRESSED_SRGB_S3TC_DXT1_EXT = constant.Constant( 'GL_COMPRESSED_SRGB_S3TC_DXT1_EXT', 0x8C4C )
GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT1_EXT = constant.Constant( 'GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT1_EXT', 0x8C4D )
GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT3_EXT = constant.Constant( 'GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT3_EXT', 0x8C4E )
GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT5_EXT = constant.Constant( 'GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT5_EXT', 0x8C4F )


def glInitTextureSrgbEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
