'''OpenGL extension DFX.texture_compression_FXT1

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_DFX_texture_compression_FXT1'
_DEPRECATED = False
GL_COMPRESSED_RGB_FXT1_3DFX = constant.Constant( 'GL_COMPRESSED_RGB_FXT1_3DFX', 0x86B0 )
GL_COMPRESSED_RGBA_FXT1_3DFX = constant.Constant( 'GL_COMPRESSED_RGBA_FXT1_3DFX', 0x86B1 )


def glInitTextureCompressionFxt1DFX():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
