'''OpenGL extension EXT.texture_snorm

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_texture_snorm'
_DEPRECATED = False
GL_ALPHA_SNORM = constant.Constant( 'GL_ALPHA_SNORM', 0x9010 )
GL_LUMINANCE_SNORM = constant.Constant( 'GL_LUMINANCE_SNORM', 0x9011 )
GL_LUMINANCE_ALPHA_SNORM = constant.Constant( 'GL_LUMINANCE_ALPHA_SNORM', 0x9012 )
GL_INTENSITY_SNORM = constant.Constant( 'GL_INTENSITY_SNORM', 0x9013 )
GL_ALPHA8_SNORM = constant.Constant( 'GL_ALPHA8_SNORM', 0x9014 )
GL_LUMINANCE8_SNORM = constant.Constant( 'GL_LUMINANCE8_SNORM', 0x9015 )
GL_LUMINANCE8_ALPHA8_SNORM = constant.Constant( 'GL_LUMINANCE8_ALPHA8_SNORM', 0x9016 )
GL_INTENSITY8_SNORM = constant.Constant( 'GL_INTENSITY8_SNORM', 0x9017 )
GL_ALPHA16_SNORM = constant.Constant( 'GL_ALPHA16_SNORM', 0x9018 )
GL_LUMINANCE16_SNORM = constant.Constant( 'GL_LUMINANCE16_SNORM', 0x9019 )
GL_LUMINANCE16_ALPHA16_SNORM = constant.Constant( 'GL_LUMINANCE16_ALPHA16_SNORM', 0x901A )
GL_INTENSITY16_SNORM = constant.Constant( 'GL_INTENSITY16_SNORM', 0x901B )


def glInitTextureSnormEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
