'''OpenGL extension EXT.direct_state_access

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_direct_state_access'
_DEPRECATED = False
GL_PROGRAM_MATRIX_EXT = constant.Constant( 'GL_PROGRAM_MATRIX_EXT', 0x8E2D )
GL_TRANSPOSE_PROGRAM_MATRIX_EXT = constant.Constant( 'GL_TRANSPOSE_PROGRAM_MATRIX_EXT', 0x8E2E )
GL_PROGRAM_MATRIX_STACK_DEPTH_EXT = constant.Constant( 'GL_PROGRAM_MATRIX_STACK_DEPTH_EXT', 0x8E2F )
glClientAttribDefaultEXT = platform.createExtensionFunction( 
'glClientAttribDefaultEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLbitfield,),
doc='glClientAttribDefaultEXT(GLbitfield(mask)) -> None',
argNames=('mask',),
deprecated=_DEPRECATED,
)

glPushClientAttribDefaultEXT = platform.createExtensionFunction( 
'glPushClientAttribDefaultEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLbitfield,),
doc='glPushClientAttribDefaultEXT(GLbitfield(mask)) -> None',
argNames=('mask',),
deprecated=_DEPRECATED,
)

glMatrixLoadfEXT = platform.createExtensionFunction( 
'glMatrixLoadfEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLfloatArray,),
doc='glMatrixLoadfEXT(GLenum(mode), GLfloatArray(m)) -> None',
argNames=('mode','m',),
deprecated=_DEPRECATED,
)

glMatrixLoaddEXT = platform.createExtensionFunction( 
'glMatrixLoaddEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLdoubleArray,),
doc='glMatrixLoaddEXT(GLenum(mode), GLdoubleArray(m)) -> None',
argNames=('mode','m',),
deprecated=_DEPRECATED,
)

glMatrixMultfEXT = platform.createExtensionFunction( 
'glMatrixMultfEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLfloatArray,),
doc='glMatrixMultfEXT(GLenum(mode), GLfloatArray(m)) -> None',
argNames=('mode','m',),
deprecated=_DEPRECATED,
)

glMatrixMultdEXT = platform.createExtensionFunction( 
'glMatrixMultdEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLdoubleArray,),
doc='glMatrixMultdEXT(GLenum(mode), GLdoubleArray(m)) -> None',
argNames=('mode','m',),
deprecated=_DEPRECATED,
)

glMatrixLoadIdentityEXT = platform.createExtensionFunction( 
'glMatrixLoadIdentityEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,),
doc='glMatrixLoadIdentityEXT(GLenum(mode)) -> None',
argNames=('mode',),
deprecated=_DEPRECATED,
)

glMatrixRotatefEXT = platform.createExtensionFunction( 
'glMatrixRotatefEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glMatrixRotatefEXT(GLenum(mode), GLfloat(angle), GLfloat(x), GLfloat(y), GLfloat(z)) -> None',
argNames=('mode','angle','x','y','z',),
deprecated=_DEPRECATED,
)

glMatrixRotatedEXT = platform.createExtensionFunction( 
'glMatrixRotatedEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLdouble,constants.GLdouble,constants.GLdouble,constants.GLdouble,),
doc='glMatrixRotatedEXT(GLenum(mode), GLdouble(angle), GLdouble(x), GLdouble(y), GLdouble(z)) -> None',
argNames=('mode','angle','x','y','z',),
deprecated=_DEPRECATED,
)

glMatrixScalefEXT = platform.createExtensionFunction( 
'glMatrixScalefEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glMatrixScalefEXT(GLenum(mode), GLfloat(x), GLfloat(y), GLfloat(z)) -> None',
argNames=('mode','x','y','z',),
deprecated=_DEPRECATED,
)

glMatrixScaledEXT = platform.createExtensionFunction( 
'glMatrixScaledEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLdouble,constants.GLdouble,constants.GLdouble,),
doc='glMatrixScaledEXT(GLenum(mode), GLdouble(x), GLdouble(y), GLdouble(z)) -> None',
argNames=('mode','x','y','z',),
deprecated=_DEPRECATED,
)

glMatrixTranslatefEXT = platform.createExtensionFunction( 
'glMatrixTranslatefEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glMatrixTranslatefEXT(GLenum(mode), GLfloat(x), GLfloat(y), GLfloat(z)) -> None',
argNames=('mode','x','y','z',),
deprecated=_DEPRECATED,
)

glMatrixTranslatedEXT = platform.createExtensionFunction( 
'glMatrixTranslatedEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLdouble,constants.GLdouble,constants.GLdouble,),
doc='glMatrixTranslatedEXT(GLenum(mode), GLdouble(x), GLdouble(y), GLdouble(z)) -> None',
argNames=('mode','x','y','z',),
deprecated=_DEPRECATED,
)

glMatrixFrustumEXT = platform.createExtensionFunction( 
'glMatrixFrustumEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLdouble,constants.GLdouble,constants.GLdouble,constants.GLdouble,constants.GLdouble,constants.GLdouble,),
doc='glMatrixFrustumEXT(GLenum(mode), GLdouble(left), GLdouble(right), GLdouble(bottom), GLdouble(top), GLdouble(zNear), GLdouble(zFar)) -> None',
argNames=('mode','left','right','bottom','top','zNear','zFar',),
deprecated=_DEPRECATED,
)

glMatrixOrthoEXT = platform.createExtensionFunction( 
'glMatrixOrthoEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLdouble,constants.GLdouble,constants.GLdouble,constants.GLdouble,constants.GLdouble,constants.GLdouble,),
doc='glMatrixOrthoEXT(GLenum(mode), GLdouble(left), GLdouble(right), GLdouble(bottom), GLdouble(top), GLdouble(zNear), GLdouble(zFar)) -> None',
argNames=('mode','left','right','bottom','top','zNear','zFar',),
deprecated=_DEPRECATED,
)

glMatrixPopEXT = platform.createExtensionFunction( 
'glMatrixPopEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,),
doc='glMatrixPopEXT(GLenum(mode)) -> None',
argNames=('mode',),
deprecated=_DEPRECATED,
)

glMatrixPushEXT = platform.createExtensionFunction( 
'glMatrixPushEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,),
doc='glMatrixPushEXT(GLenum(mode)) -> None',
argNames=('mode',),
deprecated=_DEPRECATED,
)

glMatrixLoadTransposefEXT = platform.createExtensionFunction( 
'glMatrixLoadTransposefEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLfloatArray,),
doc='glMatrixLoadTransposefEXT(GLenum(mode), GLfloatArray(m)) -> None',
argNames=('mode','m',),
deprecated=_DEPRECATED,
)

glMatrixLoadTransposedEXT = platform.createExtensionFunction( 
'glMatrixLoadTransposedEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLdoubleArray,),
doc='glMatrixLoadTransposedEXT(GLenum(mode), GLdoubleArray(m)) -> None',
argNames=('mode','m',),
deprecated=_DEPRECATED,
)

glMatrixMultTransposefEXT = platform.createExtensionFunction( 
'glMatrixMultTransposefEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLfloatArray,),
doc='glMatrixMultTransposefEXT(GLenum(mode), GLfloatArray(m)) -> None',
argNames=('mode','m',),
deprecated=_DEPRECATED,
)

glMatrixMultTransposedEXT = platform.createExtensionFunction( 
'glMatrixMultTransposedEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLdoubleArray,),
doc='glMatrixMultTransposedEXT(GLenum(mode), GLdoubleArray(m)) -> None',
argNames=('mode','m',),
deprecated=_DEPRECATED,
)

glTextureParameterfEXT = platform.createExtensionFunction( 
'glTextureParameterfEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLenum,constants.GLfloat,),
doc='glTextureParameterfEXT(GLuint(texture), GLenum(target), GLenum(pname), GLfloat(param)) -> None',
argNames=('texture','target','pname','param',),
deprecated=_DEPRECATED,
)

glTextureParameterfvEXT = platform.createExtensionFunction( 
'glTextureParameterfvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLenum,arrays.GLfloatArray,),
doc='glTextureParameterfvEXT(GLuint(texture), GLenum(target), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('texture','target','pname','params',),
deprecated=_DEPRECATED,
)

glTextureParameteriEXT = platform.createExtensionFunction( 
'glTextureParameteriEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLenum,constants.GLint,),
doc='glTextureParameteriEXT(GLuint(texture), GLenum(target), GLenum(pname), GLint(param)) -> None',
argNames=('texture','target','pname','param',),
deprecated=_DEPRECATED,
)

glTextureParameterivEXT = platform.createExtensionFunction( 
'glTextureParameterivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glTextureParameterivEXT(GLuint(texture), GLenum(target), GLenum(pname), GLintArray(params)) -> None',
argNames=('texture','target','pname','params',),
deprecated=_DEPRECATED,
)

glTextureImage1DEXT = platform.createExtensionFunction( 
'glTextureImage1DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLint,constants.GLenum,constants.GLsizei,constants.GLint,constants.GLenum,constants.GLenum,ctypes.c_void_p,),
doc='glTextureImage1DEXT(GLuint(texture), GLenum(target), GLint(level), GLenum(internalformat), GLsizei(width), GLint(border), GLenum(format), GLenum(type), c_void_p(pixels)) -> None',
argNames=('texture','target','level','internalformat','width','border','format','type','pixels',),
deprecated=_DEPRECATED,
)

glTextureImage2DEXT = platform.createExtensionFunction( 
'glTextureImage2DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLint,constants.GLenum,constants.GLsizei,constants.GLsizei,constants.GLint,constants.GLenum,constants.GLenum,ctypes.c_void_p,),
doc='glTextureImage2DEXT(GLuint(texture), GLenum(target), GLint(level), GLenum(internalformat), GLsizei(width), GLsizei(height), GLint(border), GLenum(format), GLenum(type), c_void_p(pixels)) -> None',
argNames=('texture','target','level','internalformat','width','height','border','format','type','pixels',),
deprecated=_DEPRECATED,
)

glTextureSubImage1DEXT = platform.createExtensionFunction( 
'glTextureSubImage1DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLint,constants.GLint,constants.GLsizei,constants.GLenum,constants.GLenum,ctypes.c_void_p,),
doc='glTextureSubImage1DEXT(GLuint(texture), GLenum(target), GLint(level), GLint(xoffset), GLsizei(width), GLenum(format), GLenum(type), c_void_p(pixels)) -> None',
argNames=('texture','target','level','xoffset','width','format','type','pixels',),
deprecated=_DEPRECATED,
)

glTextureSubImage2DEXT = platform.createExtensionFunction( 
'glTextureSubImage2DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLint,constants.GLint,constants.GLint,constants.GLsizei,constants.GLsizei,constants.GLenum,constants.GLenum,ctypes.c_void_p,),
doc='glTextureSubImage2DEXT(GLuint(texture), GLenum(target), GLint(level), GLint(xoffset), GLint(yoffset), GLsizei(width), GLsizei(height), GLenum(format), GLenum(type), c_void_p(pixels)) -> None',
argNames=('texture','target','level','xoffset','yoffset','width','height','format','type','pixels',),
deprecated=_DEPRECATED,
)

glCopyTextureImage1DEXT = platform.createExtensionFunction( 
'glCopyTextureImage1DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLint,constants.GLenum,constants.GLint,constants.GLint,constants.GLsizei,constants.GLint,),
doc='glCopyTextureImage1DEXT(GLuint(texture), GLenum(target), GLint(level), GLenum(internalformat), GLint(x), GLint(y), GLsizei(width), GLint(border)) -> None',
argNames=('texture','target','level','internalformat','x','y','width','border',),
deprecated=_DEPRECATED,
)

glCopyTextureImage2DEXT = platform.createExtensionFunction( 
'glCopyTextureImage2DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLint,constants.GLenum,constants.GLint,constants.GLint,constants.GLsizei,constants.GLsizei,constants.GLint,),
doc='glCopyTextureImage2DEXT(GLuint(texture), GLenum(target), GLint(level), GLenum(internalformat), GLint(x), GLint(y), GLsizei(width), GLsizei(height), GLint(border)) -> None',
argNames=('texture','target','level','internalformat','x','y','width','height','border',),
deprecated=_DEPRECATED,
)

glCopyTextureSubImage1DEXT = platform.createExtensionFunction( 
'glCopyTextureSubImage1DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLsizei,),
doc='glCopyTextureSubImage1DEXT(GLuint(texture), GLenum(target), GLint(level), GLint(xoffset), GLint(x), GLint(y), GLsizei(width)) -> None',
argNames=('texture','target','level','xoffset','x','y','width',),
deprecated=_DEPRECATED,
)

glCopyTextureSubImage2DEXT = platform.createExtensionFunction( 
'glCopyTextureSubImage2DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLsizei,constants.GLsizei,),
doc='glCopyTextureSubImage2DEXT(GLuint(texture), GLenum(target), GLint(level), GLint(xoffset), GLint(yoffset), GLint(x), GLint(y), GLsizei(width), GLsizei(height)) -> None',
argNames=('texture','target','level','xoffset','yoffset','x','y','width','height',),
deprecated=_DEPRECATED,
)

glGetTextureImageEXT = platform.createExtensionFunction( 
'glGetTextureImageEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLint,constants.GLenum,constants.GLenum,ctypes.c_void_p,),
doc='glGetTextureImageEXT(GLuint(texture), GLenum(target), GLint(level), GLenum(format), GLenum(type), c_void_p(pixels)) -> None',
argNames=('texture','target','level','format','type','pixels',),
deprecated=_DEPRECATED,
)

glGetTextureParameterfvEXT = platform.createExtensionFunction( 
'glGetTextureParameterfvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLenum,arrays.GLfloatArray,),
doc='glGetTextureParameterfvEXT(GLuint(texture), GLenum(target), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('texture','target','pname','params',),
deprecated=_DEPRECATED,
)

glGetTextureParameterivEXT = platform.createExtensionFunction( 
'glGetTextureParameterivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glGetTextureParameterivEXT(GLuint(texture), GLenum(target), GLenum(pname), GLintArray(params)) -> None',
argNames=('texture','target','pname','params',),
deprecated=_DEPRECATED,
)

glGetTextureLevelParameterfvEXT = platform.createExtensionFunction( 
'glGetTextureLevelParameterfvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLint,constants.GLenum,arrays.GLfloatArray,),
doc='glGetTextureLevelParameterfvEXT(GLuint(texture), GLenum(target), GLint(level), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('texture','target','level','pname','params',),
deprecated=_DEPRECATED,
)

glGetTextureLevelParameterivEXT = platform.createExtensionFunction( 
'glGetTextureLevelParameterivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLint,constants.GLenum,arrays.GLintArray,),
doc='glGetTextureLevelParameterivEXT(GLuint(texture), GLenum(target), GLint(level), GLenum(pname), GLintArray(params)) -> None',
argNames=('texture','target','level','pname','params',),
deprecated=_DEPRECATED,
)

glTextureImage3DEXT = platform.createExtensionFunction( 
'glTextureImage3DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLint,constants.GLenum,constants.GLsizei,constants.GLsizei,constants.GLsizei,constants.GLint,constants.GLenum,constants.GLenum,ctypes.c_void_p,),
doc='glTextureImage3DEXT(GLuint(texture), GLenum(target), GLint(level), GLenum(internalformat), GLsizei(width), GLsizei(height), GLsizei(depth), GLint(border), GLenum(format), GLenum(type), c_void_p(pixels)) -> None',
argNames=('texture','target','level','internalformat','width','height','depth','border','format','type','pixels',),
deprecated=_DEPRECATED,
)

glTextureSubImage3DEXT = platform.createExtensionFunction( 
'glTextureSubImage3DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLsizei,constants.GLsizei,constants.GLsizei,constants.GLenum,constants.GLenum,ctypes.c_void_p,),
doc='glTextureSubImage3DEXT(GLuint(texture), GLenum(target), GLint(level), GLint(xoffset), GLint(yoffset), GLint(zoffset), GLsizei(width), GLsizei(height), GLsizei(depth), GLenum(format), GLenum(type), c_void_p(pixels)) -> None',
argNames=('texture','target','level','xoffset','yoffset','zoffset','width','height','depth','format','type','pixels',),
deprecated=_DEPRECATED,
)

glCopyTextureSubImage3DEXT = platform.createExtensionFunction( 
'glCopyTextureSubImage3DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLsizei,constants.GLsizei,),
doc='glCopyTextureSubImage3DEXT(GLuint(texture), GLenum(target), GLint(level), GLint(xoffset), GLint(yoffset), GLint(zoffset), GLint(x), GLint(y), GLsizei(width), GLsizei(height)) -> None',
argNames=('texture','target','level','xoffset','yoffset','zoffset','x','y','width','height',),
deprecated=_DEPRECATED,
)

glMultiTexParameterfEXT = platform.createExtensionFunction( 
'glMultiTexParameterfEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,constants.GLfloat,),
doc='glMultiTexParameterfEXT(GLenum(texunit), GLenum(target), GLenum(pname), GLfloat(param)) -> None',
argNames=('texunit','target','pname','param',),
deprecated=_DEPRECATED,
)

glMultiTexParameterfvEXT = platform.createExtensionFunction( 
'glMultiTexParameterfvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,arrays.GLfloatArray,),
doc='glMultiTexParameterfvEXT(GLenum(texunit), GLenum(target), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('texunit','target','pname','params',),
deprecated=_DEPRECATED,
)

glMultiTexParameteriEXT = platform.createExtensionFunction( 
'glMultiTexParameteriEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,constants.GLint,),
doc='glMultiTexParameteriEXT(GLenum(texunit), GLenum(target), GLenum(pname), GLint(param)) -> None',
argNames=('texunit','target','pname','param',),
deprecated=_DEPRECATED,
)

glMultiTexParameterivEXT = platform.createExtensionFunction( 
'glMultiTexParameterivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glMultiTexParameterivEXT(GLenum(texunit), GLenum(target), GLenum(pname), GLintArray(params)) -> None',
argNames=('texunit','target','pname','params',),
deprecated=_DEPRECATED,
)

glMultiTexImage1DEXT = platform.createExtensionFunction( 
'glMultiTexImage1DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLint,constants.GLenum,constants.GLsizei,constants.GLint,constants.GLenum,constants.GLenum,ctypes.c_void_p,),
doc='glMultiTexImage1DEXT(GLenum(texunit), GLenum(target), GLint(level), GLenum(internalformat), GLsizei(width), GLint(border), GLenum(format), GLenum(type), c_void_p(pixels)) -> None',
argNames=('texunit','target','level','internalformat','width','border','format','type','pixels',),
deprecated=_DEPRECATED,
)

glMultiTexImage2DEXT = platform.createExtensionFunction( 
'glMultiTexImage2DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLint,constants.GLenum,constants.GLsizei,constants.GLsizei,constants.GLint,constants.GLenum,constants.GLenum,ctypes.c_void_p,),
doc='glMultiTexImage2DEXT(GLenum(texunit), GLenum(target), GLint(level), GLenum(internalformat), GLsizei(width), GLsizei(height), GLint(border), GLenum(format), GLenum(type), c_void_p(pixels)) -> None',
argNames=('texunit','target','level','internalformat','width','height','border','format','type','pixels',),
deprecated=_DEPRECATED,
)

glMultiTexSubImage1DEXT = platform.createExtensionFunction( 
'glMultiTexSubImage1DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLint,constants.GLint,constants.GLsizei,constants.GLenum,constants.GLenum,ctypes.c_void_p,),
doc='glMultiTexSubImage1DEXT(GLenum(texunit), GLenum(target), GLint(level), GLint(xoffset), GLsizei(width), GLenum(format), GLenum(type), c_void_p(pixels)) -> None',
argNames=('texunit','target','level','xoffset','width','format','type','pixels',),
deprecated=_DEPRECATED,
)

glMultiTexSubImage2DEXT = platform.createExtensionFunction( 
'glMultiTexSubImage2DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLint,constants.GLint,constants.GLint,constants.GLsizei,constants.GLsizei,constants.GLenum,constants.GLenum,ctypes.c_void_p,),
doc='glMultiTexSubImage2DEXT(GLenum(texunit), GLenum(target), GLint(level), GLint(xoffset), GLint(yoffset), GLsizei(width), GLsizei(height), GLenum(format), GLenum(type), c_void_p(pixels)) -> None',
argNames=('texunit','target','level','xoffset','yoffset','width','height','format','type','pixels',),
deprecated=_DEPRECATED,
)

glCopyMultiTexImage1DEXT = platform.createExtensionFunction( 
'glCopyMultiTexImage1DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLint,constants.GLenum,constants.GLint,constants.GLint,constants.GLsizei,constants.GLint,),
doc='glCopyMultiTexImage1DEXT(GLenum(texunit), GLenum(target), GLint(level), GLenum(internalformat), GLint(x), GLint(y), GLsizei(width), GLint(border)) -> None',
argNames=('texunit','target','level','internalformat','x','y','width','border',),
deprecated=_DEPRECATED,
)

glCopyMultiTexImage2DEXT = platform.createExtensionFunction( 
'glCopyMultiTexImage2DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLint,constants.GLenum,constants.GLint,constants.GLint,constants.GLsizei,constants.GLsizei,constants.GLint,),
doc='glCopyMultiTexImage2DEXT(GLenum(texunit), GLenum(target), GLint(level), GLenum(internalformat), GLint(x), GLint(y), GLsizei(width), GLsizei(height), GLint(border)) -> None',
argNames=('texunit','target','level','internalformat','x','y','width','height','border',),
deprecated=_DEPRECATED,
)

glCopyMultiTexSubImage1DEXT = platform.createExtensionFunction( 
'glCopyMultiTexSubImage1DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLsizei,),
doc='glCopyMultiTexSubImage1DEXT(GLenum(texunit), GLenum(target), GLint(level), GLint(xoffset), GLint(x), GLint(y), GLsizei(width)) -> None',
argNames=('texunit','target','level','xoffset','x','y','width',),
deprecated=_DEPRECATED,
)

glCopyMultiTexSubImage2DEXT = platform.createExtensionFunction( 
'glCopyMultiTexSubImage2DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLsizei,constants.GLsizei,),
doc='glCopyMultiTexSubImage2DEXT(GLenum(texunit), GLenum(target), GLint(level), GLint(xoffset), GLint(yoffset), GLint(x), GLint(y), GLsizei(width), GLsizei(height)) -> None',
argNames=('texunit','target','level','xoffset','yoffset','x','y','width','height',),
deprecated=_DEPRECATED,
)

glGetMultiTexImageEXT = platform.createExtensionFunction( 
'glGetMultiTexImageEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLint,constants.GLenum,constants.GLenum,ctypes.c_void_p,),
doc='glGetMultiTexImageEXT(GLenum(texunit), GLenum(target), GLint(level), GLenum(format), GLenum(type), c_void_p(pixels)) -> None',
argNames=('texunit','target','level','format','type','pixels',),
deprecated=_DEPRECATED,
)

glGetMultiTexParameterfvEXT = platform.createExtensionFunction( 
'glGetMultiTexParameterfvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,arrays.GLfloatArray,),
doc='glGetMultiTexParameterfvEXT(GLenum(texunit), GLenum(target), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('texunit','target','pname','params',),
deprecated=_DEPRECATED,
)

glGetMultiTexParameterivEXT = platform.createExtensionFunction( 
'glGetMultiTexParameterivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glGetMultiTexParameterivEXT(GLenum(texunit), GLenum(target), GLenum(pname), GLintArray(params)) -> None',
argNames=('texunit','target','pname','params',),
deprecated=_DEPRECATED,
)

glGetMultiTexLevelParameterfvEXT = platform.createExtensionFunction( 
'glGetMultiTexLevelParameterfvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLint,constants.GLenum,arrays.GLfloatArray,),
doc='glGetMultiTexLevelParameterfvEXT(GLenum(texunit), GLenum(target), GLint(level), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('texunit','target','level','pname','params',),
deprecated=_DEPRECATED,
)

glGetMultiTexLevelParameterivEXT = platform.createExtensionFunction( 
'glGetMultiTexLevelParameterivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLint,constants.GLenum,arrays.GLintArray,),
doc='glGetMultiTexLevelParameterivEXT(GLenum(texunit), GLenum(target), GLint(level), GLenum(pname), GLintArray(params)) -> None',
argNames=('texunit','target','level','pname','params',),
deprecated=_DEPRECATED,
)

glMultiTexImage3DEXT = platform.createExtensionFunction( 
'glMultiTexImage3DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLint,constants.GLenum,constants.GLsizei,constants.GLsizei,constants.GLsizei,constants.GLint,constants.GLenum,constants.GLenum,ctypes.c_void_p,),
doc='glMultiTexImage3DEXT(GLenum(texunit), GLenum(target), GLint(level), GLenum(internalformat), GLsizei(width), GLsizei(height), GLsizei(depth), GLint(border), GLenum(format), GLenum(type), c_void_p(pixels)) -> None',
argNames=('texunit','target','level','internalformat','width','height','depth','border','format','type','pixels',),
deprecated=_DEPRECATED,
)

glMultiTexSubImage3DEXT = platform.createExtensionFunction( 
'glMultiTexSubImage3DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLsizei,constants.GLsizei,constants.GLsizei,constants.GLenum,constants.GLenum,ctypes.c_void_p,),
doc='glMultiTexSubImage3DEXT(GLenum(texunit), GLenum(target), GLint(level), GLint(xoffset), GLint(yoffset), GLint(zoffset), GLsizei(width), GLsizei(height), GLsizei(depth), GLenum(format), GLenum(type), c_void_p(pixels)) -> None',
argNames=('texunit','target','level','xoffset','yoffset','zoffset','width','height','depth','format','type','pixels',),
deprecated=_DEPRECATED,
)

glCopyMultiTexSubImage3DEXT = platform.createExtensionFunction( 
'glCopyMultiTexSubImage3DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLsizei,constants.GLsizei,),
doc='glCopyMultiTexSubImage3DEXT(GLenum(texunit), GLenum(target), GLint(level), GLint(xoffset), GLint(yoffset), GLint(zoffset), GLint(x), GLint(y), GLsizei(width), GLsizei(height)) -> None',
argNames=('texunit','target','level','xoffset','yoffset','zoffset','x','y','width','height',),
deprecated=_DEPRECATED,
)

glBindMultiTextureEXT = platform.createExtensionFunction( 
'glBindMultiTextureEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLuint,),
doc='glBindMultiTextureEXT(GLenum(texunit), GLenum(target), GLuint(texture)) -> None',
argNames=('texunit','target','texture',),
deprecated=_DEPRECATED,
)

glEnableClientStateIndexedEXT = platform.createExtensionFunction( 
'glEnableClientStateIndexedEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,),
doc='glEnableClientStateIndexedEXT(GLenum(array), GLuint(index)) -> None',
argNames=('array','index',),
deprecated=_DEPRECATED,
)

glDisableClientStateIndexedEXT = platform.createExtensionFunction( 
'glDisableClientStateIndexedEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,),
doc='glDisableClientStateIndexedEXT(GLenum(array), GLuint(index)) -> None',
argNames=('array','index',),
deprecated=_DEPRECATED,
)

glMultiTexCoordPointerEXT = platform.createExtensionFunction( 
'glMultiTexCoordPointerEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,constants.GLenum,constants.GLsizei,ctypes.c_void_p,),
doc='glMultiTexCoordPointerEXT(GLenum(texunit), GLint(size), GLenum(type), GLsizei(stride), c_void_p(pointer)) -> None',
argNames=('texunit','size','type','stride','pointer',),
deprecated=_DEPRECATED,
)

glMultiTexEnvfEXT = platform.createExtensionFunction( 
'glMultiTexEnvfEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,constants.GLfloat,),
doc='glMultiTexEnvfEXT(GLenum(texunit), GLenum(target), GLenum(pname), GLfloat(param)) -> None',
argNames=('texunit','target','pname','param',),
deprecated=_DEPRECATED,
)

glMultiTexEnvfvEXT = platform.createExtensionFunction( 
'glMultiTexEnvfvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,arrays.GLfloatArray,),
doc='glMultiTexEnvfvEXT(GLenum(texunit), GLenum(target), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('texunit','target','pname','params',),
deprecated=_DEPRECATED,
)

glMultiTexEnviEXT = platform.createExtensionFunction( 
'glMultiTexEnviEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,constants.GLint,),
doc='glMultiTexEnviEXT(GLenum(texunit), GLenum(target), GLenum(pname), GLint(param)) -> None',
argNames=('texunit','target','pname','param',),
deprecated=_DEPRECATED,
)

glMultiTexEnvivEXT = platform.createExtensionFunction( 
'glMultiTexEnvivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glMultiTexEnvivEXT(GLenum(texunit), GLenum(target), GLenum(pname), GLintArray(params)) -> None',
argNames=('texunit','target','pname','params',),
deprecated=_DEPRECATED,
)

glMultiTexGendEXT = platform.createExtensionFunction( 
'glMultiTexGendEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,constants.GLdouble,),
doc='glMultiTexGendEXT(GLenum(texunit), GLenum(coord), GLenum(pname), GLdouble(param)) -> None',
argNames=('texunit','coord','pname','param',),
deprecated=_DEPRECATED,
)

glMultiTexGendvEXT = platform.createExtensionFunction( 
'glMultiTexGendvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,arrays.GLdoubleArray,),
doc='glMultiTexGendvEXT(GLenum(texunit), GLenum(coord), GLenum(pname), GLdoubleArray(params)) -> None',
argNames=('texunit','coord','pname','params',),
deprecated=_DEPRECATED,
)

glMultiTexGenfEXT = platform.createExtensionFunction( 
'glMultiTexGenfEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,constants.GLfloat,),
doc='glMultiTexGenfEXT(GLenum(texunit), GLenum(coord), GLenum(pname), GLfloat(param)) -> None',
argNames=('texunit','coord','pname','param',),
deprecated=_DEPRECATED,
)

glMultiTexGenfvEXT = platform.createExtensionFunction( 
'glMultiTexGenfvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,arrays.GLfloatArray,),
doc='glMultiTexGenfvEXT(GLenum(texunit), GLenum(coord), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('texunit','coord','pname','params',),
deprecated=_DEPRECATED,
)

glMultiTexGeniEXT = platform.createExtensionFunction( 
'glMultiTexGeniEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,constants.GLint,),
doc='glMultiTexGeniEXT(GLenum(texunit), GLenum(coord), GLenum(pname), GLint(param)) -> None',
argNames=('texunit','coord','pname','param',),
deprecated=_DEPRECATED,
)

glMultiTexGenivEXT = platform.createExtensionFunction( 
'glMultiTexGenivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glMultiTexGenivEXT(GLenum(texunit), GLenum(coord), GLenum(pname), GLintArray(params)) -> None',
argNames=('texunit','coord','pname','params',),
deprecated=_DEPRECATED,
)

glGetMultiTexEnvfvEXT = platform.createExtensionFunction( 
'glGetMultiTexEnvfvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,arrays.GLfloatArray,),
doc='glGetMultiTexEnvfvEXT(GLenum(texunit), GLenum(target), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('texunit','target','pname','params',),
deprecated=_DEPRECATED,
)

glGetMultiTexEnvivEXT = platform.createExtensionFunction( 
'glGetMultiTexEnvivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glGetMultiTexEnvivEXT(GLenum(texunit), GLenum(target), GLenum(pname), GLintArray(params)) -> None',
argNames=('texunit','target','pname','params',),
deprecated=_DEPRECATED,
)

glGetMultiTexGendvEXT = platform.createExtensionFunction( 
'glGetMultiTexGendvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,arrays.GLdoubleArray,),
doc='glGetMultiTexGendvEXT(GLenum(texunit), GLenum(coord), GLenum(pname), GLdoubleArray(params)) -> None',
argNames=('texunit','coord','pname','params',),
deprecated=_DEPRECATED,
)

glGetMultiTexGenfvEXT = platform.createExtensionFunction( 
'glGetMultiTexGenfvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,arrays.GLfloatArray,),
doc='glGetMultiTexGenfvEXT(GLenum(texunit), GLenum(coord), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('texunit','coord','pname','params',),
deprecated=_DEPRECATED,
)

glGetMultiTexGenivEXT = platform.createExtensionFunction( 
'glGetMultiTexGenivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glGetMultiTexGenivEXT(GLenum(texunit), GLenum(coord), GLenum(pname), GLintArray(params)) -> None',
argNames=('texunit','coord','pname','params',),
deprecated=_DEPRECATED,
)

glGetFloatIndexedvEXT = platform.createExtensionFunction( 
'glGetFloatIndexedvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,arrays.GLfloatArray,),
doc='glGetFloatIndexedvEXT(GLenum(target), GLuint(index), GLfloatArray(data)) -> None',
argNames=('target','index','data',),
deprecated=_DEPRECATED,
)

glGetDoubleIndexedvEXT = platform.createExtensionFunction( 
'glGetDoubleIndexedvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,arrays.GLdoubleArray,),
doc='glGetDoubleIndexedvEXT(GLenum(target), GLuint(index), GLdoubleArray(data)) -> None',
argNames=('target','index','data',),
deprecated=_DEPRECATED,
)

glGetPointerIndexedvEXT = platform.createExtensionFunction( 
'glGetPointerIndexedvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,ctypes.POINTER(ctypes.c_void_p),),
doc='glGetPointerIndexedvEXT(GLenum(target), GLuint(index), POINTER(ctypes.c_void_p)(data)) -> None',
argNames=('target','index','data',),
deprecated=_DEPRECATED,
)

glCompressedTextureImage3DEXT = platform.createExtensionFunction( 
'glCompressedTextureImage3DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLint,constants.GLenum,constants.GLsizei,constants.GLsizei,constants.GLsizei,constants.GLint,constants.GLsizei,ctypes.c_void_p,),
doc='glCompressedTextureImage3DEXT(GLuint(texture), GLenum(target), GLint(level), GLenum(internalformat), GLsizei(width), GLsizei(height), GLsizei(depth), GLint(border), GLsizei(imageSize), c_void_p(bits)) -> None',
argNames=('texture','target','level','internalformat','width','height','depth','border','imageSize','bits',),
deprecated=_DEPRECATED,
)

glCompressedTextureImage2DEXT = platform.createExtensionFunction( 
'glCompressedTextureImage2DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLint,constants.GLenum,constants.GLsizei,constants.GLsizei,constants.GLint,constants.GLsizei,ctypes.c_void_p,),
doc='glCompressedTextureImage2DEXT(GLuint(texture), GLenum(target), GLint(level), GLenum(internalformat), GLsizei(width), GLsizei(height), GLint(border), GLsizei(imageSize), c_void_p(bits)) -> None',
argNames=('texture','target','level','internalformat','width','height','border','imageSize','bits',),
deprecated=_DEPRECATED,
)

glCompressedTextureImage1DEXT = platform.createExtensionFunction( 
'glCompressedTextureImage1DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLint,constants.GLenum,constants.GLsizei,constants.GLint,constants.GLsizei,ctypes.c_void_p,),
doc='glCompressedTextureImage1DEXT(GLuint(texture), GLenum(target), GLint(level), GLenum(internalformat), GLsizei(width), GLint(border), GLsizei(imageSize), c_void_p(bits)) -> None',
argNames=('texture','target','level','internalformat','width','border','imageSize','bits',),
deprecated=_DEPRECATED,
)

glCompressedTextureSubImage3DEXT = platform.createExtensionFunction( 
'glCompressedTextureSubImage3DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLsizei,constants.GLsizei,constants.GLsizei,constants.GLenum,constants.GLsizei,ctypes.c_void_p,),
doc='glCompressedTextureSubImage3DEXT(GLuint(texture), GLenum(target), GLint(level), GLint(xoffset), GLint(yoffset), GLint(zoffset), GLsizei(width), GLsizei(height), GLsizei(depth), GLenum(format), GLsizei(imageSize), c_void_p(bits)) -> None',
argNames=('texture','target','level','xoffset','yoffset','zoffset','width','height','depth','format','imageSize','bits',),
deprecated=_DEPRECATED,
)

glCompressedTextureSubImage2DEXT = platform.createExtensionFunction( 
'glCompressedTextureSubImage2DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLint,constants.GLint,constants.GLint,constants.GLsizei,constants.GLsizei,constants.GLenum,constants.GLsizei,ctypes.c_void_p,),
doc='glCompressedTextureSubImage2DEXT(GLuint(texture), GLenum(target), GLint(level), GLint(xoffset), GLint(yoffset), GLsizei(width), GLsizei(height), GLenum(format), GLsizei(imageSize), c_void_p(bits)) -> None',
argNames=('texture','target','level','xoffset','yoffset','width','height','format','imageSize','bits',),
deprecated=_DEPRECATED,
)

glCompressedTextureSubImage1DEXT = platform.createExtensionFunction( 
'glCompressedTextureSubImage1DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLint,constants.GLint,constants.GLsizei,constants.GLenum,constants.GLsizei,ctypes.c_void_p,),
doc='glCompressedTextureSubImage1DEXT(GLuint(texture), GLenum(target), GLint(level), GLint(xoffset), GLsizei(width), GLenum(format), GLsizei(imageSize), c_void_p(bits)) -> None',
argNames=('texture','target','level','xoffset','width','format','imageSize','bits',),
deprecated=_DEPRECATED,
)

glGetCompressedTextureImageEXT = platform.createExtensionFunction( 
'glGetCompressedTextureImageEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLint,ctypes.c_void_p,),
doc='glGetCompressedTextureImageEXT(GLuint(texture), GLenum(target), GLint(lod), c_void_p(img)) -> None',
argNames=('texture','target','lod','img',),
deprecated=_DEPRECATED,
)

glCompressedMultiTexImage3DEXT = platform.createExtensionFunction( 
'glCompressedMultiTexImage3DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLint,constants.GLenum,constants.GLsizei,constants.GLsizei,constants.GLsizei,constants.GLint,constants.GLsizei,ctypes.c_void_p,),
doc='glCompressedMultiTexImage3DEXT(GLenum(texunit), GLenum(target), GLint(level), GLenum(internalformat), GLsizei(width), GLsizei(height), GLsizei(depth), GLint(border), GLsizei(imageSize), c_void_p(bits)) -> None',
argNames=('texunit','target','level','internalformat','width','height','depth','border','imageSize','bits',),
deprecated=_DEPRECATED,
)

glCompressedMultiTexImage2DEXT = platform.createExtensionFunction( 
'glCompressedMultiTexImage2DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLint,constants.GLenum,constants.GLsizei,constants.GLsizei,constants.GLint,constants.GLsizei,ctypes.c_void_p,),
doc='glCompressedMultiTexImage2DEXT(GLenum(texunit), GLenum(target), GLint(level), GLenum(internalformat), GLsizei(width), GLsizei(height), GLint(border), GLsizei(imageSize), c_void_p(bits)) -> None',
argNames=('texunit','target','level','internalformat','width','height','border','imageSize','bits',),
deprecated=_DEPRECATED,
)

glCompressedMultiTexImage1DEXT = platform.createExtensionFunction( 
'glCompressedMultiTexImage1DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLint,constants.GLenum,constants.GLsizei,constants.GLint,constants.GLsizei,ctypes.c_void_p,),
doc='glCompressedMultiTexImage1DEXT(GLenum(texunit), GLenum(target), GLint(level), GLenum(internalformat), GLsizei(width), GLint(border), GLsizei(imageSize), c_void_p(bits)) -> None',
argNames=('texunit','target','level','internalformat','width','border','imageSize','bits',),
deprecated=_DEPRECATED,
)

glCompressedMultiTexSubImage3DEXT = platform.createExtensionFunction( 
'glCompressedMultiTexSubImage3DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLsizei,constants.GLsizei,constants.GLsizei,constants.GLenum,constants.GLsizei,ctypes.c_void_p,),
doc='glCompressedMultiTexSubImage3DEXT(GLenum(texunit), GLenum(target), GLint(level), GLint(xoffset), GLint(yoffset), GLint(zoffset), GLsizei(width), GLsizei(height), GLsizei(depth), GLenum(format), GLsizei(imageSize), c_void_p(bits)) -> None',
argNames=('texunit','target','level','xoffset','yoffset','zoffset','width','height','depth','format','imageSize','bits',),
deprecated=_DEPRECATED,
)

glCompressedMultiTexSubImage2DEXT = platform.createExtensionFunction( 
'glCompressedMultiTexSubImage2DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLint,constants.GLint,constants.GLint,constants.GLsizei,constants.GLsizei,constants.GLenum,constants.GLsizei,ctypes.c_void_p,),
doc='glCompressedMultiTexSubImage2DEXT(GLenum(texunit), GLenum(target), GLint(level), GLint(xoffset), GLint(yoffset), GLsizei(width), GLsizei(height), GLenum(format), GLsizei(imageSize), c_void_p(bits)) -> None',
argNames=('texunit','target','level','xoffset','yoffset','width','height','format','imageSize','bits',),
deprecated=_DEPRECATED,
)

glCompressedMultiTexSubImage1DEXT = platform.createExtensionFunction( 
'glCompressedMultiTexSubImage1DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLint,constants.GLint,constants.GLsizei,constants.GLenum,constants.GLsizei,ctypes.c_void_p,),
doc='glCompressedMultiTexSubImage1DEXT(GLenum(texunit), GLenum(target), GLint(level), GLint(xoffset), GLsizei(width), GLenum(format), GLsizei(imageSize), c_void_p(bits)) -> None',
argNames=('texunit','target','level','xoffset','width','format','imageSize','bits',),
deprecated=_DEPRECATED,
)

glGetCompressedMultiTexImageEXT = platform.createExtensionFunction( 
'glGetCompressedMultiTexImageEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLint,ctypes.c_void_p,),
doc='glGetCompressedMultiTexImageEXT(GLenum(texunit), GLenum(target), GLint(lod), c_void_p(img)) -> None',
argNames=('texunit','target','lod','img',),
deprecated=_DEPRECATED,
)

glNamedProgramStringEXT = platform.createExtensionFunction( 
'glNamedProgramStringEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLenum,constants.GLsizei,ctypes.c_void_p,),
doc='glNamedProgramStringEXT(GLuint(program), GLenum(target), GLenum(format), GLsizei(len), c_void_p(string)) -> None',
argNames=('program','target','format','len','string',),
deprecated=_DEPRECATED,
)

glNamedProgramLocalParameter4dEXT = platform.createExtensionFunction( 
'glNamedProgramLocalParameter4dEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLuint,constants.GLdouble,constants.GLdouble,constants.GLdouble,constants.GLdouble,),
doc='glNamedProgramLocalParameter4dEXT(GLuint(program), GLenum(target), GLuint(index), GLdouble(x), GLdouble(y), GLdouble(z), GLdouble(w)) -> None',
argNames=('program','target','index','x','y','z','w',),
deprecated=_DEPRECATED,
)

glNamedProgramLocalParameter4dvEXT = platform.createExtensionFunction( 
'glNamedProgramLocalParameter4dvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLuint,arrays.GLdoubleArray,),
doc='glNamedProgramLocalParameter4dvEXT(GLuint(program), GLenum(target), GLuint(index), GLdoubleArray(params)) -> None',
argNames=('program','target','index','params',),
deprecated=_DEPRECATED,
)

glNamedProgramLocalParameter4fEXT = platform.createExtensionFunction( 
'glNamedProgramLocalParameter4fEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLuint,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glNamedProgramLocalParameter4fEXT(GLuint(program), GLenum(target), GLuint(index), GLfloat(x), GLfloat(y), GLfloat(z), GLfloat(w)) -> None',
argNames=('program','target','index','x','y','z','w',),
deprecated=_DEPRECATED,
)

glNamedProgramLocalParameter4fvEXT = platform.createExtensionFunction( 
'glNamedProgramLocalParameter4fvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLuint,arrays.GLfloatArray,),
doc='glNamedProgramLocalParameter4fvEXT(GLuint(program), GLenum(target), GLuint(index), GLfloatArray(params)) -> None',
argNames=('program','target','index','params',),
deprecated=_DEPRECATED,
)

glGetNamedProgramLocalParameterdvEXT = platform.createExtensionFunction( 
'glGetNamedProgramLocalParameterdvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLuint,arrays.GLdoubleArray,),
doc='glGetNamedProgramLocalParameterdvEXT(GLuint(program), GLenum(target), GLuint(index), GLdoubleArray(params)) -> None',
argNames=('program','target','index','params',),
deprecated=_DEPRECATED,
)

glGetNamedProgramLocalParameterfvEXT = platform.createExtensionFunction( 
'glGetNamedProgramLocalParameterfvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLuint,arrays.GLfloatArray,),
doc='glGetNamedProgramLocalParameterfvEXT(GLuint(program), GLenum(target), GLuint(index), GLfloatArray(params)) -> None',
argNames=('program','target','index','params',),
deprecated=_DEPRECATED,
)

glGetNamedProgramivEXT = platform.createExtensionFunction( 
'glGetNamedProgramivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glGetNamedProgramivEXT(GLuint(program), GLenum(target), GLenum(pname), GLintArray(params)) -> None',
argNames=('program','target','pname','params',),
deprecated=_DEPRECATED,
)

glGetNamedProgramStringEXT = platform.createExtensionFunction( 
'glGetNamedProgramStringEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLenum,ctypes.c_void_p,),
doc='glGetNamedProgramStringEXT(GLuint(program), GLenum(target), GLenum(pname), c_void_p(string)) -> None',
argNames=('program','target','pname','string',),
deprecated=_DEPRECATED,
)

glNamedProgramLocalParameters4fvEXT = platform.createExtensionFunction( 
'glNamedProgramLocalParameters4fvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLuint,constants.GLsizei,arrays.GLfloatArray,),
doc='glNamedProgramLocalParameters4fvEXT(GLuint(program), GLenum(target), GLuint(index), GLsizei(count), GLfloatArray(params)) -> None',
argNames=('program','target','index','count','params',),
deprecated=_DEPRECATED,
)

glNamedProgramLocalParameterI4iEXT = platform.createExtensionFunction( 
'glNamedProgramLocalParameterI4iEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLuint,constants.GLint,constants.GLint,constants.GLint,constants.GLint,),
doc='glNamedProgramLocalParameterI4iEXT(GLuint(program), GLenum(target), GLuint(index), GLint(x), GLint(y), GLint(z), GLint(w)) -> None',
argNames=('program','target','index','x','y','z','w',),
deprecated=_DEPRECATED,
)

glNamedProgramLocalParameterI4ivEXT = platform.createExtensionFunction( 
'glNamedProgramLocalParameterI4ivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLuint,arrays.GLintArray,),
doc='glNamedProgramLocalParameterI4ivEXT(GLuint(program), GLenum(target), GLuint(index), GLintArray(params)) -> None',
argNames=('program','target','index','params',),
deprecated=_DEPRECATED,
)

glNamedProgramLocalParametersI4ivEXT = platform.createExtensionFunction( 
'glNamedProgramLocalParametersI4ivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLuint,constants.GLsizei,arrays.GLintArray,),
doc='glNamedProgramLocalParametersI4ivEXT(GLuint(program), GLenum(target), GLuint(index), GLsizei(count), GLintArray(params)) -> None',
argNames=('program','target','index','count','params',),
deprecated=_DEPRECATED,
)

glNamedProgramLocalParameterI4uiEXT = platform.createExtensionFunction( 
'glNamedProgramLocalParameterI4uiEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,),
doc='glNamedProgramLocalParameterI4uiEXT(GLuint(program), GLenum(target), GLuint(index), GLuint(x), GLuint(y), GLuint(z), GLuint(w)) -> None',
argNames=('program','target','index','x','y','z','w',),
deprecated=_DEPRECATED,
)

glNamedProgramLocalParameterI4uivEXT = platform.createExtensionFunction( 
'glNamedProgramLocalParameterI4uivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLuint,arrays.GLuintArray,),
doc='glNamedProgramLocalParameterI4uivEXT(GLuint(program), GLenum(target), GLuint(index), GLuintArray(params)) -> None',
argNames=('program','target','index','params',),
deprecated=_DEPRECATED,
)

glNamedProgramLocalParametersI4uivEXT = platform.createExtensionFunction( 
'glNamedProgramLocalParametersI4uivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLuint,constants.GLsizei,arrays.GLuintArray,),
doc='glNamedProgramLocalParametersI4uivEXT(GLuint(program), GLenum(target), GLuint(index), GLsizei(count), GLuintArray(params)) -> None',
argNames=('program','target','index','count','params',),
deprecated=_DEPRECATED,
)

glGetNamedProgramLocalParameterIivEXT = platform.createExtensionFunction( 
'glGetNamedProgramLocalParameterIivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLuint,arrays.GLintArray,),
doc='glGetNamedProgramLocalParameterIivEXT(GLuint(program), GLenum(target), GLuint(index), GLintArray(params)) -> None',
argNames=('program','target','index','params',),
deprecated=_DEPRECATED,
)

glGetNamedProgramLocalParameterIuivEXT = platform.createExtensionFunction( 
'glGetNamedProgramLocalParameterIuivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLuint,arrays.GLuintArray,),
doc='glGetNamedProgramLocalParameterIuivEXT(GLuint(program), GLenum(target), GLuint(index), GLuintArray(params)) -> None',
argNames=('program','target','index','params',),
deprecated=_DEPRECATED,
)

glTextureParameterIivEXT = platform.createExtensionFunction( 
'glTextureParameterIivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glTextureParameterIivEXT(GLuint(texture), GLenum(target), GLenum(pname), GLintArray(params)) -> None',
argNames=('texture','target','pname','params',),
deprecated=_DEPRECATED,
)

glTextureParameterIuivEXT = platform.createExtensionFunction( 
'glTextureParameterIuivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLenum,arrays.GLuintArray,),
doc='glTextureParameterIuivEXT(GLuint(texture), GLenum(target), GLenum(pname), GLuintArray(params)) -> None',
argNames=('texture','target','pname','params',),
deprecated=_DEPRECATED,
)

glGetTextureParameterIivEXT = platform.createExtensionFunction( 
'glGetTextureParameterIivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glGetTextureParameterIivEXT(GLuint(texture), GLenum(target), GLenum(pname), GLintArray(params)) -> None',
argNames=('texture','target','pname','params',),
deprecated=_DEPRECATED,
)

glGetTextureParameterIuivEXT = platform.createExtensionFunction( 
'glGetTextureParameterIuivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLenum,arrays.GLuintArray,),
doc='glGetTextureParameterIuivEXT(GLuint(texture), GLenum(target), GLenum(pname), GLuintArray(params)) -> None',
argNames=('texture','target','pname','params',),
deprecated=_DEPRECATED,
)

glMultiTexParameterIivEXT = platform.createExtensionFunction( 
'glMultiTexParameterIivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glMultiTexParameterIivEXT(GLenum(texunit), GLenum(target), GLenum(pname), GLintArray(params)) -> None',
argNames=('texunit','target','pname','params',),
deprecated=_DEPRECATED,
)

glMultiTexParameterIuivEXT = platform.createExtensionFunction( 
'glMultiTexParameterIuivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,arrays.GLuintArray,),
doc='glMultiTexParameterIuivEXT(GLenum(texunit), GLenum(target), GLenum(pname), GLuintArray(params)) -> None',
argNames=('texunit','target','pname','params',),
deprecated=_DEPRECATED,
)

glGetMultiTexParameterIivEXT = platform.createExtensionFunction( 
'glGetMultiTexParameterIivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glGetMultiTexParameterIivEXT(GLenum(texunit), GLenum(target), GLenum(pname), GLintArray(params)) -> None',
argNames=('texunit','target','pname','params',),
deprecated=_DEPRECATED,
)

glGetMultiTexParameterIuivEXT = platform.createExtensionFunction( 
'glGetMultiTexParameterIuivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,arrays.GLuintArray,),
doc='glGetMultiTexParameterIuivEXT(GLenum(texunit), GLenum(target), GLenum(pname), GLuintArray(params)) -> None',
argNames=('texunit','target','pname','params',),
deprecated=_DEPRECATED,
)

glProgramUniform1fEXT = platform.createExtensionFunction( 
'glProgramUniform1fEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLfloat,),
doc='glProgramUniform1fEXT(GLuint(program), GLint(location), GLfloat(v0)) -> None',
argNames=('program','location','v0',),
deprecated=_DEPRECATED,
)

glProgramUniform2fEXT = platform.createExtensionFunction( 
'glProgramUniform2fEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLfloat,constants.GLfloat,),
doc='glProgramUniform2fEXT(GLuint(program), GLint(location), GLfloat(v0), GLfloat(v1)) -> None',
argNames=('program','location','v0','v1',),
deprecated=_DEPRECATED,
)

glProgramUniform3fEXT = platform.createExtensionFunction( 
'glProgramUniform3fEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glProgramUniform3fEXT(GLuint(program), GLint(location), GLfloat(v0), GLfloat(v1), GLfloat(v2)) -> None',
argNames=('program','location','v0','v1','v2',),
deprecated=_DEPRECATED,
)

glProgramUniform4fEXT = platform.createExtensionFunction( 
'glProgramUniform4fEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glProgramUniform4fEXT(GLuint(program), GLint(location), GLfloat(v0), GLfloat(v1), GLfloat(v2), GLfloat(v3)) -> None',
argNames=('program','location','v0','v1','v2','v3',),
deprecated=_DEPRECATED,
)

glProgramUniform1iEXT = platform.createExtensionFunction( 
'glProgramUniform1iEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLint,),
doc='glProgramUniform1iEXT(GLuint(program), GLint(location), GLint(v0)) -> None',
argNames=('program','location','v0',),
deprecated=_DEPRECATED,
)

glProgramUniform2iEXT = platform.createExtensionFunction( 
'glProgramUniform2iEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLint,constants.GLint,),
doc='glProgramUniform2iEXT(GLuint(program), GLint(location), GLint(v0), GLint(v1)) -> None',
argNames=('program','location','v0','v1',),
deprecated=_DEPRECATED,
)

glProgramUniform3iEXT = platform.createExtensionFunction( 
'glProgramUniform3iEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLint,constants.GLint,constants.GLint,),
doc='glProgramUniform3iEXT(GLuint(program), GLint(location), GLint(v0), GLint(v1), GLint(v2)) -> None',
argNames=('program','location','v0','v1','v2',),
deprecated=_DEPRECATED,
)

glProgramUniform4iEXT = platform.createExtensionFunction( 
'glProgramUniform4iEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLint,),
doc='glProgramUniform4iEXT(GLuint(program), GLint(location), GLint(v0), GLint(v1), GLint(v2), GLint(v3)) -> None',
argNames=('program','location','v0','v1','v2','v3',),
deprecated=_DEPRECATED,
)

glProgramUniform1fvEXT = platform.createExtensionFunction( 
'glProgramUniform1fvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLsizei,arrays.GLfloatArray,),
doc='glProgramUniform1fvEXT(GLuint(program), GLint(location), GLsizei(count), GLfloatArray(value)) -> None',
argNames=('program','location','count','value',),
deprecated=_DEPRECATED,
)

glProgramUniform2fvEXT = platform.createExtensionFunction( 
'glProgramUniform2fvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLsizei,arrays.GLfloatArray,),
doc='glProgramUniform2fvEXT(GLuint(program), GLint(location), GLsizei(count), GLfloatArray(value)) -> None',
argNames=('program','location','count','value',),
deprecated=_DEPRECATED,
)

glProgramUniform3fvEXT = platform.createExtensionFunction( 
'glProgramUniform3fvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLsizei,arrays.GLfloatArray,),
doc='glProgramUniform3fvEXT(GLuint(program), GLint(location), GLsizei(count), GLfloatArray(value)) -> None',
argNames=('program','location','count','value',),
deprecated=_DEPRECATED,
)

glProgramUniform4fvEXT = platform.createExtensionFunction( 
'glProgramUniform4fvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLsizei,arrays.GLfloatArray,),
doc='glProgramUniform4fvEXT(GLuint(program), GLint(location), GLsizei(count), GLfloatArray(value)) -> None',
argNames=('program','location','count','value',),
deprecated=_DEPRECATED,
)

glProgramUniform1ivEXT = platform.createExtensionFunction( 
'glProgramUniform1ivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLsizei,arrays.GLintArray,),
doc='glProgramUniform1ivEXT(GLuint(program), GLint(location), GLsizei(count), GLintArray(value)) -> None',
argNames=('program','location','count','value',),
deprecated=_DEPRECATED,
)

glProgramUniform2ivEXT = platform.createExtensionFunction( 
'glProgramUniform2ivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLsizei,arrays.GLintArray,),
doc='glProgramUniform2ivEXT(GLuint(program), GLint(location), GLsizei(count), GLintArray(value)) -> None',
argNames=('program','location','count','value',),
deprecated=_DEPRECATED,
)

glProgramUniform3ivEXT = platform.createExtensionFunction( 
'glProgramUniform3ivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLsizei,arrays.GLintArray,),
doc='glProgramUniform3ivEXT(GLuint(program), GLint(location), GLsizei(count), GLintArray(value)) -> None',
argNames=('program','location','count','value',),
deprecated=_DEPRECATED,
)

glProgramUniform4ivEXT = platform.createExtensionFunction( 
'glProgramUniform4ivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLsizei,arrays.GLintArray,),
doc='glProgramUniform4ivEXT(GLuint(program), GLint(location), GLsizei(count), GLintArray(value)) -> None',
argNames=('program','location','count','value',),
deprecated=_DEPRECATED,
)

glProgramUniformMatrix2fvEXT = platform.createExtensionFunction( 
'glProgramUniformMatrix2fvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLsizei,constants.GLboolean,arrays.GLfloatArray,),
doc='glProgramUniformMatrix2fvEXT(GLuint(program), GLint(location), GLsizei(count), GLboolean(transpose), GLfloatArray(value)) -> None',
argNames=('program','location','count','transpose','value',),
deprecated=_DEPRECATED,
)

glProgramUniformMatrix3fvEXT = platform.createExtensionFunction( 
'glProgramUniformMatrix3fvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLsizei,constants.GLboolean,arrays.GLfloatArray,),
doc='glProgramUniformMatrix3fvEXT(GLuint(program), GLint(location), GLsizei(count), GLboolean(transpose), GLfloatArray(value)) -> None',
argNames=('program','location','count','transpose','value',),
deprecated=_DEPRECATED,
)

glProgramUniformMatrix4fvEXT = platform.createExtensionFunction( 
'glProgramUniformMatrix4fvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLsizei,constants.GLboolean,arrays.GLfloatArray,),
doc='glProgramUniformMatrix4fvEXT(GLuint(program), GLint(location), GLsizei(count), GLboolean(transpose), GLfloatArray(value)) -> None',
argNames=('program','location','count','transpose','value',),
deprecated=_DEPRECATED,
)

glProgramUniformMatrix2x3fvEXT = platform.createExtensionFunction( 
'glProgramUniformMatrix2x3fvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLsizei,constants.GLboolean,arrays.GLfloatArray,),
doc='glProgramUniformMatrix2x3fvEXT(GLuint(program), GLint(location), GLsizei(count), GLboolean(transpose), GLfloatArray(value)) -> None',
argNames=('program','location','count','transpose','value',),
deprecated=_DEPRECATED,
)

glProgramUniformMatrix3x2fvEXT = platform.createExtensionFunction( 
'glProgramUniformMatrix3x2fvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLsizei,constants.GLboolean,arrays.GLfloatArray,),
doc='glProgramUniformMatrix3x2fvEXT(GLuint(program), GLint(location), GLsizei(count), GLboolean(transpose), GLfloatArray(value)) -> None',
argNames=('program','location','count','transpose','value',),
deprecated=_DEPRECATED,
)

glProgramUniformMatrix2x4fvEXT = platform.createExtensionFunction( 
'glProgramUniformMatrix2x4fvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLsizei,constants.GLboolean,arrays.GLfloatArray,),
doc='glProgramUniformMatrix2x4fvEXT(GLuint(program), GLint(location), GLsizei(count), GLboolean(transpose), GLfloatArray(value)) -> None',
argNames=('program','location','count','transpose','value',),
deprecated=_DEPRECATED,
)

glProgramUniformMatrix4x2fvEXT = platform.createExtensionFunction( 
'glProgramUniformMatrix4x2fvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLsizei,constants.GLboolean,arrays.GLfloatArray,),
doc='glProgramUniformMatrix4x2fvEXT(GLuint(program), GLint(location), GLsizei(count), GLboolean(transpose), GLfloatArray(value)) -> None',
argNames=('program','location','count','transpose','value',),
deprecated=_DEPRECATED,
)

glProgramUniformMatrix3x4fvEXT = platform.createExtensionFunction( 
'glProgramUniformMatrix3x4fvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLsizei,constants.GLboolean,arrays.GLfloatArray,),
doc='glProgramUniformMatrix3x4fvEXT(GLuint(program), GLint(location), GLsizei(count), GLboolean(transpose), GLfloatArray(value)) -> None',
argNames=('program','location','count','transpose','value',),
deprecated=_DEPRECATED,
)

glProgramUniformMatrix4x3fvEXT = platform.createExtensionFunction( 
'glProgramUniformMatrix4x3fvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLsizei,constants.GLboolean,arrays.GLfloatArray,),
doc='glProgramUniformMatrix4x3fvEXT(GLuint(program), GLint(location), GLsizei(count), GLboolean(transpose), GLfloatArray(value)) -> None',
argNames=('program','location','count','transpose','value',),
deprecated=_DEPRECATED,
)

glProgramUniform1uiEXT = platform.createExtensionFunction( 
'glProgramUniform1uiEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLuint,),
doc='glProgramUniform1uiEXT(GLuint(program), GLint(location), GLuint(v0)) -> None',
argNames=('program','location','v0',),
deprecated=_DEPRECATED,
)

glProgramUniform2uiEXT = platform.createExtensionFunction( 
'glProgramUniform2uiEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLuint,constants.GLuint,),
doc='glProgramUniform2uiEXT(GLuint(program), GLint(location), GLuint(v0), GLuint(v1)) -> None',
argNames=('program','location','v0','v1',),
deprecated=_DEPRECATED,
)

glProgramUniform3uiEXT = platform.createExtensionFunction( 
'glProgramUniform3uiEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLuint,constants.GLuint,constants.GLuint,),
doc='glProgramUniform3uiEXT(GLuint(program), GLint(location), GLuint(v0), GLuint(v1), GLuint(v2)) -> None',
argNames=('program','location','v0','v1','v2',),
deprecated=_DEPRECATED,
)

glProgramUniform4uiEXT = platform.createExtensionFunction( 
'glProgramUniform4uiEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,),
doc='glProgramUniform4uiEXT(GLuint(program), GLint(location), GLuint(v0), GLuint(v1), GLuint(v2), GLuint(v3)) -> None',
argNames=('program','location','v0','v1','v2','v3',),
deprecated=_DEPRECATED,
)

glProgramUniform1uivEXT = platform.createExtensionFunction( 
'glProgramUniform1uivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLsizei,arrays.GLuintArray,),
doc='glProgramUniform1uivEXT(GLuint(program), GLint(location), GLsizei(count), GLuintArray(value)) -> None',
argNames=('program','location','count','value',),
deprecated=_DEPRECATED,
)

glProgramUniform2uivEXT = platform.createExtensionFunction( 
'glProgramUniform2uivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLsizei,arrays.GLuintArray,),
doc='glProgramUniform2uivEXT(GLuint(program), GLint(location), GLsizei(count), GLuintArray(value)) -> None',
argNames=('program','location','count','value',),
deprecated=_DEPRECATED,
)

glProgramUniform3uivEXT = platform.createExtensionFunction( 
'glProgramUniform3uivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLsizei,arrays.GLuintArray,),
doc='glProgramUniform3uivEXT(GLuint(program), GLint(location), GLsizei(count), GLuintArray(value)) -> None',
argNames=('program','location','count','value',),
deprecated=_DEPRECATED,
)

glProgramUniform4uivEXT = platform.createExtensionFunction( 
'glProgramUniform4uivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLsizei,arrays.GLuintArray,),
doc='glProgramUniform4uivEXT(GLuint(program), GLint(location), GLsizei(count), GLuintArray(value)) -> None',
argNames=('program','location','count','value',),
deprecated=_DEPRECATED,
)

glNamedBufferDataEXT = platform.createExtensionFunction( 
'glNamedBufferDataEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLsizeiptr,ctypes.c_void_p,constants.GLenum,),
doc='glNamedBufferDataEXT(GLuint(buffer), GLsizeiptr(size), c_void_p(data), GLenum(usage)) -> None',
argNames=('buffer','size','data','usage',),
deprecated=_DEPRECATED,
)

glNamedBufferSubDataEXT = platform.createExtensionFunction( 
'glNamedBufferSubDataEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLintptr,constants.GLsizeiptr,ctypes.c_void_p,),
doc='glNamedBufferSubDataEXT(GLuint(buffer), GLintptr(offset), GLsizeiptr(size), c_void_p(data)) -> None',
argNames=('buffer','offset','size','data',),
deprecated=_DEPRECATED,
)

glMapNamedBufferEXT = platform.createExtensionFunction( 
'glMapNamedBufferEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=ctypes.c_void_p, 
argTypes=(constants.GLuint,constants.GLenum,),
doc='glMapNamedBufferEXT(GLuint(buffer), GLenum(access)) -> ctypes.c_void_p',
argNames=('buffer','access',),
deprecated=_DEPRECATED,
)

glUnmapNamedBufferEXT = platform.createExtensionFunction( 
'glUnmapNamedBufferEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLboolean, 
argTypes=(constants.GLuint,),
doc='glUnmapNamedBufferEXT(GLuint(buffer)) -> constants.GLboolean',
argNames=('buffer',),
deprecated=_DEPRECATED,
)

glGetNamedBufferParameterivEXT = platform.createExtensionFunction( 
'glGetNamedBufferParameterivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLintArray,),
doc='glGetNamedBufferParameterivEXT(GLuint(buffer), GLenum(pname), GLintArray(params)) -> None',
argNames=('buffer','pname','params',),
deprecated=_DEPRECATED,
)

glGetNamedBufferPointervEXT = platform.createExtensionFunction( 
'glGetNamedBufferPointervEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,ctypes.POINTER(ctypes.c_void_p),),
doc='glGetNamedBufferPointervEXT(GLuint(buffer), GLenum(pname), POINTER(ctypes.c_void_p)(params)) -> None',
argNames=('buffer','pname','params',),
deprecated=_DEPRECATED,
)

glGetNamedBufferSubDataEXT = platform.createExtensionFunction( 
'glGetNamedBufferSubDataEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLintptr,constants.GLsizeiptr,ctypes.c_void_p,),
doc='glGetNamedBufferSubDataEXT(GLuint(buffer), GLintptr(offset), GLsizeiptr(size), c_void_p(data)) -> None',
argNames=('buffer','offset','size','data',),
deprecated=_DEPRECATED,
)

glTextureBufferEXT = platform.createExtensionFunction( 
'glTextureBufferEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLenum,constants.GLuint,),
doc='glTextureBufferEXT(GLuint(texture), GLenum(target), GLenum(internalformat), GLuint(buffer)) -> None',
argNames=('texture','target','internalformat','buffer',),
deprecated=_DEPRECATED,
)

glMultiTexBufferEXT = platform.createExtensionFunction( 
'glMultiTexBufferEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,constants.GLuint,),
doc='glMultiTexBufferEXT(GLenum(texunit), GLenum(target), GLenum(internalformat), GLuint(buffer)) -> None',
argNames=('texunit','target','internalformat','buffer',),
deprecated=_DEPRECATED,
)

glNamedRenderbufferStorageEXT = platform.createExtensionFunction( 
'glNamedRenderbufferStorageEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLsizei,constants.GLsizei,),
doc='glNamedRenderbufferStorageEXT(GLuint(renderbuffer), GLenum(internalformat), GLsizei(width), GLsizei(height)) -> None',
argNames=('renderbuffer','internalformat','width','height',),
deprecated=_DEPRECATED,
)

glGetNamedRenderbufferParameterivEXT = platform.createExtensionFunction( 
'glGetNamedRenderbufferParameterivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLintArray,),
doc='glGetNamedRenderbufferParameterivEXT(GLuint(renderbuffer), GLenum(pname), GLintArray(params)) -> None',
argNames=('renderbuffer','pname','params',),
deprecated=_DEPRECATED,
)

glCheckNamedFramebufferStatusEXT = platform.createExtensionFunction( 
'glCheckNamedFramebufferStatusEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLenum, 
argTypes=(constants.GLuint,constants.GLenum,),
doc='glCheckNamedFramebufferStatusEXT(GLuint(framebuffer), GLenum(target)) -> constants.GLenum',
argNames=('framebuffer','target',),
deprecated=_DEPRECATED,
)

glNamedFramebufferTexture1DEXT = platform.createExtensionFunction( 
'glNamedFramebufferTexture1DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLenum,constants.GLuint,constants.GLint,),
doc='glNamedFramebufferTexture1DEXT(GLuint(framebuffer), GLenum(attachment), GLenum(textarget), GLuint(texture), GLint(level)) -> None',
argNames=('framebuffer','attachment','textarget','texture','level',),
deprecated=_DEPRECATED,
)

glNamedFramebufferTexture2DEXT = platform.createExtensionFunction( 
'glNamedFramebufferTexture2DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLenum,constants.GLuint,constants.GLint,),
doc='glNamedFramebufferTexture2DEXT(GLuint(framebuffer), GLenum(attachment), GLenum(textarget), GLuint(texture), GLint(level)) -> None',
argNames=('framebuffer','attachment','textarget','texture','level',),
deprecated=_DEPRECATED,
)

glNamedFramebufferTexture3DEXT = platform.createExtensionFunction( 
'glNamedFramebufferTexture3DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLenum,constants.GLuint,constants.GLint,constants.GLint,),
doc='glNamedFramebufferTexture3DEXT(GLuint(framebuffer), GLenum(attachment), GLenum(textarget), GLuint(texture), GLint(level), GLint(zoffset)) -> None',
argNames=('framebuffer','attachment','textarget','texture','level','zoffset',),
deprecated=_DEPRECATED,
)

glNamedFramebufferRenderbufferEXT = platform.createExtensionFunction( 
'glNamedFramebufferRenderbufferEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLenum,constants.GLuint,),
doc='glNamedFramebufferRenderbufferEXT(GLuint(framebuffer), GLenum(attachment), GLenum(renderbuffertarget), GLuint(renderbuffer)) -> None',
argNames=('framebuffer','attachment','renderbuffertarget','renderbuffer',),
deprecated=_DEPRECATED,
)

glGetNamedFramebufferAttachmentParameterivEXT = platform.createExtensionFunction( 
'glGetNamedFramebufferAttachmentParameterivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glGetNamedFramebufferAttachmentParameterivEXT(GLuint(framebuffer), GLenum(attachment), GLenum(pname), GLintArray(params)) -> None',
argNames=('framebuffer','attachment','pname','params',),
deprecated=_DEPRECATED,
)

glGenerateTextureMipmapEXT = platform.createExtensionFunction( 
'glGenerateTextureMipmapEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,),
doc='glGenerateTextureMipmapEXT(GLuint(texture), GLenum(target)) -> None',
argNames=('texture','target',),
deprecated=_DEPRECATED,
)

glGenerateMultiTexMipmapEXT = platform.createExtensionFunction( 
'glGenerateMultiTexMipmapEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,),
doc='glGenerateMultiTexMipmapEXT(GLenum(texunit), GLenum(target)) -> None',
argNames=('texunit','target',),
deprecated=_DEPRECATED,
)

glFramebufferDrawBufferEXT = platform.createExtensionFunction( 
'glFramebufferDrawBufferEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,),
doc='glFramebufferDrawBufferEXT(GLuint(framebuffer), GLenum(mode)) -> None',
argNames=('framebuffer','mode',),
deprecated=_DEPRECATED,
)

glFramebufferDrawBuffersEXT = platform.createExtensionFunction( 
'glFramebufferDrawBuffersEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLsizei,arrays.GLuintArray,),
doc='glFramebufferDrawBuffersEXT(GLuint(framebuffer), GLsizei(n), GLuintArray(bufs)) -> None',
argNames=('framebuffer','n','bufs',),
deprecated=_DEPRECATED,
)

glFramebufferReadBufferEXT = platform.createExtensionFunction( 
'glFramebufferReadBufferEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,),
doc='glFramebufferReadBufferEXT(GLuint(framebuffer), GLenum(mode)) -> None',
argNames=('framebuffer','mode',),
deprecated=_DEPRECATED,
)

glGetFramebufferParameterivEXT = platform.createExtensionFunction( 
'glGetFramebufferParameterivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLintArray,),
doc='glGetFramebufferParameterivEXT(GLuint(framebuffer), GLenum(pname), GLintArray(params)) -> None',
argNames=('framebuffer','pname','params',),
deprecated=_DEPRECATED,
)

glNamedRenderbufferStorageMultisampleEXT = platform.createExtensionFunction( 
'glNamedRenderbufferStorageMultisampleEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLsizei,constants.GLenum,constants.GLsizei,constants.GLsizei,),
doc='glNamedRenderbufferStorageMultisampleEXT(GLuint(renderbuffer), GLsizei(samples), GLenum(internalformat), GLsizei(width), GLsizei(height)) -> None',
argNames=('renderbuffer','samples','internalformat','width','height',),
deprecated=_DEPRECATED,
)

glNamedRenderbufferStorageMultisampleCoverageEXT = platform.createExtensionFunction( 
'glNamedRenderbufferStorageMultisampleCoverageEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLsizei,constants.GLsizei,constants.GLenum,constants.GLsizei,constants.GLsizei,),
doc='glNamedRenderbufferStorageMultisampleCoverageEXT(GLuint(renderbuffer), GLsizei(coverageSamples), GLsizei(colorSamples), GLenum(internalformat), GLsizei(width), GLsizei(height)) -> None',
argNames=('renderbuffer','coverageSamples','colorSamples','internalformat','width','height',),
deprecated=_DEPRECATED,
)

glNamedFramebufferTextureEXT = platform.createExtensionFunction( 
'glNamedFramebufferTextureEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLuint,constants.GLint,),
doc='glNamedFramebufferTextureEXT(GLuint(framebuffer), GLenum(attachment), GLuint(texture), GLint(level)) -> None',
argNames=('framebuffer','attachment','texture','level',),
deprecated=_DEPRECATED,
)

glNamedFramebufferTextureLayerEXT = platform.createExtensionFunction( 
'glNamedFramebufferTextureLayerEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLuint,constants.GLint,constants.GLint,),
doc='glNamedFramebufferTextureLayerEXT(GLuint(framebuffer), GLenum(attachment), GLuint(texture), GLint(level), GLint(layer)) -> None',
argNames=('framebuffer','attachment','texture','level','layer',),
deprecated=_DEPRECATED,
)

glNamedFramebufferTextureFaceEXT = platform.createExtensionFunction( 
'glNamedFramebufferTextureFaceEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLuint,constants.GLint,constants.GLenum,),
doc='glNamedFramebufferTextureFaceEXT(GLuint(framebuffer), GLenum(attachment), GLuint(texture), GLint(level), GLenum(face)) -> None',
argNames=('framebuffer','attachment','texture','level','face',),
deprecated=_DEPRECATED,
)

glTextureRenderbufferEXT = platform.createExtensionFunction( 
'glTextureRenderbufferEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLuint,),
doc='glTextureRenderbufferEXT(GLuint(texture), GLenum(target), GLuint(renderbuffer)) -> None',
argNames=('texture','target','renderbuffer',),
deprecated=_DEPRECATED,
)

glMultiTexRenderbufferEXT = platform.createExtensionFunction( 
'glMultiTexRenderbufferEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLuint,),
doc='glMultiTexRenderbufferEXT(GLenum(texunit), GLenum(target), GLuint(renderbuffer)) -> None',
argNames=('texunit','target','renderbuffer',),
deprecated=_DEPRECATED,
)


def glInitDirectStateAccessEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
