'''OpenGL extension NV.copy_image

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_copy_image'
_DEPRECATED = False

glCopyImageSubDataNV = platform.createExtensionFunction( 
'glCopyImageSubDataNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLuint,constants.GLenum,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLsizei,constants.GLsizei,constants.GLsizei,),
doc='glCopyImageSubDataNV(GLuint(srcName), GLenum(srcTarget), GLint(srcLevel), GLint(srcX), GLint(srcY), GLint(srcZ), GLuint(dstName), GLenum(dstTarget), GLint(dstLevel), GLint(dstX), GLint(dstY), GLint(dstZ), GLsizei(width), GLsizei(height), GLsizei(depth)) -> None',
argNames=('srcName','srcTarget','srcLevel','srcX','srcY','srcZ','dstName','dstTarget','dstLevel','dstX','dstY','dstZ','width','height','depth',),
deprecated=_DEPRECATED,
)


def glInitCopyImageNV():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
