'''OpenGL extension EXT.index_material

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_index_material'
_DEPRECATED = False
GL_INDEX_MATERIAL_EXT = constant.Constant( 'GL_INDEX_MATERIAL_EXT', 0x81B8 )
GL_INDEX_MATERIAL_PARAMETER_EXT = constant.Constant( 'GL_INDEX_MATERIAL_PARAMETER_EXT', 0x81B9 )
GL_INDEX_MATERIAL_FACE_EXT = constant.Constant( 'GL_INDEX_MATERIAL_FACE_EXT', 0x81BA )
glIndexMaterialEXT = platform.createExtensionFunction( 
'glIndexMaterialEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,),
doc='glIndexMaterialEXT(GLenum(face), GLenum(mode)) -> None',
argNames=('face','mode',),
deprecated=_DEPRECATED,
)


def glInitIndexMaterialEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
