"""Constants for OpenGL.GL

Automatically generated by the generateraw script, do not edit!
"""

from ctypes import *
from OpenGL import platform, arrays
from OpenGL.constant import Constant
from OpenGL import constants as GLconstants
GLvoid = GLconstants.GLvoid

from OpenGL.constants import GL_BYTE
from OpenGL.constants import GL_DOUBLE
from OpenGL.constants import GL_FALSE
from OpenGL.constants import GL_FLOAT
from OpenGL.constants import GL_INT
from OpenGL.constants import GL_SHORT
from OpenGL.constants import GL_TRUE
from OpenGL.constants import GL_UNSIGNED_BYTE
from OpenGL.constants import GL_UNSIGNED_INT
from OpenGL.constants import GL_UNSIGNED_SHORT


GL_1PASS_EXT = Constant( 'GL_1PASS_EXT', 32929)
GL_1PASS_SGIS = Constant( 'GL_1PASS_SGIS', 32929)
GL_2D = Constant( 'GL_2D', 1536)
GL_2PASS_0_EXT = Constant( 'GL_2PASS_0_EXT', 32930)
GL_2PASS_0_SGIS = Constant( 'GL_2PASS_0_SGIS', 32930)
GL_2PASS_1_EXT = Constant( 'GL_2PASS_1_EXT', 32931)
GL_2PASS_1_SGIS = Constant( 'GL_2PASS_1_SGIS', 32931)
GL_2X_BIT_ATI = Constant( 'GL_2X_BIT_ATI', 1)
GL_2_BYTES = Constant( 'GL_2_BYTES', 5127)
GL_3D = Constant( 'GL_3D', 1537)
GL_3D_COLOR = Constant( 'GL_3D_COLOR', 1538)
GL_3D_COLOR_TEXTURE = Constant( 'GL_3D_COLOR_TEXTURE', 1539)
GL_3_BYTES = Constant( 'GL_3_BYTES', 5128)
GL_422_AVERAGE_EXT = Constant( 'GL_422_AVERAGE_EXT', 32974)
GL_422_EXT = Constant( 'GL_422_EXT', 32972)
GL_422_REV_AVERAGE_EXT = Constant( 'GL_422_REV_AVERAGE_EXT', 32975)
GL_422_REV_EXT = Constant( 'GL_422_REV_EXT', 32973)
GL_4D_COLOR_TEXTURE = Constant( 'GL_4D_COLOR_TEXTURE', 1540)
GL_4PASS_0_EXT = Constant( 'GL_4PASS_0_EXT', 32932)
GL_4PASS_0_SGIS = Constant( 'GL_4PASS_0_SGIS', 32932)
GL_4PASS_1_EXT = Constant( 'GL_4PASS_1_EXT', 32933)
GL_4PASS_1_SGIS = Constant( 'GL_4PASS_1_SGIS', 32933)
GL_4PASS_2_EXT = Constant( 'GL_4PASS_2_EXT', 32934)
GL_4PASS_2_SGIS = Constant( 'GL_4PASS_2_SGIS', 32934)
GL_4PASS_3_EXT = Constant( 'GL_4PASS_3_EXT', 32935)
GL_4PASS_3_SGIS = Constant( 'GL_4PASS_3_SGIS', 32935)
GL_4X_BIT_ATI = Constant( 'GL_4X_BIT_ATI', 2)
GL_4_BYTES = Constant( 'GL_4_BYTES', 5129)
GL_8X_BIT_ATI = Constant( 'GL_8X_BIT_ATI', 4)
GL_ABGR_EXT = Constant( 'GL_ABGR_EXT', 32768)
GL_ACCUM = Constant( 'GL_ACCUM', 256)
GL_ACCUM_ALPHA_BITS = Constant( 'GL_ACCUM_ALPHA_BITS', 3419)
GL_ACCUM_BLUE_BITS = Constant( 'GL_ACCUM_BLUE_BITS', 3418)
GL_ACCUM_BUFFER_BIT = Constant( 'GL_ACCUM_BUFFER_BIT', 512)
GL_ACCUM_CLEAR_VALUE = Constant( 'GL_ACCUM_CLEAR_VALUE', 2944)
GL_ACCUM_GREEN_BITS = Constant( 'GL_ACCUM_GREEN_BITS', 3417)
GL_ACCUM_RED_BITS = Constant( 'GL_ACCUM_RED_BITS', 3416)
GL_ACTIVE_ATTRIBUTES = Constant( 'GL_ACTIVE_ATTRIBUTES', 35721)
GL_ACTIVE_ATTRIBUTE_MAX_LENGTH = Constant( 'GL_ACTIVE_ATTRIBUTE_MAX_LENGTH', 35722)
GL_ACTIVE_STENCIL_FACE_EXT = Constant( 'GL_ACTIVE_STENCIL_FACE_EXT', 35089)
GL_ACTIVE_TEXTURE = Constant( 'GL_ACTIVE_TEXTURE', 34016)
GL_ACTIVE_TEXTURE_ARB = Constant( 'GL_ACTIVE_TEXTURE_ARB', 34016)
GL_ACTIVE_UNIFORMS = Constant( 'GL_ACTIVE_UNIFORMS', 35718)
GL_ACTIVE_UNIFORM_MAX_LENGTH = Constant( 'GL_ACTIVE_UNIFORM_MAX_LENGTH', 35719)
GL_ACTIVE_VERTEX_UNITS_ARB = Constant( 'GL_ACTIVE_VERTEX_UNITS_ARB', 34469)
GL_ADD = Constant( 'GL_ADD', 260)
GL_ADD_ATI = Constant( 'GL_ADD_ATI', 35171)
GL_ADD_SIGNED = Constant( 'GL_ADD_SIGNED', 34164)
GL_ADD_SIGNED_ARB = Constant( 'GL_ADD_SIGNED_ARB', 34164)
GL_ADD_SIGNED_EXT = Constant( 'GL_ADD_SIGNED_EXT', 34164)
GL_ALIASED_LINE_WIDTH_RANGE = Constant( 'GL_ALIASED_LINE_WIDTH_RANGE', 33902)
GL_ALIASED_POINT_SIZE_RANGE = Constant( 'GL_ALIASED_POINT_SIZE_RANGE', 33901)
GL_ALLOW_DRAW_FRG_HINT_PGI = Constant( 'GL_ALLOW_DRAW_FRG_HINT_PGI', 107024)
GL_ALLOW_DRAW_MEM_HINT_PGI = Constant( 'GL_ALLOW_DRAW_MEM_HINT_PGI', 107025)
GL_ALLOW_DRAW_OBJ_HINT_PGI = Constant( 'GL_ALLOW_DRAW_OBJ_HINT_PGI', 107022)
GL_ALLOW_DRAW_WIN_HINT_PGI = Constant( 'GL_ALLOW_DRAW_WIN_HINT_PGI', 107023)
GL_ALL_ATTRIB_BITS = Constant( 'GL_ALL_ATTRIB_BITS', 0xfffff )
GL_ALL_COMPLETED_NV = Constant( 'GL_ALL_COMPLETED_NV', 34034)
GL_ALPHA = Constant( 'GL_ALPHA', 6406)
GL_ALPHA12 = Constant( 'GL_ALPHA12', 32829)
GL_ALPHA12_EXT = Constant( 'GL_ALPHA12_EXT', 32829)
GL_ALPHA16 = Constant( 'GL_ALPHA16', 32830)
GL_ALPHA16F_ARB = Constant( 'GL_ALPHA16F_ARB', 34844)
GL_ALPHA16_EXT = Constant( 'GL_ALPHA16_EXT', 32830)
GL_ALPHA32F_ARB = Constant( 'GL_ALPHA32F_ARB', 34838)
GL_ALPHA4 = Constant( 'GL_ALPHA4', 32827)
GL_ALPHA4_EXT = Constant( 'GL_ALPHA4_EXT', 32827)
GL_ALPHA8 = Constant( 'GL_ALPHA8', 32828)
GL_ALPHA8_EXT = Constant( 'GL_ALPHA8_EXT', 32828)
GL_ALPHA_BIAS = Constant( 'GL_ALPHA_BIAS', 3357)
GL_ALPHA_BITS = Constant( 'GL_ALPHA_BITS', 3413)
GL_ALPHA_FLOAT16_ATI = Constant( 'GL_ALPHA_FLOAT16_ATI', 34844)
GL_ALPHA_FLOAT32_ATI = Constant( 'GL_ALPHA_FLOAT32_ATI', 34838)
GL_ALPHA_MAX_CLAMP_INGR = Constant( 'GL_ALPHA_MAX_CLAMP_INGR', 34151)
GL_ALPHA_MAX_SGIX = Constant( 'GL_ALPHA_MAX_SGIX', 33569)
GL_ALPHA_MIN_CLAMP_INGR = Constant( 'GL_ALPHA_MIN_CLAMP_INGR', 34147)
GL_ALPHA_MIN_SGIX = Constant( 'GL_ALPHA_MIN_SGIX', 33568)
GL_ALPHA_SCALE = Constant( 'GL_ALPHA_SCALE', 3356)
GL_ALPHA_TEST = Constant( 'GL_ALPHA_TEST', 3008)
GL_ALPHA_TEST_FUNC = Constant( 'GL_ALPHA_TEST_FUNC', 3009)
GL_ALPHA_TEST_REF = Constant( 'GL_ALPHA_TEST_REF', 3010)
GL_ALWAYS = Constant( 'GL_ALWAYS', 519)
GL_ALWAYS_FAST_HINT_PGI = Constant( 'GL_ALWAYS_FAST_HINT_PGI', 107020)
GL_ALWAYS_SOFT_HINT_PGI = Constant( 'GL_ALWAYS_SOFT_HINT_PGI', 107021)
GL_AMBIENT = Constant( 'GL_AMBIENT', 4608)
GL_AMBIENT_AND_DIFFUSE = Constant( 'GL_AMBIENT_AND_DIFFUSE', 5634)
GL_AND = Constant( 'GL_AND', 5377)
GL_AND_INVERTED = Constant( 'GL_AND_INVERTED', 5380)
GL_AND_REVERSE = Constant( 'GL_AND_REVERSE', 5378)
GL_ARRAY_BUFFER = Constant( 'GL_ARRAY_BUFFER', 34962)
GL_ARRAY_BUFFER_ARB = Constant( 'GL_ARRAY_BUFFER_ARB', 34962)
GL_ARRAY_BUFFER_BINDING = Constant( 'GL_ARRAY_BUFFER_BINDING', 34964)
GL_ARRAY_BUFFER_BINDING_ARB = Constant( 'GL_ARRAY_BUFFER_BINDING_ARB', 34964)
GL_ARRAY_ELEMENT_LOCK_COUNT_EXT = Constant( 'GL_ARRAY_ELEMENT_LOCK_COUNT_EXT', 33193)
GL_ARRAY_ELEMENT_LOCK_FIRST_EXT = Constant( 'GL_ARRAY_ELEMENT_LOCK_FIRST_EXT', 33192)
GL_ARRAY_OBJECT_BUFFER_ATI = Constant( 'GL_ARRAY_OBJECT_BUFFER_ATI', 34662)
GL_ARRAY_OBJECT_OFFSET_ATI = Constant( 'GL_ARRAY_OBJECT_OFFSET_ATI', 34663)
GL_ASYNC_DRAW_PIXELS_SGIX = Constant( 'GL_ASYNC_DRAW_PIXELS_SGIX', 33629)
GL_ASYNC_HISTOGRAM_SGIX = Constant( 'GL_ASYNC_HISTOGRAM_SGIX', 33580)
GL_ASYNC_MARKER_SGIX = Constant( 'GL_ASYNC_MARKER_SGIX', 33577)
GL_ASYNC_READ_PIXELS_SGIX = Constant( 'GL_ASYNC_READ_PIXELS_SGIX', 33630)
GL_ASYNC_TEX_IMAGE_SGIX = Constant( 'GL_ASYNC_TEX_IMAGE_SGIX', 33628)
GL_ATTACHED_SHADERS = Constant( 'GL_ATTACHED_SHADERS', 35717)
GL_ATTENUATION_EXT = Constant( 'GL_ATTENUATION_EXT', 33613)
GL_ATTRIB_ARRAY_POINTER_NV = Constant( 'GL_ATTRIB_ARRAY_POINTER_NV', 34373)
GL_ATTRIB_ARRAY_SIZE_NV = Constant( 'GL_ATTRIB_ARRAY_SIZE_NV', 34339)
GL_ATTRIB_ARRAY_STRIDE_NV = Constant( 'GL_ATTRIB_ARRAY_STRIDE_NV', 34340)
GL_ATTRIB_ARRAY_TYPE_NV = Constant( 'GL_ATTRIB_ARRAY_TYPE_NV', 34341)
GL_ATTRIB_STACK_DEPTH = Constant( 'GL_ATTRIB_STACK_DEPTH', 2992)
GL_AUTO_NORMAL = Constant( 'GL_AUTO_NORMAL', 3456)
GL_AUX0 = Constant( 'GL_AUX0', 1033)
GL_AUX1 = Constant( 'GL_AUX1', 1034)
GL_AUX2 = Constant( 'GL_AUX2', 1035)
GL_AUX3 = Constant( 'GL_AUX3', 1036)
GL_AUX_BUFFERS = Constant( 'GL_AUX_BUFFERS', 3072)
GL_AVERAGE_EXT = Constant( 'GL_AVERAGE_EXT', 33589)
GL_AVERAGE_HP = Constant( 'GL_AVERAGE_HP', 33120)
GL_BACK = Constant( 'GL_BACK', 1029)
GL_BACK_LEFT = Constant( 'GL_BACK_LEFT', 1026)
GL_BACK_NORMALS_HINT_PGI = Constant( 'GL_BACK_NORMALS_HINT_PGI', 107043)
GL_BACK_RIGHT = Constant( 'GL_BACK_RIGHT', 1027)
GL_BGR = Constant( 'GL_BGR', 32992)
GL_BGRA = Constant( 'GL_BGRA', 32993)
GL_BGRA_EXT = Constant( 'GL_BGRA_EXT', 32993)
GL_BGR_EXT = Constant( 'GL_BGR_EXT', 32992)
GL_BIAS_BIT_ATI = Constant( 'GL_BIAS_BIT_ATI', 8)
GL_BIAS_BY_NEGATIVE_ONE_HALF_NV = Constant( 'GL_BIAS_BY_NEGATIVE_ONE_HALF_NV', 34113)
GL_BINORMAL_ARRAY_EXT = Constant( 'GL_BINORMAL_ARRAY_EXT', 33850)
GL_BINORMAL_ARRAY_POINTER_EXT = Constant( 'GL_BINORMAL_ARRAY_POINTER_EXT', 33859)
GL_BINORMAL_ARRAY_STRIDE_EXT = Constant( 'GL_BINORMAL_ARRAY_STRIDE_EXT', 33857)
GL_BINORMAL_ARRAY_TYPE_EXT = Constant( 'GL_BINORMAL_ARRAY_TYPE_EXT', 33856)
GL_BITMAP = Constant( 'GL_BITMAP', 6656)
GL_BITMAP_TOKEN = Constant( 'GL_BITMAP_TOKEN', 1796)
GL_BLEND = Constant( 'GL_BLEND', 3042)
GL_BLEND_COLOR = Constant( 'GL_BLEND_COLOR', 32773)
GL_BLEND_COLOR_EXT = Constant( 'GL_BLEND_COLOR_EXT', 32773)
GL_BLEND_DST = Constant( 'GL_BLEND_DST', 3040)
GL_BLEND_DST_ALPHA = Constant( 'GL_BLEND_DST_ALPHA', 32970)
GL_BLEND_DST_ALPHA_EXT = Constant( 'GL_BLEND_DST_ALPHA_EXT', 32970)
GL_BLEND_DST_RGB = Constant( 'GL_BLEND_DST_RGB', 32968)
GL_BLEND_DST_RGB_EXT = Constant( 'GL_BLEND_DST_RGB_EXT', 32968)
GL_BLEND_EQUATION = Constant( 'GL_BLEND_EQUATION', 32777)
GL_BLEND_EQUATION_ALPHA = Constant( 'GL_BLEND_EQUATION_ALPHA', 34877)
GL_BLEND_EQUATION_ALPHA_EXT = Constant( 'GL_BLEND_EQUATION_ALPHA_EXT', 34877)
GL_BLEND_EQUATION_EXT = Constant( 'GL_BLEND_EQUATION_EXT', 32777)
GL_BLEND_SRC = Constant( 'GL_BLEND_SRC', 3041)
GL_BLEND_SRC_ALPHA = Constant( 'GL_BLEND_SRC_ALPHA', 32971)
GL_BLEND_SRC_ALPHA_EXT = Constant( 'GL_BLEND_SRC_ALPHA_EXT', 32971)
GL_BLEND_SRC_RGB = Constant( 'GL_BLEND_SRC_RGB', 32969)
GL_BLEND_SRC_RGB_EXT = Constant( 'GL_BLEND_SRC_RGB_EXT', 32969)
GL_BLUE = Constant( 'GL_BLUE', 6405)
GL_BLUE_BIAS = Constant( 'GL_BLUE_BIAS', 3355)
GL_BLUE_BITS = Constant( 'GL_BLUE_BITS', 3412)
GL_BLUE_BIT_ATI = Constant( 'GL_BLUE_BIT_ATI', 4)
GL_BLUE_MAX_CLAMP_INGR = Constant( 'GL_BLUE_MAX_CLAMP_INGR', 34150)
GL_BLUE_MIN_CLAMP_INGR = Constant( 'GL_BLUE_MIN_CLAMP_INGR', 34146)
GL_BLUE_SCALE = Constant( 'GL_BLUE_SCALE', 3354)
GL_BOOL = Constant( 'GL_BOOL', 35670)
GL_BOOL_ARB = Constant( 'GL_BOOL_ARB', 35670)
GL_BOOL_VEC2 = Constant( 'GL_BOOL_VEC2', 35671)
GL_BOOL_VEC2_ARB = Constant( 'GL_BOOL_VEC2_ARB', 35671)
GL_BOOL_VEC3 = Constant( 'GL_BOOL_VEC3', 35672)
GL_BOOL_VEC3_ARB = Constant( 'GL_BOOL_VEC3_ARB', 35672)
GL_BOOL_VEC4 = Constant( 'GL_BOOL_VEC4', 35673)
GL_BOOL_VEC4_ARB = Constant( 'GL_BOOL_VEC4_ARB', 35673)
GL_BUFFER_ACCESS = Constant( 'GL_BUFFER_ACCESS', 35003)
GL_BUFFER_ACCESS_ARB = Constant( 'GL_BUFFER_ACCESS_ARB', 35003)
GL_BUFFER_MAPPED = Constant( 'GL_BUFFER_MAPPED', 35004)
GL_BUFFER_MAPPED_ARB = Constant( 'GL_BUFFER_MAPPED_ARB', 35004)
GL_BUFFER_MAP_POINTER = Constant( 'GL_BUFFER_MAP_POINTER', 35005)
GL_BUFFER_MAP_POINTER_ARB = Constant( 'GL_BUFFER_MAP_POINTER_ARB', 35005)
GL_BUFFER_SIZE = Constant( 'GL_BUFFER_SIZE', 34660)
GL_BUFFER_SIZE_ARB = Constant( 'GL_BUFFER_SIZE_ARB', 34660)
GL_BUFFER_USAGE = Constant( 'GL_BUFFER_USAGE', 34661)
GL_BUFFER_USAGE_ARB = Constant( 'GL_BUFFER_USAGE_ARB', 34661)
GL_BUMP_ENVMAP_ATI = Constant( 'GL_BUMP_ENVMAP_ATI', 34683)
GL_BUMP_NUM_TEX_UNITS_ATI = Constant( 'GL_BUMP_NUM_TEX_UNITS_ATI', 34679)
GL_BUMP_ROT_MATRIX_ATI = Constant( 'GL_BUMP_ROT_MATRIX_ATI', 34677)
GL_BUMP_ROT_MATRIX_SIZE_ATI = Constant( 'GL_BUMP_ROT_MATRIX_SIZE_ATI', 34678)
GL_BUMP_TARGET_ATI = Constant( 'GL_BUMP_TARGET_ATI', 34684)
GL_BUMP_TEX_UNITS_ATI = Constant( 'GL_BUMP_TEX_UNITS_ATI', 34680)
GL_C3F_V3F = Constant( 'GL_C3F_V3F', 10788)
GL_C4F_N3F_V3F = Constant( 'GL_C4F_N3F_V3F', 10790)
GL_C4UB_V2F = Constant( 'GL_C4UB_V2F', 10786)
GL_C4UB_V3F = Constant( 'GL_C4UB_V3F', 10787)
GL_CALLIGRAPHIC_FRAGMENT_SGIX = Constant( 'GL_CALLIGRAPHIC_FRAGMENT_SGIX', 33155)
GL_CCW = Constant( 'GL_CCW', 2305)
GL_CLAMP = Constant( 'GL_CLAMP', 10496)
GL_CLAMP_FRAGMENT_COLOR_ARB = Constant( 'GL_CLAMP_FRAGMENT_COLOR_ARB', 35099)
GL_CLAMP_READ_COLOR_ARB = Constant( 'GL_CLAMP_READ_COLOR_ARB', 35100)
GL_CLAMP_TO_BORDER = Constant( 'GL_CLAMP_TO_BORDER', 33069)
GL_CLAMP_TO_BORDER_ARB = Constant( 'GL_CLAMP_TO_BORDER_ARB', 33069)
GL_CLAMP_TO_BORDER_SGIS = Constant( 'GL_CLAMP_TO_BORDER_SGIS', 33069)
GL_CLAMP_TO_EDGE = Constant( 'GL_CLAMP_TO_EDGE', 33071)
GL_CLAMP_TO_EDGE_SGIS = Constant( 'GL_CLAMP_TO_EDGE_SGIS', 33071)
GL_CLAMP_VERTEX_COLOR_ARB = Constant( 'GL_CLAMP_VERTEX_COLOR_ARB', 35098)
GL_CLEAR = Constant( 'GL_CLEAR', 5376)
GL_CLIENT_ACTIVE_TEXTURE = Constant( 'GL_CLIENT_ACTIVE_TEXTURE', 34017)
GL_CLIENT_ACTIVE_TEXTURE_ARB = Constant( 'GL_CLIENT_ACTIVE_TEXTURE_ARB', 34017)
GL_CLIENT_ALL_ATTRIB_BITS = Constant( 'GL_CLIENT_ALL_ATTRIB_BITS', 4294967295)
GL_CLIENT_ATTRIB_STACK_DEPTH = Constant( 'GL_CLIENT_ATTRIB_STACK_DEPTH', 2993)
GL_CLIENT_PIXEL_STORE_BIT = Constant( 'GL_CLIENT_PIXEL_STORE_BIT', 1)
GL_CLIENT_VERTEX_ARRAY_BIT = Constant( 'GL_CLIENT_VERTEX_ARRAY_BIT', 2)
GL_CLIP_FAR_HINT_PGI = Constant( 'GL_CLIP_FAR_HINT_PGI', 107041)
GL_CLIP_NEAR_HINT_PGI = Constant( 'GL_CLIP_NEAR_HINT_PGI', 107040)
GL_CLIP_PLANE0 = Constant( 'GL_CLIP_PLANE0', 12288)
GL_CLIP_PLANE1 = Constant( 'GL_CLIP_PLANE1', 12289)
GL_CLIP_PLANE2 = Constant( 'GL_CLIP_PLANE2', 12290)
GL_CLIP_PLANE3 = Constant( 'GL_CLIP_PLANE3', 12291)
GL_CLIP_PLANE4 = Constant( 'GL_CLIP_PLANE4', 12292)
GL_CLIP_PLANE5 = Constant( 'GL_CLIP_PLANE5', 12293)
GL_CLIP_VOLUME_CLIPPING_HINT_EXT = Constant( 'GL_CLIP_VOLUME_CLIPPING_HINT_EXT', 33008)
GL_CMYKA_EXT = Constant( 'GL_CMYKA_EXT', 32781)
GL_CMYK_EXT = Constant( 'GL_CMYK_EXT', 32780)
GL_CND0_ATI = Constant( 'GL_CND0_ATI', 35179)
GL_CND_ATI = Constant( 'GL_CND_ATI', 35178)
GL_COEFF = Constant( 'GL_COEFF', 2560)
GL_COLOR = Constant( 'GL_COLOR', 6144)
GL_COLOR3_BIT_PGI = Constant( 'GL_COLOR3_BIT_PGI', 65536)
GL_COLOR4_BIT_PGI = Constant( 'GL_COLOR4_BIT_PGI', 131072)
GL_COLOR_ALPHA_PAIRING_ATI = Constant( 'GL_COLOR_ALPHA_PAIRING_ATI', 35189)
GL_COLOR_ARRAY = Constant( 'GL_COLOR_ARRAY', 32886)
GL_COLOR_ARRAY_BUFFER_BINDING = Constant( 'GL_COLOR_ARRAY_BUFFER_BINDING', 34968)
GL_COLOR_ARRAY_BUFFER_BINDING_ARB = Constant( 'GL_COLOR_ARRAY_BUFFER_BINDING_ARB', 34968)
GL_COLOR_ARRAY_COUNT_EXT = Constant( 'GL_COLOR_ARRAY_COUNT_EXT', 32900)
GL_COLOR_ARRAY_EXT = Constant( 'GL_COLOR_ARRAY_EXT', 32886)
GL_COLOR_ARRAY_LIST_IBM = Constant( 'GL_COLOR_ARRAY_LIST_IBM', 103072)
GL_COLOR_ARRAY_LIST_STRIDE_IBM = Constant( 'GL_COLOR_ARRAY_LIST_STRIDE_IBM', 103082)
GL_COLOR_ARRAY_PARALLEL_POINTERS_INTEL = Constant( 'GL_COLOR_ARRAY_PARALLEL_POINTERS_INTEL', 33783)
GL_COLOR_ARRAY_POINTER = Constant( 'GL_COLOR_ARRAY_POINTER', 32912)
GL_COLOR_ARRAY_POINTER_EXT = Constant( 'GL_COLOR_ARRAY_POINTER_EXT', 32912)
GL_COLOR_ARRAY_SIZE = Constant( 'GL_COLOR_ARRAY_SIZE', 32897)
GL_COLOR_ARRAY_SIZE_EXT = Constant( 'GL_COLOR_ARRAY_SIZE_EXT', 32897)
GL_COLOR_ARRAY_STRIDE = Constant( 'GL_COLOR_ARRAY_STRIDE', 32899)
GL_COLOR_ARRAY_STRIDE_EXT = Constant( 'GL_COLOR_ARRAY_STRIDE_EXT', 32899)
GL_COLOR_ARRAY_TYPE = Constant( 'GL_COLOR_ARRAY_TYPE', 32898)
GL_COLOR_ARRAY_TYPE_EXT = Constant( 'GL_COLOR_ARRAY_TYPE_EXT', 32898)
GL_COLOR_ATTACHMENT0_EXT = Constant( 'GL_COLOR_ATTACHMENT0_EXT', 36064)
GL_COLOR_ATTACHMENT10_EXT = Constant( 'GL_COLOR_ATTACHMENT10_EXT', 36074)
GL_COLOR_ATTACHMENT11_EXT = Constant( 'GL_COLOR_ATTACHMENT11_EXT', 36075)
GL_COLOR_ATTACHMENT12_EXT = Constant( 'GL_COLOR_ATTACHMENT12_EXT', 36076)
GL_COLOR_ATTACHMENT13_EXT = Constant( 'GL_COLOR_ATTACHMENT13_EXT', 36077)
GL_COLOR_ATTACHMENT14_EXT = Constant( 'GL_COLOR_ATTACHMENT14_EXT', 36078)
GL_COLOR_ATTACHMENT15_EXT = Constant( 'GL_COLOR_ATTACHMENT15_EXT', 36079)
GL_COLOR_ATTACHMENT1_EXT = Constant( 'GL_COLOR_ATTACHMENT1_EXT', 36065)
GL_COLOR_ATTACHMENT2_EXT = Constant( 'GL_COLOR_ATTACHMENT2_EXT', 36066)
GL_COLOR_ATTACHMENT3_EXT = Constant( 'GL_COLOR_ATTACHMENT3_EXT', 36067)
GL_COLOR_ATTACHMENT4_EXT = Constant( 'GL_COLOR_ATTACHMENT4_EXT', 36068)
GL_COLOR_ATTACHMENT5_EXT = Constant( 'GL_COLOR_ATTACHMENT5_EXT', 36069)
GL_COLOR_ATTACHMENT6_EXT = Constant( 'GL_COLOR_ATTACHMENT6_EXT', 36070)
GL_COLOR_ATTACHMENT7_EXT = Constant( 'GL_COLOR_ATTACHMENT7_EXT', 36071)
GL_COLOR_ATTACHMENT8_EXT = Constant( 'GL_COLOR_ATTACHMENT8_EXT', 36072)
GL_COLOR_ATTACHMENT9_EXT = Constant( 'GL_COLOR_ATTACHMENT9_EXT', 36073)
GL_COLOR_BUFFER_BIT = Constant( 'GL_COLOR_BUFFER_BIT', 16384)
GL_COLOR_CLEAR_UNCLAMPED_VALUE_ATI = Constant( 'GL_COLOR_CLEAR_UNCLAMPED_VALUE_ATI', 34869)
GL_COLOR_CLEAR_VALUE = Constant( 'GL_COLOR_CLEAR_VALUE', 3106)
GL_COLOR_INDEX = Constant( 'GL_COLOR_INDEX', 6400)
GL_COLOR_INDEX12_EXT = Constant( 'GL_COLOR_INDEX12_EXT', 32998)
GL_COLOR_INDEX16_EXT = Constant( 'GL_COLOR_INDEX16_EXT', 32999)
GL_COLOR_INDEX1_EXT = Constant( 'GL_COLOR_INDEX1_EXT', 32994)
GL_COLOR_INDEX2_EXT = Constant( 'GL_COLOR_INDEX2_EXT', 32995)
GL_COLOR_INDEX4_EXT = Constant( 'GL_COLOR_INDEX4_EXT', 32996)
GL_COLOR_INDEX8_EXT = Constant( 'GL_COLOR_INDEX8_EXT', 32997)
GL_COLOR_INDEXES = Constant( 'GL_COLOR_INDEXES', 5635)
GL_COLOR_LOGIC_OP = Constant( 'GL_COLOR_LOGIC_OP', 3058)
GL_COLOR_MATERIAL = Constant( 'GL_COLOR_MATERIAL', 2903)
GL_COLOR_MATERIAL_FACE = Constant( 'GL_COLOR_MATERIAL_FACE', 2901)
GL_COLOR_MATERIAL_PARAMETER = Constant( 'GL_COLOR_MATERIAL_PARAMETER', 2902)
GL_COLOR_MATRIX = Constant( 'GL_COLOR_MATRIX', 32945)
GL_COLOR_MATRIX_SGI = Constant( 'GL_COLOR_MATRIX_SGI', 32945)
GL_COLOR_MATRIX_STACK_DEPTH = Constant( 'GL_COLOR_MATRIX_STACK_DEPTH', 32946)
GL_COLOR_MATRIX_STACK_DEPTH_SGI = Constant( 'GL_COLOR_MATRIX_STACK_DEPTH_SGI', 32946)
GL_COLOR_SUM = Constant( 'GL_COLOR_SUM', 33880)
GL_COLOR_SUM_ARB = Constant( 'GL_COLOR_SUM_ARB', 33880)
GL_COLOR_SUM_CLAMP_NV = Constant( 'GL_COLOR_SUM_CLAMP_NV', 34127)
GL_COLOR_SUM_EXT = Constant( 'GL_COLOR_SUM_EXT', 33880)
GL_COLOR_TABLE = Constant( 'GL_COLOR_TABLE', 32976)
GL_COLOR_TABLE_ALPHA_SIZE = Constant( 'GL_COLOR_TABLE_ALPHA_SIZE', 32989)
GL_COLOR_TABLE_ALPHA_SIZE_SGI = Constant( 'GL_COLOR_TABLE_ALPHA_SIZE_SGI', 32989)
GL_COLOR_TABLE_BIAS = Constant( 'GL_COLOR_TABLE_BIAS', 32983)
GL_COLOR_TABLE_BIAS_SGI = Constant( 'GL_COLOR_TABLE_BIAS_SGI', 32983)
GL_COLOR_TABLE_BLUE_SIZE = Constant( 'GL_COLOR_TABLE_BLUE_SIZE', 32988)
GL_COLOR_TABLE_BLUE_SIZE_SGI = Constant( 'GL_COLOR_TABLE_BLUE_SIZE_SGI', 32988)
GL_COLOR_TABLE_FORMAT = Constant( 'GL_COLOR_TABLE_FORMAT', 32984)
GL_COLOR_TABLE_FORMAT_SGI = Constant( 'GL_COLOR_TABLE_FORMAT_SGI', 32984)
GL_COLOR_TABLE_GREEN_SIZE = Constant( 'GL_COLOR_TABLE_GREEN_SIZE', 32987)
GL_COLOR_TABLE_GREEN_SIZE_SGI = Constant( 'GL_COLOR_TABLE_GREEN_SIZE_SGI', 32987)
GL_COLOR_TABLE_INTENSITY_SIZE = Constant( 'GL_COLOR_TABLE_INTENSITY_SIZE', 32991)
GL_COLOR_TABLE_INTENSITY_SIZE_SGI = Constant( 'GL_COLOR_TABLE_INTENSITY_SIZE_SGI', 32991)
GL_COLOR_TABLE_LUMINANCE_SIZE = Constant( 'GL_COLOR_TABLE_LUMINANCE_SIZE', 32990)
GL_COLOR_TABLE_LUMINANCE_SIZE_SGI = Constant( 'GL_COLOR_TABLE_LUMINANCE_SIZE_SGI', 32990)
GL_COLOR_TABLE_RED_SIZE = Constant( 'GL_COLOR_TABLE_RED_SIZE', 32986)
GL_COLOR_TABLE_RED_SIZE_SGI = Constant( 'GL_COLOR_TABLE_RED_SIZE_SGI', 32986)
GL_COLOR_TABLE_SCALE = Constant( 'GL_COLOR_TABLE_SCALE', 32982)
GL_COLOR_TABLE_SCALE_SGI = Constant( 'GL_COLOR_TABLE_SCALE_SGI', 32982)
GL_COLOR_TABLE_SGI = Constant( 'GL_COLOR_TABLE_SGI', 32976)
GL_COLOR_TABLE_WIDTH = Constant( 'GL_COLOR_TABLE_WIDTH', 32985)
GL_COLOR_TABLE_WIDTH_SGI = Constant( 'GL_COLOR_TABLE_WIDTH_SGI', 32985)
GL_COLOR_WRITEMASK = Constant( 'GL_COLOR_WRITEMASK', 3107)
GL_COMBINE = Constant( 'GL_COMBINE', 34160)
GL_COMBINE4_NV = Constant( 'GL_COMBINE4_NV', 34051)
GL_COMBINER0_NV = Constant( 'GL_COMBINER0_NV', 34128)
GL_COMBINER1_NV = Constant( 'GL_COMBINER1_NV', 34129)
GL_COMBINER2_NV = Constant( 'GL_COMBINER2_NV', 34130)
GL_COMBINER3_NV = Constant( 'GL_COMBINER3_NV', 34131)
GL_COMBINER4_NV = Constant( 'GL_COMBINER4_NV', 34132)
GL_COMBINER5_NV = Constant( 'GL_COMBINER5_NV', 34133)
GL_COMBINER6_NV = Constant( 'GL_COMBINER6_NV', 34134)
GL_COMBINER7_NV = Constant( 'GL_COMBINER7_NV', 34135)
GL_COMBINER_AB_DOT_PRODUCT_NV = Constant( 'GL_COMBINER_AB_DOT_PRODUCT_NV', 34117)
GL_COMBINER_AB_OUTPUT_NV = Constant( 'GL_COMBINER_AB_OUTPUT_NV', 34122)
GL_COMBINER_BIAS_NV = Constant( 'GL_COMBINER_BIAS_NV', 34121)
GL_COMBINER_CD_DOT_PRODUCT_NV = Constant( 'GL_COMBINER_CD_DOT_PRODUCT_NV', 34118)
GL_COMBINER_CD_OUTPUT_NV = Constant( 'GL_COMBINER_CD_OUTPUT_NV', 34123)
GL_COMBINER_COMPONENT_USAGE_NV = Constant( 'GL_COMBINER_COMPONENT_USAGE_NV', 34116)
GL_COMBINER_INPUT_NV = Constant( 'GL_COMBINER_INPUT_NV', 34114)
GL_COMBINER_MAPPING_NV = Constant( 'GL_COMBINER_MAPPING_NV', 34115)
GL_COMBINER_MUX_SUM_NV = Constant( 'GL_COMBINER_MUX_SUM_NV', 34119)
GL_COMBINER_SCALE_NV = Constant( 'GL_COMBINER_SCALE_NV', 34120)
GL_COMBINER_SUM_OUTPUT_NV = Constant( 'GL_COMBINER_SUM_OUTPUT_NV', 34124)
GL_COMBINE_ALPHA = Constant( 'GL_COMBINE_ALPHA', 34162)
GL_COMBINE_ALPHA_ARB = Constant( 'GL_COMBINE_ALPHA_ARB', 34162)
GL_COMBINE_ALPHA_EXT = Constant( 'GL_COMBINE_ALPHA_EXT', 34162)
GL_COMBINE_ARB = Constant( 'GL_COMBINE_ARB', 34160)
GL_COMBINE_EXT = Constant( 'GL_COMBINE_EXT', 34160)
GL_COMBINE_RGB = Constant( 'GL_COMBINE_RGB', 34161)
GL_COMBINE_RGB_ARB = Constant( 'GL_COMBINE_RGB_ARB', 34161)
GL_COMBINE_RGB_EXT = Constant( 'GL_COMBINE_RGB_EXT', 34161)
GL_COMPARE_R_TO_TEXTURE = Constant( 'GL_COMPARE_R_TO_TEXTURE', 34894)
GL_COMPARE_R_TO_TEXTURE_ARB = Constant( 'GL_COMPARE_R_TO_TEXTURE_ARB', 34894)
GL_COMPILE = Constant( 'GL_COMPILE', 4864)
GL_COMPILE_AND_EXECUTE = Constant( 'GL_COMPILE_AND_EXECUTE', 4865)
GL_COMPILE_STATUS = Constant( 'GL_COMPILE_STATUS', 35713)
GL_COMPRESSED_ALPHA = Constant( 'GL_COMPRESSED_ALPHA', 34025)
GL_COMPRESSED_ALPHA_ARB = Constant( 'GL_COMPRESSED_ALPHA_ARB', 34025)
GL_COMPRESSED_INTENSITY = Constant( 'GL_COMPRESSED_INTENSITY', 34028)
GL_COMPRESSED_INTENSITY_ARB = Constant( 'GL_COMPRESSED_INTENSITY_ARB', 34028)
GL_COMPRESSED_LUMINANCE = Constant( 'GL_COMPRESSED_LUMINANCE', 34026)
GL_COMPRESSED_LUMINANCE_ALPHA = Constant( 'GL_COMPRESSED_LUMINANCE_ALPHA', 34027)
GL_COMPRESSED_LUMINANCE_ALPHA_ARB = Constant( 'GL_COMPRESSED_LUMINANCE_ALPHA_ARB', 34027)
GL_COMPRESSED_LUMINANCE_ARB = Constant( 'GL_COMPRESSED_LUMINANCE_ARB', 34026)
GL_COMPRESSED_RGB = Constant( 'GL_COMPRESSED_RGB', 34029)
GL_COMPRESSED_RGBA = Constant( 'GL_COMPRESSED_RGBA', 34030)
GL_COMPRESSED_RGBA_ARB = Constant( 'GL_COMPRESSED_RGBA_ARB', 34030)
GL_COMPRESSED_RGBA_FXT1_3DFX = Constant( 'GL_COMPRESSED_RGBA_FXT1_3DFX', 34481)
GL_COMPRESSED_RGBA_S3TC_DXT1_EXT = Constant( 'GL_COMPRESSED_RGBA_S3TC_DXT1_EXT', 33777)
GL_COMPRESSED_RGBA_S3TC_DXT3_EXT = Constant( 'GL_COMPRESSED_RGBA_S3TC_DXT3_EXT', 33778)
GL_COMPRESSED_RGBA_S3TC_DXT5_EXT = Constant( 'GL_COMPRESSED_RGBA_S3TC_DXT5_EXT', 33779)
GL_COMPRESSED_RGB_ARB = Constant( 'GL_COMPRESSED_RGB_ARB', 34029)
GL_COMPRESSED_RGB_FXT1_3DFX = Constant( 'GL_COMPRESSED_RGB_FXT1_3DFX', 34480)
GL_COMPRESSED_RGB_S3TC_DXT1_EXT = Constant( 'GL_COMPRESSED_RGB_S3TC_DXT1_EXT', 33776)
GL_COMPRESSED_TEXTURE_FORMATS = Constant( 'GL_COMPRESSED_TEXTURE_FORMATS', 34467)
GL_COMPRESSED_TEXTURE_FORMATS_ARB = Constant( 'GL_COMPRESSED_TEXTURE_FORMATS_ARB', 34467)
GL_COMP_BIT_ATI = Constant( 'GL_COMP_BIT_ATI', 2)
GL_CONSERVE_MEMORY_HINT_PGI = Constant( 'GL_CONSERVE_MEMORY_HINT_PGI', 107005)
GL_CONSTANT = Constant( 'GL_CONSTANT', 34166)
GL_CONSTANT_ALPHA = Constant( 'GL_CONSTANT_ALPHA', 32771)
GL_CONSTANT_ALPHA_EXT = Constant( 'GL_CONSTANT_ALPHA_EXT', 32771)
GL_CONSTANT_ARB = Constant( 'GL_CONSTANT_ARB', 34166)
GL_CONSTANT_ATTENUATION = Constant( 'GL_CONSTANT_ATTENUATION', 4615)
GL_CONSTANT_BORDER = Constant( 'GL_CONSTANT_BORDER', 33105)
GL_CONSTANT_BORDER_HP = Constant( 'GL_CONSTANT_BORDER_HP', 33105)
GL_CONSTANT_COLOR = Constant( 'GL_CONSTANT_COLOR', 32769)
GL_CONSTANT_COLOR0_NV = Constant( 'GL_CONSTANT_COLOR0_NV', 34090)
GL_CONSTANT_COLOR1_NV = Constant( 'GL_CONSTANT_COLOR1_NV', 34091)
GL_CONSTANT_COLOR_EXT = Constant( 'GL_CONSTANT_COLOR_EXT', 32769)
GL_CONSTANT_EXT = Constant( 'GL_CONSTANT_EXT', 34166)
GL_CONST_EYE_NV = Constant( 'GL_CONST_EYE_NV', 34533)
GL_CONVOLUTION_1D = Constant( 'GL_CONVOLUTION_1D', 32784)
GL_CONVOLUTION_1D_EXT = Constant( 'GL_CONVOLUTION_1D_EXT', 32784)
GL_CONVOLUTION_2D = Constant( 'GL_CONVOLUTION_2D', 32785)
GL_CONVOLUTION_2D_EXT = Constant( 'GL_CONVOLUTION_2D_EXT', 32785)
GL_CONVOLUTION_BORDER_COLOR = Constant( 'GL_CONVOLUTION_BORDER_COLOR', 33108)
GL_CONVOLUTION_BORDER_COLOR_HP = Constant( 'GL_CONVOLUTION_BORDER_COLOR_HP', 33108)
GL_CONVOLUTION_BORDER_MODE = Constant( 'GL_CONVOLUTION_BORDER_MODE', 32787)
GL_CONVOLUTION_BORDER_MODE_EXT = Constant( 'GL_CONVOLUTION_BORDER_MODE_EXT', 32787)
GL_CONVOLUTION_FILTER_BIAS = Constant( 'GL_CONVOLUTION_FILTER_BIAS', 32789)
GL_CONVOLUTION_FILTER_BIAS_EXT = Constant( 'GL_CONVOLUTION_FILTER_BIAS_EXT', 32789)
GL_CONVOLUTION_FILTER_SCALE = Constant( 'GL_CONVOLUTION_FILTER_SCALE', 32788)
GL_CONVOLUTION_FILTER_SCALE_EXT = Constant( 'GL_CONVOLUTION_FILTER_SCALE_EXT', 32788)
GL_CONVOLUTION_FORMAT = Constant( 'GL_CONVOLUTION_FORMAT', 32791)
GL_CONVOLUTION_FORMAT_EXT = Constant( 'GL_CONVOLUTION_FORMAT_EXT', 32791)
GL_CONVOLUTION_HEIGHT = Constant( 'GL_CONVOLUTION_HEIGHT', 32793)
GL_CONVOLUTION_HEIGHT_EXT = Constant( 'GL_CONVOLUTION_HEIGHT_EXT', 32793)
GL_CONVOLUTION_HINT_SGIX = Constant( 'GL_CONVOLUTION_HINT_SGIX', 33558)
GL_CONVOLUTION_WIDTH = Constant( 'GL_CONVOLUTION_WIDTH', 32792)
GL_CONVOLUTION_WIDTH_EXT = Constant( 'GL_CONVOLUTION_WIDTH_EXT', 32792)
GL_CON_0_ATI = Constant( 'GL_CON_0_ATI', 35137)
GL_CON_10_ATI = Constant( 'GL_CON_10_ATI', 35147)
GL_CON_11_ATI = Constant( 'GL_CON_11_ATI', 35148)
GL_CON_12_ATI = Constant( 'GL_CON_12_ATI', 35149)
GL_CON_13_ATI = Constant( 'GL_CON_13_ATI', 35150)
GL_CON_14_ATI = Constant( 'GL_CON_14_ATI', 35151)
GL_CON_15_ATI = Constant( 'GL_CON_15_ATI', 35152)
GL_CON_16_ATI = Constant( 'GL_CON_16_ATI', 35153)
GL_CON_17_ATI = Constant( 'GL_CON_17_ATI', 35154)
GL_CON_18_ATI = Constant( 'GL_CON_18_ATI', 35155)
GL_CON_19_ATI = Constant( 'GL_CON_19_ATI', 35156)
GL_CON_1_ATI = Constant( 'GL_CON_1_ATI', 35138)
GL_CON_20_ATI = Constant( 'GL_CON_20_ATI', 35157)
GL_CON_21_ATI = Constant( 'GL_CON_21_ATI', 35158)
GL_CON_22_ATI = Constant( 'GL_CON_22_ATI', 35159)
GL_CON_23_ATI = Constant( 'GL_CON_23_ATI', 35160)
GL_CON_24_ATI = Constant( 'GL_CON_24_ATI', 35161)
GL_CON_25_ATI = Constant( 'GL_CON_25_ATI', 35162)
GL_CON_26_ATI = Constant( 'GL_CON_26_ATI', 35163)
GL_CON_27_ATI = Constant( 'GL_CON_27_ATI', 35164)
GL_CON_28_ATI = Constant( 'GL_CON_28_ATI', 35165)
GL_CON_29_ATI = Constant( 'GL_CON_29_ATI', 35166)
GL_CON_2_ATI = Constant( 'GL_CON_2_ATI', 35139)
GL_CON_30_ATI = Constant( 'GL_CON_30_ATI', 35167)
GL_CON_31_ATI = Constant( 'GL_CON_31_ATI', 35168)
GL_CON_3_ATI = Constant( 'GL_CON_3_ATI', 35140)
GL_CON_4_ATI = Constant( 'GL_CON_4_ATI', 35141)
GL_CON_5_ATI = Constant( 'GL_CON_5_ATI', 35142)
GL_CON_6_ATI = Constant( 'GL_CON_6_ATI', 35143)
GL_CON_7_ATI = Constant( 'GL_CON_7_ATI', 35144)
GL_CON_8_ATI = Constant( 'GL_CON_8_ATI', 35145)
GL_CON_9_ATI = Constant( 'GL_CON_9_ATI', 35146)
GL_COORD_REPLACE = Constant( 'GL_COORD_REPLACE', 34914)
GL_COORD_REPLACE_ARB = Constant( 'GL_COORD_REPLACE_ARB', 34914)
GL_COORD_REPLACE_NV = Constant( 'GL_COORD_REPLACE_NV', 34914)
GL_COPY = Constant( 'GL_COPY', 5379)
GL_COPY_INVERTED = Constant( 'GL_COPY_INVERTED', 5388)
GL_COPY_PIXEL_TOKEN = Constant( 'GL_COPY_PIXEL_TOKEN', 1798)
GL_CUBIC_EXT = Constant( 'GL_CUBIC_EXT', 33588)
GL_CUBIC_HP = Constant( 'GL_CUBIC_HP', 33119)
GL_CULL_FACE = Constant( 'GL_CULL_FACE', 2884)
GL_CULL_FACE_MODE = Constant( 'GL_CULL_FACE_MODE', 2885)
GL_CULL_FRAGMENT_NV = Constant( 'GL_CULL_FRAGMENT_NV', 34535)
GL_CULL_MODES_NV = Constant( 'GL_CULL_MODES_NV', 34528)
GL_CULL_VERTEX_EXT = Constant( 'GL_CULL_VERTEX_EXT', 33194)
GL_CULL_VERTEX_EYE_POSITION_EXT = Constant( 'GL_CULL_VERTEX_EYE_POSITION_EXT', 33195)
GL_CULL_VERTEX_IBM = Constant( 'GL_CULL_VERTEX_IBM', 103050)
GL_CULL_VERTEX_OBJECT_POSITION_EXT = Constant( 'GL_CULL_VERTEX_OBJECT_POSITION_EXT', 33196)
GL_CURRENT_ATTRIB_NV = Constant( 'GL_CURRENT_ATTRIB_NV', 34342)
GL_CURRENT_BINORMAL_EXT = Constant( 'GL_CURRENT_BINORMAL_EXT', 33852)
GL_CURRENT_BIT = Constant( 'GL_CURRENT_BIT', 1)
GL_CURRENT_COLOR = Constant( 'GL_CURRENT_COLOR', 2816)
GL_CURRENT_FOG_COORDINATE = Constant( 'GL_CURRENT_FOG_COORDINATE', 33875)
GL_CURRENT_FOG_COORDINATE_EXT = Constant( 'GL_CURRENT_FOG_COORDINATE_EXT', 33875)
GL_CURRENT_INDEX = Constant( 'GL_CURRENT_INDEX', 2817)
GL_CURRENT_MATRIX_ARB = Constant( 'GL_CURRENT_MATRIX_ARB', 34369)
GL_CURRENT_MATRIX_INDEX_ARB = Constant( 'GL_CURRENT_MATRIX_INDEX_ARB', 34885)
GL_CURRENT_MATRIX_NV = Constant( 'GL_CURRENT_MATRIX_NV', 34369)
GL_CURRENT_MATRIX_STACK_DEPTH_ARB = Constant( 'GL_CURRENT_MATRIX_STACK_DEPTH_ARB', 34368)
GL_CURRENT_MATRIX_STACK_DEPTH_NV = Constant( 'GL_CURRENT_MATRIX_STACK_DEPTH_NV', 34368)
GL_CURRENT_NORMAL = Constant( 'GL_CURRENT_NORMAL', 2818)
GL_CURRENT_OCCLUSION_QUERY_ID_NV = Constant( 'GL_CURRENT_OCCLUSION_QUERY_ID_NV', 34917)
GL_CURRENT_PALETTE_MATRIX_ARB = Constant( 'GL_CURRENT_PALETTE_MATRIX_ARB', 34883)
GL_CURRENT_PROGRAM = Constant( 'GL_CURRENT_PROGRAM', 35725)
GL_CURRENT_QUERY = Constant( 'GL_CURRENT_QUERY', 34917)
GL_CURRENT_QUERY_ARB = Constant( 'GL_CURRENT_QUERY_ARB', 34917)
GL_CURRENT_RASTER_COLOR = Constant( 'GL_CURRENT_RASTER_COLOR', 2820)
GL_CURRENT_RASTER_DISTANCE = Constant( 'GL_CURRENT_RASTER_DISTANCE', 2825)
GL_CURRENT_RASTER_INDEX = Constant( 'GL_CURRENT_RASTER_INDEX', 2821)
GL_CURRENT_RASTER_NORMAL_SGIX = Constant( 'GL_CURRENT_RASTER_NORMAL_SGIX', 33798)
GL_CURRENT_RASTER_POSITION = Constant( 'GL_CURRENT_RASTER_POSITION', 2823)
GL_CURRENT_RASTER_POSITION_VALID = Constant( 'GL_CURRENT_RASTER_POSITION_VALID', 2824)
GL_CURRENT_RASTER_TEXTURE_COORDS = Constant( 'GL_CURRENT_RASTER_TEXTURE_COORDS', 2822)
GL_CURRENT_SECONDARY_COLOR = Constant( 'GL_CURRENT_SECONDARY_COLOR', 33881)
GL_CURRENT_SECONDARY_COLOR_EXT = Constant( 'GL_CURRENT_SECONDARY_COLOR_EXT', 33881)
GL_CURRENT_TANGENT_EXT = Constant( 'GL_CURRENT_TANGENT_EXT', 33851)
GL_CURRENT_TEXTURE_COORDS = Constant( 'GL_CURRENT_TEXTURE_COORDS', 2819)
GL_CURRENT_VERTEX_ATTRIB = Constant( 'GL_CURRENT_VERTEX_ATTRIB', 34342)
GL_CURRENT_VERTEX_ATTRIB_ARB = Constant( 'GL_CURRENT_VERTEX_ATTRIB_ARB', 34342)
GL_CURRENT_VERTEX_EXT = Constant( 'GL_CURRENT_VERTEX_EXT', 34786)
GL_CURRENT_VERTEX_WEIGHT_EXT = Constant( 'GL_CURRENT_VERTEX_WEIGHT_EXT', 34059)
GL_CURRENT_WEIGHT_ARB = Constant( 'GL_CURRENT_WEIGHT_ARB', 34472)
GL_CW = Constant( 'GL_CW', 2304)
GL_DECAL = Constant( 'GL_DECAL', 8449)
GL_DECR = Constant( 'GL_DECR', 7683)
GL_DECR_WRAP = Constant( 'GL_DECR_WRAP', 34056)
GL_DECR_WRAP_EXT = Constant( 'GL_DECR_WRAP_EXT', 34056)
GL_DEFORMATIONS_MASK_SGIX = Constant( 'GL_DEFORMATIONS_MASK_SGIX', 33174)
GL_DELETE_STATUS = Constant( 'GL_DELETE_STATUS', 35712)
GL_DEPENDENT_AR_TEXTURE_2D_NV = Constant( 'GL_DEPENDENT_AR_TEXTURE_2D_NV', 34537)
GL_DEPENDENT_GB_TEXTURE_2D_NV = Constant( 'GL_DEPENDENT_GB_TEXTURE_2D_NV', 34538)
GL_DEPENDENT_HILO_TEXTURE_2D_NV = Constant( 'GL_DEPENDENT_HILO_TEXTURE_2D_NV', 34904)
GL_DEPENDENT_RGB_TEXTURE_3D_NV = Constant( 'GL_DEPENDENT_RGB_TEXTURE_3D_NV', 34905)
GL_DEPENDENT_RGB_TEXTURE_CUBE_MAP_NV = Constant( 'GL_DEPENDENT_RGB_TEXTURE_CUBE_MAP_NV', 34906)
GL_DEPTH = Constant( 'GL_DEPTH', 6145)
GL_DEPTH_ATTACHMENT_EXT = Constant( 'GL_DEPTH_ATTACHMENT_EXT', 36096)
GL_DEPTH_BIAS = Constant( 'GL_DEPTH_BIAS', 3359)
GL_DEPTH_BITS = Constant( 'GL_DEPTH_BITS', 3414)
GL_DEPTH_BOUNDS_EXT = Constant( 'GL_DEPTH_BOUNDS_EXT', 34961)
GL_DEPTH_BOUNDS_TEST_EXT = Constant( 'GL_DEPTH_BOUNDS_TEST_EXT', 34960)
GL_DEPTH_BUFFER_BIT = Constant( 'GL_DEPTH_BUFFER_BIT', 256)
GL_DEPTH_CLAMP_NV = Constant( 'GL_DEPTH_CLAMP_NV', 34383)
GL_DEPTH_CLEAR_VALUE = Constant( 'GL_DEPTH_CLEAR_VALUE', 2931)
GL_DEPTH_COMPONENT = Constant( 'GL_DEPTH_COMPONENT', 6402)
GL_DEPTH_COMPONENT16 = Constant( 'GL_DEPTH_COMPONENT16', 33189)
GL_DEPTH_COMPONENT16_ARB = Constant( 'GL_DEPTH_COMPONENT16_ARB', 33189)
GL_DEPTH_COMPONENT16_SGIX = Constant( 'GL_DEPTH_COMPONENT16_SGIX', 33189)
GL_DEPTH_COMPONENT24 = Constant( 'GL_DEPTH_COMPONENT24', 33190)
GL_DEPTH_COMPONENT24_ARB = Constant( 'GL_DEPTH_COMPONENT24_ARB', 33190)
GL_DEPTH_COMPONENT24_SGIX = Constant( 'GL_DEPTH_COMPONENT24_SGIX', 33190)
GL_DEPTH_COMPONENT32 = Constant( 'GL_DEPTH_COMPONENT32', 33191)
GL_DEPTH_COMPONENT32_ARB = Constant( 'GL_DEPTH_COMPONENT32_ARB', 33191)
GL_DEPTH_COMPONENT32_SGIX = Constant( 'GL_DEPTH_COMPONENT32_SGIX', 33191)
GL_DEPTH_FUNC = Constant( 'GL_DEPTH_FUNC', 2932)
GL_DEPTH_PASS_INSTRUMENT_COUNTERS_SGIX = Constant( 'GL_DEPTH_PASS_INSTRUMENT_COUNTERS_SGIX', 33553)
GL_DEPTH_PASS_INSTRUMENT_MAX_SGIX = Constant( 'GL_DEPTH_PASS_INSTRUMENT_MAX_SGIX', 33554)
GL_DEPTH_PASS_INSTRUMENT_SGIX = Constant( 'GL_DEPTH_PASS_INSTRUMENT_SGIX', 33552)
GL_DEPTH_RANGE = Constant( 'GL_DEPTH_RANGE', 2928)
GL_DEPTH_SCALE = Constant( 'GL_DEPTH_SCALE', 3358)
GL_DEPTH_STENCIL_NV = Constant( 'GL_DEPTH_STENCIL_NV', 34041)
GL_DEPTH_STENCIL_TO_BGRA_NV = Constant( 'GL_DEPTH_STENCIL_TO_BGRA_NV', 34927)
GL_DEPTH_STENCIL_TO_RGBA_NV = Constant( 'GL_DEPTH_STENCIL_TO_RGBA_NV', 34926)
GL_DEPTH_TEST = Constant( 'GL_DEPTH_TEST', 2929)
GL_DEPTH_TEXTURE_MODE = Constant( 'GL_DEPTH_TEXTURE_MODE', 34891)
GL_DEPTH_TEXTURE_MODE_ARB = Constant( 'GL_DEPTH_TEXTURE_MODE_ARB', 34891)
GL_DEPTH_WRITEMASK = Constant( 'GL_DEPTH_WRITEMASK', 2930)
GL_DETAIL_TEXTURE_2D_BINDING_SGIS = Constant( 'GL_DETAIL_TEXTURE_2D_BINDING_SGIS', 32918)
GL_DETAIL_TEXTURE_2D_SGIS = Constant( 'GL_DETAIL_TEXTURE_2D_SGIS', 32917)
GL_DETAIL_TEXTURE_FUNC_POINTS_SGIS = Constant( 'GL_DETAIL_TEXTURE_FUNC_POINTS_SGIS', 32924)
GL_DETAIL_TEXTURE_LEVEL_SGIS = Constant( 'GL_DETAIL_TEXTURE_LEVEL_SGIS', 32922)
GL_DETAIL_TEXTURE_MODE_SGIS = Constant( 'GL_DETAIL_TEXTURE_MODE_SGIS', 32923)
GL_DIFFUSE = Constant( 'GL_DIFFUSE', 4609)
GL_DISCARD_ATI = Constant( 'GL_DISCARD_ATI', 34659)
GL_DISCARD_NV = Constant( 'GL_DISCARD_NV', 34096)
GL_DISTANCE_ATTENUATION_EXT = Constant( 'GL_DISTANCE_ATTENUATION_EXT', 33065)
GL_DISTANCE_ATTENUATION_SGIS = Constant( 'GL_DISTANCE_ATTENUATION_SGIS', 33065)
GL_DITHER = Constant( 'GL_DITHER', 3024)
GL_DOMAIN = Constant( 'GL_DOMAIN', 2562)
GL_DONT_CARE = Constant( 'GL_DONT_CARE', 4352)
GL_DOT2_ADD_ATI = Constant( 'GL_DOT2_ADD_ATI', 35180)
GL_DOT3_ATI = Constant( 'GL_DOT3_ATI', 35174)
GL_DOT3_RGB = Constant( 'GL_DOT3_RGB', 34478)
GL_DOT3_RGBA = Constant( 'GL_DOT3_RGBA', 34479)
GL_DOT3_RGBA_ARB = Constant( 'GL_DOT3_RGBA_ARB', 34479)
GL_DOT3_RGBA_EXT = Constant( 'GL_DOT3_RGBA_EXT', 34625)
GL_DOT3_RGB_ARB = Constant( 'GL_DOT3_RGB_ARB', 34478)
GL_DOT3_RGB_EXT = Constant( 'GL_DOT3_RGB_EXT', 34624)
GL_DOT4_ATI = Constant( 'GL_DOT4_ATI', 35175)
GL_DOT_PRODUCT_AFFINE_DEPTH_REPLACE_NV = Constant( 'GL_DOT_PRODUCT_AFFINE_DEPTH_REPLACE_NV', 34909)
GL_DOT_PRODUCT_CONST_EYE_REFLECT_CUBE_MAP_NV = Constant( 'GL_DOT_PRODUCT_CONST_EYE_REFLECT_CUBE_MAP_NV', 34547)
GL_DOT_PRODUCT_DEPTH_REPLACE_NV = Constant( 'GL_DOT_PRODUCT_DEPTH_REPLACE_NV', 34541)
GL_DOT_PRODUCT_DIFFUSE_CUBE_MAP_NV = Constant( 'GL_DOT_PRODUCT_DIFFUSE_CUBE_MAP_NV', 34545)
GL_DOT_PRODUCT_NV = Constant( 'GL_DOT_PRODUCT_NV', 34540)
GL_DOT_PRODUCT_PASS_THROUGH_NV = Constant( 'GL_DOT_PRODUCT_PASS_THROUGH_NV', 34907)
GL_DOT_PRODUCT_REFLECT_CUBE_MAP_NV = Constant( 'GL_DOT_PRODUCT_REFLECT_CUBE_MAP_NV', 34546)
GL_DOT_PRODUCT_TEXTURE_1D_NV = Constant( 'GL_DOT_PRODUCT_TEXTURE_1D_NV', 34908)
GL_DOT_PRODUCT_TEXTURE_2D_NV = Constant( 'GL_DOT_PRODUCT_TEXTURE_2D_NV', 34542)
GL_DOT_PRODUCT_TEXTURE_3D_NV = Constant( 'GL_DOT_PRODUCT_TEXTURE_3D_NV', 34543)
GL_DOT_PRODUCT_TEXTURE_CUBE_MAP_NV = Constant( 'GL_DOT_PRODUCT_TEXTURE_CUBE_MAP_NV', 34544)
GL_DOT_PRODUCT_TEXTURE_RECTANGLE_NV = Constant( 'GL_DOT_PRODUCT_TEXTURE_RECTANGLE_NV', 34382)
GL_DOUBLEBUFFER = Constant( 'GL_DOUBLEBUFFER', 3122)
GL_DOUBLE_EXT = Constant( 'GL_DOUBLE_EXT', 5130)
GL_DRAW_BUFFER = Constant( 'GL_DRAW_BUFFER', 3073)
GL_DRAW_BUFFER0 = Constant( 'GL_DRAW_BUFFER0', 34853)
GL_DRAW_BUFFER0_ARB = Constant( 'GL_DRAW_BUFFER0_ARB', 34853)
GL_DRAW_BUFFER0_ATI = Constant( 'GL_DRAW_BUFFER0_ATI', 34853)
GL_DRAW_BUFFER1 = Constant( 'GL_DRAW_BUFFER1', 34854)
GL_DRAW_BUFFER10 = Constant( 'GL_DRAW_BUFFER10', 34863)
GL_DRAW_BUFFER10_ARB = Constant( 'GL_DRAW_BUFFER10_ARB', 34863)
GL_DRAW_BUFFER10_ATI = Constant( 'GL_DRAW_BUFFER10_ATI', 34863)
GL_DRAW_BUFFER11 = Constant( 'GL_DRAW_BUFFER11', 34864)
GL_DRAW_BUFFER11_ARB = Constant( 'GL_DRAW_BUFFER11_ARB', 34864)
GL_DRAW_BUFFER11_ATI = Constant( 'GL_DRAW_BUFFER11_ATI', 34864)
GL_DRAW_BUFFER12 = Constant( 'GL_DRAW_BUFFER12', 34865)
GL_DRAW_BUFFER12_ARB = Constant( 'GL_DRAW_BUFFER12_ARB', 34865)
GL_DRAW_BUFFER12_ATI = Constant( 'GL_DRAW_BUFFER12_ATI', 34865)
GL_DRAW_BUFFER13 = Constant( 'GL_DRAW_BUFFER13', 34866)
GL_DRAW_BUFFER13_ARB = Constant( 'GL_DRAW_BUFFER13_ARB', 34866)
GL_DRAW_BUFFER13_ATI = Constant( 'GL_DRAW_BUFFER13_ATI', 34866)
GL_DRAW_BUFFER14 = Constant( 'GL_DRAW_BUFFER14', 34867)
GL_DRAW_BUFFER14_ARB = Constant( 'GL_DRAW_BUFFER14_ARB', 34867)
GL_DRAW_BUFFER14_ATI = Constant( 'GL_DRAW_BUFFER14_ATI', 34867)
GL_DRAW_BUFFER15 = Constant( 'GL_DRAW_BUFFER15', 34868)
GL_DRAW_BUFFER15_ARB = Constant( 'GL_DRAW_BUFFER15_ARB', 34868)
GL_DRAW_BUFFER15_ATI = Constant( 'GL_DRAW_BUFFER15_ATI', 34868)
GL_DRAW_BUFFER1_ARB = Constant( 'GL_DRAW_BUFFER1_ARB', 34854)
GL_DRAW_BUFFER1_ATI = Constant( 'GL_DRAW_BUFFER1_ATI', 34854)
GL_DRAW_BUFFER2 = Constant( 'GL_DRAW_BUFFER2', 34855)
GL_DRAW_BUFFER2_ARB = Constant( 'GL_DRAW_BUFFER2_ARB', 34855)
GL_DRAW_BUFFER2_ATI = Constant( 'GL_DRAW_BUFFER2_ATI', 34855)
GL_DRAW_BUFFER3 = Constant( 'GL_DRAW_BUFFER3', 34856)
GL_DRAW_BUFFER3_ARB = Constant( 'GL_DRAW_BUFFER3_ARB', 34856)
GL_DRAW_BUFFER3_ATI = Constant( 'GL_DRAW_BUFFER3_ATI', 34856)
GL_DRAW_BUFFER4 = Constant( 'GL_DRAW_BUFFER4', 34857)
GL_DRAW_BUFFER4_ARB = Constant( 'GL_DRAW_BUFFER4_ARB', 34857)
GL_DRAW_BUFFER4_ATI = Constant( 'GL_DRAW_BUFFER4_ATI', 34857)
GL_DRAW_BUFFER5 = Constant( 'GL_DRAW_BUFFER5', 34858)
GL_DRAW_BUFFER5_ARB = Constant( 'GL_DRAW_BUFFER5_ARB', 34858)
GL_DRAW_BUFFER5_ATI = Constant( 'GL_DRAW_BUFFER5_ATI', 34858)
GL_DRAW_BUFFER6 = Constant( 'GL_DRAW_BUFFER6', 34859)
GL_DRAW_BUFFER6_ARB = Constant( 'GL_DRAW_BUFFER6_ARB', 34859)
GL_DRAW_BUFFER6_ATI = Constant( 'GL_DRAW_BUFFER6_ATI', 34859)
GL_DRAW_BUFFER7 = Constant( 'GL_DRAW_BUFFER7', 34860)
GL_DRAW_BUFFER7_ARB = Constant( 'GL_DRAW_BUFFER7_ARB', 34860)
GL_DRAW_BUFFER7_ATI = Constant( 'GL_DRAW_BUFFER7_ATI', 34860)
GL_DRAW_BUFFER8 = Constant( 'GL_DRAW_BUFFER8', 34861)
GL_DRAW_BUFFER8_ARB = Constant( 'GL_DRAW_BUFFER8_ARB', 34861)
GL_DRAW_BUFFER8_ATI = Constant( 'GL_DRAW_BUFFER8_ATI', 34861)
GL_DRAW_BUFFER9 = Constant( 'GL_DRAW_BUFFER9', 34862)
GL_DRAW_BUFFER9_ARB = Constant( 'GL_DRAW_BUFFER9_ARB', 34862)
GL_DRAW_BUFFER9_ATI = Constant( 'GL_DRAW_BUFFER9_ATI', 34862)
GL_DRAW_PIXELS_APPLE = Constant( 'GL_DRAW_PIXELS_APPLE', 35338)
GL_DRAW_PIXEL_TOKEN = Constant( 'GL_DRAW_PIXEL_TOKEN', 1797)
GL_DSDT8_MAG8_INTENSITY8_NV = Constant( 'GL_DSDT8_MAG8_INTENSITY8_NV', 34571)
GL_DSDT8_MAG8_NV = Constant( 'GL_DSDT8_MAG8_NV', 34570)
GL_DSDT8_NV = Constant( 'GL_DSDT8_NV', 34569)
GL_DSDT_MAG_INTENSITY_NV = Constant( 'GL_DSDT_MAG_INTENSITY_NV', 34524)
GL_DSDT_MAG_NV = Constant( 'GL_DSDT_MAG_NV', 34550)
GL_DSDT_MAG_VIB_NV = Constant( 'GL_DSDT_MAG_VIB_NV', 34551)
GL_DSDT_NV = Constant( 'GL_DSDT_NV', 34549)
GL_DST_ALPHA = Constant( 'GL_DST_ALPHA', 772)
GL_DST_COLOR = Constant( 'GL_DST_COLOR', 774)
GL_DS_BIAS_NV = Constant( 'GL_DS_BIAS_NV', 34582)
GL_DS_SCALE_NV = Constant( 'GL_DS_SCALE_NV', 34576)
GL_DT_BIAS_NV = Constant( 'GL_DT_BIAS_NV', 34583)
GL_DT_SCALE_NV = Constant( 'GL_DT_SCALE_NV', 34577)
GL_DU8DV8_ATI = Constant( 'GL_DU8DV8_ATI', 34682)
GL_DUAL_ALPHA12_SGIS = Constant( 'GL_DUAL_ALPHA12_SGIS', 33042)
GL_DUAL_ALPHA16_SGIS = Constant( 'GL_DUAL_ALPHA16_SGIS', 33043)
GL_DUAL_ALPHA4_SGIS = Constant( 'GL_DUAL_ALPHA4_SGIS', 33040)
GL_DUAL_ALPHA8_SGIS = Constant( 'GL_DUAL_ALPHA8_SGIS', 33041)
GL_DUAL_INTENSITY12_SGIS = Constant( 'GL_DUAL_INTENSITY12_SGIS', 33050)
GL_DUAL_INTENSITY16_SGIS = Constant( 'GL_DUAL_INTENSITY16_SGIS', 33051)
GL_DUAL_INTENSITY4_SGIS = Constant( 'GL_DUAL_INTENSITY4_SGIS', 33048)
GL_DUAL_INTENSITY8_SGIS = Constant( 'GL_DUAL_INTENSITY8_SGIS', 33049)
GL_DUAL_LUMINANCE12_SGIS = Constant( 'GL_DUAL_LUMINANCE12_SGIS', 33046)
GL_DUAL_LUMINANCE16_SGIS = Constant( 'GL_DUAL_LUMINANCE16_SGIS', 33047)
GL_DUAL_LUMINANCE4_SGIS = Constant( 'GL_DUAL_LUMINANCE4_SGIS', 33044)
GL_DUAL_LUMINANCE8_SGIS = Constant( 'GL_DUAL_LUMINANCE8_SGIS', 33045)
GL_DUAL_LUMINANCE_ALPHA4_SGIS = Constant( 'GL_DUAL_LUMINANCE_ALPHA4_SGIS', 33052)
GL_DUAL_LUMINANCE_ALPHA8_SGIS = Constant( 'GL_DUAL_LUMINANCE_ALPHA8_SGIS', 33053)
GL_DUAL_TEXTURE_SELECT_SGIS = Constant( 'GL_DUAL_TEXTURE_SELECT_SGIS', 33060)
GL_DUDV_ATI = Constant( 'GL_DUDV_ATI', 34681)
GL_DYNAMIC_ATI = Constant( 'GL_DYNAMIC_ATI', 34657)
GL_DYNAMIC_COPY = Constant( 'GL_DYNAMIC_COPY', 35050)
GL_DYNAMIC_COPY_ARB = Constant( 'GL_DYNAMIC_COPY_ARB', 35050)
GL_DYNAMIC_DRAW = Constant( 'GL_DYNAMIC_DRAW', 35048)
GL_DYNAMIC_DRAW_ARB = Constant( 'GL_DYNAMIC_DRAW_ARB', 35048)
GL_DYNAMIC_READ = Constant( 'GL_DYNAMIC_READ', 35049)
GL_DYNAMIC_READ_ARB = Constant( 'GL_DYNAMIC_READ_ARB', 35049)
GL_EDGEFLAG_BIT_PGI = Constant( 'GL_EDGEFLAG_BIT_PGI', 262144)
GL_EDGE_FLAG = Constant( 'GL_EDGE_FLAG', 2883)
GL_EDGE_FLAG_ARRAY = Constant( 'GL_EDGE_FLAG_ARRAY', 32889)
GL_EDGE_FLAG_ARRAY_BUFFER_BINDING = Constant( 'GL_EDGE_FLAG_ARRAY_BUFFER_BINDING', 34971)
GL_EDGE_FLAG_ARRAY_BUFFER_BINDING_ARB = Constant( 'GL_EDGE_FLAG_ARRAY_BUFFER_BINDING_ARB', 34971)
GL_EDGE_FLAG_ARRAY_COUNT_EXT = Constant( 'GL_EDGE_FLAG_ARRAY_COUNT_EXT', 32909)
GL_EDGE_FLAG_ARRAY_EXT = Constant( 'GL_EDGE_FLAG_ARRAY_EXT', 32889)
GL_EDGE_FLAG_ARRAY_LIST_IBM = Constant( 'GL_EDGE_FLAG_ARRAY_LIST_IBM', 103075)
GL_EDGE_FLAG_ARRAY_LIST_STRIDE_IBM = Constant( 'GL_EDGE_FLAG_ARRAY_LIST_STRIDE_IBM', 103085)
GL_EDGE_FLAG_ARRAY_POINTER = Constant( 'GL_EDGE_FLAG_ARRAY_POINTER', 32915)
GL_EDGE_FLAG_ARRAY_POINTER_EXT = Constant( 'GL_EDGE_FLAG_ARRAY_POINTER_EXT', 32915)
GL_EDGE_FLAG_ARRAY_STRIDE = Constant( 'GL_EDGE_FLAG_ARRAY_STRIDE', 32908)
GL_EDGE_FLAG_ARRAY_STRIDE_EXT = Constant( 'GL_EDGE_FLAG_ARRAY_STRIDE_EXT', 32908)
GL_EIGHTH_BIT_ATI = Constant( 'GL_EIGHTH_BIT_ATI', 32)
GL_ELEMENT_ARRAY_APPLE = Constant( 'GL_ELEMENT_ARRAY_APPLE', 34664)
GL_ELEMENT_ARRAY_ATI = Constant( 'GL_ELEMENT_ARRAY_ATI', 34664)
GL_ELEMENT_ARRAY_BUFFER = Constant( 'GL_ELEMENT_ARRAY_BUFFER', 34963)
GL_ELEMENT_ARRAY_BUFFER_ARB = Constant( 'GL_ELEMENT_ARRAY_BUFFER_ARB', 34963)
GL_ELEMENT_ARRAY_BUFFER_BINDING = Constant( 'GL_ELEMENT_ARRAY_BUFFER_BINDING', 34965)
GL_ELEMENT_ARRAY_BUFFER_BINDING_ARB = Constant( 'GL_ELEMENT_ARRAY_BUFFER_BINDING_ARB', 34965)
GL_ELEMENT_ARRAY_POINTER_APPLE = Constant( 'GL_ELEMENT_ARRAY_POINTER_APPLE', 34666)
GL_ELEMENT_ARRAY_POINTER_ATI = Constant( 'GL_ELEMENT_ARRAY_POINTER_ATI', 34666)
GL_ELEMENT_ARRAY_TYPE_APPLE = Constant( 'GL_ELEMENT_ARRAY_TYPE_APPLE', 34665)
GL_ELEMENT_ARRAY_TYPE_ATI = Constant( 'GL_ELEMENT_ARRAY_TYPE_ATI', 34665)
GL_EMBOSS_CONSTANT_NV = Constant( 'GL_EMBOSS_CONSTANT_NV', 34142)
GL_EMBOSS_LIGHT_NV = Constant( 'GL_EMBOSS_LIGHT_NV', 34141)
GL_EMBOSS_MAP_NV = Constant( 'GL_EMBOSS_MAP_NV', 34143)
GL_EMISSION = Constant( 'GL_EMISSION', 5632)
GL_ENABLE_BIT = Constant( 'GL_ENABLE_BIT', 8192)
GL_EQUAL = Constant( 'GL_EQUAL', 514)
GL_EQUIV = Constant( 'GL_EQUIV', 5385)
GL_EVAL_2D_NV = Constant( 'GL_EVAL_2D_NV', 34496)
GL_EVAL_BIT = Constant( 'GL_EVAL_BIT', 65536)
GL_EVAL_FRACTIONAL_TESSELLATION_NV = Constant( 'GL_EVAL_FRACTIONAL_TESSELLATION_NV', 34501)
GL_EVAL_TRIANGULAR_2D_NV = Constant( 'GL_EVAL_TRIANGULAR_2D_NV', 34497)
GL_EVAL_VERTEX_ATTRIB0_NV = Constant( 'GL_EVAL_VERTEX_ATTRIB0_NV', 34502)
GL_EVAL_VERTEX_ATTRIB10_NV = Constant( 'GL_EVAL_VERTEX_ATTRIB10_NV', 34512)
GL_EVAL_VERTEX_ATTRIB11_NV = Constant( 'GL_EVAL_VERTEX_ATTRIB11_NV', 34513)
GL_EVAL_VERTEX_ATTRIB12_NV = Constant( 'GL_EVAL_VERTEX_ATTRIB12_NV', 34514)
GL_EVAL_VERTEX_ATTRIB13_NV = Constant( 'GL_EVAL_VERTEX_ATTRIB13_NV', 34515)
GL_EVAL_VERTEX_ATTRIB14_NV = Constant( 'GL_EVAL_VERTEX_ATTRIB14_NV', 34516)
GL_EVAL_VERTEX_ATTRIB15_NV = Constant( 'GL_EVAL_VERTEX_ATTRIB15_NV', 34517)
GL_EVAL_VERTEX_ATTRIB1_NV = Constant( 'GL_EVAL_VERTEX_ATTRIB1_NV', 34503)
GL_EVAL_VERTEX_ATTRIB2_NV = Constant( 'GL_EVAL_VERTEX_ATTRIB2_NV', 34504)
GL_EVAL_VERTEX_ATTRIB3_NV = Constant( 'GL_EVAL_VERTEX_ATTRIB3_NV', 34505)
GL_EVAL_VERTEX_ATTRIB4_NV = Constant( 'GL_EVAL_VERTEX_ATTRIB4_NV', 34506)
GL_EVAL_VERTEX_ATTRIB5_NV = Constant( 'GL_EVAL_VERTEX_ATTRIB5_NV', 34507)
GL_EVAL_VERTEX_ATTRIB6_NV = Constant( 'GL_EVAL_VERTEX_ATTRIB6_NV', 34508)
GL_EVAL_VERTEX_ATTRIB7_NV = Constant( 'GL_EVAL_VERTEX_ATTRIB7_NV', 34509)
GL_EVAL_VERTEX_ATTRIB8_NV = Constant( 'GL_EVAL_VERTEX_ATTRIB8_NV', 34510)
GL_EVAL_VERTEX_ATTRIB9_NV = Constant( 'GL_EVAL_VERTEX_ATTRIB9_NV', 34511)
GL_EXP = Constant( 'GL_EXP', 2048)
GL_EXP2 = Constant( 'GL_EXP2', 2049)
GL_EXPAND_NEGATE_NV = Constant( 'GL_EXPAND_NEGATE_NV', 34105)
GL_EXPAND_NORMAL_NV = Constant( 'GL_EXPAND_NORMAL_NV', 34104)
GL_EXTENSIONS = Constant( 'GL_EXTENSIONS', 7939)
GL_EYE_DISTANCE_TO_LINE_SGIS = Constant( 'GL_EYE_DISTANCE_TO_LINE_SGIS', 33266)
GL_EYE_DISTANCE_TO_POINT_SGIS = Constant( 'GL_EYE_DISTANCE_TO_POINT_SGIS', 33264)
GL_EYE_LINEAR = Constant( 'GL_EYE_LINEAR', 9216)
GL_EYE_LINE_SGIS = Constant( 'GL_EYE_LINE_SGIS', 33270)
GL_EYE_PLANE = Constant( 'GL_EYE_PLANE', 9474)
GL_EYE_PLANE_ABSOLUTE_NV = Constant( 'GL_EYE_PLANE_ABSOLUTE_NV', 34140)
GL_EYE_POINT_SGIS = Constant( 'GL_EYE_POINT_SGIS', 33268)
GL_EYE_RADIAL_NV = Constant( 'GL_EYE_RADIAL_NV', 34139)
GL_E_TIMES_F_NV = Constant( 'GL_E_TIMES_F_NV', 34097)
GL_FASTEST = Constant( 'GL_FASTEST', 4353)
GL_FEEDBACK = Constant( 'GL_FEEDBACK', 7169)
GL_FEEDBACK_BUFFER_POINTER = Constant( 'GL_FEEDBACK_BUFFER_POINTER', 3568)
GL_FEEDBACK_BUFFER_SIZE = Constant( 'GL_FEEDBACK_BUFFER_SIZE', 3569)
GL_FEEDBACK_BUFFER_TYPE = Constant( 'GL_FEEDBACK_BUFFER_TYPE', 3570)
GL_FENCE_APPLE = Constant( 'GL_FENCE_APPLE', 35339)
GL_FENCE_CONDITION_NV = Constant( 'GL_FENCE_CONDITION_NV', 34036)
GL_FENCE_STATUS_NV = Constant( 'GL_FENCE_STATUS_NV', 34035)
GL_FILL = Constant( 'GL_FILL', 6914)
GL_FILTER4_SGIS = Constant( 'GL_FILTER4_SGIS', 33094)
GL_FIXED_ONLY_ARB = Constant( 'GL_FIXED_ONLY_ARB', 35101)
GL_FLAT = Constant( 'GL_FLAT', 7424)
GL_FLOAT_CLEAR_COLOR_VALUE_NV = Constant( 'GL_FLOAT_CLEAR_COLOR_VALUE_NV', 34957)
GL_FLOAT_MAT2 = Constant( 'GL_FLOAT_MAT2', 35674)
GL_FLOAT_MAT2_ARB = Constant( 'GL_FLOAT_MAT2_ARB', 35674)
GL_FLOAT_MAT3 = Constant( 'GL_FLOAT_MAT3', 35675)
GL_FLOAT_MAT3_ARB = Constant( 'GL_FLOAT_MAT3_ARB', 35675)
GL_FLOAT_MAT4 = Constant( 'GL_FLOAT_MAT4', 35676)
GL_FLOAT_MAT4_ARB = Constant( 'GL_FLOAT_MAT4_ARB', 35676)
GL_FLOAT_R16_NV = Constant( 'GL_FLOAT_R16_NV', 34948)
GL_FLOAT_R32_NV = Constant( 'GL_FLOAT_R32_NV', 34949)
GL_FLOAT_RG16_NV = Constant( 'GL_FLOAT_RG16_NV', 34950)
GL_FLOAT_RG32_NV = Constant( 'GL_FLOAT_RG32_NV', 34951)
GL_FLOAT_RGB16_NV = Constant( 'GL_FLOAT_RGB16_NV', 34952)
GL_FLOAT_RGB32_NV = Constant( 'GL_FLOAT_RGB32_NV', 34953)
GL_FLOAT_RGBA16_NV = Constant( 'GL_FLOAT_RGBA16_NV', 34954)
GL_FLOAT_RGBA32_NV = Constant( 'GL_FLOAT_RGBA32_NV', 34955)
GL_FLOAT_RGBA_MODE_NV = Constant( 'GL_FLOAT_RGBA_MODE_NV', 34958)
GL_FLOAT_RGBA_NV = Constant( 'GL_FLOAT_RGBA_NV', 34947)
GL_FLOAT_RGB_NV = Constant( 'GL_FLOAT_RGB_NV', 34946)
GL_FLOAT_RG_NV = Constant( 'GL_FLOAT_RG_NV', 34945)
GL_FLOAT_R_NV = Constant( 'GL_FLOAT_R_NV', 34944)
GL_FLOAT_VEC2 = Constant( 'GL_FLOAT_VEC2', 35664)
GL_FLOAT_VEC2_ARB = Constant( 'GL_FLOAT_VEC2_ARB', 35664)
GL_FLOAT_VEC3 = Constant( 'GL_FLOAT_VEC3', 35665)
GL_FLOAT_VEC3_ARB = Constant( 'GL_FLOAT_VEC3_ARB', 35665)
GL_FLOAT_VEC4 = Constant( 'GL_FLOAT_VEC4', 35666)
GL_FLOAT_VEC4_ARB = Constant( 'GL_FLOAT_VEC4_ARB', 35666)
GL_FOG = Constant( 'GL_FOG', 2912)
GL_FOG_BIT = Constant( 'GL_FOG_BIT', 128)
GL_FOG_COLOR = Constant( 'GL_FOG_COLOR', 2918)
GL_FOG_COORDINATE = Constant( 'GL_FOG_COORDINATE', 33873)
GL_FOG_COORDINATE_ARRAY = Constant( 'GL_FOG_COORDINATE_ARRAY', 33879)
GL_FOG_COORDINATE_ARRAY_BUFFER_BINDING = Constant( 'GL_FOG_COORDINATE_ARRAY_BUFFER_BINDING', 34973)
GL_FOG_COORDINATE_ARRAY_BUFFER_BINDING_ARB = Constant( 'GL_FOG_COORDINATE_ARRAY_BUFFER_BINDING_ARB', 34973)
GL_FOG_COORDINATE_ARRAY_EXT = Constant( 'GL_FOG_COORDINATE_ARRAY_EXT', 33879)
GL_FOG_COORDINATE_ARRAY_LIST_IBM = Constant( 'GL_FOG_COORDINATE_ARRAY_LIST_IBM', 103076)
GL_FOG_COORDINATE_ARRAY_LIST_STRIDE_IBM = Constant( 'GL_FOG_COORDINATE_ARRAY_LIST_STRIDE_IBM', 103086)
GL_FOG_COORDINATE_ARRAY_POINTER = Constant( 'GL_FOG_COORDINATE_ARRAY_POINTER', 33878)
GL_FOG_COORDINATE_ARRAY_POINTER_EXT = Constant( 'GL_FOG_COORDINATE_ARRAY_POINTER_EXT', 33878)
GL_FOG_COORDINATE_ARRAY_STRIDE = Constant( 'GL_FOG_COORDINATE_ARRAY_STRIDE', 33877)
GL_FOG_COORDINATE_ARRAY_STRIDE_EXT = Constant( 'GL_FOG_COORDINATE_ARRAY_STRIDE_EXT', 33877)
GL_FOG_COORDINATE_ARRAY_TYPE = Constant( 'GL_FOG_COORDINATE_ARRAY_TYPE', 33876)
GL_FOG_COORDINATE_ARRAY_TYPE_EXT = Constant( 'GL_FOG_COORDINATE_ARRAY_TYPE_EXT', 33876)
GL_FOG_COORDINATE_EXT = Constant( 'GL_FOG_COORDINATE_EXT', 33873)
GL_FOG_COORDINATE_SOURCE = Constant( 'GL_FOG_COORDINATE_SOURCE', 33872)
GL_FOG_COORDINATE_SOURCE_EXT = Constant( 'GL_FOG_COORDINATE_SOURCE_EXT', 33872)
GL_FOG_DENSITY = Constant( 'GL_FOG_DENSITY', 2914)
GL_FOG_DISTANCE_MODE_NV = Constant( 'GL_FOG_DISTANCE_MODE_NV', 34138)
GL_FOG_END = Constant( 'GL_FOG_END', 2916)
GL_FOG_FUNC_POINTS_SGIS = Constant( 'GL_FOG_FUNC_POINTS_SGIS', 33067)
GL_FOG_FUNC_SGIS = Constant( 'GL_FOG_FUNC_SGIS', 33066)
GL_FOG_HINT = Constant( 'GL_FOG_HINT', 3156)
GL_FOG_INDEX = Constant( 'GL_FOG_INDEX', 2913)
GL_FOG_MODE = Constant( 'GL_FOG_MODE', 2917)
GL_FOG_OFFSET_SGIX = Constant( 'GL_FOG_OFFSET_SGIX', 33176)
GL_FOG_OFFSET_VALUE_SGIX = Constant( 'GL_FOG_OFFSET_VALUE_SGIX', 33177)
GL_FOG_SCALE_SGIX = Constant( 'GL_FOG_SCALE_SGIX', 33276)
GL_FOG_SCALE_VALUE_SGIX = Constant( 'GL_FOG_SCALE_VALUE_SGIX', 33277)
GL_FOG_SPECULAR_TEXTURE_WIN = Constant( 'GL_FOG_SPECULAR_TEXTURE_WIN', 33004)
GL_FOG_START = Constant( 'GL_FOG_START', 2915)
GL_FORCE_BLUE_TO_ONE_NV = Constant( 'GL_FORCE_BLUE_TO_ONE_NV', 34912)
GL_FORMAT_SUBSAMPLE_244_244_OML = Constant( 'GL_FORMAT_SUBSAMPLE_244_244_OML', 35203)
GL_FORMAT_SUBSAMPLE_24_24_OML = Constant( 'GL_FORMAT_SUBSAMPLE_24_24_OML', 35202)
GL_FRAGMENT_COLOR_EXT = Constant( 'GL_FRAGMENT_COLOR_EXT', 33612)
GL_FRAGMENT_COLOR_MATERIAL_FACE_SGIX = Constant( 'GL_FRAGMENT_COLOR_MATERIAL_FACE_SGIX', 33794)
GL_FRAGMENT_COLOR_MATERIAL_PARAMETER_SGIX = Constant( 'GL_FRAGMENT_COLOR_MATERIAL_PARAMETER_SGIX', 33795)
GL_FRAGMENT_COLOR_MATERIAL_SGIX = Constant( 'GL_FRAGMENT_COLOR_MATERIAL_SGIX', 33793)
GL_FRAGMENT_DEPTH = Constant( 'GL_FRAGMENT_DEPTH', 33874)
GL_FRAGMENT_DEPTH_EXT = Constant( 'GL_FRAGMENT_DEPTH_EXT', 33874)
GL_FRAGMENT_LIGHT0_SGIX = Constant( 'GL_FRAGMENT_LIGHT0_SGIX', 33804)
GL_FRAGMENT_LIGHT1_SGIX = Constant( 'GL_FRAGMENT_LIGHT1_SGIX', 33805)
GL_FRAGMENT_LIGHT2_SGIX = Constant( 'GL_FRAGMENT_LIGHT2_SGIX', 33806)
GL_FRAGMENT_LIGHT3_SGIX = Constant( 'GL_FRAGMENT_LIGHT3_SGIX', 33807)
GL_FRAGMENT_LIGHT4_SGIX = Constant( 'GL_FRAGMENT_LIGHT4_SGIX', 33808)
GL_FRAGMENT_LIGHT5_SGIX = Constant( 'GL_FRAGMENT_LIGHT5_SGIX', 33809)
GL_FRAGMENT_LIGHT6_SGIX = Constant( 'GL_FRAGMENT_LIGHT6_SGIX', 33810)
GL_FRAGMENT_LIGHT7_SGIX = Constant( 'GL_FRAGMENT_LIGHT7_SGIX', 33811)
GL_FRAGMENT_LIGHTING_SGIX = Constant( 'GL_FRAGMENT_LIGHTING_SGIX', 33792)
GL_FRAGMENT_LIGHT_MODEL_AMBIENT_SGIX = Constant( 'GL_FRAGMENT_LIGHT_MODEL_AMBIENT_SGIX', 33802)
GL_FRAGMENT_LIGHT_MODEL_LOCAL_VIEWER_SGIX = Constant( 'GL_FRAGMENT_LIGHT_MODEL_LOCAL_VIEWER_SGIX', 33800)
GL_FRAGMENT_LIGHT_MODEL_NORMAL_INTERPOLATION_SGIX = Constant( 'GL_FRAGMENT_LIGHT_MODEL_NORMAL_INTERPOLATION_SGIX', 33803)
GL_FRAGMENT_LIGHT_MODEL_TWO_SIDE_SGIX = Constant( 'GL_FRAGMENT_LIGHT_MODEL_TWO_SIDE_SGIX', 33801)
GL_FRAGMENT_MATERIAL_EXT = Constant( 'GL_FRAGMENT_MATERIAL_EXT', 33609)
GL_FRAGMENT_NORMAL_EXT = Constant( 'GL_FRAGMENT_NORMAL_EXT', 33610)
GL_FRAGMENT_PROGRAM_ARB = Constant( 'GL_FRAGMENT_PROGRAM_ARB', 34820)
GL_FRAGMENT_PROGRAM_BINDING_NV = Constant( 'GL_FRAGMENT_PROGRAM_BINDING_NV', 34931)
GL_FRAGMENT_PROGRAM_NV = Constant( 'GL_FRAGMENT_PROGRAM_NV', 34928)
GL_FRAGMENT_SHADER = Constant( 'GL_FRAGMENT_SHADER', 35632)
GL_FRAGMENT_SHADER_ARB = Constant( 'GL_FRAGMENT_SHADER_ARB', 35632)
GL_FRAGMENT_SHADER_ATI = Constant( 'GL_FRAGMENT_SHADER_ATI', 35104)
GL_FRAGMENT_SHADER_DERIVATIVE_HINT = Constant( 'GL_FRAGMENT_SHADER_DERIVATIVE_HINT', 35723)
GL_FRAGMENT_SHADER_DERIVATIVE_HINT_ARB = Constant( 'GL_FRAGMENT_SHADER_DERIVATIVE_HINT_ARB', 35723)
GL_FRAMEBUFFER_ATTACHMENT_OBJECT_NAME_EXT = Constant( 'GL_FRAMEBUFFER_ATTACHMENT_OBJECT_NAME_EXT', 36049)
GL_FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE_EXT = Constant( 'GL_FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE_EXT', 36048)
GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_3D_ZOFFSET_EXT = Constant( 'GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_3D_ZOFFSET_EXT', 36052)
GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE_EXT = Constant( 'GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE_EXT', 36051)
GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL_EXT = Constant( 'GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL_EXT', 36050)
GL_FRAMEBUFFER_BINDING_EXT = Constant( 'GL_FRAMEBUFFER_BINDING_EXT', 36006)
GL_FRAMEBUFFER_COMPLETE_EXT = Constant( 'GL_FRAMEBUFFER_COMPLETE_EXT', 36053)
GL_FRAMEBUFFER_EXT = Constant( 'GL_FRAMEBUFFER_EXT', 36160)
GL_FRAMEBUFFER_INCOMPLETE_ATTACHMENT_EXT = Constant( 'GL_FRAMEBUFFER_INCOMPLETE_ATTACHMENT_EXT', 36054)
GL_FRAMEBUFFER_INCOMPLETE_DIMENSIONS_EXT = Constant( 'GL_FRAMEBUFFER_INCOMPLETE_DIMENSIONS_EXT', 36057)
GL_FRAMEBUFFER_INCOMPLETE_DRAW_BUFFER_EXT = Constant( 'GL_FRAMEBUFFER_INCOMPLETE_DRAW_BUFFER_EXT', 36059)
GL_FRAMEBUFFER_INCOMPLETE_DUPLICATE_ATTACHMENT_EXT = Constant( 'GL_FRAMEBUFFER_INCOMPLETE_DUPLICATE_ATTACHMENT_EXT', 36056)
GL_FRAMEBUFFER_INCOMPLETE_FORMATS_EXT = Constant( 'GL_FRAMEBUFFER_INCOMPLETE_FORMATS_EXT', 36058)
GL_FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT_EXT = Constant( 'GL_FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT_EXT', 36055)
GL_FRAMEBUFFER_INCOMPLETE_READ_BUFFER_EXT = Constant( 'GL_FRAMEBUFFER_INCOMPLETE_READ_BUFFER_EXT', 36060)
GL_FRAMEBUFFER_UNSUPPORTED_EXT = Constant( 'GL_FRAMEBUFFER_UNSUPPORTED_EXT', 36061)
GL_FRAMEZOOM_FACTOR_SGIX = Constant( 'GL_FRAMEZOOM_FACTOR_SGIX', 33164)
GL_FRAMEZOOM_SGIX = Constant( 'GL_FRAMEZOOM_SGIX', 33163)
GL_FRONT = Constant( 'GL_FRONT', 1028)
GL_FRONT_AND_BACK = Constant( 'GL_FRONT_AND_BACK', 1032)
GL_FRONT_FACE = Constant( 'GL_FRONT_FACE', 2886)
GL_FRONT_LEFT = Constant( 'GL_FRONT_LEFT', 1024)
GL_FRONT_RIGHT = Constant( 'GL_FRONT_RIGHT', 1025)
GL_FULL_RANGE_EXT = Constant( 'GL_FULL_RANGE_EXT', 34785)
GL_FULL_STIPPLE_HINT_PGI = Constant( 'GL_FULL_STIPPLE_HINT_PGI', 107033)
GL_FUNC_ADD = Constant( 'GL_FUNC_ADD', 32774)
GL_FUNC_ADD_EXT = Constant( 'GL_FUNC_ADD_EXT', 32774)
GL_FUNC_REVERSE_SUBTRACT = Constant( 'GL_FUNC_REVERSE_SUBTRACT', 32779)
GL_FUNC_REVERSE_SUBTRACT_EXT = Constant( 'GL_FUNC_REVERSE_SUBTRACT_EXT', 32779)
GL_FUNC_SUBTRACT = Constant( 'GL_FUNC_SUBTRACT', 32778)
GL_FUNC_SUBTRACT_EXT = Constant( 'GL_FUNC_SUBTRACT_EXT', 32778)
GL_GENERATE_MIPMAP = Constant( 'GL_GENERATE_MIPMAP', 33169)
GL_GENERATE_MIPMAP_HINT = Constant( 'GL_GENERATE_MIPMAP_HINT', 33170)
GL_GENERATE_MIPMAP_HINT_SGIS = Constant( 'GL_GENERATE_MIPMAP_HINT_SGIS', 33170)
GL_GENERATE_MIPMAP_SGIS = Constant( 'GL_GENERATE_MIPMAP_SGIS', 33169)
GL_GEOMETRY_DEFORMATION_BIT_SGIX = Constant( 'GL_GEOMETRY_DEFORMATION_BIT_SGIX', 2)
GL_GEOMETRY_DEFORMATION_SGIX = Constant( 'GL_GEOMETRY_DEFORMATION_SGIX', 33172)
GL_GEQUAL = Constant( 'GL_GEQUAL', 518)
GL_GLEXT_VERSION = Constant( 'GL_GLEXT_VERSION', 29)
GL_GLOBAL_ALPHA_FACTOR_SUN = Constant( 'GL_GLOBAL_ALPHA_FACTOR_SUN', 33242)
GL_GLOBAL_ALPHA_SUN = Constant( 'GL_GLOBAL_ALPHA_SUN', 33241)
GL_GREATER = Constant( 'GL_GREATER', 516)
GL_GREEN = Constant( 'GL_GREEN', 6404)
GL_GREEN_BIAS = Constant( 'GL_GREEN_BIAS', 3353)
GL_GREEN_BITS = Constant( 'GL_GREEN_BITS', 3411)
GL_GREEN_BIT_ATI = Constant( 'GL_GREEN_BIT_ATI', 2)
GL_GREEN_MAX_CLAMP_INGR = Constant( 'GL_GREEN_MAX_CLAMP_INGR', 34149)
GL_GREEN_MIN_CLAMP_INGR = Constant( 'GL_GREEN_MIN_CLAMP_INGR', 34145)
GL_GREEN_SCALE = Constant( 'GL_GREEN_SCALE', 3352)
GL_HALF_BIAS_NEGATE_NV = Constant( 'GL_HALF_BIAS_NEGATE_NV', 34107)
GL_HALF_BIAS_NORMAL_NV = Constant( 'GL_HALF_BIAS_NORMAL_NV', 34106)
GL_HALF_BIT_ATI = Constant( 'GL_HALF_BIT_ATI', 8)
GL_HALF_FLOAT_ARB = Constant( 'GL_HALF_FLOAT_ARB', 5131)
GL_HALF_FLOAT_NV = Constant( 'GL_HALF_FLOAT_NV', 5131)
GL_HILO16_NV = Constant( 'GL_HILO16_NV', 34552)
GL_HILO8_NV = Constant( 'GL_HILO8_NV', 34910)
GL_HILO_NV = Constant( 'GL_HILO_NV', 34548)
GL_HINT_BIT = Constant( 'GL_HINT_BIT', 32768)
GL_HISTOGRAM = Constant( 'GL_HISTOGRAM', 32804)
GL_HISTOGRAM_ALPHA_SIZE = Constant( 'GL_HISTOGRAM_ALPHA_SIZE', 32811)
GL_HISTOGRAM_ALPHA_SIZE_EXT = Constant( 'GL_HISTOGRAM_ALPHA_SIZE_EXT', 32811)
GL_HISTOGRAM_BLUE_SIZE = Constant( 'GL_HISTOGRAM_BLUE_SIZE', 32810)
GL_HISTOGRAM_BLUE_SIZE_EXT = Constant( 'GL_HISTOGRAM_BLUE_SIZE_EXT', 32810)
GL_HISTOGRAM_EXT = Constant( 'GL_HISTOGRAM_EXT', 32804)
GL_HISTOGRAM_FORMAT = Constant( 'GL_HISTOGRAM_FORMAT', 32807)
GL_HISTOGRAM_FORMAT_EXT = Constant( 'GL_HISTOGRAM_FORMAT_EXT', 32807)
GL_HISTOGRAM_GREEN_SIZE = Constant( 'GL_HISTOGRAM_GREEN_SIZE', 32809)
GL_HISTOGRAM_GREEN_SIZE_EXT = Constant( 'GL_HISTOGRAM_GREEN_SIZE_EXT', 32809)
GL_HISTOGRAM_LUMINANCE_SIZE = Constant( 'GL_HISTOGRAM_LUMINANCE_SIZE', 32812)
GL_HISTOGRAM_LUMINANCE_SIZE_EXT = Constant( 'GL_HISTOGRAM_LUMINANCE_SIZE_EXT', 32812)
GL_HISTOGRAM_RED_SIZE = Constant( 'GL_HISTOGRAM_RED_SIZE', 32808)
GL_HISTOGRAM_RED_SIZE_EXT = Constant( 'GL_HISTOGRAM_RED_SIZE_EXT', 32808)
GL_HISTOGRAM_SINK = Constant( 'GL_HISTOGRAM_SINK', 32813)
GL_HISTOGRAM_SINK_EXT = Constant( 'GL_HISTOGRAM_SINK_EXT', 32813)
GL_HISTOGRAM_WIDTH = Constant( 'GL_HISTOGRAM_WIDTH', 32806)
GL_HISTOGRAM_WIDTH_EXT = Constant( 'GL_HISTOGRAM_WIDTH_EXT', 32806)
GL_HI_BIAS_NV = Constant( 'GL_HI_BIAS_NV', 34580)
GL_HI_SCALE_NV = Constant( 'GL_HI_SCALE_NV', 34574)
GL_IDENTITY_NV = Constant( 'GL_IDENTITY_NV', 34346)
GL_IGNORE_BORDER_HP = Constant( 'GL_IGNORE_BORDER_HP', 33104)
GL_IMAGE_CUBIC_WEIGHT_HP = Constant( 'GL_IMAGE_CUBIC_WEIGHT_HP', 33118)
GL_IMAGE_MAG_FILTER_HP = Constant( 'GL_IMAGE_MAG_FILTER_HP', 33116)
GL_IMAGE_MIN_FILTER_HP = Constant( 'GL_IMAGE_MIN_FILTER_HP', 33117)
GL_IMAGE_ROTATE_ANGLE_HP = Constant( 'GL_IMAGE_ROTATE_ANGLE_HP', 33113)
GL_IMAGE_ROTATE_ORIGIN_X_HP = Constant( 'GL_IMAGE_ROTATE_ORIGIN_X_HP', 33114)
GL_IMAGE_ROTATE_ORIGIN_Y_HP = Constant( 'GL_IMAGE_ROTATE_ORIGIN_Y_HP', 33115)
GL_IMAGE_SCALE_X_HP = Constant( 'GL_IMAGE_SCALE_X_HP', 33109)
GL_IMAGE_SCALE_Y_HP = Constant( 'GL_IMAGE_SCALE_Y_HP', 33110)
GL_IMAGE_TRANSFORM_2D_HP = Constant( 'GL_IMAGE_TRANSFORM_2D_HP', 33121)
GL_IMAGE_TRANSLATE_X_HP = Constant( 'GL_IMAGE_TRANSLATE_X_HP', 33111)
GL_IMAGE_TRANSLATE_Y_HP = Constant( 'GL_IMAGE_TRANSLATE_Y_HP', 33112)
GL_IMPLEMENTATION_COLOR_READ_FORMAT_OES = Constant( 'GL_IMPLEMENTATION_COLOR_READ_FORMAT_OES', 35739)
GL_IMPLEMENTATION_COLOR_READ_TYPE_OES = Constant( 'GL_IMPLEMENTATION_COLOR_READ_TYPE_OES', 35738)
GL_INCR = Constant( 'GL_INCR', 7682)
GL_INCR_WRAP = Constant( 'GL_INCR_WRAP', 34055)
GL_INCR_WRAP_EXT = Constant( 'GL_INCR_WRAP_EXT', 34055)
GL_INDEX_ARRAY = Constant( 'GL_INDEX_ARRAY', 32887)
GL_INDEX_ARRAY_BUFFER_BINDING = Constant( 'GL_INDEX_ARRAY_BUFFER_BINDING', 34969)
GL_INDEX_ARRAY_BUFFER_BINDING_ARB = Constant( 'GL_INDEX_ARRAY_BUFFER_BINDING_ARB', 34969)
GL_INDEX_ARRAY_COUNT_EXT = Constant( 'GL_INDEX_ARRAY_COUNT_EXT', 32903)
GL_INDEX_ARRAY_EXT = Constant( 'GL_INDEX_ARRAY_EXT', 32887)
GL_INDEX_ARRAY_LIST_IBM = Constant( 'GL_INDEX_ARRAY_LIST_IBM', 103073)
GL_INDEX_ARRAY_LIST_STRIDE_IBM = Constant( 'GL_INDEX_ARRAY_LIST_STRIDE_IBM', 103083)
GL_INDEX_ARRAY_POINTER = Constant( 'GL_INDEX_ARRAY_POINTER', 32913)
GL_INDEX_ARRAY_POINTER_EXT = Constant( 'GL_INDEX_ARRAY_POINTER_EXT', 32913)
GL_INDEX_ARRAY_STRIDE = Constant( 'GL_INDEX_ARRAY_STRIDE', 32902)
GL_INDEX_ARRAY_STRIDE_EXT = Constant( 'GL_INDEX_ARRAY_STRIDE_EXT', 32902)
GL_INDEX_ARRAY_TYPE = Constant( 'GL_INDEX_ARRAY_TYPE', 32901)
GL_INDEX_ARRAY_TYPE_EXT = Constant( 'GL_INDEX_ARRAY_TYPE_EXT', 32901)
GL_INDEX_BITS = Constant( 'GL_INDEX_BITS', 3409)
GL_INDEX_BIT_PGI = Constant( 'GL_INDEX_BIT_PGI', 524288)
GL_INDEX_CLEAR_VALUE = Constant( 'GL_INDEX_CLEAR_VALUE', 3104)
GL_INDEX_LOGIC_OP = Constant( 'GL_INDEX_LOGIC_OP', 3057)
GL_INDEX_MATERIAL_EXT = Constant( 'GL_INDEX_MATERIAL_EXT', 33208)
GL_INDEX_MATERIAL_FACE_EXT = Constant( 'GL_INDEX_MATERIAL_FACE_EXT', 33210)
GL_INDEX_MATERIAL_PARAMETER_EXT = Constant( 'GL_INDEX_MATERIAL_PARAMETER_EXT', 33209)
GL_INDEX_MODE = Constant( 'GL_INDEX_MODE', 3120)
GL_INDEX_OFFSET = Constant( 'GL_INDEX_OFFSET', 3347)
GL_INDEX_SHIFT = Constant( 'GL_INDEX_SHIFT', 3346)
GL_INDEX_TEST_EXT = Constant( 'GL_INDEX_TEST_EXT', 33205)
GL_INDEX_TEST_FUNC_EXT = Constant( 'GL_INDEX_TEST_FUNC_EXT', 33206)
GL_INDEX_TEST_REF_EXT = Constant( 'GL_INDEX_TEST_REF_EXT', 33207)
GL_INDEX_WRITEMASK = Constant( 'GL_INDEX_WRITEMASK', 3105)
GL_INFO_LOG_LENGTH = Constant( 'GL_INFO_LOG_LENGTH', 35716)
GL_INSTRUMENT_BUFFER_POINTER_SGIX = Constant( 'GL_INSTRUMENT_BUFFER_POINTER_SGIX', 33152)
GL_INSTRUMENT_MEASUREMENTS_SGIX = Constant( 'GL_INSTRUMENT_MEASUREMENTS_SGIX', 33153)
GL_INTENSITY = Constant( 'GL_INTENSITY', 32841)
GL_INTENSITY12 = Constant( 'GL_INTENSITY12', 32844)
GL_INTENSITY12_EXT = Constant( 'GL_INTENSITY12_EXT', 32844)
GL_INTENSITY16 = Constant( 'GL_INTENSITY16', 32845)
GL_INTENSITY16F_ARB = Constant( 'GL_INTENSITY16F_ARB', 34845)
GL_INTENSITY16_EXT = Constant( 'GL_INTENSITY16_EXT', 32845)
GL_INTENSITY32F_ARB = Constant( 'GL_INTENSITY32F_ARB', 34839)
GL_INTENSITY4 = Constant( 'GL_INTENSITY4', 32842)
GL_INTENSITY4_EXT = Constant( 'GL_INTENSITY4_EXT', 32842)
GL_INTENSITY8 = Constant( 'GL_INTENSITY8', 32843)
GL_INTENSITY8_EXT = Constant( 'GL_INTENSITY8_EXT', 32843)
GL_INTENSITY_EXT = Constant( 'GL_INTENSITY_EXT', 32841)
GL_INTENSITY_FLOAT16_ATI = Constant( 'GL_INTENSITY_FLOAT16_ATI', 34845)
GL_INTENSITY_FLOAT32_ATI = Constant( 'GL_INTENSITY_FLOAT32_ATI', 34839)
GL_INTERLACE_OML = Constant( 'GL_INTERLACE_OML', 35200)
GL_INTERLACE_READ_INGR = Constant( 'GL_INTERLACE_READ_INGR', 34152)
GL_INTERLACE_READ_OML = Constant( 'GL_INTERLACE_READ_OML', 35201)
GL_INTERLACE_SGIX = Constant( 'GL_INTERLACE_SGIX', 32916)
GL_INTERPOLATE = Constant( 'GL_INTERPOLATE', 34165)
GL_INTERPOLATE_ARB = Constant( 'GL_INTERPOLATE_ARB', 34165)
GL_INTERPOLATE_EXT = Constant( 'GL_INTERPOLATE_EXT', 34165)
GL_INT_VEC2 = Constant( 'GL_INT_VEC2', 35667)
GL_INT_VEC2_ARB = Constant( 'GL_INT_VEC2_ARB', 35667)
GL_INT_VEC3 = Constant( 'GL_INT_VEC3', 35668)
GL_INT_VEC3_ARB = Constant( 'GL_INT_VEC3_ARB', 35668)
GL_INT_VEC4 = Constant( 'GL_INT_VEC4', 35669)
GL_INT_VEC4_ARB = Constant( 'GL_INT_VEC4_ARB', 35669)
GL_INVALID_ENUM = Constant( 'GL_INVALID_ENUM', 1280)
GL_INVALID_FRAMEBUFFER_OPERATION_EXT = Constant( 'GL_INVALID_FRAMEBUFFER_OPERATION_EXT', 1286)
GL_INVALID_OPERATION = Constant( 'GL_INVALID_OPERATION', 1282)
GL_INVALID_VALUE = Constant( 'GL_INVALID_VALUE', 1281)
GL_INVARIANT_DATATYPE_EXT = Constant( 'GL_INVARIANT_DATATYPE_EXT', 34795)
GL_INVARIANT_EXT = Constant( 'GL_INVARIANT_EXT', 34754)
GL_INVARIANT_VALUE_EXT = Constant( 'GL_INVARIANT_VALUE_EXT', 34794)
GL_INVERSE_NV = Constant( 'GL_INVERSE_NV', 34347)
GL_INVERSE_TRANSPOSE_NV = Constant( 'GL_INVERSE_TRANSPOSE_NV', 34349)
GL_INVERT = Constant( 'GL_INVERT', 5386)
GL_INVERTED_SCREEN_W_REND = Constant( 'GL_INVERTED_SCREEN_W_REND', 33937)
GL_IR_INSTRUMENT1_SGIX = Constant( 'GL_IR_INSTRUMENT1_SGIX', 33151)
GL_IUI_N3F_V2F_EXT = Constant( 'GL_IUI_N3F_V2F_EXT', 33199)
GL_IUI_N3F_V3F_EXT = Constant( 'GL_IUI_N3F_V3F_EXT', 33200)
GL_IUI_V2F_EXT = Constant( 'GL_IUI_V2F_EXT', 33197)
GL_IUI_V3F_EXT = Constant( 'GL_IUI_V3F_EXT', 33198)
GL_KEEP = Constant( 'GL_KEEP', 7680)
GL_LEFT = Constant( 'GL_LEFT', 1030)
GL_LEQUAL = Constant( 'GL_LEQUAL', 515)
GL_LERP_ATI = Constant( 'GL_LERP_ATI', 35177)
GL_LESS = Constant( 'GL_LESS', 513)
GL_LIGHT0 = Constant( 'GL_LIGHT0', 16384)
GL_LIGHT1 = Constant( 'GL_LIGHT1', 16385)
GL_LIGHT2 = Constant( 'GL_LIGHT2', 16386)
GL_LIGHT3 = Constant( 'GL_LIGHT3', 16387)
GL_LIGHT4 = Constant( 'GL_LIGHT4', 16388)
GL_LIGHT5 = Constant( 'GL_LIGHT5', 16389)
GL_LIGHT6 = Constant( 'GL_LIGHT6', 16390)
GL_LIGHT7 = Constant( 'GL_LIGHT7', 16391)
GL_LIGHTING = Constant( 'GL_LIGHTING', 2896)
GL_LIGHTING_BIT = Constant( 'GL_LIGHTING_BIT', 64)
GL_LIGHT_ENV_MODE_SGIX = Constant( 'GL_LIGHT_ENV_MODE_SGIX', 33799)
GL_LIGHT_MODEL_AMBIENT = Constant( 'GL_LIGHT_MODEL_AMBIENT', 2899)
GL_LIGHT_MODEL_COLOR_CONTROL = Constant( 'GL_LIGHT_MODEL_COLOR_CONTROL', 33272)
GL_LIGHT_MODEL_COLOR_CONTROL_EXT = Constant( 'GL_LIGHT_MODEL_COLOR_CONTROL_EXT', 33272)
GL_LIGHT_MODEL_LOCAL_VIEWER = Constant( 'GL_LIGHT_MODEL_LOCAL_VIEWER', 2897)
GL_LIGHT_MODEL_SPECULAR_VECTOR_APPLE = Constant( 'GL_LIGHT_MODEL_SPECULAR_VECTOR_APPLE', 34224)
GL_LIGHT_MODEL_TWO_SIDE = Constant( 'GL_LIGHT_MODEL_TWO_SIDE', 2898)
GL_LINE = Constant( 'GL_LINE', 6913)
GL_LINEAR = Constant( 'GL_LINEAR', 9729)
GL_LINEAR_ATTENUATION = Constant( 'GL_LINEAR_ATTENUATION', 4616)
GL_LINEAR_CLIPMAP_LINEAR_SGIX = Constant( 'GL_LINEAR_CLIPMAP_LINEAR_SGIX', 33136)
GL_LINEAR_CLIPMAP_NEAREST_SGIX = Constant( 'GL_LINEAR_CLIPMAP_NEAREST_SGIX', 33871)
GL_LINEAR_DETAIL_ALPHA_SGIS = Constant( 'GL_LINEAR_DETAIL_ALPHA_SGIS', 32920)
GL_LINEAR_DETAIL_COLOR_SGIS = Constant( 'GL_LINEAR_DETAIL_COLOR_SGIS', 32921)
GL_LINEAR_DETAIL_SGIS = Constant( 'GL_LINEAR_DETAIL_SGIS', 32919)
GL_LINEAR_MIPMAP_LINEAR = Constant( 'GL_LINEAR_MIPMAP_LINEAR', 9987)
GL_LINEAR_MIPMAP_NEAREST = Constant( 'GL_LINEAR_MIPMAP_NEAREST', 9985)
GL_LINEAR_SHARPEN_ALPHA_SGIS = Constant( 'GL_LINEAR_SHARPEN_ALPHA_SGIS', 32942)
GL_LINEAR_SHARPEN_COLOR_SGIS = Constant( 'GL_LINEAR_SHARPEN_COLOR_SGIS', 32943)
GL_LINEAR_SHARPEN_SGIS = Constant( 'GL_LINEAR_SHARPEN_SGIS', 32941)
GL_LINES = Constant( 'GL_LINES', 1)
GL_LINE_BIT = Constant( 'GL_LINE_BIT', 4)
GL_LINE_LOOP = Constant( 'GL_LINE_LOOP', 2)
GL_LINE_RESET_TOKEN = Constant( 'GL_LINE_RESET_TOKEN', 1799)
GL_LINE_SMOOTH = Constant( 'GL_LINE_SMOOTH', 2848)
GL_LINE_SMOOTH_HINT = Constant( 'GL_LINE_SMOOTH_HINT', 3154)
GL_LINE_STIPPLE = Constant( 'GL_LINE_STIPPLE', 2852)
GL_LINE_STIPPLE_PATTERN = Constant( 'GL_LINE_STIPPLE_PATTERN', 2853)
GL_LINE_STIPPLE_REPEAT = Constant( 'GL_LINE_STIPPLE_REPEAT', 2854)
GL_LINE_STRIP = Constant( 'GL_LINE_STRIP', 3)
GL_LINE_TOKEN = Constant( 'GL_LINE_TOKEN', 1794)
GL_LINE_WIDTH = Constant( 'GL_LINE_WIDTH', 2849)
GL_LINK_STATUS = Constant( 'GL_LINK_STATUS', 35714)
GL_LIST_BASE = Constant( 'GL_LIST_BASE', 2866)
GL_LIST_BIT = Constant( 'GL_LIST_BIT', 131072)
GL_LIST_INDEX = Constant( 'GL_LIST_INDEX', 2867)
GL_LIST_MODE = Constant( 'GL_LIST_MODE', 2864)
GL_LIST_PRIORITY_SGIX = Constant( 'GL_LIST_PRIORITY_SGIX', 33154)
GL_LOAD = Constant( 'GL_LOAD', 257)
GL_LOCAL_CONSTANT_DATATYPE_EXT = Constant( 'GL_LOCAL_CONSTANT_DATATYPE_EXT', 34797)
GL_LOCAL_CONSTANT_EXT = Constant( 'GL_LOCAL_CONSTANT_EXT', 34755)
GL_LOCAL_CONSTANT_VALUE_EXT = Constant( 'GL_LOCAL_CONSTANT_VALUE_EXT', 34796)
GL_LOCAL_EXT = Constant( 'GL_LOCAL_EXT', 34756)
GL_LOGIC_OP_MODE = Constant( 'GL_LOGIC_OP_MODE', 3056)
GL_LOWER_LEFT = Constant( 'GL_LOWER_LEFT', 36001)
GL_LO_BIAS_NV = Constant( 'GL_LO_BIAS_NV', 34581)
GL_LO_SCALE_NV = Constant( 'GL_LO_SCALE_NV', 34575)
GL_LUMINANCE = Constant( 'GL_LUMINANCE', 6409)
GL_LUMINANCE12 = Constant( 'GL_LUMINANCE12', 32833)
GL_LUMINANCE12_ALPHA12 = Constant( 'GL_LUMINANCE12_ALPHA12', 32839)
GL_LUMINANCE12_ALPHA12_EXT = Constant( 'GL_LUMINANCE12_ALPHA12_EXT', 32839)
GL_LUMINANCE12_ALPHA4 = Constant( 'GL_LUMINANCE12_ALPHA4', 32838)
GL_LUMINANCE12_ALPHA4_EXT = Constant( 'GL_LUMINANCE12_ALPHA4_EXT', 32838)
GL_LUMINANCE12_EXT = Constant( 'GL_LUMINANCE12_EXT', 32833)
GL_LUMINANCE16 = Constant( 'GL_LUMINANCE16', 32834)
GL_LUMINANCE16F_ARB = Constant( 'GL_LUMINANCE16F_ARB', 34846)
GL_LUMINANCE16_ALPHA16 = Constant( 'GL_LUMINANCE16_ALPHA16', 32840)
GL_LUMINANCE16_ALPHA16_EXT = Constant( 'GL_LUMINANCE16_ALPHA16_EXT', 32840)
GL_LUMINANCE16_EXT = Constant( 'GL_LUMINANCE16_EXT', 32834)
GL_LUMINANCE32F_ARB = Constant( 'GL_LUMINANCE32F_ARB', 34840)
GL_LUMINANCE4 = Constant( 'GL_LUMINANCE4', 32831)
GL_LUMINANCE4_ALPHA4 = Constant( 'GL_LUMINANCE4_ALPHA4', 32835)
GL_LUMINANCE4_ALPHA4_EXT = Constant( 'GL_LUMINANCE4_ALPHA4_EXT', 32835)
GL_LUMINANCE4_EXT = Constant( 'GL_LUMINANCE4_EXT', 32831)
GL_LUMINANCE6_ALPHA2 = Constant( 'GL_LUMINANCE6_ALPHA2', 32836)
GL_LUMINANCE6_ALPHA2_EXT = Constant( 'GL_LUMINANCE6_ALPHA2_EXT', 32836)
GL_LUMINANCE8 = Constant( 'GL_LUMINANCE8', 32832)
GL_LUMINANCE8_ALPHA8 = Constant( 'GL_LUMINANCE8_ALPHA8', 32837)
GL_LUMINANCE8_ALPHA8_EXT = Constant( 'GL_LUMINANCE8_ALPHA8_EXT', 32837)
GL_LUMINANCE8_EXT = Constant( 'GL_LUMINANCE8_EXT', 32832)
GL_LUMINANCE_ALPHA = Constant( 'GL_LUMINANCE_ALPHA', 6410)
GL_LUMINANCE_ALPHA16F_ARB = Constant( 'GL_LUMINANCE_ALPHA16F_ARB', 34847)
GL_LUMINANCE_ALPHA32F_ARB = Constant( 'GL_LUMINANCE_ALPHA32F_ARB', 34841)
GL_LUMINANCE_ALPHA_FLOAT16_ATI = Constant( 'GL_LUMINANCE_ALPHA_FLOAT16_ATI', 34847)
GL_LUMINANCE_ALPHA_FLOAT32_ATI = Constant( 'GL_LUMINANCE_ALPHA_FLOAT32_ATI', 34841)
GL_LUMINANCE_FLOAT16_ATI = Constant( 'GL_LUMINANCE_FLOAT16_ATI', 34846)
GL_LUMINANCE_FLOAT32_ATI = Constant( 'GL_LUMINANCE_FLOAT32_ATI', 34840)
GL_MAD_ATI = Constant( 'GL_MAD_ATI', 35176)
GL_MAGNITUDE_BIAS_NV = Constant( 'GL_MAGNITUDE_BIAS_NV', 34584)
GL_MAGNITUDE_SCALE_NV = Constant( 'GL_MAGNITUDE_SCALE_NV', 34578)
GL_MAP1_BINORMAL_EXT = Constant( 'GL_MAP1_BINORMAL_EXT', 33862)
GL_MAP1_COLOR_4 = Constant( 'GL_MAP1_COLOR_4', 3472)
GL_MAP1_GRID_DOMAIN = Constant( 'GL_MAP1_GRID_DOMAIN', 3536)
GL_MAP1_GRID_SEGMENTS = Constant( 'GL_MAP1_GRID_SEGMENTS', 3537)
GL_MAP1_INDEX = Constant( 'GL_MAP1_INDEX', 3473)
GL_MAP1_NORMAL = Constant( 'GL_MAP1_NORMAL', 3474)
GL_MAP1_TANGENT_EXT = Constant( 'GL_MAP1_TANGENT_EXT', 33860)
GL_MAP1_TEXTURE_COORD_1 = Constant( 'GL_MAP1_TEXTURE_COORD_1', 3475)
GL_MAP1_TEXTURE_COORD_2 = Constant( 'GL_MAP1_TEXTURE_COORD_2', 3476)
GL_MAP1_TEXTURE_COORD_3 = Constant( 'GL_MAP1_TEXTURE_COORD_3', 3477)
GL_MAP1_TEXTURE_COORD_4 = Constant( 'GL_MAP1_TEXTURE_COORD_4', 3478)
GL_MAP1_VERTEX_3 = Constant( 'GL_MAP1_VERTEX_3', 3479)
GL_MAP1_VERTEX_4 = Constant( 'GL_MAP1_VERTEX_4', 3480)
GL_MAP1_VERTEX_ATTRIB0_4_NV = Constant( 'GL_MAP1_VERTEX_ATTRIB0_4_NV', 34400)
GL_MAP1_VERTEX_ATTRIB10_4_NV = Constant( 'GL_MAP1_VERTEX_ATTRIB10_4_NV', 34410)
GL_MAP1_VERTEX_ATTRIB11_4_NV = Constant( 'GL_MAP1_VERTEX_ATTRIB11_4_NV', 34411)
GL_MAP1_VERTEX_ATTRIB12_4_NV = Constant( 'GL_MAP1_VERTEX_ATTRIB12_4_NV', 34412)
GL_MAP1_VERTEX_ATTRIB13_4_NV = Constant( 'GL_MAP1_VERTEX_ATTRIB13_4_NV', 34413)
GL_MAP1_VERTEX_ATTRIB14_4_NV = Constant( 'GL_MAP1_VERTEX_ATTRIB14_4_NV', 34414)
GL_MAP1_VERTEX_ATTRIB15_4_NV = Constant( 'GL_MAP1_VERTEX_ATTRIB15_4_NV', 34415)
GL_MAP1_VERTEX_ATTRIB1_4_NV = Constant( 'GL_MAP1_VERTEX_ATTRIB1_4_NV', 34401)
GL_MAP1_VERTEX_ATTRIB2_4_NV = Constant( 'GL_MAP1_VERTEX_ATTRIB2_4_NV', 34402)
GL_MAP1_VERTEX_ATTRIB3_4_NV = Constant( 'GL_MAP1_VERTEX_ATTRIB3_4_NV', 34403)
GL_MAP1_VERTEX_ATTRIB4_4_NV = Constant( 'GL_MAP1_VERTEX_ATTRIB4_4_NV', 34404)
GL_MAP1_VERTEX_ATTRIB5_4_NV = Constant( 'GL_MAP1_VERTEX_ATTRIB5_4_NV', 34405)
GL_MAP1_VERTEX_ATTRIB6_4_NV = Constant( 'GL_MAP1_VERTEX_ATTRIB6_4_NV', 34406)
GL_MAP1_VERTEX_ATTRIB7_4_NV = Constant( 'GL_MAP1_VERTEX_ATTRIB7_4_NV', 34407)
GL_MAP1_VERTEX_ATTRIB8_4_NV = Constant( 'GL_MAP1_VERTEX_ATTRIB8_4_NV', 34408)
GL_MAP1_VERTEX_ATTRIB9_4_NV = Constant( 'GL_MAP1_VERTEX_ATTRIB9_4_NV', 34409)
GL_MAP2_BINORMAL_EXT = Constant( 'GL_MAP2_BINORMAL_EXT', 33863)
GL_MAP2_COLOR_4 = Constant( 'GL_MAP2_COLOR_4', 3504)
GL_MAP2_GRID_DOMAIN = Constant( 'GL_MAP2_GRID_DOMAIN', 3538)
GL_MAP2_GRID_SEGMENTS = Constant( 'GL_MAP2_GRID_SEGMENTS', 3539)
GL_MAP2_INDEX = Constant( 'GL_MAP2_INDEX', 3505)
GL_MAP2_NORMAL = Constant( 'GL_MAP2_NORMAL', 3506)
GL_MAP2_TANGENT_EXT = Constant( 'GL_MAP2_TANGENT_EXT', 33861)
GL_MAP2_TEXTURE_COORD_1 = Constant( 'GL_MAP2_TEXTURE_COORD_1', 3507)
GL_MAP2_TEXTURE_COORD_2 = Constant( 'GL_MAP2_TEXTURE_COORD_2', 3508)
GL_MAP2_TEXTURE_COORD_3 = Constant( 'GL_MAP2_TEXTURE_COORD_3', 3509)
GL_MAP2_TEXTURE_COORD_4 = Constant( 'GL_MAP2_TEXTURE_COORD_4', 3510)
GL_MAP2_VERTEX_3 = Constant( 'GL_MAP2_VERTEX_3', 3511)
GL_MAP2_VERTEX_4 = Constant( 'GL_MAP2_VERTEX_4', 3512)
GL_MAP2_VERTEX_ATTRIB0_4_NV = Constant( 'GL_MAP2_VERTEX_ATTRIB0_4_NV', 34416)
GL_MAP2_VERTEX_ATTRIB10_4_NV = Constant( 'GL_MAP2_VERTEX_ATTRIB10_4_NV', 34426)
GL_MAP2_VERTEX_ATTRIB11_4_NV = Constant( 'GL_MAP2_VERTEX_ATTRIB11_4_NV', 34427)
GL_MAP2_VERTEX_ATTRIB12_4_NV = Constant( 'GL_MAP2_VERTEX_ATTRIB12_4_NV', 34428)
GL_MAP2_VERTEX_ATTRIB13_4_NV = Constant( 'GL_MAP2_VERTEX_ATTRIB13_4_NV', 34429)
GL_MAP2_VERTEX_ATTRIB14_4_NV = Constant( 'GL_MAP2_VERTEX_ATTRIB14_4_NV', 34430)
GL_MAP2_VERTEX_ATTRIB15_4_NV = Constant( 'GL_MAP2_VERTEX_ATTRIB15_4_NV', 34431)
GL_MAP2_VERTEX_ATTRIB1_4_NV = Constant( 'GL_MAP2_VERTEX_ATTRIB1_4_NV', 34417)
GL_MAP2_VERTEX_ATTRIB2_4_NV = Constant( 'GL_MAP2_VERTEX_ATTRIB2_4_NV', 34418)
GL_MAP2_VERTEX_ATTRIB3_4_NV = Constant( 'GL_MAP2_VERTEX_ATTRIB3_4_NV', 34419)
GL_MAP2_VERTEX_ATTRIB4_4_NV = Constant( 'GL_MAP2_VERTEX_ATTRIB4_4_NV', 34420)
GL_MAP2_VERTEX_ATTRIB5_4_NV = Constant( 'GL_MAP2_VERTEX_ATTRIB5_4_NV', 34421)
GL_MAP2_VERTEX_ATTRIB6_4_NV = Constant( 'GL_MAP2_VERTEX_ATTRIB6_4_NV', 34422)
GL_MAP2_VERTEX_ATTRIB7_4_NV = Constant( 'GL_MAP2_VERTEX_ATTRIB7_4_NV', 34423)
GL_MAP2_VERTEX_ATTRIB8_4_NV = Constant( 'GL_MAP2_VERTEX_ATTRIB8_4_NV', 34424)
GL_MAP2_VERTEX_ATTRIB9_4_NV = Constant( 'GL_MAP2_VERTEX_ATTRIB9_4_NV', 34425)
GL_MAP_ATTRIB_U_ORDER_NV = Constant( 'GL_MAP_ATTRIB_U_ORDER_NV', 34499)
GL_MAP_ATTRIB_V_ORDER_NV = Constant( 'GL_MAP_ATTRIB_V_ORDER_NV', 34500)
GL_MAP_COLOR = Constant( 'GL_MAP_COLOR', 3344)
GL_MAP_STENCIL = Constant( 'GL_MAP_STENCIL', 3345)
GL_MAP_TESSELLATION_NV = Constant( 'GL_MAP_TESSELLATION_NV', 34498)
GL_MATERIAL_SIDE_HINT_PGI = Constant( 'GL_MATERIAL_SIDE_HINT_PGI', 107052)
GL_MATRIX0_ARB = Constant( 'GL_MATRIX0_ARB', 35008)
GL_MATRIX0_NV = Constant( 'GL_MATRIX0_NV', 34352)
GL_MATRIX10_ARB = Constant( 'GL_MATRIX10_ARB', 35018)
GL_MATRIX11_ARB = Constant( 'GL_MATRIX11_ARB', 35019)
GL_MATRIX12_ARB = Constant( 'GL_MATRIX12_ARB', 35020)
GL_MATRIX13_ARB = Constant( 'GL_MATRIX13_ARB', 35021)
GL_MATRIX14_ARB = Constant( 'GL_MATRIX14_ARB', 35022)
GL_MATRIX15_ARB = Constant( 'GL_MATRIX15_ARB', 35023)
GL_MATRIX16_ARB = Constant( 'GL_MATRIX16_ARB', 35024)
GL_MATRIX17_ARB = Constant( 'GL_MATRIX17_ARB', 35025)
GL_MATRIX18_ARB = Constant( 'GL_MATRIX18_ARB', 35026)
GL_MATRIX19_ARB = Constant( 'GL_MATRIX19_ARB', 35027)
GL_MATRIX1_ARB = Constant( 'GL_MATRIX1_ARB', 35009)
GL_MATRIX1_NV = Constant( 'GL_MATRIX1_NV', 34353)
GL_MATRIX20_ARB = Constant( 'GL_MATRIX20_ARB', 35028)
GL_MATRIX21_ARB = Constant( 'GL_MATRIX21_ARB', 35029)
GL_MATRIX22_ARB = Constant( 'GL_MATRIX22_ARB', 35030)
GL_MATRIX23_ARB = Constant( 'GL_MATRIX23_ARB', 35031)
GL_MATRIX24_ARB = Constant( 'GL_MATRIX24_ARB', 35032)
GL_MATRIX25_ARB = Constant( 'GL_MATRIX25_ARB', 35033)
GL_MATRIX26_ARB = Constant( 'GL_MATRIX26_ARB', 35034)
GL_MATRIX27_ARB = Constant( 'GL_MATRIX27_ARB', 35035)
GL_MATRIX28_ARB = Constant( 'GL_MATRIX28_ARB', 35036)
GL_MATRIX29_ARB = Constant( 'GL_MATRIX29_ARB', 35037)
GL_MATRIX2_ARB = Constant( 'GL_MATRIX2_ARB', 35010)
GL_MATRIX2_NV = Constant( 'GL_MATRIX2_NV', 34354)
GL_MATRIX30_ARB = Constant( 'GL_MATRIX30_ARB', 35038)
GL_MATRIX31_ARB = Constant( 'GL_MATRIX31_ARB', 35039)
GL_MATRIX3_ARB = Constant( 'GL_MATRIX3_ARB', 35011)
GL_MATRIX3_NV = Constant( 'GL_MATRIX3_NV', 34355)
GL_MATRIX4_ARB = Constant( 'GL_MATRIX4_ARB', 35012)
GL_MATRIX4_NV = Constant( 'GL_MATRIX4_NV', 34356)
GL_MATRIX5_ARB = Constant( 'GL_MATRIX5_ARB', 35013)
GL_MATRIX5_NV = Constant( 'GL_MATRIX5_NV', 34357)
GL_MATRIX6_ARB = Constant( 'GL_MATRIX6_ARB', 35014)
GL_MATRIX6_NV = Constant( 'GL_MATRIX6_NV', 34358)
GL_MATRIX7_ARB = Constant( 'GL_MATRIX7_ARB', 35015)
GL_MATRIX7_NV = Constant( 'GL_MATRIX7_NV', 34359)
GL_MATRIX8_ARB = Constant( 'GL_MATRIX8_ARB', 35016)
GL_MATRIX9_ARB = Constant( 'GL_MATRIX9_ARB', 35017)
GL_MATRIX_EXT = Constant( 'GL_MATRIX_EXT', 34752)
GL_MATRIX_INDEX_ARRAY_ARB = Constant( 'GL_MATRIX_INDEX_ARRAY_ARB', 34884)
GL_MATRIX_INDEX_ARRAY_POINTER_ARB = Constant( 'GL_MATRIX_INDEX_ARRAY_POINTER_ARB', 34889)
GL_MATRIX_INDEX_ARRAY_SIZE_ARB = Constant( 'GL_MATRIX_INDEX_ARRAY_SIZE_ARB', 34886)
GL_MATRIX_INDEX_ARRAY_STRIDE_ARB = Constant( 'GL_MATRIX_INDEX_ARRAY_STRIDE_ARB', 34888)
GL_MATRIX_INDEX_ARRAY_TYPE_ARB = Constant( 'GL_MATRIX_INDEX_ARRAY_TYPE_ARB', 34887)
GL_MATRIX_MODE = Constant( 'GL_MATRIX_MODE', 2976)
GL_MATRIX_PALETTE_ARB = Constant( 'GL_MATRIX_PALETTE_ARB', 34880)
GL_MAT_AMBIENT_AND_DIFFUSE_BIT_PGI = Constant( 'GL_MAT_AMBIENT_AND_DIFFUSE_BIT_PGI', 2097152)
GL_MAT_AMBIENT_BIT_PGI = Constant( 'GL_MAT_AMBIENT_BIT_PGI', 1048576)
GL_MAT_COLOR_INDEXES_BIT_PGI = Constant( 'GL_MAT_COLOR_INDEXES_BIT_PGI', 16777216)
GL_MAT_DIFFUSE_BIT_PGI = Constant( 'GL_MAT_DIFFUSE_BIT_PGI', 4194304)
GL_MAT_EMISSION_BIT_PGI = Constant( 'GL_MAT_EMISSION_BIT_PGI', 8388608)
GL_MAT_SHININESS_BIT_PGI = Constant( 'GL_MAT_SHININESS_BIT_PGI', 33554432)
GL_MAT_SPECULAR_BIT_PGI = Constant( 'GL_MAT_SPECULAR_BIT_PGI', 67108864)
GL_MAX = Constant( 'GL_MAX', 32776)
GL_MAX_3D_TEXTURE_SIZE = Constant( 'GL_MAX_3D_TEXTURE_SIZE', 32883)
GL_MAX_3D_TEXTURE_SIZE_EXT = Constant( 'GL_MAX_3D_TEXTURE_SIZE_EXT', 32883)
GL_MAX_4D_TEXTURE_SIZE_SGIS = Constant( 'GL_MAX_4D_TEXTURE_SIZE_SGIS', 33080)
GL_MAX_ACTIVE_LIGHTS_SGIX = Constant( 'GL_MAX_ACTIVE_LIGHTS_SGIX', 33797)
GL_MAX_ASYNC_DRAW_PIXELS_SGIX = Constant( 'GL_MAX_ASYNC_DRAW_PIXELS_SGIX', 33632)
GL_MAX_ASYNC_HISTOGRAM_SGIX = Constant( 'GL_MAX_ASYNC_HISTOGRAM_SGIX', 33581)
GL_MAX_ASYNC_READ_PIXELS_SGIX = Constant( 'GL_MAX_ASYNC_READ_PIXELS_SGIX', 33633)
GL_MAX_ASYNC_TEX_IMAGE_SGIX = Constant( 'GL_MAX_ASYNC_TEX_IMAGE_SGIX', 33631)
GL_MAX_ATTRIB_STACK_DEPTH = Constant( 'GL_MAX_ATTRIB_STACK_DEPTH', 3381)
GL_MAX_CLIENT_ATTRIB_STACK_DEPTH = Constant( 'GL_MAX_CLIENT_ATTRIB_STACK_DEPTH', 3387)
GL_MAX_CLIPMAP_DEPTH_SGIX = Constant( 'GL_MAX_CLIPMAP_DEPTH_SGIX', 33143)
GL_MAX_CLIPMAP_VIRTUAL_DEPTH_SGIX = Constant( 'GL_MAX_CLIPMAP_VIRTUAL_DEPTH_SGIX', 33144)
GL_MAX_CLIP_PLANES = Constant( 'GL_MAX_CLIP_PLANES', 3378)
GL_MAX_COLOR_ATTACHMENTS_EXT = Constant( 'GL_MAX_COLOR_ATTACHMENTS_EXT', 36063)
GL_MAX_COLOR_MATRIX_STACK_DEPTH = Constant( 'GL_MAX_COLOR_MATRIX_STACK_DEPTH', 32947)
GL_MAX_COLOR_MATRIX_STACK_DEPTH_SGI = Constant( 'GL_MAX_COLOR_MATRIX_STACK_DEPTH_SGI', 32947)
GL_MAX_COMBINED_TEXTURE_IMAGE_UNITS = Constant( 'GL_MAX_COMBINED_TEXTURE_IMAGE_UNITS', 35661)
GL_MAX_COMBINED_TEXTURE_IMAGE_UNITS_ARB = Constant( 'GL_MAX_COMBINED_TEXTURE_IMAGE_UNITS_ARB', 35661)
GL_MAX_CONVOLUTION_HEIGHT = Constant( 'GL_MAX_CONVOLUTION_HEIGHT', 32795)
GL_MAX_CONVOLUTION_HEIGHT_EXT = Constant( 'GL_MAX_CONVOLUTION_HEIGHT_EXT', 32795)
GL_MAX_CONVOLUTION_WIDTH = Constant( 'GL_MAX_CONVOLUTION_WIDTH', 32794)
GL_MAX_CONVOLUTION_WIDTH_EXT = Constant( 'GL_MAX_CONVOLUTION_WIDTH_EXT', 32794)
GL_MAX_CUBE_MAP_TEXTURE_SIZE = Constant( 'GL_MAX_CUBE_MAP_TEXTURE_SIZE', 34076)
GL_MAX_CUBE_MAP_TEXTURE_SIZE_ARB = Constant( 'GL_MAX_CUBE_MAP_TEXTURE_SIZE_ARB', 34076)
GL_MAX_CUBE_MAP_TEXTURE_SIZE_EXT = Constant( 'GL_MAX_CUBE_MAP_TEXTURE_SIZE_EXT', 34076)
GL_MAX_DEFORMATION_ORDER_SGIX = Constant( 'GL_MAX_DEFORMATION_ORDER_SGIX', 33175)
GL_MAX_DRAW_BUFFERS = Constant( 'GL_MAX_DRAW_BUFFERS', 34852)
GL_MAX_DRAW_BUFFERS_ARB = Constant( 'GL_MAX_DRAW_BUFFERS_ARB', 34852)
GL_MAX_DRAW_BUFFERS_ATI = Constant( 'GL_MAX_DRAW_BUFFERS_ATI', 34852)
GL_MAX_ELEMENTS_INDICES = Constant( 'GL_MAX_ELEMENTS_INDICES', 33001)
GL_MAX_ELEMENTS_INDICES_EXT = Constant( 'GL_MAX_ELEMENTS_INDICES_EXT', 33001)
GL_MAX_ELEMENTS_VERTICES = Constant( 'GL_MAX_ELEMENTS_VERTICES', 33000)
GL_MAX_ELEMENTS_VERTICES_EXT = Constant( 'GL_MAX_ELEMENTS_VERTICES_EXT', 33000)
GL_MAX_EVAL_ORDER = Constant( 'GL_MAX_EVAL_ORDER', 3376)
GL_MAX_EXT = Constant( 'GL_MAX_EXT', 32776)
GL_MAX_FOG_FUNC_POINTS_SGIS = Constant( 'GL_MAX_FOG_FUNC_POINTS_SGIS', 33068)
GL_MAX_FRAGMENT_LIGHTS_SGIX = Constant( 'GL_MAX_FRAGMENT_LIGHTS_SGIX', 33796)
GL_MAX_FRAGMENT_PROGRAM_LOCAL_PARAMETERS_NV = Constant( 'GL_MAX_FRAGMENT_PROGRAM_LOCAL_PARAMETERS_NV', 34920)
GL_MAX_FRAGMENT_UNIFORM_COMPONENTS = Constant( 'GL_MAX_FRAGMENT_UNIFORM_COMPONENTS', 35657)
GL_MAX_FRAGMENT_UNIFORM_COMPONENTS_ARB = Constant( 'GL_MAX_FRAGMENT_UNIFORM_COMPONENTS_ARB', 35657)
GL_MAX_FRAMEZOOM_FACTOR_SGIX = Constant( 'GL_MAX_FRAMEZOOM_FACTOR_SGIX', 33165)
GL_MAX_GENERAL_COMBINERS_NV = Constant( 'GL_MAX_GENERAL_COMBINERS_NV', 34125)
GL_MAX_LIGHTS = Constant( 'GL_MAX_LIGHTS', 3377)
GL_MAX_LIST_NESTING = Constant( 'GL_MAX_LIST_NESTING', 2865)
GL_MAX_MAP_TESSELLATION_NV = Constant( 'GL_MAX_MAP_TESSELLATION_NV', 34518)
GL_MAX_MATRIX_PALETTE_STACK_DEPTH_ARB = Constant( 'GL_MAX_MATRIX_PALETTE_STACK_DEPTH_ARB', 34881)
GL_MAX_MODELVIEW_STACK_DEPTH = Constant( 'GL_MAX_MODELVIEW_STACK_DEPTH', 3382)
GL_MAX_NAME_STACK_DEPTH = Constant( 'GL_MAX_NAME_STACK_DEPTH', 3383)
GL_MAX_OPTIMIZED_VERTEX_SHADER_INSTRUCTIONS_EXT = Constant( 'GL_MAX_OPTIMIZED_VERTEX_SHADER_INSTRUCTIONS_EXT', 34762)
GL_MAX_OPTIMIZED_VERTEX_SHADER_INVARIANTS_EXT = Constant( 'GL_MAX_OPTIMIZED_VERTEX_SHADER_INVARIANTS_EXT', 34765)
GL_MAX_OPTIMIZED_VERTEX_SHADER_LOCALS_EXT = Constant( 'GL_MAX_OPTIMIZED_VERTEX_SHADER_LOCALS_EXT', 34766)
GL_MAX_OPTIMIZED_VERTEX_SHADER_LOCAL_CONSTANTS_EXT = Constant( 'GL_MAX_OPTIMIZED_VERTEX_SHADER_LOCAL_CONSTANTS_EXT', 34764)
GL_MAX_OPTIMIZED_VERTEX_SHADER_VARIANTS_EXT = Constant( 'GL_MAX_OPTIMIZED_VERTEX_SHADER_VARIANTS_EXT', 34763)
GL_MAX_PALETTE_MATRICES_ARB = Constant( 'GL_MAX_PALETTE_MATRICES_ARB', 34882)
GL_MAX_PIXEL_MAP_TABLE = Constant( 'GL_MAX_PIXEL_MAP_TABLE', 3380)
GL_MAX_PIXEL_TRANSFORM_2D_STACK_DEPTH_EXT = Constant( 'GL_MAX_PIXEL_TRANSFORM_2D_STACK_DEPTH_EXT', 33591)
GL_MAX_PN_TRIANGLES_TESSELATION_LEVEL_ATI = Constant( 'GL_MAX_PN_TRIANGLES_TESSELATION_LEVEL_ATI', 34801)
GL_MAX_PROGRAM_ADDRESS_REGISTERS_ARB = Constant( 'GL_MAX_PROGRAM_ADDRESS_REGISTERS_ARB', 34993)
GL_MAX_PROGRAM_ALU_INSTRUCTIONS_ARB = Constant( 'GL_MAX_PROGRAM_ALU_INSTRUCTIONS_ARB', 34827)
GL_MAX_PROGRAM_ATTRIBS_ARB = Constant( 'GL_MAX_PROGRAM_ATTRIBS_ARB', 34989)
GL_MAX_PROGRAM_CALL_DEPTH_NV = Constant( 'GL_MAX_PROGRAM_CALL_DEPTH_NV', 35061)
GL_MAX_PROGRAM_ENV_PARAMETERS_ARB = Constant( 'GL_MAX_PROGRAM_ENV_PARAMETERS_ARB', 34997)
GL_MAX_PROGRAM_EXEC_INSTRUCTIONS_NV = Constant( 'GL_MAX_PROGRAM_EXEC_INSTRUCTIONS_NV', 35060)
GL_MAX_PROGRAM_IF_DEPTH_NV = Constant( 'GL_MAX_PROGRAM_IF_DEPTH_NV', 35062)
GL_MAX_PROGRAM_INSTRUCTIONS_ARB = Constant( 'GL_MAX_PROGRAM_INSTRUCTIONS_ARB', 34977)
GL_MAX_PROGRAM_LOCAL_PARAMETERS_ARB = Constant( 'GL_MAX_PROGRAM_LOCAL_PARAMETERS_ARB', 34996)
GL_MAX_PROGRAM_LOOP_COUNT_NV = Constant( 'GL_MAX_PROGRAM_LOOP_COUNT_NV', 35064)
GL_MAX_PROGRAM_LOOP_DEPTH_NV = Constant( 'GL_MAX_PROGRAM_LOOP_DEPTH_NV', 35063)
GL_MAX_PROGRAM_MATRICES_ARB = Constant( 'GL_MAX_PROGRAM_MATRICES_ARB', 34351)
GL_MAX_PROGRAM_MATRIX_STACK_DEPTH_ARB = Constant( 'GL_MAX_PROGRAM_MATRIX_STACK_DEPTH_ARB', 34350)
GL_MAX_PROGRAM_NATIVE_ADDRESS_REGISTERS_ARB = Constant( 'GL_MAX_PROGRAM_NATIVE_ADDRESS_REGISTERS_ARB', 34995)
GL_MAX_PROGRAM_NATIVE_ALU_INSTRUCTIONS_ARB = Constant( 'GL_MAX_PROGRAM_NATIVE_ALU_INSTRUCTIONS_ARB', 34830)
GL_MAX_PROGRAM_NATIVE_ATTRIBS_ARB = Constant( 'GL_MAX_PROGRAM_NATIVE_ATTRIBS_ARB', 34991)
GL_MAX_PROGRAM_NATIVE_INSTRUCTIONS_ARB = Constant( 'GL_MAX_PROGRAM_NATIVE_INSTRUCTIONS_ARB', 34979)
GL_MAX_PROGRAM_NATIVE_PARAMETERS_ARB = Constant( 'GL_MAX_PROGRAM_NATIVE_PARAMETERS_ARB', 34987)
GL_MAX_PROGRAM_NATIVE_TEMPORARIES_ARB = Constant( 'GL_MAX_PROGRAM_NATIVE_TEMPORARIES_ARB', 34983)
GL_MAX_PROGRAM_NATIVE_TEX_INDIRECTIONS_ARB = Constant( 'GL_MAX_PROGRAM_NATIVE_TEX_INDIRECTIONS_ARB', 34832)
GL_MAX_PROGRAM_NATIVE_TEX_INSTRUCTIONS_ARB = Constant( 'GL_MAX_PROGRAM_NATIVE_TEX_INSTRUCTIONS_ARB', 34831)
GL_MAX_PROGRAM_PARAMETERS_ARB = Constant( 'GL_MAX_PROGRAM_PARAMETERS_ARB', 34985)
GL_MAX_PROGRAM_TEMPORARIES_ARB = Constant( 'GL_MAX_PROGRAM_TEMPORARIES_ARB', 34981)
GL_MAX_PROGRAM_TEX_INDIRECTIONS_ARB = Constant( 'GL_MAX_PROGRAM_TEX_INDIRECTIONS_ARB', 34829)
GL_MAX_PROGRAM_TEX_INSTRUCTIONS_ARB = Constant( 'GL_MAX_PROGRAM_TEX_INSTRUCTIONS_ARB', 34828)
GL_MAX_PROJECTION_STACK_DEPTH = Constant( 'GL_MAX_PROJECTION_STACK_DEPTH', 3384)
GL_MAX_RATIONAL_EVAL_ORDER_NV = Constant( 'GL_MAX_RATIONAL_EVAL_ORDER_NV', 34519)
GL_MAX_RECTANGLE_TEXTURE_SIZE_ARB = Constant( 'GL_MAX_RECTANGLE_TEXTURE_SIZE_ARB', 34040)
GL_MAX_RECTANGLE_TEXTURE_SIZE_NV = Constant( 'GL_MAX_RECTANGLE_TEXTURE_SIZE_NV', 34040)
GL_MAX_RENDERBUFFER_SIZE_EXT = Constant( 'GL_MAX_RENDERBUFFER_SIZE_EXT', 34024)
GL_MAX_SHININESS_NV = Constant( 'GL_MAX_SHININESS_NV', 34052)
GL_MAX_SPOT_EXPONENT_NV = Constant( 'GL_MAX_SPOT_EXPONENT_NV', 34053)
GL_MAX_TEXTURE_COORDS = Constant( 'GL_MAX_TEXTURE_COORDS', 34929)
GL_MAX_TEXTURE_COORDS_ARB = Constant( 'GL_MAX_TEXTURE_COORDS_ARB', 34929)
GL_MAX_TEXTURE_COORDS_NV = Constant( 'GL_MAX_TEXTURE_COORDS_NV', 34929)
GL_MAX_TEXTURE_IMAGE_UNITS = Constant( 'GL_MAX_TEXTURE_IMAGE_UNITS', 34930)
GL_MAX_TEXTURE_IMAGE_UNITS_ARB = Constant( 'GL_MAX_TEXTURE_IMAGE_UNITS_ARB', 34930)
GL_MAX_TEXTURE_IMAGE_UNITS_NV = Constant( 'GL_MAX_TEXTURE_IMAGE_UNITS_NV', 34930)
GL_MAX_TEXTURE_LOD_BIAS = Constant( 'GL_MAX_TEXTURE_LOD_BIAS', 34045)
GL_MAX_TEXTURE_LOD_BIAS_EXT = Constant( 'GL_MAX_TEXTURE_LOD_BIAS_EXT', 34045)
GL_MAX_TEXTURE_MAX_ANISOTROPY_EXT = Constant( 'GL_MAX_TEXTURE_MAX_ANISOTROPY_EXT', 34047)
GL_MAX_TEXTURE_SIZE = Constant( 'GL_MAX_TEXTURE_SIZE', 3379)
GL_MAX_TEXTURE_STACK_DEPTH = Constant( 'GL_MAX_TEXTURE_STACK_DEPTH', 3385)
GL_MAX_TEXTURE_UNITS = Constant( 'GL_MAX_TEXTURE_UNITS', 34018)
GL_MAX_TEXTURE_UNITS_ARB = Constant( 'GL_MAX_TEXTURE_UNITS_ARB', 34018)
GL_MAX_TRACK_MATRICES_NV = Constant( 'GL_MAX_TRACK_MATRICES_NV', 34351)
GL_MAX_TRACK_MATRIX_STACK_DEPTH_NV = Constant( 'GL_MAX_TRACK_MATRIX_STACK_DEPTH_NV', 34350)
GL_MAX_VARYING_FLOATS = Constant( 'GL_MAX_VARYING_FLOATS', 35659)
GL_MAX_VARYING_FLOATS_ARB = Constant( 'GL_MAX_VARYING_FLOATS_ARB', 35659)
GL_MAX_VERTEX_ARRAY_RANGE_ELEMENT_NV = Constant( 'GL_MAX_VERTEX_ARRAY_RANGE_ELEMENT_NV', 34080)
GL_MAX_VERTEX_ATTRIBS = Constant( 'GL_MAX_VERTEX_ATTRIBS', 34921)
GL_MAX_VERTEX_ATTRIBS_ARB = Constant( 'GL_MAX_VERTEX_ATTRIBS_ARB', 34921)
GL_MAX_VERTEX_HINT_PGI = Constant( 'GL_MAX_VERTEX_HINT_PGI', 107053)
GL_MAX_VERTEX_SHADER_INSTRUCTIONS_EXT = Constant( 'GL_MAX_VERTEX_SHADER_INSTRUCTIONS_EXT', 34757)
GL_MAX_VERTEX_SHADER_INVARIANTS_EXT = Constant( 'GL_MAX_VERTEX_SHADER_INVARIANTS_EXT', 34759)
GL_MAX_VERTEX_SHADER_LOCALS_EXT = Constant( 'GL_MAX_VERTEX_SHADER_LOCALS_EXT', 34761)
GL_MAX_VERTEX_SHADER_LOCAL_CONSTANTS_EXT = Constant( 'GL_MAX_VERTEX_SHADER_LOCAL_CONSTANTS_EXT', 34760)
GL_MAX_VERTEX_SHADER_VARIANTS_EXT = Constant( 'GL_MAX_VERTEX_SHADER_VARIANTS_EXT', 34758)
GL_MAX_VERTEX_STREAMS_ATI = Constant( 'GL_MAX_VERTEX_STREAMS_ATI', 34667)
GL_MAX_VERTEX_TEXTURE_IMAGE_UNITS = Constant( 'GL_MAX_VERTEX_TEXTURE_IMAGE_UNITS', 35660)
GL_MAX_VERTEX_TEXTURE_IMAGE_UNITS_ARB = Constant( 'GL_MAX_VERTEX_TEXTURE_IMAGE_UNITS_ARB', 35660)
GL_MAX_VERTEX_UNIFORM_COMPONENTS = Constant( 'GL_MAX_VERTEX_UNIFORM_COMPONENTS', 35658)
GL_MAX_VERTEX_UNIFORM_COMPONENTS_ARB = Constant( 'GL_MAX_VERTEX_UNIFORM_COMPONENTS_ARB', 35658)
GL_MAX_VERTEX_UNITS_ARB = Constant( 'GL_MAX_VERTEX_UNITS_ARB', 34468)
GL_MAX_VIEWPORT_DIMS = Constant( 'GL_MAX_VIEWPORT_DIMS', 3386)
GL_MIN = Constant( 'GL_MIN', 32775)
GL_MINMAX = Constant( 'GL_MINMAX', 32814)
GL_MINMAX_EXT = Constant( 'GL_MINMAX_EXT', 32814)
GL_MINMAX_FORMAT = Constant( 'GL_MINMAX_FORMAT', 32815)
GL_MINMAX_FORMAT_EXT = Constant( 'GL_MINMAX_FORMAT_EXT', 32815)
GL_MINMAX_SINK = Constant( 'GL_MINMAX_SINK', 32816)
GL_MINMAX_SINK_EXT = Constant( 'GL_MINMAX_SINK_EXT', 32816)
GL_MIN_EXT = Constant( 'GL_MIN_EXT', 32775)
GL_MIRRORED_REPEAT = Constant( 'GL_MIRRORED_REPEAT', 33648)
GL_MIRRORED_REPEAT_ARB = Constant( 'GL_MIRRORED_REPEAT_ARB', 33648)
GL_MIRRORED_REPEAT_IBM = Constant( 'GL_MIRRORED_REPEAT_IBM', 33648)
GL_MIRROR_CLAMP_ATI = Constant( 'GL_MIRROR_CLAMP_ATI', 34626)
GL_MIRROR_CLAMP_EXT = Constant( 'GL_MIRROR_CLAMP_EXT', 34626)
GL_MIRROR_CLAMP_TO_BORDER_EXT = Constant( 'GL_MIRROR_CLAMP_TO_BORDER_EXT', 35090)
GL_MIRROR_CLAMP_TO_EDGE_ATI = Constant( 'GL_MIRROR_CLAMP_TO_EDGE_ATI', 34627)
GL_MIRROR_CLAMP_TO_EDGE_EXT = Constant( 'GL_MIRROR_CLAMP_TO_EDGE_EXT', 34627)
GL_MODELVIEW = Constant( 'GL_MODELVIEW', 5888)
GL_MODELVIEW0_ARB = Constant( 'GL_MODELVIEW0_ARB', 5888)
GL_MODELVIEW10_ARB = Constant( 'GL_MODELVIEW10_ARB', 34602)
GL_MODELVIEW11_ARB = Constant( 'GL_MODELVIEW11_ARB', 34603)
GL_MODELVIEW12_ARB = Constant( 'GL_MODELVIEW12_ARB', 34604)
GL_MODELVIEW13_ARB = Constant( 'GL_MODELVIEW13_ARB', 34605)
GL_MODELVIEW14_ARB = Constant( 'GL_MODELVIEW14_ARB', 34606)
GL_MODELVIEW15_ARB = Constant( 'GL_MODELVIEW15_ARB', 34607)
GL_MODELVIEW16_ARB = Constant( 'GL_MODELVIEW16_ARB', 34608)
GL_MODELVIEW17_ARB = Constant( 'GL_MODELVIEW17_ARB', 34609)
GL_MODELVIEW18_ARB = Constant( 'GL_MODELVIEW18_ARB', 34610)
GL_MODELVIEW19_ARB = Constant( 'GL_MODELVIEW19_ARB', 34611)
GL_MODELVIEW1_ARB = Constant( 'GL_MODELVIEW1_ARB', 34058)
GL_MODELVIEW1_EXT = Constant( 'GL_MODELVIEW1_EXT', 34058)
GL_MODELVIEW1_MATRIX_EXT = Constant( 'GL_MODELVIEW1_MATRIX_EXT', 34054)
GL_MODELVIEW1_STACK_DEPTH_EXT = Constant( 'GL_MODELVIEW1_STACK_DEPTH_EXT', 34050)
GL_MODELVIEW20_ARB = Constant( 'GL_MODELVIEW20_ARB', 34612)
GL_MODELVIEW21_ARB = Constant( 'GL_MODELVIEW21_ARB', 34613)
GL_MODELVIEW22_ARB = Constant( 'GL_MODELVIEW22_ARB', 34614)
GL_MODELVIEW23_ARB = Constant( 'GL_MODELVIEW23_ARB', 34615)
GL_MODELVIEW24_ARB = Constant( 'GL_MODELVIEW24_ARB', 34616)
GL_MODELVIEW25_ARB = Constant( 'GL_MODELVIEW25_ARB', 34617)
GL_MODELVIEW26_ARB = Constant( 'GL_MODELVIEW26_ARB', 34618)
GL_MODELVIEW27_ARB = Constant( 'GL_MODELVIEW27_ARB', 34619)
GL_MODELVIEW28_ARB = Constant( 'GL_MODELVIEW28_ARB', 34620)
GL_MODELVIEW29_ARB = Constant( 'GL_MODELVIEW29_ARB', 34621)
GL_MODELVIEW2_ARB = Constant( 'GL_MODELVIEW2_ARB', 34594)
GL_MODELVIEW30_ARB = Constant( 'GL_MODELVIEW30_ARB', 34622)
GL_MODELVIEW31_ARB = Constant( 'GL_MODELVIEW31_ARB', 34623)
GL_MODELVIEW3_ARB = Constant( 'GL_MODELVIEW3_ARB', 34595)
GL_MODELVIEW4_ARB = Constant( 'GL_MODELVIEW4_ARB', 34596)
GL_MODELVIEW5_ARB = Constant( 'GL_MODELVIEW5_ARB', 34597)
GL_MODELVIEW6_ARB = Constant( 'GL_MODELVIEW6_ARB', 34598)
GL_MODELVIEW7_ARB = Constant( 'GL_MODELVIEW7_ARB', 34599)
GL_MODELVIEW8_ARB = Constant( 'GL_MODELVIEW8_ARB', 34600)
GL_MODELVIEW9_ARB = Constant( 'GL_MODELVIEW9_ARB', 34601)
GL_MODELVIEW_MATRIX = Constant( 'GL_MODELVIEW_MATRIX', 2982)
GL_MODELVIEW_PROJECTION_NV = Constant( 'GL_MODELVIEW_PROJECTION_NV', 34345)
GL_MODELVIEW_STACK_DEPTH = Constant( 'GL_MODELVIEW_STACK_DEPTH', 2979)
GL_MODULATE = Constant( 'GL_MODULATE', 8448)
GL_MODULATE_ADD_ATI = Constant( 'GL_MODULATE_ADD_ATI', 34628)
GL_MODULATE_SIGNED_ADD_ATI = Constant( 'GL_MODULATE_SIGNED_ADD_ATI', 34629)
GL_MODULATE_SUBTRACT_ATI = Constant( 'GL_MODULATE_SUBTRACT_ATI', 34630)
GL_MOV_ATI = Constant( 'GL_MOV_ATI', 35169)
GL_MULT = Constant( 'GL_MULT', 259)
GL_MULTISAMPLE = Constant( 'GL_MULTISAMPLE', 32925)
GL_MULTISAMPLE_3DFX = Constant( 'GL_MULTISAMPLE_3DFX', 34482)
GL_MULTISAMPLE_ARB = Constant( 'GL_MULTISAMPLE_ARB', 32925)
GL_MULTISAMPLE_BIT = Constant( 'GL_MULTISAMPLE_BIT', 536870912)
GL_MULTISAMPLE_BIT_3DFX = Constant( 'GL_MULTISAMPLE_BIT_3DFX', 536870912)
GL_MULTISAMPLE_BIT_ARB = Constant( 'GL_MULTISAMPLE_BIT_ARB', 536870912)
GL_MULTISAMPLE_BIT_EXT = Constant( 'GL_MULTISAMPLE_BIT_EXT', 536870912)
GL_MULTISAMPLE_EXT = Constant( 'GL_MULTISAMPLE_EXT', 32925)
GL_MULTISAMPLE_FILTER_HINT_NV = Constant( 'GL_MULTISAMPLE_FILTER_HINT_NV', 34100)
GL_MULTISAMPLE_SGIS = Constant( 'GL_MULTISAMPLE_SGIS', 32925)
GL_MUL_ATI = Constant( 'GL_MUL_ATI', 35172)
GL_MVP_MATRIX_EXT = Constant( 'GL_MVP_MATRIX_EXT', 34787)
GL_N3F_V3F = Constant( 'GL_N3F_V3F', 10789)
GL_NAME_STACK_DEPTH = Constant( 'GL_NAME_STACK_DEPTH', 3440)
GL_NAND = Constant( 'GL_NAND', 5390)
GL_NATIVE_GRAPHICS_BEGIN_HINT_PGI = Constant( 'GL_NATIVE_GRAPHICS_BEGIN_HINT_PGI', 107011)
GL_NATIVE_GRAPHICS_END_HINT_PGI = Constant( 'GL_NATIVE_GRAPHICS_END_HINT_PGI', 107012)
GL_NATIVE_GRAPHICS_HANDLE_PGI = Constant( 'GL_NATIVE_GRAPHICS_HANDLE_PGI', 107010)
GL_NEAREST = Constant( 'GL_NEAREST', 9728)
GL_NEAREST_CLIPMAP_LINEAR_SGIX = Constant( 'GL_NEAREST_CLIPMAP_LINEAR_SGIX', 33870)
GL_NEAREST_CLIPMAP_NEAREST_SGIX = Constant( 'GL_NEAREST_CLIPMAP_NEAREST_SGIX', 33869)
GL_NEAREST_MIPMAP_LINEAR = Constant( 'GL_NEAREST_MIPMAP_LINEAR', 9986)
GL_NEAREST_MIPMAP_NEAREST = Constant( 'GL_NEAREST_MIPMAP_NEAREST', 9984)
GL_NEGATE_BIT_ATI = Constant( 'GL_NEGATE_BIT_ATI', 4)
GL_NEGATIVE_ONE_EXT = Constant( 'GL_NEGATIVE_ONE_EXT', 34783)
GL_NEGATIVE_W_EXT = Constant( 'GL_NEGATIVE_W_EXT', 34780)
GL_NEGATIVE_X_EXT = Constant( 'GL_NEGATIVE_X_EXT', 34777)
GL_NEGATIVE_Y_EXT = Constant( 'GL_NEGATIVE_Y_EXT', 34778)
GL_NEGATIVE_Z_EXT = Constant( 'GL_NEGATIVE_Z_EXT', 34779)
GL_NEVER = Constant( 'GL_NEVER', 512)
GL_NICEST = Constant( 'GL_NICEST', 4354)
GL_NONE = Constant( 'GL_NONE', 0)
GL_NOOP = Constant( 'GL_NOOP', 5381)
GL_NOR = Constant( 'GL_NOR', 5384)
GL_NORMALIZE = Constant( 'GL_NORMALIZE', 2977)
GL_NORMALIZED_RANGE_EXT = Constant( 'GL_NORMALIZED_RANGE_EXT', 34784)
GL_NORMAL_ARRAY = Constant( 'GL_NORMAL_ARRAY', 32885)
GL_NORMAL_ARRAY_BUFFER_BINDING = Constant( 'GL_NORMAL_ARRAY_BUFFER_BINDING', 34967)
GL_NORMAL_ARRAY_BUFFER_BINDING_ARB = Constant( 'GL_NORMAL_ARRAY_BUFFER_BINDING_ARB', 34967)
GL_NORMAL_ARRAY_COUNT_EXT = Constant( 'GL_NORMAL_ARRAY_COUNT_EXT', 32896)
GL_NORMAL_ARRAY_EXT = Constant( 'GL_NORMAL_ARRAY_EXT', 32885)
GL_NORMAL_ARRAY_LIST_IBM = Constant( 'GL_NORMAL_ARRAY_LIST_IBM', 103071)
GL_NORMAL_ARRAY_LIST_STRIDE_IBM = Constant( 'GL_NORMAL_ARRAY_LIST_STRIDE_IBM', 103081)
GL_NORMAL_ARRAY_PARALLEL_POINTERS_INTEL = Constant( 'GL_NORMAL_ARRAY_PARALLEL_POINTERS_INTEL', 33782)
GL_NORMAL_ARRAY_POINTER = Constant( 'GL_NORMAL_ARRAY_POINTER', 32911)
GL_NORMAL_ARRAY_POINTER_EXT = Constant( 'GL_NORMAL_ARRAY_POINTER_EXT', 32911)
GL_NORMAL_ARRAY_STRIDE = Constant( 'GL_NORMAL_ARRAY_STRIDE', 32895)
GL_NORMAL_ARRAY_STRIDE_EXT = Constant( 'GL_NORMAL_ARRAY_STRIDE_EXT', 32895)
GL_NORMAL_ARRAY_TYPE = Constant( 'GL_NORMAL_ARRAY_TYPE', 32894)
GL_NORMAL_ARRAY_TYPE_EXT = Constant( 'GL_NORMAL_ARRAY_TYPE_EXT', 32894)
GL_NORMAL_BIT_PGI = Constant( 'GL_NORMAL_BIT_PGI', 134217728)
GL_NORMAL_MAP = Constant( 'GL_NORMAL_MAP', 34065)
GL_NORMAL_MAP_ARB = Constant( 'GL_NORMAL_MAP_ARB', 34065)
GL_NORMAL_MAP_EXT = Constant( 'GL_NORMAL_MAP_EXT', 34065)
GL_NORMAL_MAP_NV = Constant( 'GL_NORMAL_MAP_NV', 34065)
GL_NOTEQUAL = Constant( 'GL_NOTEQUAL', 517)
GL_NO_ERROR = Constant( 'GL_NO_ERROR', 0)
GL_NUM_COMPRESSED_TEXTURE_FORMATS = Constant( 'GL_NUM_COMPRESSED_TEXTURE_FORMATS', 34466)
GL_NUM_COMPRESSED_TEXTURE_FORMATS_ARB = Constant( 'GL_NUM_COMPRESSED_TEXTURE_FORMATS_ARB', 34466)
GL_NUM_FRAGMENT_CONSTANTS_ATI = Constant( 'GL_NUM_FRAGMENT_CONSTANTS_ATI', 35183)
GL_NUM_FRAGMENT_REGISTERS_ATI = Constant( 'GL_NUM_FRAGMENT_REGISTERS_ATI', 35182)
GL_NUM_GENERAL_COMBINERS_NV = Constant( 'GL_NUM_GENERAL_COMBINERS_NV', 34126)
GL_NUM_INPUT_INTERPOLATOR_COMPONENTS_ATI = Constant( 'GL_NUM_INPUT_INTERPOLATOR_COMPONENTS_ATI', 35187)
GL_NUM_INSTRUCTIONS_PER_PASS_ATI = Constant( 'GL_NUM_INSTRUCTIONS_PER_PASS_ATI', 35185)
GL_NUM_INSTRUCTIONS_TOTAL_ATI = Constant( 'GL_NUM_INSTRUCTIONS_TOTAL_ATI', 35186)
GL_NUM_LOOPBACK_COMPONENTS_ATI = Constant( 'GL_NUM_LOOPBACK_COMPONENTS_ATI', 35188)
GL_NUM_PASSES_ATI = Constant( 'GL_NUM_PASSES_ATI', 35184)
GL_OBJECT_ACTIVE_ATTRIBUTES_ARB = Constant( 'GL_OBJECT_ACTIVE_ATTRIBUTES_ARB', 35721)
GL_OBJECT_ACTIVE_ATTRIBUTE_MAX_LENGTH_ARB = Constant( 'GL_OBJECT_ACTIVE_ATTRIBUTE_MAX_LENGTH_ARB', 35722)
GL_OBJECT_ACTIVE_UNIFORMS_ARB = Constant( 'GL_OBJECT_ACTIVE_UNIFORMS_ARB', 35718)
GL_OBJECT_ACTIVE_UNIFORM_MAX_LENGTH_ARB = Constant( 'GL_OBJECT_ACTIVE_UNIFORM_MAX_LENGTH_ARB', 35719)
GL_OBJECT_ATTACHED_OBJECTS_ARB = Constant( 'GL_OBJECT_ATTACHED_OBJECTS_ARB', 35717)
GL_OBJECT_BUFFER_SIZE_ATI = Constant( 'GL_OBJECT_BUFFER_SIZE_ATI', 34660)
GL_OBJECT_BUFFER_USAGE_ATI = Constant( 'GL_OBJECT_BUFFER_USAGE_ATI', 34661)
GL_OBJECT_COMPILE_STATUS_ARB = Constant( 'GL_OBJECT_COMPILE_STATUS_ARB', 35713)
GL_OBJECT_DELETE_STATUS_ARB = Constant( 'GL_OBJECT_DELETE_STATUS_ARB', 35712)
GL_OBJECT_DISTANCE_TO_LINE_SGIS = Constant( 'GL_OBJECT_DISTANCE_TO_LINE_SGIS', 33267)
GL_OBJECT_DISTANCE_TO_POINT_SGIS = Constant( 'GL_OBJECT_DISTANCE_TO_POINT_SGIS', 33265)
GL_OBJECT_INFO_LOG_LENGTH_ARB = Constant( 'GL_OBJECT_INFO_LOG_LENGTH_ARB', 35716)
GL_OBJECT_LINEAR = Constant( 'GL_OBJECT_LINEAR', 9217)
GL_OBJECT_LINE_SGIS = Constant( 'GL_OBJECT_LINE_SGIS', 33271)
GL_OBJECT_LINK_STATUS_ARB = Constant( 'GL_OBJECT_LINK_STATUS_ARB', 35714)
GL_OBJECT_PLANE = Constant( 'GL_OBJECT_PLANE', 9473)
GL_OBJECT_POINT_SGIS = Constant( 'GL_OBJECT_POINT_SGIS', 33269)
GL_OBJECT_SHADER_SOURCE_LENGTH_ARB = Constant( 'GL_OBJECT_SHADER_SOURCE_LENGTH_ARB', 35720)
GL_OBJECT_SUBTYPE_ARB = Constant( 'GL_OBJECT_SUBTYPE_ARB', 35663)
GL_OBJECT_TYPE_ARB = Constant( 'GL_OBJECT_TYPE_ARB', 35662)
GL_OBJECT_VALIDATE_STATUS_ARB = Constant( 'GL_OBJECT_VALIDATE_STATUS_ARB', 35715)
GL_OCCLUSION_TEST_HP = Constant( 'GL_OCCLUSION_TEST_HP', 33125)
GL_OCCLUSION_TEST_RESULT_HP = Constant( 'GL_OCCLUSION_TEST_RESULT_HP', 33126)
GL_OFFSET_HILO_PROJECTIVE_TEXTURE_2D_NV = Constant( 'GL_OFFSET_HILO_PROJECTIVE_TEXTURE_2D_NV', 34902)
GL_OFFSET_HILO_PROJECTIVE_TEXTURE_RECTANGLE_NV = Constant( 'GL_OFFSET_HILO_PROJECTIVE_TEXTURE_RECTANGLE_NV', 34903)
GL_OFFSET_HILO_TEXTURE_2D_NV = Constant( 'GL_OFFSET_HILO_TEXTURE_2D_NV', 34900)
GL_OFFSET_HILO_TEXTURE_RECTANGLE_NV = Constant( 'GL_OFFSET_HILO_TEXTURE_RECTANGLE_NV', 34901)
GL_OFFSET_PROJECTIVE_TEXTURE_2D_NV = Constant( 'GL_OFFSET_PROJECTIVE_TEXTURE_2D_NV', 34896)
GL_OFFSET_PROJECTIVE_TEXTURE_2D_SCALE_NV = Constant( 'GL_OFFSET_PROJECTIVE_TEXTURE_2D_SCALE_NV', 34897)
GL_OFFSET_PROJECTIVE_TEXTURE_RECTANGLE_NV = Constant( 'GL_OFFSET_PROJECTIVE_TEXTURE_RECTANGLE_NV', 34898)
GL_OFFSET_PROJECTIVE_TEXTURE_RECTANGLE_SCALE_NV = Constant( 'GL_OFFSET_PROJECTIVE_TEXTURE_RECTANGLE_SCALE_NV', 34899)
GL_OFFSET_TEXTURE_2D_NV = Constant( 'GL_OFFSET_TEXTURE_2D_NV', 34536)
GL_OFFSET_TEXTURE_BIAS_NV = Constant( 'GL_OFFSET_TEXTURE_BIAS_NV', 34531)
GL_OFFSET_TEXTURE_MATRIX_NV = Constant( 'GL_OFFSET_TEXTURE_MATRIX_NV', 34529)
GL_OFFSET_TEXTURE_RECTANGLE_NV = Constant( 'GL_OFFSET_TEXTURE_RECTANGLE_NV', 34380)
GL_OFFSET_TEXTURE_RECTANGLE_SCALE_NV = Constant( 'GL_OFFSET_TEXTURE_RECTANGLE_SCALE_NV', 34381)
GL_OFFSET_TEXTURE_SCALE_NV = Constant( 'GL_OFFSET_TEXTURE_SCALE_NV', 34530)
GL_ONE = Constant( 'GL_ONE', 1)
GL_ONE_EXT = Constant( 'GL_ONE_EXT', 34782)
GL_ONE_MINUS_CONSTANT_ALPHA = Constant( 'GL_ONE_MINUS_CONSTANT_ALPHA', 32772)
GL_ONE_MINUS_CONSTANT_ALPHA_EXT = Constant( 'GL_ONE_MINUS_CONSTANT_ALPHA_EXT', 32772)
GL_ONE_MINUS_CONSTANT_COLOR = Constant( 'GL_ONE_MINUS_CONSTANT_COLOR', 32770)
GL_ONE_MINUS_CONSTANT_COLOR_EXT = Constant( 'GL_ONE_MINUS_CONSTANT_COLOR_EXT', 32770)
GL_ONE_MINUS_DST_ALPHA = Constant( 'GL_ONE_MINUS_DST_ALPHA', 773)
GL_ONE_MINUS_DST_COLOR = Constant( 'GL_ONE_MINUS_DST_COLOR', 775)
GL_ONE_MINUS_SRC_ALPHA = Constant( 'GL_ONE_MINUS_SRC_ALPHA', 771)
GL_ONE_MINUS_SRC_COLOR = Constant( 'GL_ONE_MINUS_SRC_COLOR', 769)
GL_OPERAND0_ALPHA = Constant( 'GL_OPERAND0_ALPHA', 34200)
GL_OPERAND0_ALPHA_ARB = Constant( 'GL_OPERAND0_ALPHA_ARB', 34200)
GL_OPERAND0_ALPHA_EXT = Constant( 'GL_OPERAND0_ALPHA_EXT', 34200)
GL_OPERAND0_RGB = Constant( 'GL_OPERAND0_RGB', 34192)
GL_OPERAND0_RGB_ARB = Constant( 'GL_OPERAND0_RGB_ARB', 34192)
GL_OPERAND0_RGB_EXT = Constant( 'GL_OPERAND0_RGB_EXT', 34192)
GL_OPERAND1_ALPHA = Constant( 'GL_OPERAND1_ALPHA', 34201)
GL_OPERAND1_ALPHA_ARB = Constant( 'GL_OPERAND1_ALPHA_ARB', 34201)
GL_OPERAND1_ALPHA_EXT = Constant( 'GL_OPERAND1_ALPHA_EXT', 34201)
GL_OPERAND1_RGB = Constant( 'GL_OPERAND1_RGB', 34193)
GL_OPERAND1_RGB_ARB = Constant( 'GL_OPERAND1_RGB_ARB', 34193)
GL_OPERAND1_RGB_EXT = Constant( 'GL_OPERAND1_RGB_EXT', 34193)
GL_OPERAND2_ALPHA = Constant( 'GL_OPERAND2_ALPHA', 34202)
GL_OPERAND2_ALPHA_ARB = Constant( 'GL_OPERAND2_ALPHA_ARB', 34202)
GL_OPERAND2_ALPHA_EXT = Constant( 'GL_OPERAND2_ALPHA_EXT', 34202)
GL_OPERAND2_RGB = Constant( 'GL_OPERAND2_RGB', 34194)
GL_OPERAND2_RGB_ARB = Constant( 'GL_OPERAND2_RGB_ARB', 34194)
GL_OPERAND2_RGB_EXT = Constant( 'GL_OPERAND2_RGB_EXT', 34194)
GL_OPERAND3_ALPHA_NV = Constant( 'GL_OPERAND3_ALPHA_NV', 34203)
GL_OPERAND3_RGB_NV = Constant( 'GL_OPERAND3_RGB_NV', 34195)
GL_OP_ADD_EXT = Constant( 'GL_OP_ADD_EXT', 34695)
GL_OP_CLAMP_EXT = Constant( 'GL_OP_CLAMP_EXT', 34702)
GL_OP_CROSS_PRODUCT_EXT = Constant( 'GL_OP_CROSS_PRODUCT_EXT', 34711)
GL_OP_DOT3_EXT = Constant( 'GL_OP_DOT3_EXT', 34692)
GL_OP_DOT4_EXT = Constant( 'GL_OP_DOT4_EXT', 34693)
GL_OP_EXP_BASE_2_EXT = Constant( 'GL_OP_EXP_BASE_2_EXT', 34705)
GL_OP_FLOOR_EXT = Constant( 'GL_OP_FLOOR_EXT', 34703)
GL_OP_FRAC_EXT = Constant( 'GL_OP_FRAC_EXT', 34697)
GL_OP_INDEX_EXT = Constant( 'GL_OP_INDEX_EXT', 34690)
GL_OP_LOG_BASE_2_EXT = Constant( 'GL_OP_LOG_BASE_2_EXT', 34706)
GL_OP_MADD_EXT = Constant( 'GL_OP_MADD_EXT', 34696)
GL_OP_MAX_EXT = Constant( 'GL_OP_MAX_EXT', 34698)
GL_OP_MIN_EXT = Constant( 'GL_OP_MIN_EXT', 34699)
GL_OP_MOV_EXT = Constant( 'GL_OP_MOV_EXT', 34713)
GL_OP_MULTIPLY_MATRIX_EXT = Constant( 'GL_OP_MULTIPLY_MATRIX_EXT', 34712)
GL_OP_MUL_EXT = Constant( 'GL_OP_MUL_EXT', 34694)
GL_OP_NEGATE_EXT = Constant( 'GL_OP_NEGATE_EXT', 34691)
GL_OP_POWER_EXT = Constant( 'GL_OP_POWER_EXT', 34707)
GL_OP_RECIP_EXT = Constant( 'GL_OP_RECIP_EXT', 34708)
GL_OP_RECIP_SQRT_EXT = Constant( 'GL_OP_RECIP_SQRT_EXT', 34709)
GL_OP_ROUND_EXT = Constant( 'GL_OP_ROUND_EXT', 34704)
GL_OP_SET_GE_EXT = Constant( 'GL_OP_SET_GE_EXT', 34700)
GL_OP_SET_LT_EXT = Constant( 'GL_OP_SET_LT_EXT', 34701)
GL_OP_SUB_EXT = Constant( 'GL_OP_SUB_EXT', 34710)
GL_OR = Constant( 'GL_OR', 5383)
GL_ORDER = Constant( 'GL_ORDER', 2561)
GL_OR_INVERTED = Constant( 'GL_OR_INVERTED', 5389)
GL_OR_REVERSE = Constant( 'GL_OR_REVERSE', 5387)
GL_OUTPUT_COLOR0_EXT = Constant( 'GL_OUTPUT_COLOR0_EXT', 34715)
GL_OUTPUT_COLOR1_EXT = Constant( 'GL_OUTPUT_COLOR1_EXT', 34716)
GL_OUTPUT_FOG_EXT = Constant( 'GL_OUTPUT_FOG_EXT', 34749)
GL_OUTPUT_TEXTURE_COORD0_EXT = Constant( 'GL_OUTPUT_TEXTURE_COORD0_EXT', 34717)
GL_OUTPUT_TEXTURE_COORD10_EXT = Constant( 'GL_OUTPUT_TEXTURE_COORD10_EXT', 34727)
GL_OUTPUT_TEXTURE_COORD11_EXT = Constant( 'GL_OUTPUT_TEXTURE_COORD11_EXT', 34728)
GL_OUTPUT_TEXTURE_COORD12_EXT = Constant( 'GL_OUTPUT_TEXTURE_COORD12_EXT', 34729)
GL_OUTPUT_TEXTURE_COORD13_EXT = Constant( 'GL_OUTPUT_TEXTURE_COORD13_EXT', 34730)
GL_OUTPUT_TEXTURE_COORD14_EXT = Constant( 'GL_OUTPUT_TEXTURE_COORD14_EXT', 34731)
GL_OUTPUT_TEXTURE_COORD15_EXT = Constant( 'GL_OUTPUT_TEXTURE_COORD15_EXT', 34732)
GL_OUTPUT_TEXTURE_COORD16_EXT = Constant( 'GL_OUTPUT_TEXTURE_COORD16_EXT', 34733)
GL_OUTPUT_TEXTURE_COORD17_EXT = Constant( 'GL_OUTPUT_TEXTURE_COORD17_EXT', 34734)
GL_OUTPUT_TEXTURE_COORD18_EXT = Constant( 'GL_OUTPUT_TEXTURE_COORD18_EXT', 34735)
GL_OUTPUT_TEXTURE_COORD19_EXT = Constant( 'GL_OUTPUT_TEXTURE_COORD19_EXT', 34736)
GL_OUTPUT_TEXTURE_COORD1_EXT = Constant( 'GL_OUTPUT_TEXTURE_COORD1_EXT', 34718)
GL_OUTPUT_TEXTURE_COORD20_EXT = Constant( 'GL_OUTPUT_TEXTURE_COORD20_EXT', 34737)
GL_OUTPUT_TEXTURE_COORD21_EXT = Constant( 'GL_OUTPUT_TEXTURE_COORD21_EXT', 34738)
GL_OUTPUT_TEXTURE_COORD22_EXT = Constant( 'GL_OUTPUT_TEXTURE_COORD22_EXT', 34739)
GL_OUTPUT_TEXTURE_COORD23_EXT = Constant( 'GL_OUTPUT_TEXTURE_COORD23_EXT', 34740)
GL_OUTPUT_TEXTURE_COORD24_EXT = Constant( 'GL_OUTPUT_TEXTURE_COORD24_EXT', 34741)
GL_OUTPUT_TEXTURE_COORD25_EXT = Constant( 'GL_OUTPUT_TEXTURE_COORD25_EXT', 34742)
GL_OUTPUT_TEXTURE_COORD26_EXT = Constant( 'GL_OUTPUT_TEXTURE_COORD26_EXT', 34743)
GL_OUTPUT_TEXTURE_COORD27_EXT = Constant( 'GL_OUTPUT_TEXTURE_COORD27_EXT', 34744)
GL_OUTPUT_TEXTURE_COORD28_EXT = Constant( 'GL_OUTPUT_TEXTURE_COORD28_EXT', 34745)
GL_OUTPUT_TEXTURE_COORD29_EXT = Constant( 'GL_OUTPUT_TEXTURE_COORD29_EXT', 34746)
GL_OUTPUT_TEXTURE_COORD2_EXT = Constant( 'GL_OUTPUT_TEXTURE_COORD2_EXT', 34719)
GL_OUTPUT_TEXTURE_COORD30_EXT = Constant( 'GL_OUTPUT_TEXTURE_COORD30_EXT', 34747)
GL_OUTPUT_TEXTURE_COORD31_EXT = Constant( 'GL_OUTPUT_TEXTURE_COORD31_EXT', 34748)
GL_OUTPUT_TEXTURE_COORD3_EXT = Constant( 'GL_OUTPUT_TEXTURE_COORD3_EXT', 34720)
GL_OUTPUT_TEXTURE_COORD4_EXT = Constant( 'GL_OUTPUT_TEXTURE_COORD4_EXT', 34721)
GL_OUTPUT_TEXTURE_COORD5_EXT = Constant( 'GL_OUTPUT_TEXTURE_COORD5_EXT', 34722)
GL_OUTPUT_TEXTURE_COORD6_EXT = Constant( 'GL_OUTPUT_TEXTURE_COORD6_EXT', 34723)
GL_OUTPUT_TEXTURE_COORD7_EXT = Constant( 'GL_OUTPUT_TEXTURE_COORD7_EXT', 34724)
GL_OUTPUT_TEXTURE_COORD8_EXT = Constant( 'GL_OUTPUT_TEXTURE_COORD8_EXT', 34725)
GL_OUTPUT_TEXTURE_COORD9_EXT = Constant( 'GL_OUTPUT_TEXTURE_COORD9_EXT', 34726)
GL_OUTPUT_VERTEX_EXT = Constant( 'GL_OUTPUT_VERTEX_EXT', 34714)
GL_OUT_OF_MEMORY = Constant( 'GL_OUT_OF_MEMORY', 1285)
GL_PACK_ALIGNMENT = Constant( 'GL_PACK_ALIGNMENT', 3333)
GL_PACK_CMYK_HINT_EXT = Constant( 'GL_PACK_CMYK_HINT_EXT', 32782)
GL_PACK_IMAGE_DEPTH_SGIS = Constant( 'GL_PACK_IMAGE_DEPTH_SGIS', 33073)
GL_PACK_IMAGE_HEIGHT = Constant( 'GL_PACK_IMAGE_HEIGHT', 32876)
GL_PACK_IMAGE_HEIGHT_EXT = Constant( 'GL_PACK_IMAGE_HEIGHT_EXT', 32876)
GL_PACK_INVERT_MESA = Constant( 'GL_PACK_INVERT_MESA', 34648)
GL_PACK_LSB_FIRST = Constant( 'GL_PACK_LSB_FIRST', 3329)
GL_PACK_RESAMPLE_OML = Constant( 'GL_PACK_RESAMPLE_OML', 35204)
GL_PACK_RESAMPLE_SGIX = Constant( 'GL_PACK_RESAMPLE_SGIX', 33836)
GL_PACK_ROW_LENGTH = Constant( 'GL_PACK_ROW_LENGTH', 3330)
GL_PACK_SKIP_IMAGES = Constant( 'GL_PACK_SKIP_IMAGES', 32875)
GL_PACK_SKIP_IMAGES_EXT = Constant( 'GL_PACK_SKIP_IMAGES_EXT', 32875)
GL_PACK_SKIP_PIXELS = Constant( 'GL_PACK_SKIP_PIXELS', 3332)
GL_PACK_SKIP_ROWS = Constant( 'GL_PACK_SKIP_ROWS', 3331)
GL_PACK_SKIP_VOLUMES_SGIS = Constant( 'GL_PACK_SKIP_VOLUMES_SGIS', 33072)
GL_PACK_SUBSAMPLE_RATE_SGIX = Constant( 'GL_PACK_SUBSAMPLE_RATE_SGIX', 34208)
GL_PACK_SWAP_BYTES = Constant( 'GL_PACK_SWAP_BYTES', 3328)
GL_PARALLEL_ARRAYS_INTEL = Constant( 'GL_PARALLEL_ARRAYS_INTEL', 33780)
GL_PASS_THROUGH_NV = Constant( 'GL_PASS_THROUGH_NV', 34534)
GL_PASS_THROUGH_TOKEN = Constant( 'GL_PASS_THROUGH_TOKEN', 1792)
GL_PERSPECTIVE_CORRECTION_HINT = Constant( 'GL_PERSPECTIVE_CORRECTION_HINT', 3152)
GL_PERTURB_EXT = Constant( 'GL_PERTURB_EXT', 34222)
GL_PER_STAGE_CONSTANTS_NV = Constant( 'GL_PER_STAGE_CONSTANTS_NV', 34101)
GL_PHONG_HINT_WIN = Constant( 'GL_PHONG_HINT_WIN', 33003)
GL_PHONG_WIN = Constant( 'GL_PHONG_WIN', 33002)
GL_PIXEL_COUNTER_BITS_NV = Constant( 'GL_PIXEL_COUNTER_BITS_NV', 34916)
GL_PIXEL_COUNT_AVAILABLE_NV = Constant( 'GL_PIXEL_COUNT_AVAILABLE_NV', 34919)
GL_PIXEL_COUNT_NV = Constant( 'GL_PIXEL_COUNT_NV', 34918)
GL_PIXEL_CUBIC_WEIGHT_EXT = Constant( 'GL_PIXEL_CUBIC_WEIGHT_EXT', 33587)
GL_PIXEL_FRAGMENT_ALPHA_SOURCE_SGIS = Constant( 'GL_PIXEL_FRAGMENT_ALPHA_SOURCE_SGIS', 33621)
GL_PIXEL_FRAGMENT_RGB_SOURCE_SGIS = Constant( 'GL_PIXEL_FRAGMENT_RGB_SOURCE_SGIS', 33620)
GL_PIXEL_GROUP_COLOR_SGIS = Constant( 'GL_PIXEL_GROUP_COLOR_SGIS', 33622)
GL_PIXEL_MAG_FILTER_EXT = Constant( 'GL_PIXEL_MAG_FILTER_EXT', 33585)
GL_PIXEL_MAP_A_TO_A = Constant( 'GL_PIXEL_MAP_A_TO_A', 3193)
GL_PIXEL_MAP_A_TO_A_SIZE = Constant( 'GL_PIXEL_MAP_A_TO_A_SIZE', 3257)
GL_PIXEL_MAP_B_TO_B = Constant( 'GL_PIXEL_MAP_B_TO_B', 3192)
GL_PIXEL_MAP_B_TO_B_SIZE = Constant( 'GL_PIXEL_MAP_B_TO_B_SIZE', 3256)
GL_PIXEL_MAP_G_TO_G = Constant( 'GL_PIXEL_MAP_G_TO_G', 3191)
GL_PIXEL_MAP_G_TO_G_SIZE = Constant( 'GL_PIXEL_MAP_G_TO_G_SIZE', 3255)
GL_PIXEL_MAP_I_TO_A = Constant( 'GL_PIXEL_MAP_I_TO_A', 3189)
GL_PIXEL_MAP_I_TO_A_SIZE = Constant( 'GL_PIXEL_MAP_I_TO_A_SIZE', 3253)
GL_PIXEL_MAP_I_TO_B = Constant( 'GL_PIXEL_MAP_I_TO_B', 3188)
GL_PIXEL_MAP_I_TO_B_SIZE = Constant( 'GL_PIXEL_MAP_I_TO_B_SIZE', 3252)
GL_PIXEL_MAP_I_TO_G = Constant( 'GL_PIXEL_MAP_I_TO_G', 3187)
GL_PIXEL_MAP_I_TO_G_SIZE = Constant( 'GL_PIXEL_MAP_I_TO_G_SIZE', 3251)
GL_PIXEL_MAP_I_TO_I = Constant( 'GL_PIXEL_MAP_I_TO_I', 3184)
GL_PIXEL_MAP_I_TO_I_SIZE = Constant( 'GL_PIXEL_MAP_I_TO_I_SIZE', 3248)
GL_PIXEL_MAP_I_TO_R = Constant( 'GL_PIXEL_MAP_I_TO_R', 3186)
GL_PIXEL_MAP_I_TO_R_SIZE = Constant( 'GL_PIXEL_MAP_I_TO_R_SIZE', 3250)
GL_PIXEL_MAP_R_TO_R = Constant( 'GL_PIXEL_MAP_R_TO_R', 3190)
GL_PIXEL_MAP_R_TO_R_SIZE = Constant( 'GL_PIXEL_MAP_R_TO_R_SIZE', 3254)
GL_PIXEL_MAP_S_TO_S = Constant( 'GL_PIXEL_MAP_S_TO_S', 3185)
GL_PIXEL_MAP_S_TO_S_SIZE = Constant( 'GL_PIXEL_MAP_S_TO_S_SIZE', 3249)
GL_PIXEL_MIN_FILTER_EXT = Constant( 'GL_PIXEL_MIN_FILTER_EXT', 33586)
GL_PIXEL_MODE_BIT = Constant( 'GL_PIXEL_MODE_BIT', 32)
GL_PIXEL_PACK_BUFFER_ARB = Constant( 'GL_PIXEL_PACK_BUFFER_ARB', 35051)
GL_PIXEL_PACK_BUFFER_BINDING_ARB = Constant( 'GL_PIXEL_PACK_BUFFER_BINDING_ARB', 35053)
GL_PIXEL_PACK_BUFFER_BINDING_EXT = Constant( 'GL_PIXEL_PACK_BUFFER_BINDING_EXT', 35053)
GL_PIXEL_PACK_BUFFER_EXT = Constant( 'GL_PIXEL_PACK_BUFFER_EXT', 35051)
GL_PIXEL_SUBSAMPLE_2424_SGIX = Constant( 'GL_PIXEL_SUBSAMPLE_2424_SGIX', 34211)
GL_PIXEL_SUBSAMPLE_4242_SGIX = Constant( 'GL_PIXEL_SUBSAMPLE_4242_SGIX', 34212)
GL_PIXEL_SUBSAMPLE_4444_SGIX = Constant( 'GL_PIXEL_SUBSAMPLE_4444_SGIX', 34210)
GL_PIXEL_TEXTURE_SGIS = Constant( 'GL_PIXEL_TEXTURE_SGIS', 33619)
GL_PIXEL_TEX_GEN_ALPHA_LS_SGIX = Constant( 'GL_PIXEL_TEX_GEN_ALPHA_LS_SGIX', 33161)
GL_PIXEL_TEX_GEN_ALPHA_MS_SGIX = Constant( 'GL_PIXEL_TEX_GEN_ALPHA_MS_SGIX', 33162)
GL_PIXEL_TEX_GEN_ALPHA_NO_REPLACE_SGIX = Constant( 'GL_PIXEL_TEX_GEN_ALPHA_NO_REPLACE_SGIX', 33160)
GL_PIXEL_TEX_GEN_ALPHA_REPLACE_SGIX = Constant( 'GL_PIXEL_TEX_GEN_ALPHA_REPLACE_SGIX', 33159)
GL_PIXEL_TEX_GEN_MODE_SGIX = Constant( 'GL_PIXEL_TEX_GEN_MODE_SGIX', 33579)
GL_PIXEL_TEX_GEN_Q_CEILING_SGIX = Constant( 'GL_PIXEL_TEX_GEN_Q_CEILING_SGIX', 33156)
GL_PIXEL_TEX_GEN_Q_FLOOR_SGIX = Constant( 'GL_PIXEL_TEX_GEN_Q_FLOOR_SGIX', 33158)
GL_PIXEL_TEX_GEN_Q_ROUND_SGIX = Constant( 'GL_PIXEL_TEX_GEN_Q_ROUND_SGIX', 33157)
GL_PIXEL_TEX_GEN_SGIX = Constant( 'GL_PIXEL_TEX_GEN_SGIX', 33081)
GL_PIXEL_TILE_BEST_ALIGNMENT_SGIX = Constant( 'GL_PIXEL_TILE_BEST_ALIGNMENT_SGIX', 33086)
GL_PIXEL_TILE_CACHE_INCREMENT_SGIX = Constant( 'GL_PIXEL_TILE_CACHE_INCREMENT_SGIX', 33087)
GL_PIXEL_TILE_CACHE_SIZE_SGIX = Constant( 'GL_PIXEL_TILE_CACHE_SIZE_SGIX', 33093)
GL_PIXEL_TILE_GRID_DEPTH_SGIX = Constant( 'GL_PIXEL_TILE_GRID_DEPTH_SGIX', 33092)
GL_PIXEL_TILE_GRID_HEIGHT_SGIX = Constant( 'GL_PIXEL_TILE_GRID_HEIGHT_SGIX', 33091)
GL_PIXEL_TILE_GRID_WIDTH_SGIX = Constant( 'GL_PIXEL_TILE_GRID_WIDTH_SGIX', 33090)
GL_PIXEL_TILE_HEIGHT_SGIX = Constant( 'GL_PIXEL_TILE_HEIGHT_SGIX', 33089)
GL_PIXEL_TILE_WIDTH_SGIX = Constant( 'GL_PIXEL_TILE_WIDTH_SGIX', 33088)
GL_PIXEL_TRANSFORM_2D_EXT = Constant( 'GL_PIXEL_TRANSFORM_2D_EXT', 33584)
GL_PIXEL_TRANSFORM_2D_MATRIX_EXT = Constant( 'GL_PIXEL_TRANSFORM_2D_MATRIX_EXT', 33592)
GL_PIXEL_TRANSFORM_2D_STACK_DEPTH_EXT = Constant( 'GL_PIXEL_TRANSFORM_2D_STACK_DEPTH_EXT', 33590)
GL_PIXEL_UNPACK_BUFFER_ARB = Constant( 'GL_PIXEL_UNPACK_BUFFER_ARB', 35052)
GL_PIXEL_UNPACK_BUFFER_BINDING_ARB = Constant( 'GL_PIXEL_UNPACK_BUFFER_BINDING_ARB', 35055)
GL_PIXEL_UNPACK_BUFFER_BINDING_EXT = Constant( 'GL_PIXEL_UNPACK_BUFFER_BINDING_EXT', 35055)
GL_PIXEL_UNPACK_BUFFER_EXT = Constant( 'GL_PIXEL_UNPACK_BUFFER_EXT', 35052)
GL_PN_TRIANGLES_ATI = Constant( 'GL_PN_TRIANGLES_ATI', 34800)
GL_PN_TRIANGLES_NORMAL_MODE_ATI = Constant( 'GL_PN_TRIANGLES_NORMAL_MODE_ATI', 34803)
GL_PN_TRIANGLES_NORMAL_MODE_LINEAR_ATI = Constant( 'GL_PN_TRIANGLES_NORMAL_MODE_LINEAR_ATI', 34807)
GL_PN_TRIANGLES_NORMAL_MODE_QUADRATIC_ATI = Constant( 'GL_PN_TRIANGLES_NORMAL_MODE_QUADRATIC_ATI', 34808)
GL_PN_TRIANGLES_POINT_MODE_ATI = Constant( 'GL_PN_TRIANGLES_POINT_MODE_ATI', 34802)
GL_PN_TRIANGLES_POINT_MODE_CUBIC_ATI = Constant( 'GL_PN_TRIANGLES_POINT_MODE_CUBIC_ATI', 34806)
GL_PN_TRIANGLES_POINT_MODE_LINEAR_ATI = Constant( 'GL_PN_TRIANGLES_POINT_MODE_LINEAR_ATI', 34805)
GL_PN_TRIANGLES_TESSELATION_LEVEL_ATI = Constant( 'GL_PN_TRIANGLES_TESSELATION_LEVEL_ATI', 34804)
GL_POINT = Constant( 'GL_POINT', 6912)
GL_POINTS = Constant( 'GL_POINTS', 0)
GL_POINT_BIT = Constant( 'GL_POINT_BIT', 2)
GL_POINT_DISTANCE_ATTENUATION = Constant( 'GL_POINT_DISTANCE_ATTENUATION', 33065)
GL_POINT_DISTANCE_ATTENUATION_ARB = Constant( 'GL_POINT_DISTANCE_ATTENUATION_ARB', 33065)
GL_POINT_FADE_THRESHOLD_SIZE = Constant( 'GL_POINT_FADE_THRESHOLD_SIZE', 33064)
GL_POINT_FADE_THRESHOLD_SIZE_ARB = Constant( 'GL_POINT_FADE_THRESHOLD_SIZE_ARB', 33064)
GL_POINT_FADE_THRESHOLD_SIZE_EXT = Constant( 'GL_POINT_FADE_THRESHOLD_SIZE_EXT', 33064)
GL_POINT_FADE_THRESHOLD_SIZE_SGIS = Constant( 'GL_POINT_FADE_THRESHOLD_SIZE_SGIS', 33064)
GL_POINT_SIZE = Constant( 'GL_POINT_SIZE', 2833)
GL_POINT_SIZE_MAX = Constant( 'GL_POINT_SIZE_MAX', 33063)
GL_POINT_SIZE_MAX_ARB = Constant( 'GL_POINT_SIZE_MAX_ARB', 33063)
GL_POINT_SIZE_MAX_EXT = Constant( 'GL_POINT_SIZE_MAX_EXT', 33063)
GL_POINT_SIZE_MAX_SGIS = Constant( 'GL_POINT_SIZE_MAX_SGIS', 33063)
GL_POINT_SIZE_MIN = Constant( 'GL_POINT_SIZE_MIN', 33062)
GL_POINT_SIZE_MIN_ARB = Constant( 'GL_POINT_SIZE_MIN_ARB', 33062)
GL_POINT_SIZE_MIN_EXT = Constant( 'GL_POINT_SIZE_MIN_EXT', 33062)
GL_POINT_SIZE_MIN_SGIS = Constant( 'GL_POINT_SIZE_MIN_SGIS', 33062)
GL_POINT_SMOOTH = Constant( 'GL_POINT_SMOOTH', 2832)
GL_POINT_SMOOTH_HINT = Constant( 'GL_POINT_SMOOTH_HINT', 3153)
GL_POINT_SPRITE = Constant( 'GL_POINT_SPRITE', 34913)
GL_POINT_SPRITE_ARB = Constant( 'GL_POINT_SPRITE_ARB', 34913)
GL_POINT_SPRITE_COORD_ORIGIN = Constant( 'GL_POINT_SPRITE_COORD_ORIGIN', 36000)
GL_POINT_SPRITE_NV = Constant( 'GL_POINT_SPRITE_NV', 34913)
GL_POINT_SPRITE_R_MODE_NV = Constant( 'GL_POINT_SPRITE_R_MODE_NV', 34915)
GL_POINT_TOKEN = Constant( 'GL_POINT_TOKEN', 1793)
GL_POLYGON = Constant( 'GL_POLYGON', 9)
GL_POLYGON_BIT = Constant( 'GL_POLYGON_BIT', 8)
GL_POLYGON_MODE = Constant( 'GL_POLYGON_MODE', 2880)
GL_POLYGON_OFFSET_BIAS_EXT = Constant( 'GL_POLYGON_OFFSET_BIAS_EXT', 32825)
GL_POLYGON_OFFSET_EXT = Constant( 'GL_POLYGON_OFFSET_EXT', 32823)
GL_POLYGON_OFFSET_FACTOR = Constant( 'GL_POLYGON_OFFSET_FACTOR', 32824)
GL_POLYGON_OFFSET_FACTOR_EXT = Constant( 'GL_POLYGON_OFFSET_FACTOR_EXT', 32824)
GL_POLYGON_OFFSET_FILL = Constant( 'GL_POLYGON_OFFSET_FILL', 32823)
GL_POLYGON_OFFSET_LINE = Constant( 'GL_POLYGON_OFFSET_LINE', 10754)
GL_POLYGON_OFFSET_POINT = Constant( 'GL_POLYGON_OFFSET_POINT', 10753)
GL_POLYGON_OFFSET_UNITS = Constant( 'GL_POLYGON_OFFSET_UNITS', 10752)
GL_POLYGON_SMOOTH = Constant( 'GL_POLYGON_SMOOTH', 2881)
GL_POLYGON_SMOOTH_HINT = Constant( 'GL_POLYGON_SMOOTH_HINT', 3155)
GL_POLYGON_STIPPLE = Constant( 'GL_POLYGON_STIPPLE', 2882)
GL_POLYGON_STIPPLE_BIT = Constant( 'GL_POLYGON_STIPPLE_BIT', 16)
GL_POLYGON_TOKEN = Constant( 'GL_POLYGON_TOKEN', 1795)
GL_POSITION = Constant( 'GL_POSITION', 4611)
GL_POST_COLOR_MATRIX_ALPHA_BIAS = Constant( 'GL_POST_COLOR_MATRIX_ALPHA_BIAS', 32955)
GL_POST_COLOR_MATRIX_ALPHA_BIAS_SGI = Constant( 'GL_POST_COLOR_MATRIX_ALPHA_BIAS_SGI', 32955)
GL_POST_COLOR_MATRIX_ALPHA_SCALE = Constant( 'GL_POST_COLOR_MATRIX_ALPHA_SCALE', 32951)
GL_POST_COLOR_MATRIX_ALPHA_SCALE_SGI = Constant( 'GL_POST_COLOR_MATRIX_ALPHA_SCALE_SGI', 32951)
GL_POST_COLOR_MATRIX_BLUE_BIAS = Constant( 'GL_POST_COLOR_MATRIX_BLUE_BIAS', 32954)
GL_POST_COLOR_MATRIX_BLUE_BIAS_SGI = Constant( 'GL_POST_COLOR_MATRIX_BLUE_BIAS_SGI', 32954)
GL_POST_COLOR_MATRIX_BLUE_SCALE = Constant( 'GL_POST_COLOR_MATRIX_BLUE_SCALE', 32950)
GL_POST_COLOR_MATRIX_BLUE_SCALE_SGI = Constant( 'GL_POST_COLOR_MATRIX_BLUE_SCALE_SGI', 32950)
GL_POST_COLOR_MATRIX_COLOR_TABLE = Constant( 'GL_POST_COLOR_MATRIX_COLOR_TABLE', 32978)
GL_POST_COLOR_MATRIX_COLOR_TABLE_SGI = Constant( 'GL_POST_COLOR_MATRIX_COLOR_TABLE_SGI', 32978)
GL_POST_COLOR_MATRIX_GREEN_BIAS = Constant( 'GL_POST_COLOR_MATRIX_GREEN_BIAS', 32953)
GL_POST_COLOR_MATRIX_GREEN_BIAS_SGI = Constant( 'GL_POST_COLOR_MATRIX_GREEN_BIAS_SGI', 32953)
GL_POST_COLOR_MATRIX_GREEN_SCALE = Constant( 'GL_POST_COLOR_MATRIX_GREEN_SCALE', 32949)
GL_POST_COLOR_MATRIX_GREEN_SCALE_SGI = Constant( 'GL_POST_COLOR_MATRIX_GREEN_SCALE_SGI', 32949)
GL_POST_COLOR_MATRIX_RED_BIAS = Constant( 'GL_POST_COLOR_MATRIX_RED_BIAS', 32952)
GL_POST_COLOR_MATRIX_RED_BIAS_SGI = Constant( 'GL_POST_COLOR_MATRIX_RED_BIAS_SGI', 32952)
GL_POST_COLOR_MATRIX_RED_SCALE = Constant( 'GL_POST_COLOR_MATRIX_RED_SCALE', 32948)
GL_POST_COLOR_MATRIX_RED_SCALE_SGI = Constant( 'GL_POST_COLOR_MATRIX_RED_SCALE_SGI', 32948)
GL_POST_CONVOLUTION_ALPHA_BIAS = Constant( 'GL_POST_CONVOLUTION_ALPHA_BIAS', 32803)
GL_POST_CONVOLUTION_ALPHA_BIAS_EXT = Constant( 'GL_POST_CONVOLUTION_ALPHA_BIAS_EXT', 32803)
GL_POST_CONVOLUTION_ALPHA_SCALE = Constant( 'GL_POST_CONVOLUTION_ALPHA_SCALE', 32799)
GL_POST_CONVOLUTION_ALPHA_SCALE_EXT = Constant( 'GL_POST_CONVOLUTION_ALPHA_SCALE_EXT', 32799)
GL_POST_CONVOLUTION_BLUE_BIAS = Constant( 'GL_POST_CONVOLUTION_BLUE_BIAS', 32802)
GL_POST_CONVOLUTION_BLUE_BIAS_EXT = Constant( 'GL_POST_CONVOLUTION_BLUE_BIAS_EXT', 32802)
GL_POST_CONVOLUTION_BLUE_SCALE = Constant( 'GL_POST_CONVOLUTION_BLUE_SCALE', 32798)
GL_POST_CONVOLUTION_BLUE_SCALE_EXT = Constant( 'GL_POST_CONVOLUTION_BLUE_SCALE_EXT', 32798)
GL_POST_CONVOLUTION_COLOR_TABLE = Constant( 'GL_POST_CONVOLUTION_COLOR_TABLE', 32977)
GL_POST_CONVOLUTION_COLOR_TABLE_SGI = Constant( 'GL_POST_CONVOLUTION_COLOR_TABLE_SGI', 32977)
GL_POST_CONVOLUTION_GREEN_BIAS = Constant( 'GL_POST_CONVOLUTION_GREEN_BIAS', 32801)
GL_POST_CONVOLUTION_GREEN_BIAS_EXT = Constant( 'GL_POST_CONVOLUTION_GREEN_BIAS_EXT', 32801)
GL_POST_CONVOLUTION_GREEN_SCALE = Constant( 'GL_POST_CONVOLUTION_GREEN_SCALE', 32797)
GL_POST_CONVOLUTION_GREEN_SCALE_EXT = Constant( 'GL_POST_CONVOLUTION_GREEN_SCALE_EXT', 32797)
GL_POST_CONVOLUTION_RED_BIAS = Constant( 'GL_POST_CONVOLUTION_RED_BIAS', 32800)
GL_POST_CONVOLUTION_RED_BIAS_EXT = Constant( 'GL_POST_CONVOLUTION_RED_BIAS_EXT', 32800)
GL_POST_CONVOLUTION_RED_SCALE = Constant( 'GL_POST_CONVOLUTION_RED_SCALE', 32796)
GL_POST_CONVOLUTION_RED_SCALE_EXT = Constant( 'GL_POST_CONVOLUTION_RED_SCALE_EXT', 32796)
GL_POST_IMAGE_TRANSFORM_COLOR_TABLE_HP = Constant( 'GL_POST_IMAGE_TRANSFORM_COLOR_TABLE_HP', 33122)
GL_POST_TEXTURE_FILTER_BIAS_RANGE_SGIX = Constant( 'GL_POST_TEXTURE_FILTER_BIAS_RANGE_SGIX', 33147)
GL_POST_TEXTURE_FILTER_BIAS_SGIX = Constant( 'GL_POST_TEXTURE_FILTER_BIAS_SGIX', 33145)
GL_POST_TEXTURE_FILTER_SCALE_RANGE_SGIX = Constant( 'GL_POST_TEXTURE_FILTER_SCALE_RANGE_SGIX', 33148)
GL_POST_TEXTURE_FILTER_SCALE_SGIX = Constant( 'GL_POST_TEXTURE_FILTER_SCALE_SGIX', 33146)
GL_PREFER_DOUBLEBUFFER_HINT_PGI = Constant( 'GL_PREFER_DOUBLEBUFFER_HINT_PGI', 107000)
GL_PRESERVE_ATI = Constant( 'GL_PRESERVE_ATI', 34658)
GL_PREVIOUS = Constant( 'GL_PREVIOUS', 34168)
GL_PREVIOUS_ARB = Constant( 'GL_PREVIOUS_ARB', 34168)
GL_PREVIOUS_EXT = Constant( 'GL_PREVIOUS_EXT', 34168)
GL_PREVIOUS_TEXTURE_INPUT_NV = Constant( 'GL_PREVIOUS_TEXTURE_INPUT_NV', 34532)
GL_PRIMARY_COLOR = Constant( 'GL_PRIMARY_COLOR', 34167)
GL_PRIMARY_COLOR_ARB = Constant( 'GL_PRIMARY_COLOR_ARB', 34167)
GL_PRIMARY_COLOR_EXT = Constant( 'GL_PRIMARY_COLOR_EXT', 34167)
GL_PRIMARY_COLOR_NV = Constant( 'GL_PRIMARY_COLOR_NV', 34092)
GL_PRIMITIVE_RESTART_INDEX_NV = Constant( 'GL_PRIMITIVE_RESTART_INDEX_NV', 34137)
GL_PRIMITIVE_RESTART_NV = Constant( 'GL_PRIMITIVE_RESTART_NV', 34136)
GL_PROGRAM_ADDRESS_REGISTERS_ARB = Constant( 'GL_PROGRAM_ADDRESS_REGISTERS_ARB', 34992)
GL_PROGRAM_ALU_INSTRUCTIONS_ARB = Constant( 'GL_PROGRAM_ALU_INSTRUCTIONS_ARB', 34821)
GL_PROGRAM_ATTRIBS_ARB = Constant( 'GL_PROGRAM_ATTRIBS_ARB', 34988)
GL_PROGRAM_BINDING_ARB = Constant( 'GL_PROGRAM_BINDING_ARB', 34423)
GL_PROGRAM_ERROR_POSITION_ARB = Constant( 'GL_PROGRAM_ERROR_POSITION_ARB', 34379)
GL_PROGRAM_ERROR_POSITION_NV = Constant( 'GL_PROGRAM_ERROR_POSITION_NV', 34379)
GL_PROGRAM_ERROR_STRING_ARB = Constant( 'GL_PROGRAM_ERROR_STRING_ARB', 34932)
GL_PROGRAM_ERROR_STRING_NV = Constant( 'GL_PROGRAM_ERROR_STRING_NV', 34932)
GL_PROGRAM_FORMAT_ARB = Constant( 'GL_PROGRAM_FORMAT_ARB', 34934)
GL_PROGRAM_FORMAT_ASCII_ARB = Constant( 'GL_PROGRAM_FORMAT_ASCII_ARB', 34933)
GL_PROGRAM_INSTRUCTIONS_ARB = Constant( 'GL_PROGRAM_INSTRUCTIONS_ARB', 34976)
GL_PROGRAM_LENGTH_ARB = Constant( 'GL_PROGRAM_LENGTH_ARB', 34343)
GL_PROGRAM_LENGTH_NV = Constant( 'GL_PROGRAM_LENGTH_NV', 34343)
GL_PROGRAM_NATIVE_ADDRESS_REGISTERS_ARB = Constant( 'GL_PROGRAM_NATIVE_ADDRESS_REGISTERS_ARB', 34994)
GL_PROGRAM_NATIVE_ALU_INSTRUCTIONS_ARB = Constant( 'GL_PROGRAM_NATIVE_ALU_INSTRUCTIONS_ARB', 34824)
GL_PROGRAM_NATIVE_ATTRIBS_ARB = Constant( 'GL_PROGRAM_NATIVE_ATTRIBS_ARB', 34990)
GL_PROGRAM_NATIVE_INSTRUCTIONS_ARB = Constant( 'GL_PROGRAM_NATIVE_INSTRUCTIONS_ARB', 34978)
GL_PROGRAM_NATIVE_PARAMETERS_ARB = Constant( 'GL_PROGRAM_NATIVE_PARAMETERS_ARB', 34986)
GL_PROGRAM_NATIVE_TEMPORARIES_ARB = Constant( 'GL_PROGRAM_NATIVE_TEMPORARIES_ARB', 34982)
GL_PROGRAM_NATIVE_TEX_INDIRECTIONS_ARB = Constant( 'GL_PROGRAM_NATIVE_TEX_INDIRECTIONS_ARB', 34826)
GL_PROGRAM_NATIVE_TEX_INSTRUCTIONS_ARB = Constant( 'GL_PROGRAM_NATIVE_TEX_INSTRUCTIONS_ARB', 34825)
GL_PROGRAM_OBJECT_ARB = Constant( 'GL_PROGRAM_OBJECT_ARB', 35648)
GL_PROGRAM_PARAMETERS_ARB = Constant( 'GL_PROGRAM_PARAMETERS_ARB', 34984)
GL_PROGRAM_PARAMETER_NV = Constant( 'GL_PROGRAM_PARAMETER_NV', 34372)
GL_PROGRAM_RESIDENT_NV = Constant( 'GL_PROGRAM_RESIDENT_NV', 34375)
GL_PROGRAM_STRING_ARB = Constant( 'GL_PROGRAM_STRING_ARB', 34344)
GL_PROGRAM_STRING_NV = Constant( 'GL_PROGRAM_STRING_NV', 34344)
GL_PROGRAM_TARGET_NV = Constant( 'GL_PROGRAM_TARGET_NV', 34374)
GL_PROGRAM_TEMPORARIES_ARB = Constant( 'GL_PROGRAM_TEMPORARIES_ARB', 34980)
GL_PROGRAM_TEX_INDIRECTIONS_ARB = Constant( 'GL_PROGRAM_TEX_INDIRECTIONS_ARB', 34823)
GL_PROGRAM_TEX_INSTRUCTIONS_ARB = Constant( 'GL_PROGRAM_TEX_INSTRUCTIONS_ARB', 34822)
GL_PROGRAM_UNDER_NATIVE_LIMITS_ARB = Constant( 'GL_PROGRAM_UNDER_NATIVE_LIMITS_ARB', 34998)
GL_PROJECTION = Constant( 'GL_PROJECTION', 5889)
GL_PROJECTION_MATRIX = Constant( 'GL_PROJECTION_MATRIX', 2983)
GL_PROJECTION_STACK_DEPTH = Constant( 'GL_PROJECTION_STACK_DEPTH', 2980)
GL_PROXY_COLOR_TABLE = Constant( 'GL_PROXY_COLOR_TABLE', 32979)
GL_PROXY_COLOR_TABLE_SGI = Constant( 'GL_PROXY_COLOR_TABLE_SGI', 32979)
GL_PROXY_HISTOGRAM = Constant( 'GL_PROXY_HISTOGRAM', 32805)
GL_PROXY_HISTOGRAM_EXT = Constant( 'GL_PROXY_HISTOGRAM_EXT', 32805)
GL_PROXY_POST_COLOR_MATRIX_COLOR_TABLE = Constant( 'GL_PROXY_POST_COLOR_MATRIX_COLOR_TABLE', 32981)
GL_PROXY_POST_COLOR_MATRIX_COLOR_TABLE_SGI = Constant( 'GL_PROXY_POST_COLOR_MATRIX_COLOR_TABLE_SGI', 32981)
GL_PROXY_POST_CONVOLUTION_COLOR_TABLE = Constant( 'GL_PROXY_POST_CONVOLUTION_COLOR_TABLE', 32980)
GL_PROXY_POST_CONVOLUTION_COLOR_TABLE_SGI = Constant( 'GL_PROXY_POST_CONVOLUTION_COLOR_TABLE_SGI', 32980)
GL_PROXY_POST_IMAGE_TRANSFORM_COLOR_TABLE_HP = Constant( 'GL_PROXY_POST_IMAGE_TRANSFORM_COLOR_TABLE_HP', 33123)
GL_PROXY_TEXTURE_1D = Constant( 'GL_PROXY_TEXTURE_1D', 32867)
GL_PROXY_TEXTURE_1D_EXT = Constant( 'GL_PROXY_TEXTURE_1D_EXT', 32867)
GL_PROXY_TEXTURE_2D = Constant( 'GL_PROXY_TEXTURE_2D', 32868)
GL_PROXY_TEXTURE_2D_EXT = Constant( 'GL_PROXY_TEXTURE_2D_EXT', 32868)
GL_PROXY_TEXTURE_3D = Constant( 'GL_PROXY_TEXTURE_3D', 32880)
GL_PROXY_TEXTURE_3D_EXT = Constant( 'GL_PROXY_TEXTURE_3D_EXT', 32880)
GL_PROXY_TEXTURE_4D_SGIS = Constant( 'GL_PROXY_TEXTURE_4D_SGIS', 33077)
GL_PROXY_TEXTURE_COLOR_TABLE_SGI = Constant( 'GL_PROXY_TEXTURE_COLOR_TABLE_SGI', 32957)
GL_PROXY_TEXTURE_CUBE_MAP = Constant( 'GL_PROXY_TEXTURE_CUBE_MAP', 34075)
GL_PROXY_TEXTURE_CUBE_MAP_ARB = Constant( 'GL_PROXY_TEXTURE_CUBE_MAP_ARB', 34075)
GL_PROXY_TEXTURE_CUBE_MAP_EXT = Constant( 'GL_PROXY_TEXTURE_CUBE_MAP_EXT', 34075)
GL_PROXY_TEXTURE_RECTANGLE_ARB = Constant( 'GL_PROXY_TEXTURE_RECTANGLE_ARB', 34039)
GL_PROXY_TEXTURE_RECTANGLE_NV = Constant( 'GL_PROXY_TEXTURE_RECTANGLE_NV', 34039)
GL_Q = Constant( 'GL_Q', 8195)
GL_QUADRATIC_ATTENUATION = Constant( 'GL_QUADRATIC_ATTENUATION', 4617)
GL_QUADS = Constant( 'GL_QUADS', 7)
GL_QUAD_ALPHA4_SGIS = Constant( 'GL_QUAD_ALPHA4_SGIS', 33054)
GL_QUAD_ALPHA8_SGIS = Constant( 'GL_QUAD_ALPHA8_SGIS', 33055)
GL_QUAD_INTENSITY4_SGIS = Constant( 'GL_QUAD_INTENSITY4_SGIS', 33058)
GL_QUAD_INTENSITY8_SGIS = Constant( 'GL_QUAD_INTENSITY8_SGIS', 33059)
GL_QUAD_LUMINANCE4_SGIS = Constant( 'GL_QUAD_LUMINANCE4_SGIS', 33056)
GL_QUAD_LUMINANCE8_SGIS = Constant( 'GL_QUAD_LUMINANCE8_SGIS', 33057)
GL_QUAD_MESH_SUN = Constant( 'GL_QUAD_MESH_SUN', 34324)
GL_QUAD_STRIP = Constant( 'GL_QUAD_STRIP', 8)
GL_QUAD_TEXTURE_SELECT_SGIS = Constant( 'GL_QUAD_TEXTURE_SELECT_SGIS', 33061)
GL_QUARTER_BIT_ATI = Constant( 'GL_QUARTER_BIT_ATI', 16)
GL_QUERY_COUNTER_BITS = Constant( 'GL_QUERY_COUNTER_BITS', 34916)
GL_QUERY_COUNTER_BITS_ARB = Constant( 'GL_QUERY_COUNTER_BITS_ARB', 34916)
GL_QUERY_RESULT = Constant( 'GL_QUERY_RESULT', 34918)
GL_QUERY_RESULT_ARB = Constant( 'GL_QUERY_RESULT_ARB', 34918)
GL_QUERY_RESULT_AVAILABLE = Constant( 'GL_QUERY_RESULT_AVAILABLE', 34919)
GL_QUERY_RESULT_AVAILABLE_ARB = Constant( 'GL_QUERY_RESULT_AVAILABLE_ARB', 34919)
GL_R = Constant( 'GL_R', 8194)
GL_R1UI_C3F_V3F_SUN = Constant( 'GL_R1UI_C3F_V3F_SUN', 34246)
GL_R1UI_C4F_N3F_V3F_SUN = Constant( 'GL_R1UI_C4F_N3F_V3F_SUN', 34248)
GL_R1UI_C4UB_V3F_SUN = Constant( 'GL_R1UI_C4UB_V3F_SUN', 34245)
GL_R1UI_N3F_V3F_SUN = Constant( 'GL_R1UI_N3F_V3F_SUN', 34247)
GL_R1UI_T2F_C4F_N3F_V3F_SUN = Constant( 'GL_R1UI_T2F_C4F_N3F_V3F_SUN', 34251)
GL_R1UI_T2F_N3F_V3F_SUN = Constant( 'GL_R1UI_T2F_N3F_V3F_SUN', 34250)
GL_R1UI_T2F_V3F_SUN = Constant( 'GL_R1UI_T2F_V3F_SUN', 34249)
GL_R1UI_V3F_SUN = Constant( 'GL_R1UI_V3F_SUN', 34244)
GL_R3_G3_B2 = Constant( 'GL_R3_G3_B2', 10768)
GL_RASTER_POSITION_UNCLIPPED_IBM = Constant( 'GL_RASTER_POSITION_UNCLIPPED_IBM', 103010)
GL_READ_BUFFER = Constant( 'GL_READ_BUFFER', 3074)
GL_READ_ONLY = Constant( 'GL_READ_ONLY', 35000)
GL_READ_ONLY_ARB = Constant( 'GL_READ_ONLY_ARB', 35000)
GL_READ_PIXEL_DATA_RANGE_LENGTH_NV = Constant( 'GL_READ_PIXEL_DATA_RANGE_LENGTH_NV', 34939)
GL_READ_PIXEL_DATA_RANGE_NV = Constant( 'GL_READ_PIXEL_DATA_RANGE_NV', 34937)
GL_READ_PIXEL_DATA_RANGE_POINTER_NV = Constant( 'GL_READ_PIXEL_DATA_RANGE_POINTER_NV', 34941)
GL_READ_WRITE = Constant( 'GL_READ_WRITE', 35002)
GL_READ_WRITE_ARB = Constant( 'GL_READ_WRITE_ARB', 35002)
GL_RECLAIM_MEMORY_HINT_PGI = Constant( 'GL_RECLAIM_MEMORY_HINT_PGI', 107006)
GL_RED = Constant( 'GL_RED', 6403)
GL_REDUCE = Constant( 'GL_REDUCE', 32790)
GL_REDUCE_EXT = Constant( 'GL_REDUCE_EXT', 32790)
GL_RED_BIAS = Constant( 'GL_RED_BIAS', 3349)
GL_RED_BITS = Constant( 'GL_RED_BITS', 3410)
GL_RED_BIT_ATI = Constant( 'GL_RED_BIT_ATI', 1)
GL_RED_MAX_CLAMP_INGR = Constant( 'GL_RED_MAX_CLAMP_INGR', 34148)
GL_RED_MIN_CLAMP_INGR = Constant( 'GL_RED_MIN_CLAMP_INGR', 34144)
GL_RED_SCALE = Constant( 'GL_RED_SCALE', 3348)
GL_REFERENCE_PLANE_EQUATION_SGIX = Constant( 'GL_REFERENCE_PLANE_EQUATION_SGIX', 33150)
GL_REFERENCE_PLANE_SGIX = Constant( 'GL_REFERENCE_PLANE_SGIX', 33149)
GL_REFLECTION_MAP = Constant( 'GL_REFLECTION_MAP', 34066)
GL_REFLECTION_MAP_ARB = Constant( 'GL_REFLECTION_MAP_ARB', 34066)
GL_REFLECTION_MAP_EXT = Constant( 'GL_REFLECTION_MAP_EXT', 34066)
GL_REFLECTION_MAP_NV = Constant( 'GL_REFLECTION_MAP_NV', 34066)
GL_REGISTER_COMBINERS_NV = Constant( 'GL_REGISTER_COMBINERS_NV', 34082)
GL_REG_0_ATI = Constant( 'GL_REG_0_ATI', 35105)
GL_REG_10_ATI = Constant( 'GL_REG_10_ATI', 35115)
GL_REG_11_ATI = Constant( 'GL_REG_11_ATI', 35116)
GL_REG_12_ATI = Constant( 'GL_REG_12_ATI', 35117)
GL_REG_13_ATI = Constant( 'GL_REG_13_ATI', 35118)
GL_REG_14_ATI = Constant( 'GL_REG_14_ATI', 35119)
GL_REG_15_ATI = Constant( 'GL_REG_15_ATI', 35120)
GL_REG_16_ATI = Constant( 'GL_REG_16_ATI', 35121)
GL_REG_17_ATI = Constant( 'GL_REG_17_ATI', 35122)
GL_REG_18_ATI = Constant( 'GL_REG_18_ATI', 35123)
GL_REG_19_ATI = Constant( 'GL_REG_19_ATI', 35124)
GL_REG_1_ATI = Constant( 'GL_REG_1_ATI', 35106)
GL_REG_20_ATI = Constant( 'GL_REG_20_ATI', 35125)
GL_REG_21_ATI = Constant( 'GL_REG_21_ATI', 35126)
GL_REG_22_ATI = Constant( 'GL_REG_22_ATI', 35127)
GL_REG_23_ATI = Constant( 'GL_REG_23_ATI', 35128)
GL_REG_24_ATI = Constant( 'GL_REG_24_ATI', 35129)
GL_REG_25_ATI = Constant( 'GL_REG_25_ATI', 35130)
GL_REG_26_ATI = Constant( 'GL_REG_26_ATI', 35131)
GL_REG_27_ATI = Constant( 'GL_REG_27_ATI', 35132)
GL_REG_28_ATI = Constant( 'GL_REG_28_ATI', 35133)
GL_REG_29_ATI = Constant( 'GL_REG_29_ATI', 35134)
GL_REG_2_ATI = Constant( 'GL_REG_2_ATI', 35107)
GL_REG_30_ATI = Constant( 'GL_REG_30_ATI', 35135)
GL_REG_31_ATI = Constant( 'GL_REG_31_ATI', 35136)
GL_REG_3_ATI = Constant( 'GL_REG_3_ATI', 35108)
GL_REG_4_ATI = Constant( 'GL_REG_4_ATI', 35109)
GL_REG_5_ATI = Constant( 'GL_REG_5_ATI', 35110)
GL_REG_6_ATI = Constant( 'GL_REG_6_ATI', 35111)
GL_REG_7_ATI = Constant( 'GL_REG_7_ATI', 35112)
GL_REG_8_ATI = Constant( 'GL_REG_8_ATI', 35113)
GL_REG_9_ATI = Constant( 'GL_REG_9_ATI', 35114)
GL_RENDER = Constant( 'GL_RENDER', 7168)
GL_RENDERBUFFER_ALPHA_SIZE_EXT = Constant( 'GL_RENDERBUFFER_ALPHA_SIZE_EXT', 36179)
GL_RENDERBUFFER_BINDING_EXT = Constant( 'GL_RENDERBUFFER_BINDING_EXT', 36007)
GL_RENDERBUFFER_BLUE_SIZE_EXT = Constant( 'GL_RENDERBUFFER_BLUE_SIZE_EXT', 36178)
GL_RENDERBUFFER_DEPTH_SIZE_EXT = Constant( 'GL_RENDERBUFFER_DEPTH_SIZE_EXT', 36180)
GL_RENDERBUFFER_EXT = Constant( 'GL_RENDERBUFFER_EXT', 36161)
GL_RENDERBUFFER_GREEN_SIZE_EXT = Constant( 'GL_RENDERBUFFER_GREEN_SIZE_EXT', 36177)
GL_RENDERBUFFER_HEIGHT_EXT = Constant( 'GL_RENDERBUFFER_HEIGHT_EXT', 36163)
GL_RENDERBUFFER_INTERNAL_FORMAT_EXT = Constant( 'GL_RENDERBUFFER_INTERNAL_FORMAT_EXT', 36164)
GL_RENDERBUFFER_RED_SIZE_EXT = Constant( 'GL_RENDERBUFFER_RED_SIZE_EXT', 36176)
GL_RENDERBUFFER_STENCIL_SIZE_EXT = Constant( 'GL_RENDERBUFFER_STENCIL_SIZE_EXT', 36181)
GL_RENDERBUFFER_WIDTH_EXT = Constant( 'GL_RENDERBUFFER_WIDTH_EXT', 36162)
GL_RENDERER = Constant( 'GL_RENDERER', 7937)
GL_RENDER_MODE = Constant( 'GL_RENDER_MODE', 3136)
GL_REPEAT = Constant( 'GL_REPEAT', 10497)
GL_REPLACE = Constant( 'GL_REPLACE', 7681)
GL_REPLACEMENT_CODE_ARRAY_POINTER_SUN = Constant( 'GL_REPLACEMENT_CODE_ARRAY_POINTER_SUN', 34243)
GL_REPLACEMENT_CODE_ARRAY_STRIDE_SUN = Constant( 'GL_REPLACEMENT_CODE_ARRAY_STRIDE_SUN', 34242)
GL_REPLACEMENT_CODE_ARRAY_SUN = Constant( 'GL_REPLACEMENT_CODE_ARRAY_SUN', 34240)
GL_REPLACEMENT_CODE_ARRAY_TYPE_SUN = Constant( 'GL_REPLACEMENT_CODE_ARRAY_TYPE_SUN', 34241)
GL_REPLACEMENT_CODE_SUN = Constant( 'GL_REPLACEMENT_CODE_SUN', 33240)
GL_REPLACE_EXT = Constant( 'GL_REPLACE_EXT', 32866)
GL_REPLACE_MIDDLE_SUN = Constant( 'GL_REPLACE_MIDDLE_SUN', 2)
GL_REPLACE_OLDEST_SUN = Constant( 'GL_REPLACE_OLDEST_SUN', 3)
GL_REPLICATE_BORDER = Constant( 'GL_REPLICATE_BORDER', 33107)
GL_REPLICATE_BORDER_HP = Constant( 'GL_REPLICATE_BORDER_HP', 33107)
GL_RESAMPLE_AVERAGE_OML = Constant( 'GL_RESAMPLE_AVERAGE_OML', 35208)
GL_RESAMPLE_DECIMATE_OML = Constant( 'GL_RESAMPLE_DECIMATE_OML', 35209)
GL_RESAMPLE_DECIMATE_SGIX = Constant( 'GL_RESAMPLE_DECIMATE_SGIX', 33840)
GL_RESAMPLE_REPLICATE_OML = Constant( 'GL_RESAMPLE_REPLICATE_OML', 35206)
GL_RESAMPLE_REPLICATE_SGIX = Constant( 'GL_RESAMPLE_REPLICATE_SGIX', 33838)
GL_RESAMPLE_ZERO_FILL_OML = Constant( 'GL_RESAMPLE_ZERO_FILL_OML', 35207)
GL_RESAMPLE_ZERO_FILL_SGIX = Constant( 'GL_RESAMPLE_ZERO_FILL_SGIX', 33839)
GL_RESCALE_NORMAL = Constant( 'GL_RESCALE_NORMAL', 32826)
GL_RESCALE_NORMAL_EXT = Constant( 'GL_RESCALE_NORMAL_EXT', 32826)
GL_RESTART_SUN = Constant( 'GL_RESTART_SUN', 1)
GL_RETURN = Constant( 'GL_RETURN', 258)
GL_RGB = Constant( 'GL_RGB', 6407)
GL_RGB10 = Constant( 'GL_RGB10', 32850)
GL_RGB10_A2 = Constant( 'GL_RGB10_A2', 32857)
GL_RGB10_A2_EXT = Constant( 'GL_RGB10_A2_EXT', 32857)
GL_RGB10_EXT = Constant( 'GL_RGB10_EXT', 32850)
GL_RGB12 = Constant( 'GL_RGB12', 32851)
GL_RGB12_EXT = Constant( 'GL_RGB12_EXT', 32851)
GL_RGB16 = Constant( 'GL_RGB16', 32852)
GL_RGB16F_ARB = Constant( 'GL_RGB16F_ARB', 34843)
GL_RGB16_EXT = Constant( 'GL_RGB16_EXT', 32852)
GL_RGB2_EXT = Constant( 'GL_RGB2_EXT', 32846)
GL_RGB32F_ARB = Constant( 'GL_RGB32F_ARB', 34837)
GL_RGB4 = Constant( 'GL_RGB4', 32847)
GL_RGB4_EXT = Constant( 'GL_RGB4_EXT', 32847)
GL_RGB4_S3TC = Constant( 'GL_RGB4_S3TC', 33697)
GL_RGB5 = Constant( 'GL_RGB5', 32848)
GL_RGB5_A1 = Constant( 'GL_RGB5_A1', 32855)
GL_RGB5_A1_EXT = Constant( 'GL_RGB5_A1_EXT', 32855)
GL_RGB5_EXT = Constant( 'GL_RGB5_EXT', 32848)
GL_RGB8 = Constant( 'GL_RGB8', 32849)
GL_RGB8_EXT = Constant( 'GL_RGB8_EXT', 32849)
GL_RGBA = Constant( 'GL_RGBA', 6408)
GL_RGBA12 = Constant( 'GL_RGBA12', 32858)
GL_RGBA12_EXT = Constant( 'GL_RGBA12_EXT', 32858)
GL_RGBA16 = Constant( 'GL_RGBA16', 32859)
GL_RGBA16F_ARB = Constant( 'GL_RGBA16F_ARB', 34842)
GL_RGBA16_EXT = Constant( 'GL_RGBA16_EXT', 32859)
GL_RGBA2 = Constant( 'GL_RGBA2', 32853)
GL_RGBA2_EXT = Constant( 'GL_RGBA2_EXT', 32853)
GL_RGBA32F_ARB = Constant( 'GL_RGBA32F_ARB', 34836)
GL_RGBA4 = Constant( 'GL_RGBA4', 32854)
GL_RGBA4_EXT = Constant( 'GL_RGBA4_EXT', 32854)
GL_RGBA4_S3TC = Constant( 'GL_RGBA4_S3TC', 33699)
GL_RGBA8 = Constant( 'GL_RGBA8', 32856)
GL_RGBA8_EXT = Constant( 'GL_RGBA8_EXT', 32856)
GL_RGBA_FLOAT16_ATI = Constant( 'GL_RGBA_FLOAT16_ATI', 34842)
GL_RGBA_FLOAT32_ATI = Constant( 'GL_RGBA_FLOAT32_ATI', 34836)
GL_RGBA_FLOAT_MODE_ARB = Constant( 'GL_RGBA_FLOAT_MODE_ARB', 34848)
GL_RGBA_MODE = Constant( 'GL_RGBA_MODE', 3121)
GL_RGBA_S3TC = Constant( 'GL_RGBA_S3TC', 33698)
GL_RGBA_UNSIGNED_DOT_PRODUCT_MAPPING_NV = Constant( 'GL_RGBA_UNSIGNED_DOT_PRODUCT_MAPPING_NV', 34521)
GL_RGB_FLOAT16_ATI = Constant( 'GL_RGB_FLOAT16_ATI', 34843)
GL_RGB_FLOAT32_ATI = Constant( 'GL_RGB_FLOAT32_ATI', 34837)
GL_RGB_S3TC = Constant( 'GL_RGB_S3TC', 33696)
GL_RGB_SCALE = Constant( 'GL_RGB_SCALE', 34163)
GL_RGB_SCALE_ARB = Constant( 'GL_RGB_SCALE_ARB', 34163)
GL_RGB_SCALE_EXT = Constant( 'GL_RGB_SCALE_EXT', 34163)
GL_RIGHT = Constant( 'GL_RIGHT', 1031)
GL_S = Constant( 'GL_S', 8192)
GL_SAMPLER_1D = Constant( 'GL_SAMPLER_1D', 35677)
GL_SAMPLER_1D_ARB = Constant( 'GL_SAMPLER_1D_ARB', 35677)
GL_SAMPLER_1D_SHADOW = Constant( 'GL_SAMPLER_1D_SHADOW', 35681)
GL_SAMPLER_1D_SHADOW_ARB = Constant( 'GL_SAMPLER_1D_SHADOW_ARB', 35681)
GL_SAMPLER_2D = Constant( 'GL_SAMPLER_2D', 35678)
GL_SAMPLER_2D_ARB = Constant( 'GL_SAMPLER_2D_ARB', 35678)
GL_SAMPLER_2D_RECT_ARB = Constant( 'GL_SAMPLER_2D_RECT_ARB', 35683)
GL_SAMPLER_2D_RECT_SHADOW_ARB = Constant( 'GL_SAMPLER_2D_RECT_SHADOW_ARB', 35684)
GL_SAMPLER_2D_SHADOW = Constant( 'GL_SAMPLER_2D_SHADOW', 35682)
GL_SAMPLER_2D_SHADOW_ARB = Constant( 'GL_SAMPLER_2D_SHADOW_ARB', 35682)
GL_SAMPLER_3D = Constant( 'GL_SAMPLER_3D', 35679)
GL_SAMPLER_3D_ARB = Constant( 'GL_SAMPLER_3D_ARB', 35679)
GL_SAMPLER_CUBE = Constant( 'GL_SAMPLER_CUBE', 35680)
GL_SAMPLER_CUBE_ARB = Constant( 'GL_SAMPLER_CUBE_ARB', 35680)
GL_SAMPLES = Constant( 'GL_SAMPLES', 32937)
GL_SAMPLES_3DFX = Constant( 'GL_SAMPLES_3DFX', 34484)
GL_SAMPLES_ARB = Constant( 'GL_SAMPLES_ARB', 32937)
GL_SAMPLES_EXT = Constant( 'GL_SAMPLES_EXT', 32937)
GL_SAMPLES_PASSED = Constant( 'GL_SAMPLES_PASSED', 35092)
GL_SAMPLES_PASSED_ARB = Constant( 'GL_SAMPLES_PASSED_ARB', 35092)
GL_SAMPLES_SGIS = Constant( 'GL_SAMPLES_SGIS', 32937)
GL_SAMPLE_ALPHA_TO_COVERAGE = Constant( 'GL_SAMPLE_ALPHA_TO_COVERAGE', 32926)
GL_SAMPLE_ALPHA_TO_COVERAGE_ARB = Constant( 'GL_SAMPLE_ALPHA_TO_COVERAGE_ARB', 32926)
GL_SAMPLE_ALPHA_TO_MASK_EXT = Constant( 'GL_SAMPLE_ALPHA_TO_MASK_EXT', 32926)
GL_SAMPLE_ALPHA_TO_MASK_SGIS = Constant( 'GL_SAMPLE_ALPHA_TO_MASK_SGIS', 32926)
GL_SAMPLE_ALPHA_TO_ONE = Constant( 'GL_SAMPLE_ALPHA_TO_ONE', 32927)
GL_SAMPLE_ALPHA_TO_ONE_ARB = Constant( 'GL_SAMPLE_ALPHA_TO_ONE_ARB', 32927)
GL_SAMPLE_ALPHA_TO_ONE_EXT = Constant( 'GL_SAMPLE_ALPHA_TO_ONE_EXT', 32927)
GL_SAMPLE_ALPHA_TO_ONE_SGIS = Constant( 'GL_SAMPLE_ALPHA_TO_ONE_SGIS', 32927)
GL_SAMPLE_BUFFERS = Constant( 'GL_SAMPLE_BUFFERS', 32936)
GL_SAMPLE_BUFFERS_3DFX = Constant( 'GL_SAMPLE_BUFFERS_3DFX', 34483)
GL_SAMPLE_BUFFERS_ARB = Constant( 'GL_SAMPLE_BUFFERS_ARB', 32936)
GL_SAMPLE_BUFFERS_EXT = Constant( 'GL_SAMPLE_BUFFERS_EXT', 32936)
GL_SAMPLE_BUFFERS_SGIS = Constant( 'GL_SAMPLE_BUFFERS_SGIS', 32936)
GL_SAMPLE_COVERAGE = Constant( 'GL_SAMPLE_COVERAGE', 32928)
GL_SAMPLE_COVERAGE_ARB = Constant( 'GL_SAMPLE_COVERAGE_ARB', 32928)
GL_SAMPLE_COVERAGE_INVERT = Constant( 'GL_SAMPLE_COVERAGE_INVERT', 32939)
GL_SAMPLE_COVERAGE_INVERT_ARB = Constant( 'GL_SAMPLE_COVERAGE_INVERT_ARB', 32939)
GL_SAMPLE_COVERAGE_VALUE = Constant( 'GL_SAMPLE_COVERAGE_VALUE', 32938)
GL_SAMPLE_COVERAGE_VALUE_ARB = Constant( 'GL_SAMPLE_COVERAGE_VALUE_ARB', 32938)
GL_SAMPLE_MASK_EXT = Constant( 'GL_SAMPLE_MASK_EXT', 32928)
GL_SAMPLE_MASK_INVERT_EXT = Constant( 'GL_SAMPLE_MASK_INVERT_EXT', 32939)
GL_SAMPLE_MASK_INVERT_SGIS = Constant( 'GL_SAMPLE_MASK_INVERT_SGIS', 32939)
GL_SAMPLE_MASK_SGIS = Constant( 'GL_SAMPLE_MASK_SGIS', 32928)
GL_SAMPLE_MASK_VALUE_EXT = Constant( 'GL_SAMPLE_MASK_VALUE_EXT', 32938)
GL_SAMPLE_MASK_VALUE_SGIS = Constant( 'GL_SAMPLE_MASK_VALUE_SGIS', 32938)
GL_SAMPLE_PATTERN_EXT = Constant( 'GL_SAMPLE_PATTERN_EXT', 32940)
GL_SAMPLE_PATTERN_SGIS = Constant( 'GL_SAMPLE_PATTERN_SGIS', 32940)
GL_SATURATE_BIT_ATI = Constant( 'GL_SATURATE_BIT_ATI', 64)
GL_SCALAR_EXT = Constant( 'GL_SCALAR_EXT', 34750)
GL_SCALEBIAS_HINT_SGIX = Constant( 'GL_SCALEBIAS_HINT_SGIX', 33570)
GL_SCALE_BY_FOUR_NV = Constant( 'GL_SCALE_BY_FOUR_NV', 34111)
GL_SCALE_BY_ONE_HALF_NV = Constant( 'GL_SCALE_BY_ONE_HALF_NV', 34112)
GL_SCALE_BY_TWO_NV = Constant( 'GL_SCALE_BY_TWO_NV', 34110)
GL_SCISSOR_BIT = Constant( 'GL_SCISSOR_BIT', 524288)
GL_SCISSOR_BOX = Constant( 'GL_SCISSOR_BOX', 3088)
GL_SCISSOR_TEST = Constant( 'GL_SCISSOR_TEST', 3089)
GL_SCREEN_COORDINATES_REND = Constant( 'GL_SCREEN_COORDINATES_REND', 33936)
GL_SECONDARY_COLOR_ARRAY = Constant( 'GL_SECONDARY_COLOR_ARRAY', 33886)
GL_SECONDARY_COLOR_ARRAY_BUFFER_BINDING = Constant( 'GL_SECONDARY_COLOR_ARRAY_BUFFER_BINDING', 34972)
GL_SECONDARY_COLOR_ARRAY_BUFFER_BINDING_ARB = Constant( 'GL_SECONDARY_COLOR_ARRAY_BUFFER_BINDING_ARB', 34972)
GL_SECONDARY_COLOR_ARRAY_EXT = Constant( 'GL_SECONDARY_COLOR_ARRAY_EXT', 33886)
GL_SECONDARY_COLOR_ARRAY_LIST_IBM = Constant( 'GL_SECONDARY_COLOR_ARRAY_LIST_IBM', 103077)
GL_SECONDARY_COLOR_ARRAY_LIST_STRIDE_IBM = Constant( 'GL_SECONDARY_COLOR_ARRAY_LIST_STRIDE_IBM', 103087)
GL_SECONDARY_COLOR_ARRAY_POINTER = Constant( 'GL_SECONDARY_COLOR_ARRAY_POINTER', 33885)
GL_SECONDARY_COLOR_ARRAY_POINTER_EXT = Constant( 'GL_SECONDARY_COLOR_ARRAY_POINTER_EXT', 33885)
GL_SECONDARY_COLOR_ARRAY_SIZE = Constant( 'GL_SECONDARY_COLOR_ARRAY_SIZE', 33882)
GL_SECONDARY_COLOR_ARRAY_SIZE_EXT = Constant( 'GL_SECONDARY_COLOR_ARRAY_SIZE_EXT', 33882)
GL_SECONDARY_COLOR_ARRAY_STRIDE = Constant( 'GL_SECONDARY_COLOR_ARRAY_STRIDE', 33884)
GL_SECONDARY_COLOR_ARRAY_STRIDE_EXT = Constant( 'GL_SECONDARY_COLOR_ARRAY_STRIDE_EXT', 33884)
GL_SECONDARY_COLOR_ARRAY_TYPE = Constant( 'GL_SECONDARY_COLOR_ARRAY_TYPE', 33883)
GL_SECONDARY_COLOR_ARRAY_TYPE_EXT = Constant( 'GL_SECONDARY_COLOR_ARRAY_TYPE_EXT', 33883)
GL_SECONDARY_COLOR_NV = Constant( 'GL_SECONDARY_COLOR_NV', 34093)
GL_SECONDARY_INTERPOLATOR_ATI = Constant( 'GL_SECONDARY_INTERPOLATOR_ATI', 35181)
GL_SELECT = Constant( 'GL_SELECT', 7170)
GL_SELECTION_BUFFER_POINTER = Constant( 'GL_SELECTION_BUFFER_POINTER', 3571)
GL_SELECTION_BUFFER_SIZE = Constant( 'GL_SELECTION_BUFFER_SIZE', 3572)
GL_SEPARABLE_2D = Constant( 'GL_SEPARABLE_2D', 32786)
GL_SEPARABLE_2D_EXT = Constant( 'GL_SEPARABLE_2D_EXT', 32786)
GL_SEPARATE_SPECULAR_COLOR = Constant( 'GL_SEPARATE_SPECULAR_COLOR', 33274)
GL_SEPARATE_SPECULAR_COLOR_EXT = Constant( 'GL_SEPARATE_SPECULAR_COLOR_EXT', 33274)
GL_SET = Constant( 'GL_SET', 5391)
GL_SHADER_CONSISTENT_NV = Constant( 'GL_SHADER_CONSISTENT_NV', 34525)
GL_SHADER_OBJECT_ARB = Constant( 'GL_SHADER_OBJECT_ARB', 35656)
GL_SHADER_OPERATION_NV = Constant( 'GL_SHADER_OPERATION_NV', 34527)
GL_SHADER_SOURCE_LENGTH = Constant( 'GL_SHADER_SOURCE_LENGTH', 35720)
GL_SHADER_TYPE = Constant( 'GL_SHADER_TYPE', 35663)
GL_SHADE_MODEL = Constant( 'GL_SHADE_MODEL', 2900)
GL_SHADING_LANGUAGE_VERSION = Constant( 'GL_SHADING_LANGUAGE_VERSION', 35724)
GL_SHADING_LANGUAGE_VERSION_ARB = Constant( 'GL_SHADING_LANGUAGE_VERSION_ARB', 35724)
GL_SHADOW_AMBIENT_SGIX = Constant( 'GL_SHADOW_AMBIENT_SGIX', 32959)
GL_SHADOW_ATTENUATION_EXT = Constant( 'GL_SHADOW_ATTENUATION_EXT', 33614)
GL_SHARED_TEXTURE_PALETTE_EXT = Constant( 'GL_SHARED_TEXTURE_PALETTE_EXT', 33275)
GL_SHARPEN_TEXTURE_FUNC_POINTS_SGIS = Constant( 'GL_SHARPEN_TEXTURE_FUNC_POINTS_SGIS', 32944)
GL_SHININESS = Constant( 'GL_SHININESS', 5633)
GL_SIGNED_ALPHA8_NV = Constant( 'GL_SIGNED_ALPHA8_NV', 34566)
GL_SIGNED_ALPHA_NV = Constant( 'GL_SIGNED_ALPHA_NV', 34565)
GL_SIGNED_HILO16_NV = Constant( 'GL_SIGNED_HILO16_NV', 34554)
GL_SIGNED_HILO8_NV = Constant( 'GL_SIGNED_HILO8_NV', 34911)
GL_SIGNED_HILO_NV = Constant( 'GL_SIGNED_HILO_NV', 34553)
GL_SIGNED_IDENTITY_NV = Constant( 'GL_SIGNED_IDENTITY_NV', 34108)
GL_SIGNED_INTENSITY8_NV = Constant( 'GL_SIGNED_INTENSITY8_NV', 34568)
GL_SIGNED_INTENSITY_NV = Constant( 'GL_SIGNED_INTENSITY_NV', 34567)
GL_SIGNED_LUMINANCE8_ALPHA8_NV = Constant( 'GL_SIGNED_LUMINANCE8_ALPHA8_NV', 34564)
GL_SIGNED_LUMINANCE8_NV = Constant( 'GL_SIGNED_LUMINANCE8_NV', 34562)
GL_SIGNED_LUMINANCE_ALPHA_NV = Constant( 'GL_SIGNED_LUMINANCE_ALPHA_NV', 34563)
GL_SIGNED_LUMINANCE_NV = Constant( 'GL_SIGNED_LUMINANCE_NV', 34561)
GL_SIGNED_NEGATE_NV = Constant( 'GL_SIGNED_NEGATE_NV', 34109)
GL_SIGNED_RGB8_NV = Constant( 'GL_SIGNED_RGB8_NV', 34559)
GL_SIGNED_RGB8_UNSIGNED_ALPHA8_NV = Constant( 'GL_SIGNED_RGB8_UNSIGNED_ALPHA8_NV', 34573)
GL_SIGNED_RGBA8_NV = Constant( 'GL_SIGNED_RGBA8_NV', 34556)
GL_SIGNED_RGBA_NV = Constant( 'GL_SIGNED_RGBA_NV', 34555)
GL_SIGNED_RGB_NV = Constant( 'GL_SIGNED_RGB_NV', 34558)
GL_SIGNED_RGB_UNSIGNED_ALPHA_NV = Constant( 'GL_SIGNED_RGB_UNSIGNED_ALPHA_NV', 34572)
GL_SINGLE_COLOR = Constant( 'GL_SINGLE_COLOR', 33273)
GL_SINGLE_COLOR_EXT = Constant( 'GL_SINGLE_COLOR_EXT', 33273)
GL_SLICE_ACCUM_SUN = Constant( 'GL_SLICE_ACCUM_SUN', 34252)
GL_SMOOTH = Constant( 'GL_SMOOTH', 7425)
GL_SMOOTH_LINE_WIDTH_GRANULARITY = Constant( 'GL_SMOOTH_LINE_WIDTH_GRANULARITY', 2851)
GL_SMOOTH_LINE_WIDTH_RANGE = Constant( 'GL_SMOOTH_LINE_WIDTH_RANGE', 2850)
GL_SMOOTH_POINT_SIZE_GRANULARITY = Constant( 'GL_SMOOTH_POINT_SIZE_GRANULARITY', 2835)
GL_SMOOTH_POINT_SIZE_RANGE = Constant( 'GL_SMOOTH_POINT_SIZE_RANGE', 2834)
GL_SOURCE0_ALPHA = Constant( 'GL_SOURCE0_ALPHA', 34184)
GL_SOURCE0_ALPHA_ARB = Constant( 'GL_SOURCE0_ALPHA_ARB', 34184)
GL_SOURCE0_ALPHA_EXT = Constant( 'GL_SOURCE0_ALPHA_EXT', 34184)
GL_SOURCE0_RGB = Constant( 'GL_SOURCE0_RGB', 34176)
GL_SOURCE0_RGB_ARB = Constant( 'GL_SOURCE0_RGB_ARB', 34176)
GL_SOURCE0_RGB_EXT = Constant( 'GL_SOURCE0_RGB_EXT', 34176)
GL_SOURCE1_ALPHA = Constant( 'GL_SOURCE1_ALPHA', 34185)
GL_SOURCE1_ALPHA_ARB = Constant( 'GL_SOURCE1_ALPHA_ARB', 34185)
GL_SOURCE1_ALPHA_EXT = Constant( 'GL_SOURCE1_ALPHA_EXT', 34185)
GL_SOURCE1_RGB = Constant( 'GL_SOURCE1_RGB', 34177)
GL_SOURCE1_RGB_ARB = Constant( 'GL_SOURCE1_RGB_ARB', 34177)
GL_SOURCE1_RGB_EXT = Constant( 'GL_SOURCE1_RGB_EXT', 34177)
GL_SOURCE2_ALPHA = Constant( 'GL_SOURCE2_ALPHA', 34186)
GL_SOURCE2_ALPHA_ARB = Constant( 'GL_SOURCE2_ALPHA_ARB', 34186)
GL_SOURCE2_ALPHA_EXT = Constant( 'GL_SOURCE2_ALPHA_EXT', 34186)
GL_SOURCE2_RGB = Constant( 'GL_SOURCE2_RGB', 34178)
GL_SOURCE2_RGB_ARB = Constant( 'GL_SOURCE2_RGB_ARB', 34178)
GL_SOURCE2_RGB_EXT = Constant( 'GL_SOURCE2_RGB_EXT', 34178)
GL_SOURCE3_ALPHA_NV = Constant( 'GL_SOURCE3_ALPHA_NV', 34187)
GL_SOURCE3_RGB_NV = Constant( 'GL_SOURCE3_RGB_NV', 34179)
GL_SPARE0_NV = Constant( 'GL_SPARE0_NV', 34094)
GL_SPARE0_PLUS_SECONDARY_COLOR_NV = Constant( 'GL_SPARE0_PLUS_SECONDARY_COLOR_NV', 34098)
GL_SPARE1_NV = Constant( 'GL_SPARE1_NV', 34095)
GL_SPECULAR = Constant( 'GL_SPECULAR', 4610)
GL_SPHERE_MAP = Constant( 'GL_SPHERE_MAP', 9218)
GL_SPOT_CUTOFF = Constant( 'GL_SPOT_CUTOFF', 4614)
GL_SPOT_DIRECTION = Constant( 'GL_SPOT_DIRECTION', 4612)
GL_SPOT_EXPONENT = Constant( 'GL_SPOT_EXPONENT', 4613)
GL_SPRITE_AXIAL_SGIX = Constant( 'GL_SPRITE_AXIAL_SGIX', 33100)
GL_SPRITE_AXIS_SGIX = Constant( 'GL_SPRITE_AXIS_SGIX', 33098)
GL_SPRITE_EYE_ALIGNED_SGIX = Constant( 'GL_SPRITE_EYE_ALIGNED_SGIX', 33102)
GL_SPRITE_MODE_SGIX = Constant( 'GL_SPRITE_MODE_SGIX', 33097)
GL_SPRITE_OBJECT_ALIGNED_SGIX = Constant( 'GL_SPRITE_OBJECT_ALIGNED_SGIX', 33101)
GL_SPRITE_SGIX = Constant( 'GL_SPRITE_SGIX', 33096)
GL_SPRITE_TRANSLATION_SGIX = Constant( 'GL_SPRITE_TRANSLATION_SGIX', 33099)
GL_SRC_ALPHA = Constant( 'GL_SRC_ALPHA', 770)
GL_SRC_ALPHA_SATURATE = Constant( 'GL_SRC_ALPHA_SATURATE', 776)
GL_SRC_COLOR = Constant( 'GL_SRC_COLOR', 768)
GL_STACK_OVERFLOW = Constant( 'GL_STACK_OVERFLOW', 1283)
GL_STACK_UNDERFLOW = Constant( 'GL_STACK_UNDERFLOW', 1284)
GL_STATIC_ATI = Constant( 'GL_STATIC_ATI', 34656)
GL_STATIC_COPY = Constant( 'GL_STATIC_COPY', 35046)
GL_STATIC_COPY_ARB = Constant( 'GL_STATIC_COPY_ARB', 35046)
GL_STATIC_DRAW = Constant( 'GL_STATIC_DRAW', 35044)
GL_STATIC_DRAW_ARB = Constant( 'GL_STATIC_DRAW_ARB', 35044)
GL_STATIC_READ = Constant( 'GL_STATIC_READ', 35045)
GL_STATIC_READ_ARB = Constant( 'GL_STATIC_READ_ARB', 35045)
GL_STENCIL = Constant( 'GL_STENCIL', 6146)
GL_STENCIL_ATTACHMENT_EXT = Constant( 'GL_STENCIL_ATTACHMENT_EXT', 36128)
GL_STENCIL_BACK_FAIL = Constant( 'GL_STENCIL_BACK_FAIL', 34817)
GL_STENCIL_BACK_FAIL_ATI = Constant( 'GL_STENCIL_BACK_FAIL_ATI', 34817)
GL_STENCIL_BACK_FUNC = Constant( 'GL_STENCIL_BACK_FUNC', 34816)
GL_STENCIL_BACK_FUNC_ATI = Constant( 'GL_STENCIL_BACK_FUNC_ATI', 34816)
GL_STENCIL_BACK_PASS_DEPTH_FAIL = Constant( 'GL_STENCIL_BACK_PASS_DEPTH_FAIL', 34818)
GL_STENCIL_BACK_PASS_DEPTH_FAIL_ATI = Constant( 'GL_STENCIL_BACK_PASS_DEPTH_FAIL_ATI', 34818)
GL_STENCIL_BACK_PASS_DEPTH_PASS = Constant( 'GL_STENCIL_BACK_PASS_DEPTH_PASS', 34819)
GL_STENCIL_BACK_PASS_DEPTH_PASS_ATI = Constant( 'GL_STENCIL_BACK_PASS_DEPTH_PASS_ATI', 34819)
GL_STENCIL_BACK_REF = Constant( 'GL_STENCIL_BACK_REF', 36003)
GL_STENCIL_BACK_VALUE_MASK = Constant( 'GL_STENCIL_BACK_VALUE_MASK', 36004)
GL_STENCIL_BACK_WRITEMASK = Constant( 'GL_STENCIL_BACK_WRITEMASK', 36005)
GL_STENCIL_BITS = Constant( 'GL_STENCIL_BITS', 3415)
GL_STENCIL_BUFFER_BIT = Constant( 'GL_STENCIL_BUFFER_BIT', 1024)
GL_STENCIL_CLEAR_VALUE = Constant( 'GL_STENCIL_CLEAR_VALUE', 2961)
GL_STENCIL_FAIL = Constant( 'GL_STENCIL_FAIL', 2964)
GL_STENCIL_FUNC = Constant( 'GL_STENCIL_FUNC', 2962)
GL_STENCIL_INDEX = Constant( 'GL_STENCIL_INDEX', 6401)
GL_STENCIL_INDEX16_EXT = Constant( 'GL_STENCIL_INDEX16_EXT', 36169)
GL_STENCIL_INDEX1_EXT = Constant( 'GL_STENCIL_INDEX1_EXT', 36166)
GL_STENCIL_INDEX4_EXT = Constant( 'GL_STENCIL_INDEX4_EXT', 36167)
GL_STENCIL_INDEX8_EXT = Constant( 'GL_STENCIL_INDEX8_EXT', 36168)
GL_STENCIL_PASS_DEPTH_FAIL = Constant( 'GL_STENCIL_PASS_DEPTH_FAIL', 2965)
GL_STENCIL_PASS_DEPTH_PASS = Constant( 'GL_STENCIL_PASS_DEPTH_PASS', 2966)
GL_STENCIL_REF = Constant( 'GL_STENCIL_REF', 2967)
GL_STENCIL_TEST = Constant( 'GL_STENCIL_TEST', 2960)
GL_STENCIL_TEST_TWO_SIDE_EXT = Constant( 'GL_STENCIL_TEST_TWO_SIDE_EXT', 35088)
GL_STENCIL_VALUE_MASK = Constant( 'GL_STENCIL_VALUE_MASK', 2963)
GL_STENCIL_WRITEMASK = Constant( 'GL_STENCIL_WRITEMASK', 2968)
GL_STEREO = Constant( 'GL_STEREO', 3123)
GL_STORAGE_CACHED_APPLE = Constant( 'GL_STORAGE_CACHED_APPLE', 34238)
GL_STORAGE_SHARED_APPLE = Constant( 'GL_STORAGE_SHARED_APPLE', 34239)
GL_STREAM_COPY = Constant( 'GL_STREAM_COPY', 35042)
GL_STREAM_COPY_ARB = Constant( 'GL_STREAM_COPY_ARB', 35042)
GL_STREAM_DRAW = Constant( 'GL_STREAM_DRAW', 35040)
GL_STREAM_DRAW_ARB = Constant( 'GL_STREAM_DRAW_ARB', 35040)
GL_STREAM_READ = Constant( 'GL_STREAM_READ', 35041)
GL_STREAM_READ_ARB = Constant( 'GL_STREAM_READ_ARB', 35041)
GL_STRICT_DEPTHFUNC_HINT_PGI = Constant( 'GL_STRICT_DEPTHFUNC_HINT_PGI', 107030)
GL_STRICT_LIGHTING_HINT_PGI = Constant( 'GL_STRICT_LIGHTING_HINT_PGI', 107031)
GL_STRICT_SCISSOR_HINT_PGI = Constant( 'GL_STRICT_SCISSOR_HINT_PGI', 107032)
GL_SUBPIXEL_BITS = Constant( 'GL_SUBPIXEL_BITS', 3408)
GL_SUBTRACT = Constant( 'GL_SUBTRACT', 34023)
GL_SUBTRACT_ARB = Constant( 'GL_SUBTRACT_ARB', 34023)
GL_SUB_ATI = Constant( 'GL_SUB_ATI', 35173)
GL_SWIZZLE_STQ_ATI = Constant( 'GL_SWIZZLE_STQ_ATI', 35191)
GL_SWIZZLE_STQ_DQ_ATI = Constant( 'GL_SWIZZLE_STQ_DQ_ATI', 35193)
GL_SWIZZLE_STRQ_ATI = Constant( 'GL_SWIZZLE_STRQ_ATI', 35194)
GL_SWIZZLE_STRQ_DQ_ATI = Constant( 'GL_SWIZZLE_STRQ_DQ_ATI', 35195)
GL_SWIZZLE_STR_ATI = Constant( 'GL_SWIZZLE_STR_ATI', 35190)
GL_SWIZZLE_STR_DR_ATI = Constant( 'GL_SWIZZLE_STR_DR_ATI', 35192)
GL_T = Constant( 'GL_T', 8193)
GL_T2F_C3F_V3F = Constant( 'GL_T2F_C3F_V3F', 10794)
GL_T2F_C4F_N3F_V3F = Constant( 'GL_T2F_C4F_N3F_V3F', 10796)
GL_T2F_C4UB_V3F = Constant( 'GL_T2F_C4UB_V3F', 10793)
GL_T2F_IUI_N3F_V2F_EXT = Constant( 'GL_T2F_IUI_N3F_V2F_EXT', 33203)
GL_T2F_IUI_N3F_V3F_EXT = Constant( 'GL_T2F_IUI_N3F_V3F_EXT', 33204)
GL_T2F_IUI_V2F_EXT = Constant( 'GL_T2F_IUI_V2F_EXT', 33201)
GL_T2F_IUI_V3F_EXT = Constant( 'GL_T2F_IUI_V3F_EXT', 33202)
GL_T2F_N3F_V3F = Constant( 'GL_T2F_N3F_V3F', 10795)
GL_T2F_V3F = Constant( 'GL_T2F_V3F', 10791)
GL_T4F_C4F_N3F_V4F = Constant( 'GL_T4F_C4F_N3F_V4F', 10797)
GL_T4F_V4F = Constant( 'GL_T4F_V4F', 10792)
GL_TABLE_TOO_LARGE = Constant( 'GL_TABLE_TOO_LARGE', 32817)
GL_TABLE_TOO_LARGE_EXT = Constant( 'GL_TABLE_TOO_LARGE_EXT', 32817)
GL_TANGENT_ARRAY_EXT = Constant( 'GL_TANGENT_ARRAY_EXT', 33849)
GL_TANGENT_ARRAY_POINTER_EXT = Constant( 'GL_TANGENT_ARRAY_POINTER_EXT', 33858)
GL_TANGENT_ARRAY_STRIDE_EXT = Constant( 'GL_TANGENT_ARRAY_STRIDE_EXT', 33855)
GL_TANGENT_ARRAY_TYPE_EXT = Constant( 'GL_TANGENT_ARRAY_TYPE_EXT', 33854)
GL_TEXCOORD1_BIT_PGI = Constant( 'GL_TEXCOORD1_BIT_PGI', 268435456)
GL_TEXCOORD2_BIT_PGI = Constant( 'GL_TEXCOORD2_BIT_PGI', 536870912)
GL_TEXCOORD3_BIT_PGI = Constant( 'GL_TEXCOORD3_BIT_PGI', 1073741824)
GL_TEXCOORD4_BIT_PGI = Constant( 'GL_TEXCOORD4_BIT_PGI', 2147483648)
GL_TEXTURE = Constant( 'GL_TEXTURE', 5890)
GL_TEXTURE0 = Constant( 'GL_TEXTURE0', 33984)
GL_TEXTURE0_ARB = Constant( 'GL_TEXTURE0_ARB', 33984)
GL_TEXTURE1 = Constant( 'GL_TEXTURE1', 33985)
GL_TEXTURE10 = Constant( 'GL_TEXTURE10', 33994)
GL_TEXTURE10_ARB = Constant( 'GL_TEXTURE10_ARB', 33994)
GL_TEXTURE11 = Constant( 'GL_TEXTURE11', 33995)
GL_TEXTURE11_ARB = Constant( 'GL_TEXTURE11_ARB', 33995)
GL_TEXTURE12 = Constant( 'GL_TEXTURE12', 33996)
GL_TEXTURE12_ARB = Constant( 'GL_TEXTURE12_ARB', 33996)
GL_TEXTURE13 = Constant( 'GL_TEXTURE13', 33997)
GL_TEXTURE13_ARB = Constant( 'GL_TEXTURE13_ARB', 33997)
GL_TEXTURE14 = Constant( 'GL_TEXTURE14', 33998)
GL_TEXTURE14_ARB = Constant( 'GL_TEXTURE14_ARB', 33998)
GL_TEXTURE15 = Constant( 'GL_TEXTURE15', 33999)
GL_TEXTURE15_ARB = Constant( 'GL_TEXTURE15_ARB', 33999)
GL_TEXTURE16 = Constant( 'GL_TEXTURE16', 34000)
GL_TEXTURE16_ARB = Constant( 'GL_TEXTURE16_ARB', 34000)
GL_TEXTURE17 = Constant( 'GL_TEXTURE17', 34001)
GL_TEXTURE17_ARB = Constant( 'GL_TEXTURE17_ARB', 34001)
GL_TEXTURE18 = Constant( 'GL_TEXTURE18', 34002)
GL_TEXTURE18_ARB = Constant( 'GL_TEXTURE18_ARB', 34002)
GL_TEXTURE19 = Constant( 'GL_TEXTURE19', 34003)
GL_TEXTURE19_ARB = Constant( 'GL_TEXTURE19_ARB', 34003)
GL_TEXTURE1_ARB = Constant( 'GL_TEXTURE1_ARB', 33985)
GL_TEXTURE2 = Constant( 'GL_TEXTURE2', 33986)
GL_TEXTURE20 = Constant( 'GL_TEXTURE20', 34004)
GL_TEXTURE20_ARB = Constant( 'GL_TEXTURE20_ARB', 34004)
GL_TEXTURE21 = Constant( 'GL_TEXTURE21', 34005)
GL_TEXTURE21_ARB = Constant( 'GL_TEXTURE21_ARB', 34005)
GL_TEXTURE22 = Constant( 'GL_TEXTURE22', 34006)
GL_TEXTURE22_ARB = Constant( 'GL_TEXTURE22_ARB', 34006)
GL_TEXTURE23 = Constant( 'GL_TEXTURE23', 34007)
GL_TEXTURE23_ARB = Constant( 'GL_TEXTURE23_ARB', 34007)
GL_TEXTURE24 = Constant( 'GL_TEXTURE24', 34008)
GL_TEXTURE24_ARB = Constant( 'GL_TEXTURE24_ARB', 34008)
GL_TEXTURE25 = Constant( 'GL_TEXTURE25', 34009)
GL_TEXTURE25_ARB = Constant( 'GL_TEXTURE25_ARB', 34009)
GL_TEXTURE26 = Constant( 'GL_TEXTURE26', 34010)
GL_TEXTURE26_ARB = Constant( 'GL_TEXTURE26_ARB', 34010)
GL_TEXTURE27 = Constant( 'GL_TEXTURE27', 34011)
GL_TEXTURE27_ARB = Constant( 'GL_TEXTURE27_ARB', 34011)
GL_TEXTURE28 = Constant( 'GL_TEXTURE28', 34012)
GL_TEXTURE28_ARB = Constant( 'GL_TEXTURE28_ARB', 34012)
GL_TEXTURE29 = Constant( 'GL_TEXTURE29', 34013)
GL_TEXTURE29_ARB = Constant( 'GL_TEXTURE29_ARB', 34013)
GL_TEXTURE2_ARB = Constant( 'GL_TEXTURE2_ARB', 33986)
GL_TEXTURE3 = Constant( 'GL_TEXTURE3', 33987)
GL_TEXTURE30 = Constant( 'GL_TEXTURE30', 34014)
GL_TEXTURE30_ARB = Constant( 'GL_TEXTURE30_ARB', 34014)
GL_TEXTURE31 = Constant( 'GL_TEXTURE31', 34015)
GL_TEXTURE31_ARB = Constant( 'GL_TEXTURE31_ARB', 34015)
GL_TEXTURE3_ARB = Constant( 'GL_TEXTURE3_ARB', 33987)
GL_TEXTURE4 = Constant( 'GL_TEXTURE4', 33988)
GL_TEXTURE4_ARB = Constant( 'GL_TEXTURE4_ARB', 33988)
GL_TEXTURE5 = Constant( 'GL_TEXTURE5', 33989)
GL_TEXTURE5_ARB = Constant( 'GL_TEXTURE5_ARB', 33989)
GL_TEXTURE6 = Constant( 'GL_TEXTURE6', 33990)
GL_TEXTURE6_ARB = Constant( 'GL_TEXTURE6_ARB', 33990)
GL_TEXTURE7 = Constant( 'GL_TEXTURE7', 33991)
GL_TEXTURE7_ARB = Constant( 'GL_TEXTURE7_ARB', 33991)
GL_TEXTURE8 = Constant( 'GL_TEXTURE8', 33992)
GL_TEXTURE8_ARB = Constant( 'GL_TEXTURE8_ARB', 33992)
GL_TEXTURE9 = Constant( 'GL_TEXTURE9', 33993)
GL_TEXTURE9_ARB = Constant( 'GL_TEXTURE9_ARB', 33993)
GL_TEXTURE_1D = Constant( 'GL_TEXTURE_1D', 3552)
GL_TEXTURE_1D_BINDING_EXT = Constant( 'GL_TEXTURE_1D_BINDING_EXT', 32872)
GL_TEXTURE_2D = Constant( 'GL_TEXTURE_2D', 3553)
GL_TEXTURE_2D_BINDING_EXT = Constant( 'GL_TEXTURE_2D_BINDING_EXT', 32873)
GL_TEXTURE_3D = Constant( 'GL_TEXTURE_3D', 32879)
GL_TEXTURE_3D_BINDING_EXT = Constant( 'GL_TEXTURE_3D_BINDING_EXT', 32874)
GL_TEXTURE_3D_EXT = Constant( 'GL_TEXTURE_3D_EXT', 32879)
GL_TEXTURE_4DSIZE_SGIS = Constant( 'GL_TEXTURE_4DSIZE_SGIS', 33078)
GL_TEXTURE_4D_BINDING_SGIS = Constant( 'GL_TEXTURE_4D_BINDING_SGIS', 33103)
GL_TEXTURE_4D_SGIS = Constant( 'GL_TEXTURE_4D_SGIS', 33076)
GL_TEXTURE_ALPHA_SIZE = Constant( 'GL_TEXTURE_ALPHA_SIZE', 32863)
GL_TEXTURE_ALPHA_SIZE_EXT = Constant( 'GL_TEXTURE_ALPHA_SIZE_EXT', 32863)
GL_TEXTURE_ALPHA_TYPE_ARB = Constant( 'GL_TEXTURE_ALPHA_TYPE_ARB', 35859)
GL_TEXTURE_APPLICATION_MODE_EXT = Constant( 'GL_TEXTURE_APPLICATION_MODE_EXT', 33615)
GL_TEXTURE_BASE_LEVEL = Constant( 'GL_TEXTURE_BASE_LEVEL', 33084)
GL_TEXTURE_BASE_LEVEL_SGIS = Constant( 'GL_TEXTURE_BASE_LEVEL_SGIS', 33084)
GL_TEXTURE_BINDING_1D = Constant( 'GL_TEXTURE_BINDING_1D', 32872)
GL_TEXTURE_BINDING_2D = Constant( 'GL_TEXTURE_BINDING_2D', 32873)
GL_TEXTURE_BINDING_3D = Constant( 'GL_TEXTURE_BINDING_3D', 32874)
GL_TEXTURE_BINDING_CUBE_MAP = Constant( 'GL_TEXTURE_BINDING_CUBE_MAP', 34068)
GL_TEXTURE_BINDING_CUBE_MAP_ARB = Constant( 'GL_TEXTURE_BINDING_CUBE_MAP_ARB', 34068)
GL_TEXTURE_BINDING_CUBE_MAP_EXT = Constant( 'GL_TEXTURE_BINDING_CUBE_MAP_EXT', 34068)
GL_TEXTURE_BINDING_RECTANGLE_ARB = Constant( 'GL_TEXTURE_BINDING_RECTANGLE_ARB', 34038)
GL_TEXTURE_BINDING_RECTANGLE_NV = Constant( 'GL_TEXTURE_BINDING_RECTANGLE_NV', 34038)
GL_TEXTURE_BIT = Constant( 'GL_TEXTURE_BIT', 262144)
GL_TEXTURE_BLUE_SIZE = Constant( 'GL_TEXTURE_BLUE_SIZE', 32862)
GL_TEXTURE_BLUE_SIZE_EXT = Constant( 'GL_TEXTURE_BLUE_SIZE_EXT', 32862)
GL_TEXTURE_BLUE_TYPE_ARB = Constant( 'GL_TEXTURE_BLUE_TYPE_ARB', 35858)
GL_TEXTURE_BORDER = Constant( 'GL_TEXTURE_BORDER', 4101)
GL_TEXTURE_BORDER_COLOR = Constant( 'GL_TEXTURE_BORDER_COLOR', 4100)
GL_TEXTURE_BORDER_VALUES_NV = Constant( 'GL_TEXTURE_BORDER_VALUES_NV', 34586)
GL_TEXTURE_CLIPMAP_CENTER_SGIX = Constant( 'GL_TEXTURE_CLIPMAP_CENTER_SGIX', 33137)
GL_TEXTURE_CLIPMAP_DEPTH_SGIX = Constant( 'GL_TEXTURE_CLIPMAP_DEPTH_SGIX', 33142)
GL_TEXTURE_CLIPMAP_FRAME_SGIX = Constant( 'GL_TEXTURE_CLIPMAP_FRAME_SGIX', 33138)
GL_TEXTURE_CLIPMAP_LOD_OFFSET_SGIX = Constant( 'GL_TEXTURE_CLIPMAP_LOD_OFFSET_SGIX', 33141)
GL_TEXTURE_CLIPMAP_OFFSET_SGIX = Constant( 'GL_TEXTURE_CLIPMAP_OFFSET_SGIX', 33139)
GL_TEXTURE_CLIPMAP_VIRTUAL_DEPTH_SGIX = Constant( 'GL_TEXTURE_CLIPMAP_VIRTUAL_DEPTH_SGIX', 33140)
GL_TEXTURE_COLOR_TABLE_SGI = Constant( 'GL_TEXTURE_COLOR_TABLE_SGI', 32956)
GL_TEXTURE_COLOR_WRITEMASK_SGIS = Constant( 'GL_TEXTURE_COLOR_WRITEMASK_SGIS', 33263)
GL_TEXTURE_COMPARE_FAIL_VALUE_ARB = Constant( 'GL_TEXTURE_COMPARE_FAIL_VALUE_ARB', 32959)
GL_TEXTURE_COMPARE_FUNC = Constant( 'GL_TEXTURE_COMPARE_FUNC', 34893)
GL_TEXTURE_COMPARE_FUNC_ARB = Constant( 'GL_TEXTURE_COMPARE_FUNC_ARB', 34893)
GL_TEXTURE_COMPARE_MODE = Constant( 'GL_TEXTURE_COMPARE_MODE', 34892)
GL_TEXTURE_COMPARE_MODE_ARB = Constant( 'GL_TEXTURE_COMPARE_MODE_ARB', 34892)
GL_TEXTURE_COMPARE_OPERATOR_SGIX = Constant( 'GL_TEXTURE_COMPARE_OPERATOR_SGIX', 33179)
GL_TEXTURE_COMPARE_SGIX = Constant( 'GL_TEXTURE_COMPARE_SGIX', 33178)
GL_TEXTURE_COMPRESSED = Constant( 'GL_TEXTURE_COMPRESSED', 34465)
GL_TEXTURE_COMPRESSED_ARB = Constant( 'GL_TEXTURE_COMPRESSED_ARB', 34465)
GL_TEXTURE_COMPRESSED_IMAGE_SIZE = Constant( 'GL_TEXTURE_COMPRESSED_IMAGE_SIZE', 34464)
GL_TEXTURE_COMPRESSED_IMAGE_SIZE_ARB = Constant( 'GL_TEXTURE_COMPRESSED_IMAGE_SIZE_ARB', 34464)
GL_TEXTURE_COMPRESSION_HINT = Constant( 'GL_TEXTURE_COMPRESSION_HINT', 34031)
GL_TEXTURE_COMPRESSION_HINT_ARB = Constant( 'GL_TEXTURE_COMPRESSION_HINT_ARB', 34031)
GL_TEXTURE_CONSTANT_DATA_SUNX = Constant( 'GL_TEXTURE_CONSTANT_DATA_SUNX', 33238)
GL_TEXTURE_COORD_ARRAY = Constant( 'GL_TEXTURE_COORD_ARRAY', 32888)
GL_TEXTURE_COORD_ARRAY_BUFFER_BINDING = Constant( 'GL_TEXTURE_COORD_ARRAY_BUFFER_BINDING', 34970)
GL_TEXTURE_COORD_ARRAY_BUFFER_BINDING_ARB = Constant( 'GL_TEXTURE_COORD_ARRAY_BUFFER_BINDING_ARB', 34970)
GL_TEXTURE_COORD_ARRAY_COUNT_EXT = Constant( 'GL_TEXTURE_COORD_ARRAY_COUNT_EXT', 32907)
GL_TEXTURE_COORD_ARRAY_EXT = Constant( 'GL_TEXTURE_COORD_ARRAY_EXT', 32888)
GL_TEXTURE_COORD_ARRAY_LIST_IBM = Constant( 'GL_TEXTURE_COORD_ARRAY_LIST_IBM', 103074)
GL_TEXTURE_COORD_ARRAY_LIST_STRIDE_IBM = Constant( 'GL_TEXTURE_COORD_ARRAY_LIST_STRIDE_IBM', 103084)
GL_TEXTURE_COORD_ARRAY_PARALLEL_POINTERS_INTEL = Constant( 'GL_TEXTURE_COORD_ARRAY_PARALLEL_POINTERS_INTEL', 33784)
GL_TEXTURE_COORD_ARRAY_POINTER = Constant( 'GL_TEXTURE_COORD_ARRAY_POINTER', 32914)
GL_TEXTURE_COORD_ARRAY_POINTER_EXT = Constant( 'GL_TEXTURE_COORD_ARRAY_POINTER_EXT', 32914)
GL_TEXTURE_COORD_ARRAY_SIZE = Constant( 'GL_TEXTURE_COORD_ARRAY_SIZE', 32904)
GL_TEXTURE_COORD_ARRAY_SIZE_EXT = Constant( 'GL_TEXTURE_COORD_ARRAY_SIZE_EXT', 32904)
GL_TEXTURE_COORD_ARRAY_STRIDE = Constant( 'GL_TEXTURE_COORD_ARRAY_STRIDE', 32906)
GL_TEXTURE_COORD_ARRAY_STRIDE_EXT = Constant( 'GL_TEXTURE_COORD_ARRAY_STRIDE_EXT', 32906)
GL_TEXTURE_COORD_ARRAY_TYPE = Constant( 'GL_TEXTURE_COORD_ARRAY_TYPE', 32905)
GL_TEXTURE_COORD_ARRAY_TYPE_EXT = Constant( 'GL_TEXTURE_COORD_ARRAY_TYPE_EXT', 32905)
GL_TEXTURE_CUBE_MAP = Constant( 'GL_TEXTURE_CUBE_MAP', 34067)
GL_TEXTURE_CUBE_MAP_ARB = Constant( 'GL_TEXTURE_CUBE_MAP_ARB', 34067)
GL_TEXTURE_CUBE_MAP_EXT = Constant( 'GL_TEXTURE_CUBE_MAP_EXT', 34067)
GL_TEXTURE_CUBE_MAP_NEGATIVE_X = Constant( 'GL_TEXTURE_CUBE_MAP_NEGATIVE_X', 34070)
GL_TEXTURE_CUBE_MAP_NEGATIVE_X_ARB = Constant( 'GL_TEXTURE_CUBE_MAP_NEGATIVE_X_ARB', 34070)
GL_TEXTURE_CUBE_MAP_NEGATIVE_X_EXT = Constant( 'GL_TEXTURE_CUBE_MAP_NEGATIVE_X_EXT', 34070)
GL_TEXTURE_CUBE_MAP_NEGATIVE_Y = Constant( 'GL_TEXTURE_CUBE_MAP_NEGATIVE_Y', 34072)
GL_TEXTURE_CUBE_MAP_NEGATIVE_Y_ARB = Constant( 'GL_TEXTURE_CUBE_MAP_NEGATIVE_Y_ARB', 34072)
GL_TEXTURE_CUBE_MAP_NEGATIVE_Y_EXT = Constant( 'GL_TEXTURE_CUBE_MAP_NEGATIVE_Y_EXT', 34072)
GL_TEXTURE_CUBE_MAP_NEGATIVE_Z = Constant( 'GL_TEXTURE_CUBE_MAP_NEGATIVE_Z', 34074)
GL_TEXTURE_CUBE_MAP_NEGATIVE_Z_ARB = Constant( 'GL_TEXTURE_CUBE_MAP_NEGATIVE_Z_ARB', 34074)
GL_TEXTURE_CUBE_MAP_NEGATIVE_Z_EXT = Constant( 'GL_TEXTURE_CUBE_MAP_NEGATIVE_Z_EXT', 34074)
GL_TEXTURE_CUBE_MAP_POSITIVE_X = Constant( 'GL_TEXTURE_CUBE_MAP_POSITIVE_X', 34069)
GL_TEXTURE_CUBE_MAP_POSITIVE_X_ARB = Constant( 'GL_TEXTURE_CUBE_MAP_POSITIVE_X_ARB', 34069)
GL_TEXTURE_CUBE_MAP_POSITIVE_X_EXT = Constant( 'GL_TEXTURE_CUBE_MAP_POSITIVE_X_EXT', 34069)
GL_TEXTURE_CUBE_MAP_POSITIVE_Y = Constant( 'GL_TEXTURE_CUBE_MAP_POSITIVE_Y', 34071)
GL_TEXTURE_CUBE_MAP_POSITIVE_Y_ARB = Constant( 'GL_TEXTURE_CUBE_MAP_POSITIVE_Y_ARB', 34071)
GL_TEXTURE_CUBE_MAP_POSITIVE_Y_EXT = Constant( 'GL_TEXTURE_CUBE_MAP_POSITIVE_Y_EXT', 34071)
GL_TEXTURE_CUBE_MAP_POSITIVE_Z = Constant( 'GL_TEXTURE_CUBE_MAP_POSITIVE_Z', 34073)
GL_TEXTURE_CUBE_MAP_POSITIVE_Z_ARB = Constant( 'GL_TEXTURE_CUBE_MAP_POSITIVE_Z_ARB', 34073)
GL_TEXTURE_CUBE_MAP_POSITIVE_Z_EXT = Constant( 'GL_TEXTURE_CUBE_MAP_POSITIVE_Z_EXT', 34073)
GL_TEXTURE_DEFORMATION_BIT_SGIX = Constant( 'GL_TEXTURE_DEFORMATION_BIT_SGIX', 1)
GL_TEXTURE_DEFORMATION_SGIX = Constant( 'GL_TEXTURE_DEFORMATION_SGIX', 33173)
GL_TEXTURE_DEPTH = Constant( 'GL_TEXTURE_DEPTH', 32881)
GL_TEXTURE_DEPTH_EXT = Constant( 'GL_TEXTURE_DEPTH_EXT', 32881)
GL_TEXTURE_DEPTH_SIZE = Constant( 'GL_TEXTURE_DEPTH_SIZE', 34890)
GL_TEXTURE_DEPTH_SIZE_ARB = Constant( 'GL_TEXTURE_DEPTH_SIZE_ARB', 34890)
GL_TEXTURE_DEPTH_TYPE_ARB = Constant( 'GL_TEXTURE_DEPTH_TYPE_ARB', 35862)
GL_TEXTURE_DS_SIZE_NV = Constant( 'GL_TEXTURE_DS_SIZE_NV', 34589)
GL_TEXTURE_DT_SIZE_NV = Constant( 'GL_TEXTURE_DT_SIZE_NV', 34590)
GL_TEXTURE_ENV = Constant( 'GL_TEXTURE_ENV', 8960)
GL_TEXTURE_ENV_BIAS_SGIX = Constant( 'GL_TEXTURE_ENV_BIAS_SGIX', 32958)
GL_TEXTURE_ENV_COLOR = Constant( 'GL_TEXTURE_ENV_COLOR', 8705)
GL_TEXTURE_ENV_MODE = Constant( 'GL_TEXTURE_ENV_MODE', 8704)
GL_TEXTURE_FILTER4_SIZE_SGIS = Constant( 'GL_TEXTURE_FILTER4_SIZE_SGIS', 33095)
GL_TEXTURE_FILTER_CONTROL = Constant( 'GL_TEXTURE_FILTER_CONTROL', 34048)
GL_TEXTURE_FILTER_CONTROL_EXT = Constant( 'GL_TEXTURE_FILTER_CONTROL_EXT', 34048)
GL_TEXTURE_FLOAT_COMPONENTS_NV = Constant( 'GL_TEXTURE_FLOAT_COMPONENTS_NV', 34956)
GL_TEXTURE_GEN_MODE = Constant( 'GL_TEXTURE_GEN_MODE', 9472)
GL_TEXTURE_GEN_Q = Constant( 'GL_TEXTURE_GEN_Q', 3171)
GL_TEXTURE_GEN_R = Constant( 'GL_TEXTURE_GEN_R', 3170)
GL_TEXTURE_GEN_S = Constant( 'GL_TEXTURE_GEN_S', 3168)
GL_TEXTURE_GEN_T = Constant( 'GL_TEXTURE_GEN_T', 3169)
GL_TEXTURE_GEQUAL_R_SGIX = Constant( 'GL_TEXTURE_GEQUAL_R_SGIX', 33181)
GL_TEXTURE_GREEN_SIZE = Constant( 'GL_TEXTURE_GREEN_SIZE', 32861)
GL_TEXTURE_GREEN_SIZE_EXT = Constant( 'GL_TEXTURE_GREEN_SIZE_EXT', 32861)
GL_TEXTURE_GREEN_TYPE_ARB = Constant( 'GL_TEXTURE_GREEN_TYPE_ARB', 35857)
GL_TEXTURE_HEIGHT = Constant( 'GL_TEXTURE_HEIGHT', 4097)
GL_TEXTURE_HI_SIZE_NV = Constant( 'GL_TEXTURE_HI_SIZE_NV', 34587)
GL_TEXTURE_INDEX_SIZE_EXT = Constant( 'GL_TEXTURE_INDEX_SIZE_EXT', 33005)
GL_TEXTURE_INTENSITY_SIZE = Constant( 'GL_TEXTURE_INTENSITY_SIZE', 32865)
GL_TEXTURE_INTENSITY_SIZE_EXT = Constant( 'GL_TEXTURE_INTENSITY_SIZE_EXT', 32865)
GL_TEXTURE_INTENSITY_TYPE_ARB = Constant( 'GL_TEXTURE_INTENSITY_TYPE_ARB', 35861)
GL_TEXTURE_INTERNAL_FORMAT = Constant( 'GL_TEXTURE_INTERNAL_FORMAT', 4099)
GL_TEXTURE_LEQUAL_R_SGIX = Constant( 'GL_TEXTURE_LEQUAL_R_SGIX', 33180)
GL_TEXTURE_LIGHTING_MODE_HP = Constant( 'GL_TEXTURE_LIGHTING_MODE_HP', 33127)
GL_TEXTURE_LIGHT_EXT = Constant( 'GL_TEXTURE_LIGHT_EXT', 33616)
GL_TEXTURE_LOD_BIAS = Constant( 'GL_TEXTURE_LOD_BIAS', 34049)
GL_TEXTURE_LOD_BIAS_EXT = Constant( 'GL_TEXTURE_LOD_BIAS_EXT', 34049)
GL_TEXTURE_LOD_BIAS_R_SGIX = Constant( 'GL_TEXTURE_LOD_BIAS_R_SGIX', 33168)
GL_TEXTURE_LOD_BIAS_S_SGIX = Constant( 'GL_TEXTURE_LOD_BIAS_S_SGIX', 33166)
GL_TEXTURE_LOD_BIAS_T_SGIX = Constant( 'GL_TEXTURE_LOD_BIAS_T_SGIX', 33167)
GL_TEXTURE_LO_SIZE_NV = Constant( 'GL_TEXTURE_LO_SIZE_NV', 34588)
GL_TEXTURE_LUMINANCE_SIZE = Constant( 'GL_TEXTURE_LUMINANCE_SIZE', 32864)
GL_TEXTURE_LUMINANCE_SIZE_EXT = Constant( 'GL_TEXTURE_LUMINANCE_SIZE_EXT', 32864)
GL_TEXTURE_LUMINANCE_TYPE_ARB = Constant( 'GL_TEXTURE_LUMINANCE_TYPE_ARB', 35860)
GL_TEXTURE_MAG_FILTER = Constant( 'GL_TEXTURE_MAG_FILTER', 10240)
GL_TEXTURE_MAG_SIZE_NV = Constant( 'GL_TEXTURE_MAG_SIZE_NV', 34591)
GL_TEXTURE_MATERIAL_FACE_EXT = Constant( 'GL_TEXTURE_MATERIAL_FACE_EXT', 33617)
GL_TEXTURE_MATERIAL_PARAMETER_EXT = Constant( 'GL_TEXTURE_MATERIAL_PARAMETER_EXT', 33618)
GL_TEXTURE_MATRIX = Constant( 'GL_TEXTURE_MATRIX', 2984)
GL_TEXTURE_MAX_ANISOTROPY_EXT = Constant( 'GL_TEXTURE_MAX_ANISOTROPY_EXT', 34046)
GL_TEXTURE_MAX_CLAMP_R_SGIX = Constant( 'GL_TEXTURE_MAX_CLAMP_R_SGIX', 33643)
GL_TEXTURE_MAX_CLAMP_S_SGIX = Constant( 'GL_TEXTURE_MAX_CLAMP_S_SGIX', 33641)
GL_TEXTURE_MAX_CLAMP_T_SGIX = Constant( 'GL_TEXTURE_MAX_CLAMP_T_SGIX', 33642)
GL_TEXTURE_MAX_LEVEL = Constant( 'GL_TEXTURE_MAX_LEVEL', 33085)
GL_TEXTURE_MAX_LEVEL_SGIS = Constant( 'GL_TEXTURE_MAX_LEVEL_SGIS', 33085)
GL_TEXTURE_MAX_LOD = Constant( 'GL_TEXTURE_MAX_LOD', 33083)
GL_TEXTURE_MAX_LOD_SGIS = Constant( 'GL_TEXTURE_MAX_LOD_SGIS', 33083)
GL_TEXTURE_MIN_FILTER = Constant( 'GL_TEXTURE_MIN_FILTER', 10241)
GL_TEXTURE_MIN_LOD = Constant( 'GL_TEXTURE_MIN_LOD', 33082)
GL_TEXTURE_MIN_LOD_SGIS = Constant( 'GL_TEXTURE_MIN_LOD_SGIS', 33082)
GL_TEXTURE_MULTI_BUFFER_HINT_SGIX = Constant( 'GL_TEXTURE_MULTI_BUFFER_HINT_SGIX', 33070)
GL_TEXTURE_NORMAL_EXT = Constant( 'GL_TEXTURE_NORMAL_EXT', 34223)
GL_TEXTURE_POST_SPECULAR_HP = Constant( 'GL_TEXTURE_POST_SPECULAR_HP', 33128)
GL_TEXTURE_PRE_SPECULAR_HP = Constant( 'GL_TEXTURE_PRE_SPECULAR_HP', 33129)
GL_TEXTURE_PRIORITY = Constant( 'GL_TEXTURE_PRIORITY', 32870)
GL_TEXTURE_PRIORITY_EXT = Constant( 'GL_TEXTURE_PRIORITY_EXT', 32870)
GL_TEXTURE_RECTANGLE_ARB = Constant( 'GL_TEXTURE_RECTANGLE_ARB', 34037)
GL_TEXTURE_RECTANGLE_NV = Constant( 'GL_TEXTURE_RECTANGLE_NV', 34037)
GL_TEXTURE_RED_SIZE = Constant( 'GL_TEXTURE_RED_SIZE', 32860)
GL_TEXTURE_RED_SIZE_EXT = Constant( 'GL_TEXTURE_RED_SIZE_EXT', 32860)
GL_TEXTURE_RED_TYPE_ARB = Constant( 'GL_TEXTURE_RED_TYPE_ARB', 35856)
GL_TEXTURE_RESIDENT = Constant( 'GL_TEXTURE_RESIDENT', 32871)
GL_TEXTURE_RESIDENT_EXT = Constant( 'GL_TEXTURE_RESIDENT_EXT', 32871)
GL_TEXTURE_SHADER_NV = Constant( 'GL_TEXTURE_SHADER_NV', 34526)
GL_TEXTURE_STACK_DEPTH = Constant( 'GL_TEXTURE_STACK_DEPTH', 2981)
GL_TEXTURE_TOO_LARGE_EXT = Constant( 'GL_TEXTURE_TOO_LARGE_EXT', 32869)
GL_TEXTURE_UNSIGNED_REMAP_MODE_NV = Constant( 'GL_TEXTURE_UNSIGNED_REMAP_MODE_NV', 34959)
GL_TEXTURE_WIDTH = Constant( 'GL_TEXTURE_WIDTH', 4096)
GL_TEXTURE_WRAP_Q_SGIS = Constant( 'GL_TEXTURE_WRAP_Q_SGIS', 33079)
GL_TEXTURE_WRAP_R = Constant( 'GL_TEXTURE_WRAP_R', 32882)
GL_TEXTURE_WRAP_R_EXT = Constant( 'GL_TEXTURE_WRAP_R_EXT', 32882)
GL_TEXTURE_WRAP_S = Constant( 'GL_TEXTURE_WRAP_S', 10242)
GL_TEXTURE_WRAP_T = Constant( 'GL_TEXTURE_WRAP_T', 10243)
GL_TEXT_FRAGMENT_SHADER_ATI = Constant( 'GL_TEXT_FRAGMENT_SHADER_ATI', 33280)
GL_TRACK_MATRIX_NV = Constant( 'GL_TRACK_MATRIX_NV', 34376)
GL_TRACK_MATRIX_TRANSFORM_NV = Constant( 'GL_TRACK_MATRIX_TRANSFORM_NV', 34377)
GL_TRANSFORM_BIT = Constant( 'GL_TRANSFORM_BIT', 4096)
GL_TRANSFORM_HINT_APPLE = Constant( 'GL_TRANSFORM_HINT_APPLE', 34225)
GL_TRANSPOSE_COLOR_MATRIX = Constant( 'GL_TRANSPOSE_COLOR_MATRIX', 34022)
GL_TRANSPOSE_COLOR_MATRIX_ARB = Constant( 'GL_TRANSPOSE_COLOR_MATRIX_ARB', 34022)
GL_TRANSPOSE_CURRENT_MATRIX_ARB = Constant( 'GL_TRANSPOSE_CURRENT_MATRIX_ARB', 34999)
GL_TRANSPOSE_MODELVIEW_MATRIX = Constant( 'GL_TRANSPOSE_MODELVIEW_MATRIX', 34019)
GL_TRANSPOSE_MODELVIEW_MATRIX_ARB = Constant( 'GL_TRANSPOSE_MODELVIEW_MATRIX_ARB', 34019)
GL_TRANSPOSE_NV = Constant( 'GL_TRANSPOSE_NV', 34348)
GL_TRANSPOSE_PROJECTION_MATRIX = Constant( 'GL_TRANSPOSE_PROJECTION_MATRIX', 34020)
GL_TRANSPOSE_PROJECTION_MATRIX_ARB = Constant( 'GL_TRANSPOSE_PROJECTION_MATRIX_ARB', 34020)
GL_TRANSPOSE_TEXTURE_MATRIX = Constant( 'GL_TRANSPOSE_TEXTURE_MATRIX', 34021)
GL_TRANSPOSE_TEXTURE_MATRIX_ARB = Constant( 'GL_TRANSPOSE_TEXTURE_MATRIX_ARB', 34021)
GL_TRIANGLES = Constant( 'GL_TRIANGLES', 4)
GL_TRIANGLE_FAN = Constant( 'GL_TRIANGLE_FAN', 6)
GL_TRIANGLE_LIST_SUN = Constant( 'GL_TRIANGLE_LIST_SUN', 33239)
GL_TRIANGLE_MESH_SUN = Constant( 'GL_TRIANGLE_MESH_SUN', 34325)
GL_TRIANGLE_STRIP = Constant( 'GL_TRIANGLE_STRIP', 5)
GL_TYPE_RGBA_FLOAT_ATI = Constant( 'GL_TYPE_RGBA_FLOAT_ATI', 34848)
GL_UNPACK_ALIGNMENT = Constant( 'GL_UNPACK_ALIGNMENT', 3317)
GL_UNPACK_CLIENT_STORAGE_APPLE = Constant( 'GL_UNPACK_CLIENT_STORAGE_APPLE', 34226)
GL_UNPACK_CMYK_HINT_EXT = Constant( 'GL_UNPACK_CMYK_HINT_EXT', 32783)
GL_UNPACK_CONSTANT_DATA_SUNX = Constant( 'GL_UNPACK_CONSTANT_DATA_SUNX', 33237)
GL_UNPACK_IMAGE_DEPTH_SGIS = Constant( 'GL_UNPACK_IMAGE_DEPTH_SGIS', 33075)
GL_UNPACK_IMAGE_HEIGHT = Constant( 'GL_UNPACK_IMAGE_HEIGHT', 32878)
GL_UNPACK_IMAGE_HEIGHT_EXT = Constant( 'GL_UNPACK_IMAGE_HEIGHT_EXT', 32878)
GL_UNPACK_LSB_FIRST = Constant( 'GL_UNPACK_LSB_FIRST', 3313)
GL_UNPACK_RESAMPLE_OML = Constant( 'GL_UNPACK_RESAMPLE_OML', 35205)
GL_UNPACK_RESAMPLE_SGIX = Constant( 'GL_UNPACK_RESAMPLE_SGIX', 33837)
GL_UNPACK_ROW_LENGTH = Constant( 'GL_UNPACK_ROW_LENGTH', 3314)
GL_UNPACK_SKIP_IMAGES = Constant( 'GL_UNPACK_SKIP_IMAGES', 32877)
GL_UNPACK_SKIP_IMAGES_EXT = Constant( 'GL_UNPACK_SKIP_IMAGES_EXT', 32877)
GL_UNPACK_SKIP_PIXELS = Constant( 'GL_UNPACK_SKIP_PIXELS', 3316)
GL_UNPACK_SKIP_ROWS = Constant( 'GL_UNPACK_SKIP_ROWS', 3315)
GL_UNPACK_SKIP_VOLUMES_SGIS = Constant( 'GL_UNPACK_SKIP_VOLUMES_SGIS', 33074)
GL_UNPACK_SUBSAMPLE_RATE_SGIX = Constant( 'GL_UNPACK_SUBSAMPLE_RATE_SGIX', 34209)
GL_UNPACK_SWAP_BYTES = Constant( 'GL_UNPACK_SWAP_BYTES', 3312)
GL_UNSIGNED_BYTE_2_3_3_REV = Constant( 'GL_UNSIGNED_BYTE_2_3_3_REV', 33634)
GL_UNSIGNED_BYTE_3_3_2 = Constant( 'GL_UNSIGNED_BYTE_3_3_2', 32818)
GL_UNSIGNED_BYTE_3_3_2_EXT = Constant( 'GL_UNSIGNED_BYTE_3_3_2_EXT', 32818)
GL_UNSIGNED_IDENTITY_NV = Constant( 'GL_UNSIGNED_IDENTITY_NV', 34102)
GL_UNSIGNED_INT_10_10_10_2 = Constant( 'GL_UNSIGNED_INT_10_10_10_2', 32822)
GL_UNSIGNED_INT_10_10_10_2_EXT = Constant( 'GL_UNSIGNED_INT_10_10_10_2_EXT', 32822)
GL_UNSIGNED_INT_24_8_NV = Constant( 'GL_UNSIGNED_INT_24_8_NV', 34042)
GL_UNSIGNED_INT_2_10_10_10_REV = Constant( 'GL_UNSIGNED_INT_2_10_10_10_REV', 33640)
GL_UNSIGNED_INT_8_8_8_8 = Constant( 'GL_UNSIGNED_INT_8_8_8_8', 32821)
GL_UNSIGNED_INT_8_8_8_8_EXT = Constant( 'GL_UNSIGNED_INT_8_8_8_8_EXT', 32821)
GL_UNSIGNED_INT_8_8_8_8_REV = Constant( 'GL_UNSIGNED_INT_8_8_8_8_REV', 33639)
GL_UNSIGNED_INT_8_8_S8_S8_REV_NV = Constant( 'GL_UNSIGNED_INT_8_8_S8_S8_REV_NV', 34523)
GL_UNSIGNED_INT_S8_S8_8_8_NV = Constant( 'GL_UNSIGNED_INT_S8_S8_8_8_NV', 34522)
GL_UNSIGNED_INVERT_NV = Constant( 'GL_UNSIGNED_INVERT_NV', 34103)
GL_UNSIGNED_NORMALIZED_ARB = Constant( 'GL_UNSIGNED_NORMALIZED_ARB', 35863)
GL_UNSIGNED_SHORT_1_5_5_5_REV = Constant( 'GL_UNSIGNED_SHORT_1_5_5_5_REV', 33638)
GL_UNSIGNED_SHORT_4_4_4_4 = Constant( 'GL_UNSIGNED_SHORT_4_4_4_4', 32819)
GL_UNSIGNED_SHORT_4_4_4_4_EXT = Constant( 'GL_UNSIGNED_SHORT_4_4_4_4_EXT', 32819)
GL_UNSIGNED_SHORT_4_4_4_4_REV = Constant( 'GL_UNSIGNED_SHORT_4_4_4_4_REV', 33637)
GL_UNSIGNED_SHORT_5_5_5_1 = Constant( 'GL_UNSIGNED_SHORT_5_5_5_1', 32820)
GL_UNSIGNED_SHORT_5_5_5_1_EXT = Constant( 'GL_UNSIGNED_SHORT_5_5_5_1_EXT', 32820)
GL_UNSIGNED_SHORT_5_6_5 = Constant( 'GL_UNSIGNED_SHORT_5_6_5', 33635)
GL_UNSIGNED_SHORT_5_6_5_REV = Constant( 'GL_UNSIGNED_SHORT_5_6_5_REV', 33636)
GL_UNSIGNED_SHORT_8_8_APPLE = Constant( 'GL_UNSIGNED_SHORT_8_8_APPLE', 34234)
GL_UNSIGNED_SHORT_8_8_MESA = Constant( 'GL_UNSIGNED_SHORT_8_8_MESA', 34234)
GL_UNSIGNED_SHORT_8_8_REV_APPLE = Constant( 'GL_UNSIGNED_SHORT_8_8_REV_APPLE', 34235)
GL_UNSIGNED_SHORT_8_8_REV_MESA = Constant( 'GL_UNSIGNED_SHORT_8_8_REV_MESA', 34235)
GL_UPPER_LEFT = Constant( 'GL_UPPER_LEFT', 36002)
GL_V2F = Constant( 'GL_V2F', 10784)
GL_V3F = Constant( 'GL_V3F', 10785)
GL_VALIDATE_STATUS = Constant( 'GL_VALIDATE_STATUS', 35715)
GL_VARIABLE_A_NV = Constant( 'GL_VARIABLE_A_NV', 34083)
GL_VARIABLE_B_NV = Constant( 'GL_VARIABLE_B_NV', 34084)
GL_VARIABLE_C_NV = Constant( 'GL_VARIABLE_C_NV', 34085)
GL_VARIABLE_D_NV = Constant( 'GL_VARIABLE_D_NV', 34086)
GL_VARIABLE_E_NV = Constant( 'GL_VARIABLE_E_NV', 34087)
GL_VARIABLE_F_NV = Constant( 'GL_VARIABLE_F_NV', 34088)
GL_VARIABLE_G_NV = Constant( 'GL_VARIABLE_G_NV', 34089)
GL_VARIANT_ARRAY_EXT = Constant( 'GL_VARIANT_ARRAY_EXT', 34792)
GL_VARIANT_ARRAY_POINTER_EXT = Constant( 'GL_VARIANT_ARRAY_POINTER_EXT', 34793)
GL_VARIANT_ARRAY_STRIDE_EXT = Constant( 'GL_VARIANT_ARRAY_STRIDE_EXT', 34790)
GL_VARIANT_ARRAY_TYPE_EXT = Constant( 'GL_VARIANT_ARRAY_TYPE_EXT', 34791)
GL_VARIANT_DATATYPE_EXT = Constant( 'GL_VARIANT_DATATYPE_EXT', 34789)
GL_VARIANT_EXT = Constant( 'GL_VARIANT_EXT', 34753)
GL_VARIANT_VALUE_EXT = Constant( 'GL_VARIANT_VALUE_EXT', 34788)
GL_VECTOR_EXT = Constant( 'GL_VECTOR_EXT', 34751)
GL_VENDOR = Constant( 'GL_VENDOR', 7936)
GL_VERSION = Constant( 'GL_VERSION', 7938)
GL_VERSION_1_1 = Constant( 'GL_VERSION_1_1', 1)
GL_VERSION_1_2 = Constant( 'GL_VERSION_1_2', 1)
GL_VERSION_1_3 = Constant( 'GL_VERSION_1_3', 1)
GL_VERSION_1_4 = Constant( 'GL_VERSION_1_4', 1)
GL_VERSION_1_5 = Constant( 'GL_VERSION_1_5', 1)
GL_VERSION_2_0 = Constant( 'GL_VERSION_2_0', 1)
GL_VERTEX23_BIT_PGI = Constant( 'GL_VERTEX23_BIT_PGI', 4)
GL_VERTEX4_BIT_PGI = Constant( 'GL_VERTEX4_BIT_PGI', 8)
GL_VERTEX_ARRAY = Constant( 'GL_VERTEX_ARRAY', 32884)
GL_VERTEX_ARRAY_BINDING_APPLE = Constant( 'GL_VERTEX_ARRAY_BINDING_APPLE', 34229)
GL_VERTEX_ARRAY_BUFFER_BINDING = Constant( 'GL_VERTEX_ARRAY_BUFFER_BINDING', 34966)
GL_VERTEX_ARRAY_BUFFER_BINDING_ARB = Constant( 'GL_VERTEX_ARRAY_BUFFER_BINDING_ARB', 34966)
GL_VERTEX_ARRAY_COUNT_EXT = Constant( 'GL_VERTEX_ARRAY_COUNT_EXT', 32893)
GL_VERTEX_ARRAY_EXT = Constant( 'GL_VERTEX_ARRAY_EXT', 32884)
GL_VERTEX_ARRAY_LIST_IBM = Constant( 'GL_VERTEX_ARRAY_LIST_IBM', 103070)
GL_VERTEX_ARRAY_LIST_STRIDE_IBM = Constant( 'GL_VERTEX_ARRAY_LIST_STRIDE_IBM', 103080)
GL_VERTEX_ARRAY_PARALLEL_POINTERS_INTEL = Constant( 'GL_VERTEX_ARRAY_PARALLEL_POINTERS_INTEL', 33781)
GL_VERTEX_ARRAY_POINTER = Constant( 'GL_VERTEX_ARRAY_POINTER', 32910)
GL_VERTEX_ARRAY_POINTER_EXT = Constant( 'GL_VERTEX_ARRAY_POINTER_EXT', 32910)
GL_VERTEX_ARRAY_RANGE_APPLE = Constant( 'GL_VERTEX_ARRAY_RANGE_APPLE', 34077)
GL_VERTEX_ARRAY_RANGE_LENGTH_APPLE = Constant( 'GL_VERTEX_ARRAY_RANGE_LENGTH_APPLE', 34078)
GL_VERTEX_ARRAY_RANGE_LENGTH_NV = Constant( 'GL_VERTEX_ARRAY_RANGE_LENGTH_NV', 34078)
GL_VERTEX_ARRAY_RANGE_NV = Constant( 'GL_VERTEX_ARRAY_RANGE_NV', 34077)
GL_VERTEX_ARRAY_RANGE_POINTER_APPLE = Constant( 'GL_VERTEX_ARRAY_RANGE_POINTER_APPLE', 34081)
GL_VERTEX_ARRAY_RANGE_POINTER_NV = Constant( 'GL_VERTEX_ARRAY_RANGE_POINTER_NV', 34081)
GL_VERTEX_ARRAY_RANGE_VALID_NV = Constant( 'GL_VERTEX_ARRAY_RANGE_VALID_NV', 34079)
GL_VERTEX_ARRAY_RANGE_WITHOUT_FLUSH_NV = Constant( 'GL_VERTEX_ARRAY_RANGE_WITHOUT_FLUSH_NV', 34099)
GL_VERTEX_ARRAY_SIZE = Constant( 'GL_VERTEX_ARRAY_SIZE', 32890)
GL_VERTEX_ARRAY_SIZE_EXT = Constant( 'GL_VERTEX_ARRAY_SIZE_EXT', 32890)
GL_VERTEX_ARRAY_STORAGE_HINT_APPLE = Constant( 'GL_VERTEX_ARRAY_STORAGE_HINT_APPLE', 34079)
GL_VERTEX_ARRAY_STRIDE = Constant( 'GL_VERTEX_ARRAY_STRIDE', 32892)
GL_VERTEX_ARRAY_STRIDE_EXT = Constant( 'GL_VERTEX_ARRAY_STRIDE_EXT', 32892)
GL_VERTEX_ARRAY_TYPE = Constant( 'GL_VERTEX_ARRAY_TYPE', 32891)
GL_VERTEX_ARRAY_TYPE_EXT = Constant( 'GL_VERTEX_ARRAY_TYPE_EXT', 32891)
GL_VERTEX_ATTRIB_ARRAY0_NV = Constant( 'GL_VERTEX_ATTRIB_ARRAY0_NV', 34384)
GL_VERTEX_ATTRIB_ARRAY10_NV = Constant( 'GL_VERTEX_ATTRIB_ARRAY10_NV', 34394)
GL_VERTEX_ATTRIB_ARRAY11_NV = Constant( 'GL_VERTEX_ATTRIB_ARRAY11_NV', 34395)
GL_VERTEX_ATTRIB_ARRAY12_NV = Constant( 'GL_VERTEX_ATTRIB_ARRAY12_NV', 34396)
GL_VERTEX_ATTRIB_ARRAY13_NV = Constant( 'GL_VERTEX_ATTRIB_ARRAY13_NV', 34397)
GL_VERTEX_ATTRIB_ARRAY14_NV = Constant( 'GL_VERTEX_ATTRIB_ARRAY14_NV', 34398)
GL_VERTEX_ATTRIB_ARRAY15_NV = Constant( 'GL_VERTEX_ATTRIB_ARRAY15_NV', 34399)
GL_VERTEX_ATTRIB_ARRAY1_NV = Constant( 'GL_VERTEX_ATTRIB_ARRAY1_NV', 34385)
GL_VERTEX_ATTRIB_ARRAY2_NV = Constant( 'GL_VERTEX_ATTRIB_ARRAY2_NV', 34386)
GL_VERTEX_ATTRIB_ARRAY3_NV = Constant( 'GL_VERTEX_ATTRIB_ARRAY3_NV', 34387)
GL_VERTEX_ATTRIB_ARRAY4_NV = Constant( 'GL_VERTEX_ATTRIB_ARRAY4_NV', 34388)
GL_VERTEX_ATTRIB_ARRAY5_NV = Constant( 'GL_VERTEX_ATTRIB_ARRAY5_NV', 34389)
GL_VERTEX_ATTRIB_ARRAY6_NV = Constant( 'GL_VERTEX_ATTRIB_ARRAY6_NV', 34390)
GL_VERTEX_ATTRIB_ARRAY7_NV = Constant( 'GL_VERTEX_ATTRIB_ARRAY7_NV', 34391)
GL_VERTEX_ATTRIB_ARRAY8_NV = Constant( 'GL_VERTEX_ATTRIB_ARRAY8_NV', 34392)
GL_VERTEX_ATTRIB_ARRAY9_NV = Constant( 'GL_VERTEX_ATTRIB_ARRAY9_NV', 34393)
GL_VERTEX_ATTRIB_ARRAY_BUFFER_BINDING = Constant( 'GL_VERTEX_ATTRIB_ARRAY_BUFFER_BINDING', 34975)
GL_VERTEX_ATTRIB_ARRAY_BUFFER_BINDING_ARB = Constant( 'GL_VERTEX_ATTRIB_ARRAY_BUFFER_BINDING_ARB', 34975)
GL_VERTEX_ATTRIB_ARRAY_ENABLED = Constant( 'GL_VERTEX_ATTRIB_ARRAY_ENABLED', 34338)
GL_VERTEX_ATTRIB_ARRAY_ENABLED_ARB = Constant( 'GL_VERTEX_ATTRIB_ARRAY_ENABLED_ARB', 34338)
GL_VERTEX_ATTRIB_ARRAY_NORMALIZED = Constant( 'GL_VERTEX_ATTRIB_ARRAY_NORMALIZED', 34922)
GL_VERTEX_ATTRIB_ARRAY_NORMALIZED_ARB = Constant( 'GL_VERTEX_ATTRIB_ARRAY_NORMALIZED_ARB', 34922)
GL_VERTEX_ATTRIB_ARRAY_POINTER = Constant( 'GL_VERTEX_ATTRIB_ARRAY_POINTER', 34373)
GL_VERTEX_ATTRIB_ARRAY_POINTER_ARB = Constant( 'GL_VERTEX_ATTRIB_ARRAY_POINTER_ARB', 34373)
GL_VERTEX_ATTRIB_ARRAY_SIZE = Constant( 'GL_VERTEX_ATTRIB_ARRAY_SIZE', 34339)
GL_VERTEX_ATTRIB_ARRAY_SIZE_ARB = Constant( 'GL_VERTEX_ATTRIB_ARRAY_SIZE_ARB', 34339)
GL_VERTEX_ATTRIB_ARRAY_STRIDE = Constant( 'GL_VERTEX_ATTRIB_ARRAY_STRIDE', 34340)
GL_VERTEX_ATTRIB_ARRAY_STRIDE_ARB = Constant( 'GL_VERTEX_ATTRIB_ARRAY_STRIDE_ARB', 34340)
GL_VERTEX_ATTRIB_ARRAY_TYPE = Constant( 'GL_VERTEX_ATTRIB_ARRAY_TYPE', 34341)
GL_VERTEX_ATTRIB_ARRAY_TYPE_ARB = Constant( 'GL_VERTEX_ATTRIB_ARRAY_TYPE_ARB', 34341)
GL_VERTEX_BLEND_ARB = Constant( 'GL_VERTEX_BLEND_ARB', 34471)
GL_VERTEX_CONSISTENT_HINT_PGI = Constant( 'GL_VERTEX_CONSISTENT_HINT_PGI', 107051)
GL_VERTEX_DATA_HINT_PGI = Constant( 'GL_VERTEX_DATA_HINT_PGI', 107050)
GL_VERTEX_PRECLIP_HINT_SGIX = Constant( 'GL_VERTEX_PRECLIP_HINT_SGIX', 33775)
GL_VERTEX_PRECLIP_SGIX = Constant( 'GL_VERTEX_PRECLIP_SGIX', 33774)
GL_VERTEX_PROGRAM_ARB = Constant( 'GL_VERTEX_PROGRAM_ARB', 34336)
GL_VERTEX_PROGRAM_BINDING_NV = Constant( 'GL_VERTEX_PROGRAM_BINDING_NV', 34378)
GL_VERTEX_PROGRAM_NV = Constant( 'GL_VERTEX_PROGRAM_NV', 34336)
GL_VERTEX_PROGRAM_POINT_SIZE = Constant( 'GL_VERTEX_PROGRAM_POINT_SIZE', 34370)
GL_VERTEX_PROGRAM_POINT_SIZE_ARB = Constant( 'GL_VERTEX_PROGRAM_POINT_SIZE_ARB', 34370)
GL_VERTEX_PROGRAM_POINT_SIZE_NV = Constant( 'GL_VERTEX_PROGRAM_POINT_SIZE_NV', 34370)
GL_VERTEX_PROGRAM_TWO_SIDE = Constant( 'GL_VERTEX_PROGRAM_TWO_SIDE', 34371)
GL_VERTEX_PROGRAM_TWO_SIDE_ARB = Constant( 'GL_VERTEX_PROGRAM_TWO_SIDE_ARB', 34371)
GL_VERTEX_PROGRAM_TWO_SIDE_NV = Constant( 'GL_VERTEX_PROGRAM_TWO_SIDE_NV', 34371)
GL_VERTEX_SHADER = Constant( 'GL_VERTEX_SHADER', 35633)
GL_VERTEX_SHADER_ARB = Constant( 'GL_VERTEX_SHADER_ARB', 35633)
GL_VERTEX_SHADER_BINDING_EXT = Constant( 'GL_VERTEX_SHADER_BINDING_EXT', 34689)
GL_VERTEX_SHADER_EXT = Constant( 'GL_VERTEX_SHADER_EXT', 34688)
GL_VERTEX_SHADER_INSTRUCTIONS_EXT = Constant( 'GL_VERTEX_SHADER_INSTRUCTIONS_EXT', 34767)
GL_VERTEX_SHADER_INVARIANTS_EXT = Constant( 'GL_VERTEX_SHADER_INVARIANTS_EXT', 34769)
GL_VERTEX_SHADER_LOCALS_EXT = Constant( 'GL_VERTEX_SHADER_LOCALS_EXT', 34771)
GL_VERTEX_SHADER_LOCAL_CONSTANTS_EXT = Constant( 'GL_VERTEX_SHADER_LOCAL_CONSTANTS_EXT', 34770)
GL_VERTEX_SHADER_OPTIMIZED_EXT = Constant( 'GL_VERTEX_SHADER_OPTIMIZED_EXT', 34772)
GL_VERTEX_SHADER_VARIANTS_EXT = Constant( 'GL_VERTEX_SHADER_VARIANTS_EXT', 34768)
GL_VERTEX_SOURCE_ATI = Constant( 'GL_VERTEX_SOURCE_ATI', 34676)
GL_VERTEX_STATE_PROGRAM_NV = Constant( 'GL_VERTEX_STATE_PROGRAM_NV', 34337)
GL_VERTEX_STREAM0_ATI = Constant( 'GL_VERTEX_STREAM0_ATI', 34668)
GL_VERTEX_STREAM1_ATI = Constant( 'GL_VERTEX_STREAM1_ATI', 34669)
GL_VERTEX_STREAM2_ATI = Constant( 'GL_VERTEX_STREAM2_ATI', 34670)
GL_VERTEX_STREAM3_ATI = Constant( 'GL_VERTEX_STREAM3_ATI', 34671)
GL_VERTEX_STREAM4_ATI = Constant( 'GL_VERTEX_STREAM4_ATI', 34672)
GL_VERTEX_STREAM5_ATI = Constant( 'GL_VERTEX_STREAM5_ATI', 34673)
GL_VERTEX_STREAM6_ATI = Constant( 'GL_VERTEX_STREAM6_ATI', 34674)
GL_VERTEX_STREAM7_ATI = Constant( 'GL_VERTEX_STREAM7_ATI', 34675)
GL_VERTEX_WEIGHTING_EXT = Constant( 'GL_VERTEX_WEIGHTING_EXT', 34057)
GL_VERTEX_WEIGHT_ARRAY_EXT = Constant( 'GL_VERTEX_WEIGHT_ARRAY_EXT', 34060)
GL_VERTEX_WEIGHT_ARRAY_POINTER_EXT = Constant( 'GL_VERTEX_WEIGHT_ARRAY_POINTER_EXT', 34064)
GL_VERTEX_WEIGHT_ARRAY_SIZE_EXT = Constant( 'GL_VERTEX_WEIGHT_ARRAY_SIZE_EXT', 34061)
GL_VERTEX_WEIGHT_ARRAY_STRIDE_EXT = Constant( 'GL_VERTEX_WEIGHT_ARRAY_STRIDE_EXT', 34063)
GL_VERTEX_WEIGHT_ARRAY_TYPE_EXT = Constant( 'GL_VERTEX_WEIGHT_ARRAY_TYPE_EXT', 34062)
GL_VIBRANCE_BIAS_NV = Constant( 'GL_VIBRANCE_BIAS_NV', 34585)
GL_VIBRANCE_SCALE_NV = Constant( 'GL_VIBRANCE_SCALE_NV', 34579)
GL_VIEWPORT = Constant( 'GL_VIEWPORT', 2978)
GL_VIEWPORT_BIT = Constant( 'GL_VIEWPORT_BIT', 2048)
GL_WEIGHT_ARRAY_ARB = Constant( 'GL_WEIGHT_ARRAY_ARB', 34477)
GL_WEIGHT_ARRAY_BUFFER_BINDING = Constant( 'GL_WEIGHT_ARRAY_BUFFER_BINDING', 34974)
GL_WEIGHT_ARRAY_BUFFER_BINDING_ARB = Constant( 'GL_WEIGHT_ARRAY_BUFFER_BINDING_ARB', 34974)
GL_WEIGHT_ARRAY_POINTER_ARB = Constant( 'GL_WEIGHT_ARRAY_POINTER_ARB', 34476)
GL_WEIGHT_ARRAY_SIZE_ARB = Constant( 'GL_WEIGHT_ARRAY_SIZE_ARB', 34475)
GL_WEIGHT_ARRAY_STRIDE_ARB = Constant( 'GL_WEIGHT_ARRAY_STRIDE_ARB', 34474)
GL_WEIGHT_ARRAY_TYPE_ARB = Constant( 'GL_WEIGHT_ARRAY_TYPE_ARB', 34473)
GL_WEIGHT_SUM_UNITY_ARB = Constant( 'GL_WEIGHT_SUM_UNITY_ARB', 34470)
GL_WIDE_LINE_HINT_PGI = Constant( 'GL_WIDE_LINE_HINT_PGI', 107042)
GL_WRAP_BORDER_SUN = Constant( 'GL_WRAP_BORDER_SUN', 33236)
GL_WRITE_ONLY = Constant( 'GL_WRITE_ONLY', 35001)
GL_WRITE_ONLY_ARB = Constant( 'GL_WRITE_ONLY_ARB', 35001)
GL_WRITE_PIXEL_DATA_RANGE_LENGTH_NV = Constant( 'GL_WRITE_PIXEL_DATA_RANGE_LENGTH_NV', 34938)
GL_WRITE_PIXEL_DATA_RANGE_NV = Constant( 'GL_WRITE_PIXEL_DATA_RANGE_NV', 34936)
GL_WRITE_PIXEL_DATA_RANGE_POINTER_NV = Constant( 'GL_WRITE_PIXEL_DATA_RANGE_POINTER_NV', 34940)
GL_W_EXT = Constant( 'GL_W_EXT', 34776)
GL_XOR = Constant( 'GL_XOR', 5382)
GL_X_EXT = Constant( 'GL_X_EXT', 34773)
GL_YCBCR_422_APPLE = Constant( 'GL_YCBCR_422_APPLE', 34233)
GL_YCBCR_MESA = Constant( 'GL_YCBCR_MESA', 34647)
GL_YCRCBA_SGIX = Constant( 'GL_YCRCBA_SGIX', 33561)
GL_YCRCB_422_SGIX = Constant( 'GL_YCRCB_422_SGIX', 33211)
GL_YCRCB_444_SGIX = Constant( 'GL_YCRCB_444_SGIX', 33212)
GL_YCRCB_SGIX = Constant( 'GL_YCRCB_SGIX', 33560)
GL_Y_EXT = Constant( 'GL_Y_EXT', 34774)
GL_ZERO = Constant( 'GL_ZERO', 0)
GL_ZERO_EXT = Constant( 'GL_ZERO_EXT', 34781)
GL_ZOOM_X = Constant( 'GL_ZOOM_X', 3350)
GL_ZOOM_Y = Constant( 'GL_ZOOM_Y', 3351)
GL_Z_EXT = Constant( 'GL_Z_EXT', 34775)
__all__ = [
    'GL_1PASS_EXT',
    'GL_1PASS_SGIS',
    'GL_2D',
    'GL_2PASS_0_EXT',
    'GL_2PASS_0_SGIS',
    'GL_2PASS_1_EXT',
    'GL_2PASS_1_SGIS',
    'GL_2X_BIT_ATI',
    'GL_2_BYTES',
    'GL_3D',
    'GL_3D_COLOR',
    'GL_3D_COLOR_TEXTURE',
    'GL_3_BYTES',
    'GL_422_AVERAGE_EXT',
    'GL_422_EXT',
    'GL_422_REV_AVERAGE_EXT',
    'GL_422_REV_EXT',
    'GL_4D_COLOR_TEXTURE',
    'GL_4PASS_0_EXT',
    'GL_4PASS_0_SGIS',
    'GL_4PASS_1_EXT',
    'GL_4PASS_1_SGIS',
    'GL_4PASS_2_EXT',
    'GL_4PASS_2_SGIS',
    'GL_4PASS_3_EXT',
    'GL_4PASS_3_SGIS',
    'GL_4X_BIT_ATI',
    'GL_4_BYTES',
    'GL_8X_BIT_ATI',
    'GL_ABGR_EXT',
    'GL_ACCUM',
    'GL_ACCUM_ALPHA_BITS',
    'GL_ACCUM_BLUE_BITS',
    'GL_ACCUM_BUFFER_BIT',
    'GL_ACCUM_CLEAR_VALUE',
    'GL_ACCUM_GREEN_BITS',
    'GL_ACCUM_RED_BITS',
    'GL_ACTIVE_ATTRIBUTES',
    'GL_ACTIVE_ATTRIBUTE_MAX_LENGTH',
    'GL_ACTIVE_STENCIL_FACE_EXT',
    'GL_ACTIVE_TEXTURE',
    'GL_ACTIVE_TEXTURE_ARB',
    'GL_ACTIVE_UNIFORMS',
    'GL_ACTIVE_UNIFORM_MAX_LENGTH',
    'GL_ACTIVE_VERTEX_UNITS_ARB',
    'GL_ADD',
    'GL_ADD_ATI',
    'GL_ADD_SIGNED',
    'GL_ADD_SIGNED_ARB',
    'GL_ADD_SIGNED_EXT',
    'GL_ALIASED_LINE_WIDTH_RANGE',
    'GL_ALIASED_POINT_SIZE_RANGE',
    'GL_ALLOW_DRAW_FRG_HINT_PGI',
    'GL_ALLOW_DRAW_MEM_HINT_PGI',
    'GL_ALLOW_DRAW_OBJ_HINT_PGI',
    'GL_ALLOW_DRAW_WIN_HINT_PGI',
    'GL_ALL_ATTRIB_BITS',
    'GL_ALL_COMPLETED_NV',
    'GL_ALPHA',
    'GL_ALPHA12',
    'GL_ALPHA12_EXT',
    'GL_ALPHA16',
    'GL_ALPHA16F_ARB',
    'GL_ALPHA16_EXT',
    'GL_ALPHA32F_ARB',
    'GL_ALPHA4',
    'GL_ALPHA4_EXT',
    'GL_ALPHA8',
    'GL_ALPHA8_EXT',
    'GL_ALPHA_BIAS',
    'GL_ALPHA_BITS',
    'GL_ALPHA_FLOAT16_ATI',
    'GL_ALPHA_FLOAT32_ATI',
    'GL_ALPHA_MAX_CLAMP_INGR',
    'GL_ALPHA_MAX_SGIX',
    'GL_ALPHA_MIN_CLAMP_INGR',
    'GL_ALPHA_MIN_SGIX',
    'GL_ALPHA_SCALE',
    'GL_ALPHA_TEST',
    'GL_ALPHA_TEST_FUNC',
    'GL_ALPHA_TEST_REF',
    'GL_ALWAYS',
    'GL_ALWAYS_FAST_HINT_PGI',
    'GL_ALWAYS_SOFT_HINT_PGI',
    'GL_AMBIENT',
    'GL_AMBIENT_AND_DIFFUSE',
    'GL_AND',
    'GL_AND_INVERTED',
    'GL_AND_REVERSE',
    'GL_ARRAY_BUFFER',
    'GL_ARRAY_BUFFER_ARB',
    'GL_ARRAY_BUFFER_BINDING',
    'GL_ARRAY_BUFFER_BINDING_ARB',
    'GL_ARRAY_ELEMENT_LOCK_COUNT_EXT',
    'GL_ARRAY_ELEMENT_LOCK_FIRST_EXT',
    'GL_ARRAY_OBJECT_BUFFER_ATI',
    'GL_ARRAY_OBJECT_OFFSET_ATI',
    'GL_ASYNC_DRAW_PIXELS_SGIX',
    'GL_ASYNC_HISTOGRAM_SGIX',
    'GL_ASYNC_MARKER_SGIX',
    'GL_ASYNC_READ_PIXELS_SGIX',
    'GL_ASYNC_TEX_IMAGE_SGIX',
    'GL_ATTACHED_SHADERS',
    'GL_ATTENUATION_EXT',
    'GL_ATTRIB_ARRAY_POINTER_NV',
    'GL_ATTRIB_ARRAY_SIZE_NV',
    'GL_ATTRIB_ARRAY_STRIDE_NV',
    'GL_ATTRIB_ARRAY_TYPE_NV',
    'GL_ATTRIB_STACK_DEPTH',
    'GL_AUTO_NORMAL',
    'GL_AUX0',
    'GL_AUX1',
    'GL_AUX2',
    'GL_AUX3',
    'GL_AUX_BUFFERS',
    'GL_AVERAGE_EXT',
    'GL_AVERAGE_HP',
    'GL_BACK',
    'GL_BACK_LEFT',
    'GL_BACK_NORMALS_HINT_PGI',
    'GL_BACK_RIGHT',
    'GL_BGR',
    'GL_BGRA',
    'GL_BGRA_EXT',
    'GL_BGR_EXT',
    'GL_BIAS_BIT_ATI',
    'GL_BIAS_BY_NEGATIVE_ONE_HALF_NV',
    'GL_BINORMAL_ARRAY_EXT',
    'GL_BINORMAL_ARRAY_POINTER_EXT',
    'GL_BINORMAL_ARRAY_STRIDE_EXT',
    'GL_BINORMAL_ARRAY_TYPE_EXT',
    'GL_BITMAP',
    'GL_BITMAP_TOKEN',
    'GL_BLEND',
    'GL_BLEND_COLOR',
    'GL_BLEND_COLOR_EXT',
    'GL_BLEND_DST',
    'GL_BLEND_DST_ALPHA',
    'GL_BLEND_DST_ALPHA_EXT',
    'GL_BLEND_DST_RGB',
    'GL_BLEND_DST_RGB_EXT',
    'GL_BLEND_EQUATION',
    'GL_BLEND_EQUATION_ALPHA',
    'GL_BLEND_EQUATION_ALPHA_EXT',
    'GL_BLEND_EQUATION_EXT',
    'GL_BLEND_SRC',
    'GL_BLEND_SRC_ALPHA',
    'GL_BLEND_SRC_ALPHA_EXT',
    'GL_BLEND_SRC_RGB',
    'GL_BLEND_SRC_RGB_EXT',
    'GL_BLUE',
    'GL_BLUE_BIAS',
    'GL_BLUE_BITS',
    'GL_BLUE_BIT_ATI',
    'GL_BLUE_MAX_CLAMP_INGR',
    'GL_BLUE_MIN_CLAMP_INGR',
    'GL_BLUE_SCALE',
    'GL_BOOL',
    'GL_BOOL_ARB',
    'GL_BOOL_VEC2',
    'GL_BOOL_VEC2_ARB',
    'GL_BOOL_VEC3',
    'GL_BOOL_VEC3_ARB',
    'GL_BOOL_VEC4',
    'GL_BOOL_VEC4_ARB',
    'GL_BUFFER_ACCESS',
    'GL_BUFFER_ACCESS_ARB',
    'GL_BUFFER_MAPPED',
    'GL_BUFFER_MAPPED_ARB',
    'GL_BUFFER_MAP_POINTER',
    'GL_BUFFER_MAP_POINTER_ARB',
    'GL_BUFFER_SIZE',
    'GL_BUFFER_SIZE_ARB',
    'GL_BUFFER_USAGE',
    'GL_BUFFER_USAGE_ARB',
    'GL_BUMP_ENVMAP_ATI',
    'GL_BUMP_NUM_TEX_UNITS_ATI',
    'GL_BUMP_ROT_MATRIX_ATI',
    'GL_BUMP_ROT_MATRIX_SIZE_ATI',
    'GL_BUMP_TARGET_ATI',
    'GL_BUMP_TEX_UNITS_ATI',
    'GL_BYTE',
    'GL_C3F_V3F',
    'GL_C4F_N3F_V3F',
    'GL_C4UB_V2F',
    'GL_C4UB_V3F',
    'GL_CALLIGRAPHIC_FRAGMENT_SGIX',
    'GL_CCW',
    'GL_CLAMP',
    'GL_CLAMP_FRAGMENT_COLOR_ARB',
    'GL_CLAMP_READ_COLOR_ARB',
    'GL_CLAMP_TO_BORDER',
    'GL_CLAMP_TO_BORDER_ARB',
    'GL_CLAMP_TO_BORDER_SGIS',
    'GL_CLAMP_TO_EDGE',
    'GL_CLAMP_TO_EDGE_SGIS',
    'GL_CLAMP_VERTEX_COLOR_ARB',
    'GL_CLEAR',
    'GL_CLIENT_ACTIVE_TEXTURE',
    'GL_CLIENT_ACTIVE_TEXTURE_ARB',
    'GL_CLIENT_ALL_ATTRIB_BITS',
    'GL_CLIENT_ATTRIB_STACK_DEPTH',
    'GL_CLIENT_PIXEL_STORE_BIT',
    'GL_CLIENT_VERTEX_ARRAY_BIT',
    'GL_CLIP_FAR_HINT_PGI',
    'GL_CLIP_NEAR_HINT_PGI',
    'GL_CLIP_PLANE0',
    'GL_CLIP_PLANE1',
    'GL_CLIP_PLANE2',
    'GL_CLIP_PLANE3',
    'GL_CLIP_PLANE4',
    'GL_CLIP_PLANE5',
    'GL_CLIP_VOLUME_CLIPPING_HINT_EXT',
    'GL_CMYKA_EXT',
    'GL_CMYK_EXT',
    'GL_CND0_ATI',
    'GL_CND_ATI',
    'GL_COEFF',
    'GL_COLOR',
    'GL_COLOR3_BIT_PGI',
    'GL_COLOR4_BIT_PGI',
    'GL_COLOR_ALPHA_PAIRING_ATI',
    'GL_COLOR_ARRAY',
    'GL_COLOR_ARRAY_BUFFER_BINDING',
    'GL_COLOR_ARRAY_BUFFER_BINDING_ARB',
    'GL_COLOR_ARRAY_COUNT_EXT',
    'GL_COLOR_ARRAY_EXT',
    'GL_COLOR_ARRAY_LIST_IBM',
    'GL_COLOR_ARRAY_LIST_STRIDE_IBM',
    'GL_COLOR_ARRAY_PARALLEL_POINTERS_INTEL',
    'GL_COLOR_ARRAY_POINTER',
    'GL_COLOR_ARRAY_POINTER_EXT',
    'GL_COLOR_ARRAY_SIZE',
    'GL_COLOR_ARRAY_SIZE_EXT',
    'GL_COLOR_ARRAY_STRIDE',
    'GL_COLOR_ARRAY_STRIDE_EXT',
    'GL_COLOR_ARRAY_TYPE',
    'GL_COLOR_ARRAY_TYPE_EXT',
    'GL_COLOR_ATTACHMENT0_EXT',
    'GL_COLOR_ATTACHMENT10_EXT',
    'GL_COLOR_ATTACHMENT11_EXT',
    'GL_COLOR_ATTACHMENT12_EXT',
    'GL_COLOR_ATTACHMENT13_EXT',
    'GL_COLOR_ATTACHMENT14_EXT',
    'GL_COLOR_ATTACHMENT15_EXT',
    'GL_COLOR_ATTACHMENT1_EXT',
    'GL_COLOR_ATTACHMENT2_EXT',
    'GL_COLOR_ATTACHMENT3_EXT',
    'GL_COLOR_ATTACHMENT4_EXT',
    'GL_COLOR_ATTACHMENT5_EXT',
    'GL_COLOR_ATTACHMENT6_EXT',
    'GL_COLOR_ATTACHMENT7_EXT',
    'GL_COLOR_ATTACHMENT8_EXT',
    'GL_COLOR_ATTACHMENT9_EXT',
    'GL_COLOR_BUFFER_BIT',
    'GL_COLOR_CLEAR_UNCLAMPED_VALUE_ATI',
    'GL_COLOR_CLEAR_VALUE',
    'GL_COLOR_INDEX',
    'GL_COLOR_INDEX12_EXT',
    'GL_COLOR_INDEX16_EXT',
    'GL_COLOR_INDEX1_EXT',
    'GL_COLOR_INDEX2_EXT',
    'GL_COLOR_INDEX4_EXT',
    'GL_COLOR_INDEX8_EXT',
    'GL_COLOR_INDEXES',
    'GL_COLOR_LOGIC_OP',
    'GL_COLOR_MATERIAL',
    'GL_COLOR_MATERIAL_FACE',
    'GL_COLOR_MATERIAL_PARAMETER',
    'GL_COLOR_MATRIX',
    'GL_COLOR_MATRIX_SGI',
    'GL_COLOR_MATRIX_STACK_DEPTH',
    'GL_COLOR_MATRIX_STACK_DEPTH_SGI',
    'GL_COLOR_SUM',
    'GL_COLOR_SUM_ARB',
    'GL_COLOR_SUM_CLAMP_NV',
    'GL_COLOR_SUM_EXT',
    'GL_COLOR_TABLE',
    'GL_COLOR_TABLE_ALPHA_SIZE',
    'GL_COLOR_TABLE_ALPHA_SIZE_SGI',
    'GL_COLOR_TABLE_BIAS',
    'GL_COLOR_TABLE_BIAS_SGI',
    'GL_COLOR_TABLE_BLUE_SIZE',
    'GL_COLOR_TABLE_BLUE_SIZE_SGI',
    'GL_COLOR_TABLE_FORMAT',
    'GL_COLOR_TABLE_FORMAT_SGI',
    'GL_COLOR_TABLE_GREEN_SIZE',
    'GL_COLOR_TABLE_GREEN_SIZE_SGI',
    'GL_COLOR_TABLE_INTENSITY_SIZE',
    'GL_COLOR_TABLE_INTENSITY_SIZE_SGI',
    'GL_COLOR_TABLE_LUMINANCE_SIZE',
    'GL_COLOR_TABLE_LUMINANCE_SIZE_SGI',
    'GL_COLOR_TABLE_RED_SIZE',
    'GL_COLOR_TABLE_RED_SIZE_SGI',
    'GL_COLOR_TABLE_SCALE',
    'GL_COLOR_TABLE_SCALE_SGI',
    'GL_COLOR_TABLE_SGI',
    'GL_COLOR_TABLE_WIDTH',
    'GL_COLOR_TABLE_WIDTH_SGI',
    'GL_COLOR_WRITEMASK',
    'GL_COMBINE',
    'GL_COMBINE4_NV',
    'GL_COMBINER0_NV',
    'GL_COMBINER1_NV',
    'GL_COMBINER2_NV',
    'GL_COMBINER3_NV',
    'GL_COMBINER4_NV',
    'GL_COMBINER5_NV',
    'GL_COMBINER6_NV',
    'GL_COMBINER7_NV',
    'GL_COMBINER_AB_DOT_PRODUCT_NV',
    'GL_COMBINER_AB_OUTPUT_NV',
    'GL_COMBINER_BIAS_NV',
    'GL_COMBINER_CD_DOT_PRODUCT_NV',
    'GL_COMBINER_CD_OUTPUT_NV',
    'GL_COMBINER_COMPONENT_USAGE_NV',
    'GL_COMBINER_INPUT_NV',
    'GL_COMBINER_MAPPING_NV',
    'GL_COMBINER_MUX_SUM_NV',
    'GL_COMBINER_SCALE_NV',
    'GL_COMBINER_SUM_OUTPUT_NV',
    'GL_COMBINE_ALPHA',
    'GL_COMBINE_ALPHA_ARB',
    'GL_COMBINE_ALPHA_EXT',
    'GL_COMBINE_ARB',
    'GL_COMBINE_EXT',
    'GL_COMBINE_RGB',
    'GL_COMBINE_RGB_ARB',
    'GL_COMBINE_RGB_EXT',
    'GL_COMPARE_R_TO_TEXTURE',
    'GL_COMPARE_R_TO_TEXTURE_ARB',
    'GL_COMPILE',
    'GL_COMPILE_AND_EXECUTE',
    'GL_COMPILE_STATUS',
    'GL_COMPRESSED_ALPHA',
    'GL_COMPRESSED_ALPHA_ARB',
    'GL_COMPRESSED_INTENSITY',
    'GL_COMPRESSED_INTENSITY_ARB',
    'GL_COMPRESSED_LUMINANCE',
    'GL_COMPRESSED_LUMINANCE_ALPHA',
    'GL_COMPRESSED_LUMINANCE_ALPHA_ARB',
    'GL_COMPRESSED_LUMINANCE_ARB',
    'GL_COMPRESSED_RGB',
    'GL_COMPRESSED_RGBA',
    'GL_COMPRESSED_RGBA_ARB',
    'GL_COMPRESSED_RGBA_FXT1_3DFX',
    'GL_COMPRESSED_RGBA_S3TC_DXT1_EXT',
    'GL_COMPRESSED_RGBA_S3TC_DXT3_EXT',
    'GL_COMPRESSED_RGBA_S3TC_DXT5_EXT',
    'GL_COMPRESSED_RGB_ARB',
    'GL_COMPRESSED_RGB_FXT1_3DFX',
    'GL_COMPRESSED_RGB_S3TC_DXT1_EXT',
    'GL_COMPRESSED_TEXTURE_FORMATS',
    'GL_COMPRESSED_TEXTURE_FORMATS_ARB',
    'GL_COMP_BIT_ATI',
    'GL_CONSERVE_MEMORY_HINT_PGI',
    'GL_CONSTANT',
    'GL_CONSTANT_ALPHA',
    'GL_CONSTANT_ALPHA_EXT',
    'GL_CONSTANT_ARB',
    'GL_CONSTANT_ATTENUATION',
    'GL_CONSTANT_BORDER',
    'GL_CONSTANT_BORDER_HP',
    'GL_CONSTANT_COLOR',
    'GL_CONSTANT_COLOR0_NV',
    'GL_CONSTANT_COLOR1_NV',
    'GL_CONSTANT_COLOR_EXT',
    'GL_CONSTANT_EXT',
    'GL_CONST_EYE_NV',
    'GL_CONVOLUTION_1D',
    'GL_CONVOLUTION_1D_EXT',
    'GL_CONVOLUTION_2D',
    'GL_CONVOLUTION_2D_EXT',
    'GL_CONVOLUTION_BORDER_COLOR',
    'GL_CONVOLUTION_BORDER_COLOR_HP',
    'GL_CONVOLUTION_BORDER_MODE',
    'GL_CONVOLUTION_BORDER_MODE_EXT',
    'GL_CONVOLUTION_FILTER_BIAS',
    'GL_CONVOLUTION_FILTER_BIAS_EXT',
    'GL_CONVOLUTION_FILTER_SCALE',
    'GL_CONVOLUTION_FILTER_SCALE_EXT',
    'GL_CONVOLUTION_FORMAT',
    'GL_CONVOLUTION_FORMAT_EXT',
    'GL_CONVOLUTION_HEIGHT',
    'GL_CONVOLUTION_HEIGHT_EXT',
    'GL_CONVOLUTION_HINT_SGIX',
    'GL_CONVOLUTION_WIDTH',
    'GL_CONVOLUTION_WIDTH_EXT',
    'GL_CON_0_ATI',
    'GL_CON_10_ATI',
    'GL_CON_11_ATI',
    'GL_CON_12_ATI',
    'GL_CON_13_ATI',
    'GL_CON_14_ATI',
    'GL_CON_15_ATI',
    'GL_CON_16_ATI',
    'GL_CON_17_ATI',
    'GL_CON_18_ATI',
    'GL_CON_19_ATI',
    'GL_CON_1_ATI',
    'GL_CON_20_ATI',
    'GL_CON_21_ATI',
    'GL_CON_22_ATI',
    'GL_CON_23_ATI',
    'GL_CON_24_ATI',
    'GL_CON_25_ATI',
    'GL_CON_26_ATI',
    'GL_CON_27_ATI',
    'GL_CON_28_ATI',
    'GL_CON_29_ATI',
    'GL_CON_2_ATI',
    'GL_CON_30_ATI',
    'GL_CON_31_ATI',
    'GL_CON_3_ATI',
    'GL_CON_4_ATI',
    'GL_CON_5_ATI',
    'GL_CON_6_ATI',
    'GL_CON_7_ATI',
    'GL_CON_8_ATI',
    'GL_CON_9_ATI',
    'GL_COORD_REPLACE',
    'GL_COORD_REPLACE_ARB',
    'GL_COORD_REPLACE_NV',
    'GL_COPY',
    'GL_COPY_INVERTED',
    'GL_COPY_PIXEL_TOKEN',
    'GL_CUBIC_EXT',
    'GL_CUBIC_HP',
    'GL_CULL_FACE',
    'GL_CULL_FACE_MODE',
    'GL_CULL_FRAGMENT_NV',
    'GL_CULL_MODES_NV',
    'GL_CULL_VERTEX_EXT',
    'GL_CULL_VERTEX_EYE_POSITION_EXT',
    'GL_CULL_VERTEX_IBM',
    'GL_CULL_VERTEX_OBJECT_POSITION_EXT',
    'GL_CURRENT_ATTRIB_NV',
    'GL_CURRENT_BINORMAL_EXT',
    'GL_CURRENT_BIT',
    'GL_CURRENT_COLOR',
    'GL_CURRENT_FOG_COORDINATE',
    'GL_CURRENT_FOG_COORDINATE_EXT',
    'GL_CURRENT_INDEX',
    'GL_CURRENT_MATRIX_ARB',
    'GL_CURRENT_MATRIX_INDEX_ARB',
    'GL_CURRENT_MATRIX_NV',
    'GL_CURRENT_MATRIX_STACK_DEPTH_ARB',
    'GL_CURRENT_MATRIX_STACK_DEPTH_NV',
    'GL_CURRENT_NORMAL',
    'GL_CURRENT_OCCLUSION_QUERY_ID_NV',
    'GL_CURRENT_PALETTE_MATRIX_ARB',
    'GL_CURRENT_PROGRAM',
    'GL_CURRENT_QUERY',
    'GL_CURRENT_QUERY_ARB',
    'GL_CURRENT_RASTER_COLOR',
    'GL_CURRENT_RASTER_DISTANCE',
    'GL_CURRENT_RASTER_INDEX',
    'GL_CURRENT_RASTER_NORMAL_SGIX',
    'GL_CURRENT_RASTER_POSITION',
    'GL_CURRENT_RASTER_POSITION_VALID',
    'GL_CURRENT_RASTER_TEXTURE_COORDS',
    'GL_CURRENT_SECONDARY_COLOR',
    'GL_CURRENT_SECONDARY_COLOR_EXT',
    'GL_CURRENT_TANGENT_EXT',
    'GL_CURRENT_TEXTURE_COORDS',
    'GL_CURRENT_VERTEX_ATTRIB',
    'GL_CURRENT_VERTEX_ATTRIB_ARB',
    'GL_CURRENT_VERTEX_EXT',
    'GL_CURRENT_VERTEX_WEIGHT_EXT',
    'GL_CURRENT_WEIGHT_ARB',
    'GL_CW',
    'GL_DECAL',
    'GL_DECR',
    'GL_DECR_WRAP',
    'GL_DECR_WRAP_EXT',
    'GL_DEFORMATIONS_MASK_SGIX',
    'GL_DELETE_STATUS',
    'GL_DEPENDENT_AR_TEXTURE_2D_NV',
    'GL_DEPENDENT_GB_TEXTURE_2D_NV',
    'GL_DEPENDENT_HILO_TEXTURE_2D_NV',
    'GL_DEPENDENT_RGB_TEXTURE_3D_NV',
    'GL_DEPENDENT_RGB_TEXTURE_CUBE_MAP_NV',
    'GL_DEPTH',
    'GL_DEPTH_ATTACHMENT_EXT',
    'GL_DEPTH_BIAS',
    'GL_DEPTH_BITS',
    'GL_DEPTH_BOUNDS_EXT',
    'GL_DEPTH_BOUNDS_TEST_EXT',
    'GL_DEPTH_BUFFER_BIT',
    'GL_DEPTH_CLAMP_NV',
    'GL_DEPTH_CLEAR_VALUE',
    'GL_DEPTH_COMPONENT',
    'GL_DEPTH_COMPONENT16',
    'GL_DEPTH_COMPONENT16_ARB',
    'GL_DEPTH_COMPONENT16_SGIX',
    'GL_DEPTH_COMPONENT24',
    'GL_DEPTH_COMPONENT24_ARB',
    'GL_DEPTH_COMPONENT24_SGIX',
    'GL_DEPTH_COMPONENT32',
    'GL_DEPTH_COMPONENT32_ARB',
    'GL_DEPTH_COMPONENT32_SGIX',
    'GL_DEPTH_FUNC',
    'GL_DEPTH_PASS_INSTRUMENT_COUNTERS_SGIX',
    'GL_DEPTH_PASS_INSTRUMENT_MAX_SGIX',
    'GL_DEPTH_PASS_INSTRUMENT_SGIX',
    'GL_DEPTH_RANGE',
    'GL_DEPTH_SCALE',
    'GL_DEPTH_STENCIL_NV',
    'GL_DEPTH_STENCIL_TO_BGRA_NV',
    'GL_DEPTH_STENCIL_TO_RGBA_NV',
    'GL_DEPTH_TEST',
    'GL_DEPTH_TEXTURE_MODE',
    'GL_DEPTH_TEXTURE_MODE_ARB',
    'GL_DEPTH_WRITEMASK',
    'GL_DETAIL_TEXTURE_2D_BINDING_SGIS',
    'GL_DETAIL_TEXTURE_2D_SGIS',
    'GL_DETAIL_TEXTURE_FUNC_POINTS_SGIS',
    'GL_DETAIL_TEXTURE_LEVEL_SGIS',
    'GL_DETAIL_TEXTURE_MODE_SGIS',
    'GL_DIFFUSE',
    'GL_DISCARD_ATI',
    'GL_DISCARD_NV',
    'GL_DISTANCE_ATTENUATION_EXT',
    'GL_DISTANCE_ATTENUATION_SGIS',
    'GL_DITHER',
    'GL_DOMAIN',
    'GL_DONT_CARE',
    'GL_DOT2_ADD_ATI',
    'GL_DOT3_ATI',
    'GL_DOT3_RGB',
    'GL_DOT3_RGBA',
    'GL_DOT3_RGBA_ARB',
    'GL_DOT3_RGBA_EXT',
    'GL_DOT3_RGB_ARB',
    'GL_DOT3_RGB_EXT',
    'GL_DOT4_ATI',
    'GL_DOT_PRODUCT_AFFINE_DEPTH_REPLACE_NV',
    'GL_DOT_PRODUCT_CONST_EYE_REFLECT_CUBE_MAP_NV',
    'GL_DOT_PRODUCT_DEPTH_REPLACE_NV',
    'GL_DOT_PRODUCT_DIFFUSE_CUBE_MAP_NV',
    'GL_DOT_PRODUCT_NV',
    'GL_DOT_PRODUCT_PASS_THROUGH_NV',
    'GL_DOT_PRODUCT_REFLECT_CUBE_MAP_NV',
    'GL_DOT_PRODUCT_TEXTURE_1D_NV',
    'GL_DOT_PRODUCT_TEXTURE_2D_NV',
    'GL_DOT_PRODUCT_TEXTURE_3D_NV',
    'GL_DOT_PRODUCT_TEXTURE_CUBE_MAP_NV',
    'GL_DOT_PRODUCT_TEXTURE_RECTANGLE_NV',
    'GL_DOUBLE',
    'GL_DOUBLEBUFFER',
    'GL_DOUBLE_EXT',
    'GL_DRAW_BUFFER',
    'GL_DRAW_BUFFER0',
    'GL_DRAW_BUFFER0_ARB',
    'GL_DRAW_BUFFER0_ATI',
    'GL_DRAW_BUFFER1',
    'GL_DRAW_BUFFER10',
    'GL_DRAW_BUFFER10_ARB',
    'GL_DRAW_BUFFER10_ATI',
    'GL_DRAW_BUFFER11',
    'GL_DRAW_BUFFER11_ARB',
    'GL_DRAW_BUFFER11_ATI',
    'GL_DRAW_BUFFER12',
    'GL_DRAW_BUFFER12_ARB',
    'GL_DRAW_BUFFER12_ATI',
    'GL_DRAW_BUFFER13',
    'GL_DRAW_BUFFER13_ARB',
    'GL_DRAW_BUFFER13_ATI',
    'GL_DRAW_BUFFER14',
    'GL_DRAW_BUFFER14_ARB',
    'GL_DRAW_BUFFER14_ATI',
    'GL_DRAW_BUFFER15',
    'GL_DRAW_BUFFER15_ARB',
    'GL_DRAW_BUFFER15_ATI',
    'GL_DRAW_BUFFER1_ARB',
    'GL_DRAW_BUFFER1_ATI',
    'GL_DRAW_BUFFER2',
    'GL_DRAW_BUFFER2_ARB',
    'GL_DRAW_BUFFER2_ATI',
    'GL_DRAW_BUFFER3',
    'GL_DRAW_BUFFER3_ARB',
    'GL_DRAW_BUFFER3_ATI',
    'GL_DRAW_BUFFER4',
    'GL_DRAW_BUFFER4_ARB',
    'GL_DRAW_BUFFER4_ATI',
    'GL_DRAW_BUFFER5',
    'GL_DRAW_BUFFER5_ARB',
    'GL_DRAW_BUFFER5_ATI',
    'GL_DRAW_BUFFER6',
    'GL_DRAW_BUFFER6_ARB',
    'GL_DRAW_BUFFER6_ATI',
    'GL_DRAW_BUFFER7',
    'GL_DRAW_BUFFER7_ARB',
    'GL_DRAW_BUFFER7_ATI',
    'GL_DRAW_BUFFER8',
    'GL_DRAW_BUFFER8_ARB',
    'GL_DRAW_BUFFER8_ATI',
    'GL_DRAW_BUFFER9',
    'GL_DRAW_BUFFER9_ARB',
    'GL_DRAW_BUFFER9_ATI',
    'GL_DRAW_PIXELS_APPLE',
    'GL_DRAW_PIXEL_TOKEN',
    'GL_DSDT8_MAG8_INTENSITY8_NV',
    'GL_DSDT8_MAG8_NV',
    'GL_DSDT8_NV',
    'GL_DSDT_MAG_INTENSITY_NV',
    'GL_DSDT_MAG_NV',
    'GL_DSDT_MAG_VIB_NV',
    'GL_DSDT_NV',
    'GL_DST_ALPHA',
    'GL_DST_COLOR',
    'GL_DS_BIAS_NV',
    'GL_DS_SCALE_NV',
    'GL_DT_BIAS_NV',
    'GL_DT_SCALE_NV',
    'GL_DU8DV8_ATI',
    'GL_DUAL_ALPHA12_SGIS',
    'GL_DUAL_ALPHA16_SGIS',
    'GL_DUAL_ALPHA4_SGIS',
    'GL_DUAL_ALPHA8_SGIS',
    'GL_DUAL_INTENSITY12_SGIS',
    'GL_DUAL_INTENSITY16_SGIS',
    'GL_DUAL_INTENSITY4_SGIS',
    'GL_DUAL_INTENSITY8_SGIS',
    'GL_DUAL_LUMINANCE12_SGIS',
    'GL_DUAL_LUMINANCE16_SGIS',
    'GL_DUAL_LUMINANCE4_SGIS',
    'GL_DUAL_LUMINANCE8_SGIS',
    'GL_DUAL_LUMINANCE_ALPHA4_SGIS',
    'GL_DUAL_LUMINANCE_ALPHA8_SGIS',
    'GL_DUAL_TEXTURE_SELECT_SGIS',
    'GL_DUDV_ATI',
    'GL_DYNAMIC_ATI',
    'GL_DYNAMIC_COPY',
    'GL_DYNAMIC_COPY_ARB',
    'GL_DYNAMIC_DRAW',
    'GL_DYNAMIC_DRAW_ARB',
    'GL_DYNAMIC_READ',
    'GL_DYNAMIC_READ_ARB',
    'GL_EDGEFLAG_BIT_PGI',
    'GL_EDGE_FLAG',
    'GL_EDGE_FLAG_ARRAY',
    'GL_EDGE_FLAG_ARRAY_BUFFER_BINDING',
    'GL_EDGE_FLAG_ARRAY_BUFFER_BINDING_ARB',
    'GL_EDGE_FLAG_ARRAY_COUNT_EXT',
    'GL_EDGE_FLAG_ARRAY_EXT',
    'GL_EDGE_FLAG_ARRAY_LIST_IBM',
    'GL_EDGE_FLAG_ARRAY_LIST_STRIDE_IBM',
    'GL_EDGE_FLAG_ARRAY_POINTER',
    'GL_EDGE_FLAG_ARRAY_POINTER_EXT',
    'GL_EDGE_FLAG_ARRAY_STRIDE',
    'GL_EDGE_FLAG_ARRAY_STRIDE_EXT',
    'GL_EIGHTH_BIT_ATI',
    'GL_ELEMENT_ARRAY_APPLE',
    'GL_ELEMENT_ARRAY_ATI',
    'GL_ELEMENT_ARRAY_BUFFER',
    'GL_ELEMENT_ARRAY_BUFFER_ARB',
    'GL_ELEMENT_ARRAY_BUFFER_BINDING',
    'GL_ELEMENT_ARRAY_BUFFER_BINDING_ARB',
    'GL_ELEMENT_ARRAY_POINTER_APPLE',
    'GL_ELEMENT_ARRAY_POINTER_ATI',
    'GL_ELEMENT_ARRAY_TYPE_APPLE',
    'GL_ELEMENT_ARRAY_TYPE_ATI',
    'GL_EMBOSS_CONSTANT_NV',
    'GL_EMBOSS_LIGHT_NV',
    'GL_EMBOSS_MAP_NV',
    'GL_EMISSION',
    'GL_ENABLE_BIT',
    'GL_EQUAL',
    'GL_EQUIV',
    'GL_EVAL_2D_NV',
    'GL_EVAL_BIT',
    'GL_EVAL_FRACTIONAL_TESSELLATION_NV',
    'GL_EVAL_TRIANGULAR_2D_NV',
    'GL_EVAL_VERTEX_ATTRIB0_NV',
    'GL_EVAL_VERTEX_ATTRIB10_NV',
    'GL_EVAL_VERTEX_ATTRIB11_NV',
    'GL_EVAL_VERTEX_ATTRIB12_NV',
    'GL_EVAL_VERTEX_ATTRIB13_NV',
    'GL_EVAL_VERTEX_ATTRIB14_NV',
    'GL_EVAL_VERTEX_ATTRIB15_NV',
    'GL_EVAL_VERTEX_ATTRIB1_NV',
    'GL_EVAL_VERTEX_ATTRIB2_NV',
    'GL_EVAL_VERTEX_ATTRIB3_NV',
    'GL_EVAL_VERTEX_ATTRIB4_NV',
    'GL_EVAL_VERTEX_ATTRIB5_NV',
    'GL_EVAL_VERTEX_ATTRIB6_NV',
    'GL_EVAL_VERTEX_ATTRIB7_NV',
    'GL_EVAL_VERTEX_ATTRIB8_NV',
    'GL_EVAL_VERTEX_ATTRIB9_NV',
    'GL_EXP',
    'GL_EXP2',
    'GL_EXPAND_NEGATE_NV',
    'GL_EXPAND_NORMAL_NV',
    'GL_EXTENSIONS',
    'GL_EYE_DISTANCE_TO_LINE_SGIS',
    'GL_EYE_DISTANCE_TO_POINT_SGIS',
    'GL_EYE_LINEAR',
    'GL_EYE_LINE_SGIS',
    'GL_EYE_PLANE',
    'GL_EYE_PLANE_ABSOLUTE_NV',
    'GL_EYE_POINT_SGIS',
    'GL_EYE_RADIAL_NV',
    'GL_E_TIMES_F_NV',
    'GL_FALSE',
    'GL_FASTEST',
    'GL_FEEDBACK',
    'GL_FEEDBACK_BUFFER_POINTER',
    'GL_FEEDBACK_BUFFER_SIZE',
    'GL_FEEDBACK_BUFFER_TYPE',
    'GL_FENCE_APPLE',
    'GL_FENCE_CONDITION_NV',
    'GL_FENCE_STATUS_NV',
    'GL_FILL',
    'GL_FILTER4_SGIS',
    'GL_FIXED_ONLY_ARB',
    'GL_FLAT',
    'GL_FLOAT',
    'GL_FLOAT_CLEAR_COLOR_VALUE_NV',
    'GL_FLOAT_MAT2',
    'GL_FLOAT_MAT2_ARB',
    'GL_FLOAT_MAT3',
    'GL_FLOAT_MAT3_ARB',
    'GL_FLOAT_MAT4',
    'GL_FLOAT_MAT4_ARB',
    'GL_FLOAT_R16_NV',
    'GL_FLOAT_R32_NV',
    'GL_FLOAT_RG16_NV',
    'GL_FLOAT_RG32_NV',
    'GL_FLOAT_RGB16_NV',
    'GL_FLOAT_RGB32_NV',
    'GL_FLOAT_RGBA16_NV',
    'GL_FLOAT_RGBA32_NV',
    'GL_FLOAT_RGBA_MODE_NV',
    'GL_FLOAT_RGBA_NV',
    'GL_FLOAT_RGB_NV',
    'GL_FLOAT_RG_NV',
    'GL_FLOAT_R_NV',
    'GL_FLOAT_VEC2',
    'GL_FLOAT_VEC2_ARB',
    'GL_FLOAT_VEC3',
    'GL_FLOAT_VEC3_ARB',
    'GL_FLOAT_VEC4',
    'GL_FLOAT_VEC4_ARB',
    'GL_FOG',
    'GL_FOG_BIT',
    'GL_FOG_COLOR',
    'GL_FOG_COORDINATE',
    'GL_FOG_COORDINATE_ARRAY',
    'GL_FOG_COORDINATE_ARRAY_BUFFER_BINDING',
    'GL_FOG_COORDINATE_ARRAY_BUFFER_BINDING_ARB',
    'GL_FOG_COORDINATE_ARRAY_EXT',
    'GL_FOG_COORDINATE_ARRAY_LIST_IBM',
    'GL_FOG_COORDINATE_ARRAY_LIST_STRIDE_IBM',
    'GL_FOG_COORDINATE_ARRAY_POINTER',
    'GL_FOG_COORDINATE_ARRAY_POINTER_EXT',
    'GL_FOG_COORDINATE_ARRAY_STRIDE',
    'GL_FOG_COORDINATE_ARRAY_STRIDE_EXT',
    'GL_FOG_COORDINATE_ARRAY_TYPE',
    'GL_FOG_COORDINATE_ARRAY_TYPE_EXT',
    'GL_FOG_COORDINATE_EXT',
    'GL_FOG_COORDINATE_SOURCE',
    'GL_FOG_COORDINATE_SOURCE_EXT',
    'GL_FOG_DENSITY',
    'GL_FOG_DISTANCE_MODE_NV',
    'GL_FOG_END',
    'GL_FOG_FUNC_POINTS_SGIS',
    'GL_FOG_FUNC_SGIS',
    'GL_FOG_HINT',
    'GL_FOG_INDEX',
    'GL_FOG_MODE',
    'GL_FOG_OFFSET_SGIX',
    'GL_FOG_OFFSET_VALUE_SGIX',
    'GL_FOG_SCALE_SGIX',
    'GL_FOG_SCALE_VALUE_SGIX',
    'GL_FOG_SPECULAR_TEXTURE_WIN',
    'GL_FOG_START',
    'GL_FORCE_BLUE_TO_ONE_NV',
    'GL_FORMAT_SUBSAMPLE_244_244_OML',
    'GL_FORMAT_SUBSAMPLE_24_24_OML',
    'GL_FRAGMENT_COLOR_EXT',
    'GL_FRAGMENT_COLOR_MATERIAL_FACE_SGIX',
    'GL_FRAGMENT_COLOR_MATERIAL_PARAMETER_SGIX',
    'GL_FRAGMENT_COLOR_MATERIAL_SGIX',
    'GL_FRAGMENT_DEPTH',
    'GL_FRAGMENT_DEPTH_EXT',
    'GL_FRAGMENT_LIGHT0_SGIX',
    'GL_FRAGMENT_LIGHT1_SGIX',
    'GL_FRAGMENT_LIGHT2_SGIX',
    'GL_FRAGMENT_LIGHT3_SGIX',
    'GL_FRAGMENT_LIGHT4_SGIX',
    'GL_FRAGMENT_LIGHT5_SGIX',
    'GL_FRAGMENT_LIGHT6_SGIX',
    'GL_FRAGMENT_LIGHT7_SGIX',
    'GL_FRAGMENT_LIGHTING_SGIX',
    'GL_FRAGMENT_LIGHT_MODEL_AMBIENT_SGIX',
    'GL_FRAGMENT_LIGHT_MODEL_LOCAL_VIEWER_SGIX',
    'GL_FRAGMENT_LIGHT_MODEL_NORMAL_INTERPOLATION_SGIX',
    'GL_FRAGMENT_LIGHT_MODEL_TWO_SIDE_SGIX',
    'GL_FRAGMENT_MATERIAL_EXT',
    'GL_FRAGMENT_NORMAL_EXT',
    'GL_FRAGMENT_PROGRAM_ARB',
    'GL_FRAGMENT_PROGRAM_BINDING_NV',
    'GL_FRAGMENT_PROGRAM_NV',
    'GL_FRAGMENT_SHADER',
    'GL_FRAGMENT_SHADER_ARB',
    'GL_FRAGMENT_SHADER_ATI',
    'GL_FRAGMENT_SHADER_DERIVATIVE_HINT',
    'GL_FRAGMENT_SHADER_DERIVATIVE_HINT_ARB',
    'GL_FRAMEBUFFER_ATTACHMENT_OBJECT_NAME_EXT',
    'GL_FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE_EXT',
    'GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_3D_ZOFFSET_EXT',
    'GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE_EXT',
    'GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL_EXT',
    'GL_FRAMEBUFFER_BINDING_EXT',
    'GL_FRAMEBUFFER_COMPLETE_EXT',
    'GL_FRAMEBUFFER_EXT',
    'GL_FRAMEBUFFER_INCOMPLETE_ATTACHMENT_EXT',
    'GL_FRAMEBUFFER_INCOMPLETE_DIMENSIONS_EXT',
    'GL_FRAMEBUFFER_INCOMPLETE_DRAW_BUFFER_EXT',
    'GL_FRAMEBUFFER_INCOMPLETE_DUPLICATE_ATTACHMENT_EXT',
    'GL_FRAMEBUFFER_INCOMPLETE_FORMATS_EXT',
    'GL_FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT_EXT',
    'GL_FRAMEBUFFER_INCOMPLETE_READ_BUFFER_EXT',
    'GL_FRAMEBUFFER_UNSUPPORTED_EXT',
    'GL_FRAMEZOOM_FACTOR_SGIX',
    'GL_FRAMEZOOM_SGIX',
    'GL_FRONT',
    'GL_FRONT_AND_BACK',
    'GL_FRONT_FACE',
    'GL_FRONT_LEFT',
    'GL_FRONT_RIGHT',
    'GL_FULL_RANGE_EXT',
    'GL_FULL_STIPPLE_HINT_PGI',
    'GL_FUNC_ADD',
    'GL_FUNC_ADD_EXT',
    'GL_FUNC_REVERSE_SUBTRACT',
    'GL_FUNC_REVERSE_SUBTRACT_EXT',
    'GL_FUNC_SUBTRACT',
    'GL_FUNC_SUBTRACT_EXT',
    'GL_GENERATE_MIPMAP',
    'GL_GENERATE_MIPMAP_HINT',
    'GL_GENERATE_MIPMAP_HINT_SGIS',
    'GL_GENERATE_MIPMAP_SGIS',
    'GL_GEOMETRY_DEFORMATION_BIT_SGIX',
    'GL_GEOMETRY_DEFORMATION_SGIX',
    'GL_GEQUAL',
    'GL_GLEXT_VERSION',
    'GL_GLOBAL_ALPHA_FACTOR_SUN',
    'GL_GLOBAL_ALPHA_SUN',
    'GL_GREATER',
    'GL_GREEN',
    'GL_GREEN_BIAS',
    'GL_GREEN_BITS',
    'GL_GREEN_BIT_ATI',
    'GL_GREEN_MAX_CLAMP_INGR',
    'GL_GREEN_MIN_CLAMP_INGR',
    'GL_GREEN_SCALE',
    'GL_HALF_BIAS_NEGATE_NV',
    'GL_HALF_BIAS_NORMAL_NV',
    'GL_HALF_BIT_ATI',
    'GL_HALF_FLOAT_ARB',
    'GL_HALF_FLOAT_NV',
    'GL_HILO16_NV',
    'GL_HILO8_NV',
    'GL_HILO_NV',
    'GL_HINT_BIT',
    'GL_HISTOGRAM',
    'GL_HISTOGRAM_ALPHA_SIZE',
    'GL_HISTOGRAM_ALPHA_SIZE_EXT',
    'GL_HISTOGRAM_BLUE_SIZE',
    'GL_HISTOGRAM_BLUE_SIZE_EXT',
    'GL_HISTOGRAM_EXT',
    'GL_HISTOGRAM_FORMAT',
    'GL_HISTOGRAM_FORMAT_EXT',
    'GL_HISTOGRAM_GREEN_SIZE',
    'GL_HISTOGRAM_GREEN_SIZE_EXT',
    'GL_HISTOGRAM_LUMINANCE_SIZE',
    'GL_HISTOGRAM_LUMINANCE_SIZE_EXT',
    'GL_HISTOGRAM_RED_SIZE',
    'GL_HISTOGRAM_RED_SIZE_EXT',
    'GL_HISTOGRAM_SINK',
    'GL_HISTOGRAM_SINK_EXT',
    'GL_HISTOGRAM_WIDTH',
    'GL_HISTOGRAM_WIDTH_EXT',
    'GL_HI_BIAS_NV',
    'GL_HI_SCALE_NV',
    'GL_IDENTITY_NV',
    'GL_IGNORE_BORDER_HP',
    'GL_IMAGE_CUBIC_WEIGHT_HP',
    'GL_IMAGE_MAG_FILTER_HP',
    'GL_IMAGE_MIN_FILTER_HP',
    'GL_IMAGE_ROTATE_ANGLE_HP',
    'GL_IMAGE_ROTATE_ORIGIN_X_HP',
    'GL_IMAGE_ROTATE_ORIGIN_Y_HP',
    'GL_IMAGE_SCALE_X_HP',
    'GL_IMAGE_SCALE_Y_HP',
    'GL_IMAGE_TRANSFORM_2D_HP',
    'GL_IMAGE_TRANSLATE_X_HP',
    'GL_IMAGE_TRANSLATE_Y_HP',
    'GL_IMPLEMENTATION_COLOR_READ_FORMAT_OES',
    'GL_IMPLEMENTATION_COLOR_READ_TYPE_OES',
    'GL_INCR',
    'GL_INCR_WRAP',
    'GL_INCR_WRAP_EXT',
    'GL_INDEX_ARRAY',
    'GL_INDEX_ARRAY_BUFFER_BINDING',
    'GL_INDEX_ARRAY_BUFFER_BINDING_ARB',
    'GL_INDEX_ARRAY_COUNT_EXT',
    'GL_INDEX_ARRAY_EXT',
    'GL_INDEX_ARRAY_LIST_IBM',
    'GL_INDEX_ARRAY_LIST_STRIDE_IBM',
    'GL_INDEX_ARRAY_POINTER',
    'GL_INDEX_ARRAY_POINTER_EXT',
    'GL_INDEX_ARRAY_STRIDE',
    'GL_INDEX_ARRAY_STRIDE_EXT',
    'GL_INDEX_ARRAY_TYPE',
    'GL_INDEX_ARRAY_TYPE_EXT',
    'GL_INDEX_BITS',
    'GL_INDEX_BIT_PGI',
    'GL_INDEX_CLEAR_VALUE',
    'GL_INDEX_LOGIC_OP',
    'GL_INDEX_MATERIAL_EXT',
    'GL_INDEX_MATERIAL_FACE_EXT',
    'GL_INDEX_MATERIAL_PARAMETER_EXT',
    'GL_INDEX_MODE',
    'GL_INDEX_OFFSET',
    'GL_INDEX_SHIFT',
    'GL_INDEX_TEST_EXT',
    'GL_INDEX_TEST_FUNC_EXT',
    'GL_INDEX_TEST_REF_EXT',
    'GL_INDEX_WRITEMASK',
    'GL_INFO_LOG_LENGTH',
    'GL_INSTRUMENT_BUFFER_POINTER_SGIX',
    'GL_INSTRUMENT_MEASUREMENTS_SGIX',
    'GL_INT',
    'GL_INTENSITY',
    'GL_INTENSITY12',
    'GL_INTENSITY12_EXT',
    'GL_INTENSITY16',
    'GL_INTENSITY16F_ARB',
    'GL_INTENSITY16_EXT',
    'GL_INTENSITY32F_ARB',
    'GL_INTENSITY4',
    'GL_INTENSITY4_EXT',
    'GL_INTENSITY8',
    'GL_INTENSITY8_EXT',
    'GL_INTENSITY_EXT',
    'GL_INTENSITY_FLOAT16_ATI',
    'GL_INTENSITY_FLOAT32_ATI',
    'GL_INTERLACE_OML',
    'GL_INTERLACE_READ_INGR',
    'GL_INTERLACE_READ_OML',
    'GL_INTERLACE_SGIX',
    'GL_INTERPOLATE',
    'GL_INTERPOLATE_ARB',
    'GL_INTERPOLATE_EXT',
    'GL_INT_VEC2',
    'GL_INT_VEC2_ARB',
    'GL_INT_VEC3',
    'GL_INT_VEC3_ARB',
    'GL_INT_VEC4',
    'GL_INT_VEC4_ARB',
    'GL_INVALID_ENUM',
    'GL_INVALID_FRAMEBUFFER_OPERATION_EXT',
    'GL_INVALID_OPERATION',
    'GL_INVALID_VALUE',
    'GL_INVARIANT_DATATYPE_EXT',
    'GL_INVARIANT_EXT',
    'GL_INVARIANT_VALUE_EXT',
    'GL_INVERSE_NV',
    'GL_INVERSE_TRANSPOSE_NV',
    'GL_INVERT',
    'GL_INVERTED_SCREEN_W_REND',
    'GL_IR_INSTRUMENT1_SGIX',
    'GL_IUI_N3F_V2F_EXT',
    'GL_IUI_N3F_V3F_EXT',
    'GL_IUI_V2F_EXT',
    'GL_IUI_V3F_EXT',
    'GL_KEEP',
    'GL_LEFT',
    'GL_LEQUAL',
    'GL_LERP_ATI',
    'GL_LESS',
    'GL_LIGHT0',
    'GL_LIGHT1',
    'GL_LIGHT2',
    'GL_LIGHT3',
    'GL_LIGHT4',
    'GL_LIGHT5',
    'GL_LIGHT6',
    'GL_LIGHT7',
    'GL_LIGHTING',
    'GL_LIGHTING_BIT',
    'GL_LIGHT_ENV_MODE_SGIX',
    'GL_LIGHT_MODEL_AMBIENT',
    'GL_LIGHT_MODEL_COLOR_CONTROL',
    'GL_LIGHT_MODEL_COLOR_CONTROL_EXT',
    'GL_LIGHT_MODEL_LOCAL_VIEWER',
    'GL_LIGHT_MODEL_SPECULAR_VECTOR_APPLE',
    'GL_LIGHT_MODEL_TWO_SIDE',
    'GL_LINE',
    'GL_LINEAR',
    'GL_LINEAR_ATTENUATION',
    'GL_LINEAR_CLIPMAP_LINEAR_SGIX',
    'GL_LINEAR_CLIPMAP_NEAREST_SGIX',
    'GL_LINEAR_DETAIL_ALPHA_SGIS',
    'GL_LINEAR_DETAIL_COLOR_SGIS',
    'GL_LINEAR_DETAIL_SGIS',
    'GL_LINEAR_MIPMAP_LINEAR',
    'GL_LINEAR_MIPMAP_NEAREST',
    'GL_LINEAR_SHARPEN_ALPHA_SGIS',
    'GL_LINEAR_SHARPEN_COLOR_SGIS',
    'GL_LINEAR_SHARPEN_SGIS',
    'GL_LINES',
    'GL_LINE_BIT',
    'GL_LINE_LOOP',
    'GL_LINE_RESET_TOKEN',
    'GL_LINE_SMOOTH',
    'GL_LINE_SMOOTH_HINT',
    'GL_LINE_STIPPLE',
    'GL_LINE_STIPPLE_PATTERN',
    'GL_LINE_STIPPLE_REPEAT',
    'GL_LINE_STRIP',
    'GL_LINE_TOKEN',
    'GL_LINE_WIDTH',
    'GL_LINK_STATUS',
    'GL_LIST_BASE',
    'GL_LIST_BIT',
    'GL_LIST_INDEX',
    'GL_LIST_MODE',
    'GL_LIST_PRIORITY_SGIX',
    'GL_LOAD',
    'GL_LOCAL_CONSTANT_DATATYPE_EXT',
    'GL_LOCAL_CONSTANT_EXT',
    'GL_LOCAL_CONSTANT_VALUE_EXT',
    'GL_LOCAL_EXT',
    'GL_LOGIC_OP_MODE',
    'GL_LOWER_LEFT',
    'GL_LO_BIAS_NV',
    'GL_LO_SCALE_NV',
    'GL_LUMINANCE',
    'GL_LUMINANCE12',
    'GL_LUMINANCE12_ALPHA12',
    'GL_LUMINANCE12_ALPHA12_EXT',
    'GL_LUMINANCE12_ALPHA4',
    'GL_LUMINANCE12_ALPHA4_EXT',
    'GL_LUMINANCE12_EXT',
    'GL_LUMINANCE16',
    'GL_LUMINANCE16F_ARB',
    'GL_LUMINANCE16_ALPHA16',
    'GL_LUMINANCE16_ALPHA16_EXT',
    'GL_LUMINANCE16_EXT',
    'GL_LUMINANCE32F_ARB',
    'GL_LUMINANCE4',
    'GL_LUMINANCE4_ALPHA4',
    'GL_LUMINANCE4_ALPHA4_EXT',
    'GL_LUMINANCE4_EXT',
    'GL_LUMINANCE6_ALPHA2',
    'GL_LUMINANCE6_ALPHA2_EXT',
    'GL_LUMINANCE8',
    'GL_LUMINANCE8_ALPHA8',
    'GL_LUMINANCE8_ALPHA8_EXT',
    'GL_LUMINANCE8_EXT',
    'GL_LUMINANCE_ALPHA',
    'GL_LUMINANCE_ALPHA16F_ARB',
    'GL_LUMINANCE_ALPHA32F_ARB',
    'GL_LUMINANCE_ALPHA_FLOAT16_ATI',
    'GL_LUMINANCE_ALPHA_FLOAT32_ATI',
    'GL_LUMINANCE_FLOAT16_ATI',
    'GL_LUMINANCE_FLOAT32_ATI',
    'GL_MAD_ATI',
    'GL_MAGNITUDE_BIAS_NV',
    'GL_MAGNITUDE_SCALE_NV',
    'GL_MAP1_BINORMAL_EXT',
    'GL_MAP1_COLOR_4',
    'GL_MAP1_GRID_DOMAIN',
    'GL_MAP1_GRID_SEGMENTS',
    'GL_MAP1_INDEX',
    'GL_MAP1_NORMAL',
    'GL_MAP1_TANGENT_EXT',
    'GL_MAP1_TEXTURE_COORD_1',
    'GL_MAP1_TEXTURE_COORD_2',
    'GL_MAP1_TEXTURE_COORD_3',
    'GL_MAP1_TEXTURE_COORD_4',
    'GL_MAP1_VERTEX_3',
    'GL_MAP1_VERTEX_4',
    'GL_MAP1_VERTEX_ATTRIB0_4_NV',
    'GL_MAP1_VERTEX_ATTRIB10_4_NV',
    'GL_MAP1_VERTEX_ATTRIB11_4_NV',
    'GL_MAP1_VERTEX_ATTRIB12_4_NV',
    'GL_MAP1_VERTEX_ATTRIB13_4_NV',
    'GL_MAP1_VERTEX_ATTRIB14_4_NV',
    'GL_MAP1_VERTEX_ATTRIB15_4_NV',
    'GL_MAP1_VERTEX_ATTRIB1_4_NV',
    'GL_MAP1_VERTEX_ATTRIB2_4_NV',
    'GL_MAP1_VERTEX_ATTRIB3_4_NV',
    'GL_MAP1_VERTEX_ATTRIB4_4_NV',
    'GL_MAP1_VERTEX_ATTRIB5_4_NV',
    'GL_MAP1_VERTEX_ATTRIB6_4_NV',
    'GL_MAP1_VERTEX_ATTRIB7_4_NV',
    'GL_MAP1_VERTEX_ATTRIB8_4_NV',
    'GL_MAP1_VERTEX_ATTRIB9_4_NV',
    'GL_MAP2_BINORMAL_EXT',
    'GL_MAP2_COLOR_4',
    'GL_MAP2_GRID_DOMAIN',
    'GL_MAP2_GRID_SEGMENTS',
    'GL_MAP2_INDEX',
    'GL_MAP2_NORMAL',
    'GL_MAP2_TANGENT_EXT',
    'GL_MAP2_TEXTURE_COORD_1',
    'GL_MAP2_TEXTURE_COORD_2',
    'GL_MAP2_TEXTURE_COORD_3',
    'GL_MAP2_TEXTURE_COORD_4',
    'GL_MAP2_VERTEX_3',
    'GL_MAP2_VERTEX_4',
    'GL_MAP2_VERTEX_ATTRIB0_4_NV',
    'GL_MAP2_VERTEX_ATTRIB10_4_NV',
    'GL_MAP2_VERTEX_ATTRIB11_4_NV',
    'GL_MAP2_VERTEX_ATTRIB12_4_NV',
    'GL_MAP2_VERTEX_ATTRIB13_4_NV',
    'GL_MAP2_VERTEX_ATTRIB14_4_NV',
    'GL_MAP2_VERTEX_ATTRIB15_4_NV',
    'GL_MAP2_VERTEX_ATTRIB1_4_NV',
    'GL_MAP2_VERTEX_ATTRIB2_4_NV',
    'GL_MAP2_VERTEX_ATTRIB3_4_NV',
    'GL_MAP2_VERTEX_ATTRIB4_4_NV',
    'GL_MAP2_VERTEX_ATTRIB5_4_NV',
    'GL_MAP2_VERTEX_ATTRIB6_4_NV',
    'GL_MAP2_VERTEX_ATTRIB7_4_NV',
    'GL_MAP2_VERTEX_ATTRIB8_4_NV',
    'GL_MAP2_VERTEX_ATTRIB9_4_NV',
    'GL_MAP_ATTRIB_U_ORDER_NV',
    'GL_MAP_ATTRIB_V_ORDER_NV',
    'GL_MAP_COLOR',
    'GL_MAP_STENCIL',
    'GL_MAP_TESSELLATION_NV',
    'GL_MATERIAL_SIDE_HINT_PGI',
    'GL_MATRIX0_ARB',
    'GL_MATRIX0_NV',
    'GL_MATRIX10_ARB',
    'GL_MATRIX11_ARB',
    'GL_MATRIX12_ARB',
    'GL_MATRIX13_ARB',
    'GL_MATRIX14_ARB',
    'GL_MATRIX15_ARB',
    'GL_MATRIX16_ARB',
    'GL_MATRIX17_ARB',
    'GL_MATRIX18_ARB',
    'GL_MATRIX19_ARB',
    'GL_MATRIX1_ARB',
    'GL_MATRIX1_NV',
    'GL_MATRIX20_ARB',
    'GL_MATRIX21_ARB',
    'GL_MATRIX22_ARB',
    'GL_MATRIX23_ARB',
    'GL_MATRIX24_ARB',
    'GL_MATRIX25_ARB',
    'GL_MATRIX26_ARB',
    'GL_MATRIX27_ARB',
    'GL_MATRIX28_ARB',
    'GL_MATRIX29_ARB',
    'GL_MATRIX2_ARB',
    'GL_MATRIX2_NV',
    'GL_MATRIX30_ARB',
    'GL_MATRIX31_ARB',
    'GL_MATRIX3_ARB',
    'GL_MATRIX3_NV',
    'GL_MATRIX4_ARB',
    'GL_MATRIX4_NV',
    'GL_MATRIX5_ARB',
    'GL_MATRIX5_NV',
    'GL_MATRIX6_ARB',
    'GL_MATRIX6_NV',
    'GL_MATRIX7_ARB',
    'GL_MATRIX7_NV',
    'GL_MATRIX8_ARB',
    'GL_MATRIX9_ARB',
    'GL_MATRIX_EXT',
    'GL_MATRIX_INDEX_ARRAY_ARB',
    'GL_MATRIX_INDEX_ARRAY_POINTER_ARB',
    'GL_MATRIX_INDEX_ARRAY_SIZE_ARB',
    'GL_MATRIX_INDEX_ARRAY_STRIDE_ARB',
    'GL_MATRIX_INDEX_ARRAY_TYPE_ARB',
    'GL_MATRIX_MODE',
    'GL_MATRIX_PALETTE_ARB',
    'GL_MAT_AMBIENT_AND_DIFFUSE_BIT_PGI',
    'GL_MAT_AMBIENT_BIT_PGI',
    'GL_MAT_COLOR_INDEXES_BIT_PGI',
    'GL_MAT_DIFFUSE_BIT_PGI',
    'GL_MAT_EMISSION_BIT_PGI',
    'GL_MAT_SHININESS_BIT_PGI',
    'GL_MAT_SPECULAR_BIT_PGI',
    'GL_MAX',
    'GL_MAX_3D_TEXTURE_SIZE',
    'GL_MAX_3D_TEXTURE_SIZE_EXT',
    'GL_MAX_4D_TEXTURE_SIZE_SGIS',
    'GL_MAX_ACTIVE_LIGHTS_SGIX',
    'GL_MAX_ASYNC_DRAW_PIXELS_SGIX',
    'GL_MAX_ASYNC_HISTOGRAM_SGIX',
    'GL_MAX_ASYNC_READ_PIXELS_SGIX',
    'GL_MAX_ASYNC_TEX_IMAGE_SGIX',
    'GL_MAX_ATTRIB_STACK_DEPTH',
    'GL_MAX_CLIENT_ATTRIB_STACK_DEPTH',
    'GL_MAX_CLIPMAP_DEPTH_SGIX',
    'GL_MAX_CLIPMAP_VIRTUAL_DEPTH_SGIX',
    'GL_MAX_CLIP_PLANES',
    'GL_MAX_COLOR_ATTACHMENTS_EXT',
    'GL_MAX_COLOR_MATRIX_STACK_DEPTH',
    'GL_MAX_COLOR_MATRIX_STACK_DEPTH_SGI',
    'GL_MAX_COMBINED_TEXTURE_IMAGE_UNITS',
    'GL_MAX_COMBINED_TEXTURE_IMAGE_UNITS_ARB',
    'GL_MAX_CONVOLUTION_HEIGHT',
    'GL_MAX_CONVOLUTION_HEIGHT_EXT',
    'GL_MAX_CONVOLUTION_WIDTH',
    'GL_MAX_CONVOLUTION_WIDTH_EXT',
    'GL_MAX_CUBE_MAP_TEXTURE_SIZE',
    'GL_MAX_CUBE_MAP_TEXTURE_SIZE_ARB',
    'GL_MAX_CUBE_MAP_TEXTURE_SIZE_EXT',
    'GL_MAX_DEFORMATION_ORDER_SGIX',
    'GL_MAX_DRAW_BUFFERS',
    'GL_MAX_DRAW_BUFFERS_ARB',
    'GL_MAX_DRAW_BUFFERS_ATI',
    'GL_MAX_ELEMENTS_INDICES',
    'GL_MAX_ELEMENTS_INDICES_EXT',
    'GL_MAX_ELEMENTS_VERTICES',
    'GL_MAX_ELEMENTS_VERTICES_EXT',
    'GL_MAX_EVAL_ORDER',
    'GL_MAX_EXT',
    'GL_MAX_FOG_FUNC_POINTS_SGIS',
    'GL_MAX_FRAGMENT_LIGHTS_SGIX',
    'GL_MAX_FRAGMENT_PROGRAM_LOCAL_PARAMETERS_NV',
    'GL_MAX_FRAGMENT_UNIFORM_COMPONENTS',
    'GL_MAX_FRAGMENT_UNIFORM_COMPONENTS_ARB',
    'GL_MAX_FRAMEZOOM_FACTOR_SGIX',
    'GL_MAX_GENERAL_COMBINERS_NV',
    'GL_MAX_LIGHTS',
    'GL_MAX_LIST_NESTING',
    'GL_MAX_MAP_TESSELLATION_NV',
    'GL_MAX_MATRIX_PALETTE_STACK_DEPTH_ARB',
    'GL_MAX_MODELVIEW_STACK_DEPTH',
    'GL_MAX_NAME_STACK_DEPTH',
    'GL_MAX_OPTIMIZED_VERTEX_SHADER_INSTRUCTIONS_EXT',
    'GL_MAX_OPTIMIZED_VERTEX_SHADER_INVARIANTS_EXT',
    'GL_MAX_OPTIMIZED_VERTEX_SHADER_LOCALS_EXT',
    'GL_MAX_OPTIMIZED_VERTEX_SHADER_LOCAL_CONSTANTS_EXT',
    'GL_MAX_OPTIMIZED_VERTEX_SHADER_VARIANTS_EXT',
    'GL_MAX_PALETTE_MATRICES_ARB',
    'GL_MAX_PIXEL_MAP_TABLE',
    'GL_MAX_PIXEL_TRANSFORM_2D_STACK_DEPTH_EXT',
    'GL_MAX_PN_TRIANGLES_TESSELATION_LEVEL_ATI',
    'GL_MAX_PROGRAM_ADDRESS_REGISTERS_ARB',
    'GL_MAX_PROGRAM_ALU_INSTRUCTIONS_ARB',
    'GL_MAX_PROGRAM_ATTRIBS_ARB',
    'GL_MAX_PROGRAM_CALL_DEPTH_NV',
    'GL_MAX_PROGRAM_ENV_PARAMETERS_ARB',
    'GL_MAX_PROGRAM_EXEC_INSTRUCTIONS_NV',
    'GL_MAX_PROGRAM_IF_DEPTH_NV',
    'GL_MAX_PROGRAM_INSTRUCTIONS_ARB',
    'GL_MAX_PROGRAM_LOCAL_PARAMETERS_ARB',
    'GL_MAX_PROGRAM_LOOP_COUNT_NV',
    'GL_MAX_PROGRAM_LOOP_DEPTH_NV',
    'GL_MAX_PROGRAM_MATRICES_ARB',
    'GL_MAX_PROGRAM_MATRIX_STACK_DEPTH_ARB',
    'GL_MAX_PROGRAM_NATIVE_ADDRESS_REGISTERS_ARB',
    'GL_MAX_PROGRAM_NATIVE_ALU_INSTRUCTIONS_ARB',
    'GL_MAX_PROGRAM_NATIVE_ATTRIBS_ARB',
    'GL_MAX_PROGRAM_NATIVE_INSTRUCTIONS_ARB',
    'GL_MAX_PROGRAM_NATIVE_PARAMETERS_ARB',
    'GL_MAX_PROGRAM_NATIVE_TEMPORARIES_ARB',
    'GL_MAX_PROGRAM_NATIVE_TEX_INDIRECTIONS_ARB',
    'GL_MAX_PROGRAM_NATIVE_TEX_INSTRUCTIONS_ARB',
    'GL_MAX_PROGRAM_PARAMETERS_ARB',
    'GL_MAX_PROGRAM_TEMPORARIES_ARB',
    'GL_MAX_PROGRAM_TEX_INDIRECTIONS_ARB',
    'GL_MAX_PROGRAM_TEX_INSTRUCTIONS_ARB',
    'GL_MAX_PROJECTION_STACK_DEPTH',
    'GL_MAX_RATIONAL_EVAL_ORDER_NV',
    'GL_MAX_RECTANGLE_TEXTURE_SIZE_ARB',
    'GL_MAX_RECTANGLE_TEXTURE_SIZE_NV',
    'GL_MAX_RENDERBUFFER_SIZE_EXT',
    'GL_MAX_SHININESS_NV',
    'GL_MAX_SPOT_EXPONENT_NV',
    'GL_MAX_TEXTURE_COORDS',
    'GL_MAX_TEXTURE_COORDS_ARB',
    'GL_MAX_TEXTURE_COORDS_NV',
    'GL_MAX_TEXTURE_IMAGE_UNITS',
    'GL_MAX_TEXTURE_IMAGE_UNITS_ARB',
    'GL_MAX_TEXTURE_IMAGE_UNITS_NV',
    'GL_MAX_TEXTURE_LOD_BIAS',
    'GL_MAX_TEXTURE_LOD_BIAS_EXT',
    'GL_MAX_TEXTURE_MAX_ANISOTROPY_EXT',
    'GL_MAX_TEXTURE_SIZE',
    'GL_MAX_TEXTURE_STACK_DEPTH',
    'GL_MAX_TEXTURE_UNITS',
    'GL_MAX_TEXTURE_UNITS_ARB',
    'GL_MAX_TRACK_MATRICES_NV',
    'GL_MAX_TRACK_MATRIX_STACK_DEPTH_NV',
    'GL_MAX_VARYING_FLOATS',
    'GL_MAX_VARYING_FLOATS_ARB',
    'GL_MAX_VERTEX_ARRAY_RANGE_ELEMENT_NV',
    'GL_MAX_VERTEX_ATTRIBS',
    'GL_MAX_VERTEX_ATTRIBS_ARB',
    'GL_MAX_VERTEX_HINT_PGI',
    'GL_MAX_VERTEX_SHADER_INSTRUCTIONS_EXT',
    'GL_MAX_VERTEX_SHADER_INVARIANTS_EXT',
    'GL_MAX_VERTEX_SHADER_LOCALS_EXT',
    'GL_MAX_VERTEX_SHADER_LOCAL_CONSTANTS_EXT',
    'GL_MAX_VERTEX_SHADER_VARIANTS_EXT',
    'GL_MAX_VERTEX_STREAMS_ATI',
    'GL_MAX_VERTEX_TEXTURE_IMAGE_UNITS',
    'GL_MAX_VERTEX_TEXTURE_IMAGE_UNITS_ARB',
    'GL_MAX_VERTEX_UNIFORM_COMPONENTS',
    'GL_MAX_VERTEX_UNIFORM_COMPONENTS_ARB',
    'GL_MAX_VERTEX_UNITS_ARB',
    'GL_MAX_VIEWPORT_DIMS',
    'GL_MIN',
    'GL_MINMAX',
    'GL_MINMAX_EXT',
    'GL_MINMAX_FORMAT',
    'GL_MINMAX_FORMAT_EXT',
    'GL_MINMAX_SINK',
    'GL_MINMAX_SINK_EXT',
    'GL_MIN_EXT',
    'GL_MIRRORED_REPEAT',
    'GL_MIRRORED_REPEAT_ARB',
    'GL_MIRRORED_REPEAT_IBM',
    'GL_MIRROR_CLAMP_ATI',
    'GL_MIRROR_CLAMP_EXT',
    'GL_MIRROR_CLAMP_TO_BORDER_EXT',
    'GL_MIRROR_CLAMP_TO_EDGE_ATI',
    'GL_MIRROR_CLAMP_TO_EDGE_EXT',
    'GL_MODELVIEW',
    'GL_MODELVIEW0_ARB',
    'GL_MODELVIEW10_ARB',
    'GL_MODELVIEW11_ARB',
    'GL_MODELVIEW12_ARB',
    'GL_MODELVIEW13_ARB',
    'GL_MODELVIEW14_ARB',
    'GL_MODELVIEW15_ARB',
    'GL_MODELVIEW16_ARB',
    'GL_MODELVIEW17_ARB',
    'GL_MODELVIEW18_ARB',
    'GL_MODELVIEW19_ARB',
    'GL_MODELVIEW1_ARB',
    'GL_MODELVIEW1_EXT',
    'GL_MODELVIEW1_MATRIX_EXT',
    'GL_MODELVIEW1_STACK_DEPTH_EXT',
    'GL_MODELVIEW20_ARB',
    'GL_MODELVIEW21_ARB',
    'GL_MODELVIEW22_ARB',
    'GL_MODELVIEW23_ARB',
    'GL_MODELVIEW24_ARB',
    'GL_MODELVIEW25_ARB',
    'GL_MODELVIEW26_ARB',
    'GL_MODELVIEW27_ARB',
    'GL_MODELVIEW28_ARB',
    'GL_MODELVIEW29_ARB',
    'GL_MODELVIEW2_ARB',
    'GL_MODELVIEW30_ARB',
    'GL_MODELVIEW31_ARB',
    'GL_MODELVIEW3_ARB',
    'GL_MODELVIEW4_ARB',
    'GL_MODELVIEW5_ARB',
    'GL_MODELVIEW6_ARB',
    'GL_MODELVIEW7_ARB',
    'GL_MODELVIEW8_ARB',
    'GL_MODELVIEW9_ARB',
    'GL_MODELVIEW_MATRIX',
    'GL_MODELVIEW_PROJECTION_NV',
    'GL_MODELVIEW_STACK_DEPTH',
    'GL_MODULATE',
    'GL_MODULATE_ADD_ATI',
    'GL_MODULATE_SIGNED_ADD_ATI',
    'GL_MODULATE_SUBTRACT_ATI',
    'GL_MOV_ATI',
    'GL_MULT',
    'GL_MULTISAMPLE',
    'GL_MULTISAMPLE_3DFX',
    'GL_MULTISAMPLE_ARB',
    'GL_MULTISAMPLE_BIT',
    'GL_MULTISAMPLE_BIT_3DFX',
    'GL_MULTISAMPLE_BIT_ARB',
    'GL_MULTISAMPLE_BIT_EXT',
    'GL_MULTISAMPLE_EXT',
    'GL_MULTISAMPLE_FILTER_HINT_NV',
    'GL_MULTISAMPLE_SGIS',
    'GL_MUL_ATI',
    'GL_MVP_MATRIX_EXT',
    'GL_N3F_V3F',
    'GL_NAME_STACK_DEPTH',
    'GL_NAND',
    'GL_NATIVE_GRAPHICS_BEGIN_HINT_PGI',
    'GL_NATIVE_GRAPHICS_END_HINT_PGI',
    'GL_NATIVE_GRAPHICS_HANDLE_PGI',
    'GL_NEAREST',
    'GL_NEAREST_CLIPMAP_LINEAR_SGIX',
    'GL_NEAREST_CLIPMAP_NEAREST_SGIX',
    'GL_NEAREST_MIPMAP_LINEAR',
    'GL_NEAREST_MIPMAP_NEAREST',
    'GL_NEGATE_BIT_ATI',
    'GL_NEGATIVE_ONE_EXT',
    'GL_NEGATIVE_W_EXT',
    'GL_NEGATIVE_X_EXT',
    'GL_NEGATIVE_Y_EXT',
    'GL_NEGATIVE_Z_EXT',
    'GL_NEVER',
    'GL_NICEST',
    'GL_NONE',
    'GL_NOOP',
    'GL_NOR',
    'GL_NORMALIZE',
    'GL_NORMALIZED_RANGE_EXT',
    'GL_NORMAL_ARRAY',
    'GL_NORMAL_ARRAY_BUFFER_BINDING',
    'GL_NORMAL_ARRAY_BUFFER_BINDING_ARB',
    'GL_NORMAL_ARRAY_COUNT_EXT',
    'GL_NORMAL_ARRAY_EXT',
    'GL_NORMAL_ARRAY_LIST_IBM',
    'GL_NORMAL_ARRAY_LIST_STRIDE_IBM',
    'GL_NORMAL_ARRAY_PARALLEL_POINTERS_INTEL',
    'GL_NORMAL_ARRAY_POINTER',
    'GL_NORMAL_ARRAY_POINTER_EXT',
    'GL_NORMAL_ARRAY_STRIDE',
    'GL_NORMAL_ARRAY_STRIDE_EXT',
    'GL_NORMAL_ARRAY_TYPE',
    'GL_NORMAL_ARRAY_TYPE_EXT',
    'GL_NORMAL_BIT_PGI',
    'GL_NORMAL_MAP',
    'GL_NORMAL_MAP_ARB',
    'GL_NORMAL_MAP_EXT',
    'GL_NORMAL_MAP_NV',
    'GL_NOTEQUAL',
    'GL_NO_ERROR',
    'GL_NUM_COMPRESSED_TEXTURE_FORMATS',
    'GL_NUM_COMPRESSED_TEXTURE_FORMATS_ARB',
    'GL_NUM_FRAGMENT_CONSTANTS_ATI',
    'GL_NUM_FRAGMENT_REGISTERS_ATI',
    'GL_NUM_GENERAL_COMBINERS_NV',
    'GL_NUM_INPUT_INTERPOLATOR_COMPONENTS_ATI',
    'GL_NUM_INSTRUCTIONS_PER_PASS_ATI',
    'GL_NUM_INSTRUCTIONS_TOTAL_ATI',
    'GL_NUM_LOOPBACK_COMPONENTS_ATI',
    'GL_NUM_PASSES_ATI',
    'GL_OBJECT_ACTIVE_ATTRIBUTES_ARB',
    'GL_OBJECT_ACTIVE_ATTRIBUTE_MAX_LENGTH_ARB',
    'GL_OBJECT_ACTIVE_UNIFORMS_ARB',
    'GL_OBJECT_ACTIVE_UNIFORM_MAX_LENGTH_ARB',
    'GL_OBJECT_ATTACHED_OBJECTS_ARB',
    'GL_OBJECT_BUFFER_SIZE_ATI',
    'GL_OBJECT_BUFFER_USAGE_ATI',
    'GL_OBJECT_COMPILE_STATUS_ARB',
    'GL_OBJECT_DELETE_STATUS_ARB',
    'GL_OBJECT_DISTANCE_TO_LINE_SGIS',
    'GL_OBJECT_DISTANCE_TO_POINT_SGIS',
    'GL_OBJECT_INFO_LOG_LENGTH_ARB',
    'GL_OBJECT_LINEAR',
    'GL_OBJECT_LINE_SGIS',
    'GL_OBJECT_LINK_STATUS_ARB',
    'GL_OBJECT_PLANE',
    'GL_OBJECT_POINT_SGIS',
    'GL_OBJECT_SHADER_SOURCE_LENGTH_ARB',
    'GL_OBJECT_SUBTYPE_ARB',
    'GL_OBJECT_TYPE_ARB',
    'GL_OBJECT_VALIDATE_STATUS_ARB',
    'GL_OCCLUSION_TEST_HP',
    'GL_OCCLUSION_TEST_RESULT_HP',
    'GL_OFFSET_HILO_PROJECTIVE_TEXTURE_2D_NV',
    'GL_OFFSET_HILO_PROJECTIVE_TEXTURE_RECTANGLE_NV',
    'GL_OFFSET_HILO_TEXTURE_2D_NV',
    'GL_OFFSET_HILO_TEXTURE_RECTANGLE_NV',
    'GL_OFFSET_PROJECTIVE_TEXTURE_2D_NV',
    'GL_OFFSET_PROJECTIVE_TEXTURE_2D_SCALE_NV',
    'GL_OFFSET_PROJECTIVE_TEXTURE_RECTANGLE_NV',
    'GL_OFFSET_PROJECTIVE_TEXTURE_RECTANGLE_SCALE_NV',
    'GL_OFFSET_TEXTURE_2D_NV',
    'GL_OFFSET_TEXTURE_BIAS_NV',
    'GL_OFFSET_TEXTURE_MATRIX_NV',
    'GL_OFFSET_TEXTURE_RECTANGLE_NV',
    'GL_OFFSET_TEXTURE_RECTANGLE_SCALE_NV',
    'GL_OFFSET_TEXTURE_SCALE_NV',
    'GL_ONE',
    'GL_ONE_EXT',
    'GL_ONE_MINUS_CONSTANT_ALPHA',
    'GL_ONE_MINUS_CONSTANT_ALPHA_EXT',
    'GL_ONE_MINUS_CONSTANT_COLOR',
    'GL_ONE_MINUS_CONSTANT_COLOR_EXT',
    'GL_ONE_MINUS_DST_ALPHA',
    'GL_ONE_MINUS_DST_COLOR',
    'GL_ONE_MINUS_SRC_ALPHA',
    'GL_ONE_MINUS_SRC_COLOR',
    'GL_OPERAND0_ALPHA',
    'GL_OPERAND0_ALPHA_ARB',
    'GL_OPERAND0_ALPHA_EXT',
    'GL_OPERAND0_RGB',
    'GL_OPERAND0_RGB_ARB',
    'GL_OPERAND0_RGB_EXT',
    'GL_OPERAND1_ALPHA',
    'GL_OPERAND1_ALPHA_ARB',
    'GL_OPERAND1_ALPHA_EXT',
    'GL_OPERAND1_RGB',
    'GL_OPERAND1_RGB_ARB',
    'GL_OPERAND1_RGB_EXT',
    'GL_OPERAND2_ALPHA',
    'GL_OPERAND2_ALPHA_ARB',
    'GL_OPERAND2_ALPHA_EXT',
    'GL_OPERAND2_RGB',
    'GL_OPERAND2_RGB_ARB',
    'GL_OPERAND2_RGB_EXT',
    'GL_OPERAND3_ALPHA_NV',
    'GL_OPERAND3_RGB_NV',
    'GL_OP_ADD_EXT',
    'GL_OP_CLAMP_EXT',
    'GL_OP_CROSS_PRODUCT_EXT',
    'GL_OP_DOT3_EXT',
    'GL_OP_DOT4_EXT',
    'GL_OP_EXP_BASE_2_EXT',
    'GL_OP_FLOOR_EXT',
    'GL_OP_FRAC_EXT',
    'GL_OP_INDEX_EXT',
    'GL_OP_LOG_BASE_2_EXT',
    'GL_OP_MADD_EXT',
    'GL_OP_MAX_EXT',
    'GL_OP_MIN_EXT',
    'GL_OP_MOV_EXT',
    'GL_OP_MULTIPLY_MATRIX_EXT',
    'GL_OP_MUL_EXT',
    'GL_OP_NEGATE_EXT',
    'GL_OP_POWER_EXT',
    'GL_OP_RECIP_EXT',
    'GL_OP_RECIP_SQRT_EXT',
    'GL_OP_ROUND_EXT',
    'GL_OP_SET_GE_EXT',
    'GL_OP_SET_LT_EXT',
    'GL_OP_SUB_EXT',
    'GL_OR',
    'GL_ORDER',
    'GL_OR_INVERTED',
    'GL_OR_REVERSE',
    'GL_OUTPUT_COLOR0_EXT',
    'GL_OUTPUT_COLOR1_EXT',
    'GL_OUTPUT_FOG_EXT',
    'GL_OUTPUT_TEXTURE_COORD0_EXT',
    'GL_OUTPUT_TEXTURE_COORD10_EXT',
    'GL_OUTPUT_TEXTURE_COORD11_EXT',
    'GL_OUTPUT_TEXTURE_COORD12_EXT',
    'GL_OUTPUT_TEXTURE_COORD13_EXT',
    'GL_OUTPUT_TEXTURE_COORD14_EXT',
    'GL_OUTPUT_TEXTURE_COORD15_EXT',
    'GL_OUTPUT_TEXTURE_COORD16_EXT',
    'GL_OUTPUT_TEXTURE_COORD17_EXT',
    'GL_OUTPUT_TEXTURE_COORD18_EXT',
    'GL_OUTPUT_TEXTURE_COORD19_EXT',
    'GL_OUTPUT_TEXTURE_COORD1_EXT',
    'GL_OUTPUT_TEXTURE_COORD20_EXT',
    'GL_OUTPUT_TEXTURE_COORD21_EXT',
    'GL_OUTPUT_TEXTURE_COORD22_EXT',
    'GL_OUTPUT_TEXTURE_COORD23_EXT',
    'GL_OUTPUT_TEXTURE_COORD24_EXT',
    'GL_OUTPUT_TEXTURE_COORD25_EXT',
    'GL_OUTPUT_TEXTURE_COORD26_EXT',
    'GL_OUTPUT_TEXTURE_COORD27_EXT',
    'GL_OUTPUT_TEXTURE_COORD28_EXT',
    'GL_OUTPUT_TEXTURE_COORD29_EXT',
    'GL_OUTPUT_TEXTURE_COORD2_EXT',
    'GL_OUTPUT_TEXTURE_COORD30_EXT',
    'GL_OUTPUT_TEXTURE_COORD31_EXT',
    'GL_OUTPUT_TEXTURE_COORD3_EXT',
    'GL_OUTPUT_TEXTURE_COORD4_EXT',
    'GL_OUTPUT_TEXTURE_COORD5_EXT',
    'GL_OUTPUT_TEXTURE_COORD6_EXT',
    'GL_OUTPUT_TEXTURE_COORD7_EXT',
    'GL_OUTPUT_TEXTURE_COORD8_EXT',
    'GL_OUTPUT_TEXTURE_COORD9_EXT',
    'GL_OUTPUT_VERTEX_EXT',
    'GL_OUT_OF_MEMORY',
    'GL_PACK_ALIGNMENT',
    'GL_PACK_CMYK_HINT_EXT',
    'GL_PACK_IMAGE_DEPTH_SGIS',
    'GL_PACK_IMAGE_HEIGHT',
    'GL_PACK_IMAGE_HEIGHT_EXT',
    'GL_PACK_INVERT_MESA',
    'GL_PACK_LSB_FIRST',
    'GL_PACK_RESAMPLE_OML',
    'GL_PACK_RESAMPLE_SGIX',
    'GL_PACK_ROW_LENGTH',
    'GL_PACK_SKIP_IMAGES',
    'GL_PACK_SKIP_IMAGES_EXT',
    'GL_PACK_SKIP_PIXELS',
    'GL_PACK_SKIP_ROWS',
    'GL_PACK_SKIP_VOLUMES_SGIS',
    'GL_PACK_SUBSAMPLE_RATE_SGIX',
    'GL_PACK_SWAP_BYTES',
    'GL_PARALLEL_ARRAYS_INTEL',
    'GL_PASS_THROUGH_NV',
    'GL_PASS_THROUGH_TOKEN',
    'GL_PERSPECTIVE_CORRECTION_HINT',
    'GL_PERTURB_EXT',
    'GL_PER_STAGE_CONSTANTS_NV',
    'GL_PHONG_HINT_WIN',
    'GL_PHONG_WIN',
    'GL_PIXEL_COUNTER_BITS_NV',
    'GL_PIXEL_COUNT_AVAILABLE_NV',
    'GL_PIXEL_COUNT_NV',
    'GL_PIXEL_CUBIC_WEIGHT_EXT',
    'GL_PIXEL_FRAGMENT_ALPHA_SOURCE_SGIS',
    'GL_PIXEL_FRAGMENT_RGB_SOURCE_SGIS',
    'GL_PIXEL_GROUP_COLOR_SGIS',
    'GL_PIXEL_MAG_FILTER_EXT',
    'GL_PIXEL_MAP_A_TO_A',
    'GL_PIXEL_MAP_A_TO_A_SIZE',
    'GL_PIXEL_MAP_B_TO_B',
    'GL_PIXEL_MAP_B_TO_B_SIZE',
    'GL_PIXEL_MAP_G_TO_G',
    'GL_PIXEL_MAP_G_TO_G_SIZE',
    'GL_PIXEL_MAP_I_TO_A',
    'GL_PIXEL_MAP_I_TO_A_SIZE',
    'GL_PIXEL_MAP_I_TO_B',
    'GL_PIXEL_MAP_I_TO_B_SIZE',
    'GL_PIXEL_MAP_I_TO_G',
    'GL_PIXEL_MAP_I_TO_G_SIZE',
    'GL_PIXEL_MAP_I_TO_I',
    'GL_PIXEL_MAP_I_TO_I_SIZE',
    'GL_PIXEL_MAP_I_TO_R',
    'GL_PIXEL_MAP_I_TO_R_SIZE',
    'GL_PIXEL_MAP_R_TO_R',
    'GL_PIXEL_MAP_R_TO_R_SIZE',
    'GL_PIXEL_MAP_S_TO_S',
    'GL_PIXEL_MAP_S_TO_S_SIZE',
    'GL_PIXEL_MIN_FILTER_EXT',
    'GL_PIXEL_MODE_BIT',
    'GL_PIXEL_PACK_BUFFER_ARB',
    'GL_PIXEL_PACK_BUFFER_BINDING_ARB',
    'GL_PIXEL_PACK_BUFFER_BINDING_EXT',
    'GL_PIXEL_PACK_BUFFER_EXT',
    'GL_PIXEL_SUBSAMPLE_2424_SGIX',
    'GL_PIXEL_SUBSAMPLE_4242_SGIX',
    'GL_PIXEL_SUBSAMPLE_4444_SGIX',
    'GL_PIXEL_TEXTURE_SGIS',
    'GL_PIXEL_TEX_GEN_ALPHA_LS_SGIX',
    'GL_PIXEL_TEX_GEN_ALPHA_MS_SGIX',
    'GL_PIXEL_TEX_GEN_ALPHA_NO_REPLACE_SGIX',
    'GL_PIXEL_TEX_GEN_ALPHA_REPLACE_SGIX',
    'GL_PIXEL_TEX_GEN_MODE_SGIX',
    'GL_PIXEL_TEX_GEN_Q_CEILING_SGIX',
    'GL_PIXEL_TEX_GEN_Q_FLOOR_SGIX',
    'GL_PIXEL_TEX_GEN_Q_ROUND_SGIX',
    'GL_PIXEL_TEX_GEN_SGIX',
    'GL_PIXEL_TILE_BEST_ALIGNMENT_SGIX',
    'GL_PIXEL_TILE_CACHE_INCREMENT_SGIX',
    'GL_PIXEL_TILE_CACHE_SIZE_SGIX',
    'GL_PIXEL_TILE_GRID_DEPTH_SGIX',
    'GL_PIXEL_TILE_GRID_HEIGHT_SGIX',
    'GL_PIXEL_TILE_GRID_WIDTH_SGIX',
    'GL_PIXEL_TILE_HEIGHT_SGIX',
    'GL_PIXEL_TILE_WIDTH_SGIX',
    'GL_PIXEL_TRANSFORM_2D_EXT',
    'GL_PIXEL_TRANSFORM_2D_MATRIX_EXT',
    'GL_PIXEL_TRANSFORM_2D_STACK_DEPTH_EXT',
    'GL_PIXEL_UNPACK_BUFFER_ARB',
    'GL_PIXEL_UNPACK_BUFFER_BINDING_ARB',
    'GL_PIXEL_UNPACK_BUFFER_BINDING_EXT',
    'GL_PIXEL_UNPACK_BUFFER_EXT',
    'GL_PN_TRIANGLES_ATI',
    'GL_PN_TRIANGLES_NORMAL_MODE_ATI',
    'GL_PN_TRIANGLES_NORMAL_MODE_LINEAR_ATI',
    'GL_PN_TRIANGLES_NORMAL_MODE_QUADRATIC_ATI',
    'GL_PN_TRIANGLES_POINT_MODE_ATI',
    'GL_PN_TRIANGLES_POINT_MODE_CUBIC_ATI',
    'GL_PN_TRIANGLES_POINT_MODE_LINEAR_ATI',
    'GL_PN_TRIANGLES_TESSELATION_LEVEL_ATI',
    'GL_POINT',
    'GL_POINTS',
    'GL_POINT_BIT',
    'GL_POINT_DISTANCE_ATTENUATION',
    'GL_POINT_DISTANCE_ATTENUATION_ARB',
    'GL_POINT_FADE_THRESHOLD_SIZE',
    'GL_POINT_FADE_THRESHOLD_SIZE_ARB',
    'GL_POINT_FADE_THRESHOLD_SIZE_EXT',
    'GL_POINT_FADE_THRESHOLD_SIZE_SGIS',
    'GL_POINT_SIZE',
    'GL_POINT_SIZE_MAX',
    'GL_POINT_SIZE_MAX_ARB',
    'GL_POINT_SIZE_MAX_EXT',
    'GL_POINT_SIZE_MAX_SGIS',
    'GL_POINT_SIZE_MIN',
    'GL_POINT_SIZE_MIN_ARB',
    'GL_POINT_SIZE_MIN_EXT',
    'GL_POINT_SIZE_MIN_SGIS',
    'GL_POINT_SMOOTH',
    'GL_POINT_SMOOTH_HINT',
    'GL_POINT_SPRITE',
    'GL_POINT_SPRITE_ARB',
    'GL_POINT_SPRITE_COORD_ORIGIN',
    'GL_POINT_SPRITE_NV',
    'GL_POINT_SPRITE_R_MODE_NV',
    'GL_POINT_TOKEN',
    'GL_POLYGON',
    'GL_POLYGON_BIT',
    'GL_POLYGON_MODE',
    'GL_POLYGON_OFFSET_BIAS_EXT',
    'GL_POLYGON_OFFSET_EXT',
    'GL_POLYGON_OFFSET_FACTOR',
    'GL_POLYGON_OFFSET_FACTOR_EXT',
    'GL_POLYGON_OFFSET_FILL',
    'GL_POLYGON_OFFSET_LINE',
    'GL_POLYGON_OFFSET_POINT',
    'GL_POLYGON_OFFSET_UNITS',
    'GL_POLYGON_SMOOTH',
    'GL_POLYGON_SMOOTH_HINT',
    'GL_POLYGON_STIPPLE',
    'GL_POLYGON_STIPPLE_BIT',
    'GL_POLYGON_TOKEN',
    'GL_POSITION',
    'GL_POST_COLOR_MATRIX_ALPHA_BIAS',
    'GL_POST_COLOR_MATRIX_ALPHA_BIAS_SGI',
    'GL_POST_COLOR_MATRIX_ALPHA_SCALE',
    'GL_POST_COLOR_MATRIX_ALPHA_SCALE_SGI',
    'GL_POST_COLOR_MATRIX_BLUE_BIAS',
    'GL_POST_COLOR_MATRIX_BLUE_BIAS_SGI',
    'GL_POST_COLOR_MATRIX_BLUE_SCALE',
    'GL_POST_COLOR_MATRIX_BLUE_SCALE_SGI',
    'GL_POST_COLOR_MATRIX_COLOR_TABLE',
    'GL_POST_COLOR_MATRIX_COLOR_TABLE_SGI',
    'GL_POST_COLOR_MATRIX_GREEN_BIAS',
    'GL_POST_COLOR_MATRIX_GREEN_BIAS_SGI',
    'GL_POST_COLOR_MATRIX_GREEN_SCALE',
    'GL_POST_COLOR_MATRIX_GREEN_SCALE_SGI',
    'GL_POST_COLOR_MATRIX_RED_BIAS',
    'GL_POST_COLOR_MATRIX_RED_BIAS_SGI',
    'GL_POST_COLOR_MATRIX_RED_SCALE',
    'GL_POST_COLOR_MATRIX_RED_SCALE_SGI',
    'GL_POST_CONVOLUTION_ALPHA_BIAS',
    'GL_POST_CONVOLUTION_ALPHA_BIAS_EXT',
    'GL_POST_CONVOLUTION_ALPHA_SCALE',
    'GL_POST_CONVOLUTION_ALPHA_SCALE_EXT',
    'GL_POST_CONVOLUTION_BLUE_BIAS',
    'GL_POST_CONVOLUTION_BLUE_BIAS_EXT',
    'GL_POST_CONVOLUTION_BLUE_SCALE',
    'GL_POST_CONVOLUTION_BLUE_SCALE_EXT',
    'GL_POST_CONVOLUTION_COLOR_TABLE',
    'GL_POST_CONVOLUTION_COLOR_TABLE_SGI',
    'GL_POST_CONVOLUTION_GREEN_BIAS',
    'GL_POST_CONVOLUTION_GREEN_BIAS_EXT',
    'GL_POST_CONVOLUTION_GREEN_SCALE',
    'GL_POST_CONVOLUTION_GREEN_SCALE_EXT',
    'GL_POST_CONVOLUTION_RED_BIAS',
    'GL_POST_CONVOLUTION_RED_BIAS_EXT',
    'GL_POST_CONVOLUTION_RED_SCALE',
    'GL_POST_CONVOLUTION_RED_SCALE_EXT',
    'GL_POST_IMAGE_TRANSFORM_COLOR_TABLE_HP',
    'GL_POST_TEXTURE_FILTER_BIAS_RANGE_SGIX',
    'GL_POST_TEXTURE_FILTER_BIAS_SGIX',
    'GL_POST_TEXTURE_FILTER_SCALE_RANGE_SGIX',
    'GL_POST_TEXTURE_FILTER_SCALE_SGIX',
    'GL_PREFER_DOUBLEBUFFER_HINT_PGI',
    'GL_PRESERVE_ATI',
    'GL_PREVIOUS',
    'GL_PREVIOUS_ARB',
    'GL_PREVIOUS_EXT',
    'GL_PREVIOUS_TEXTURE_INPUT_NV',
    'GL_PRIMARY_COLOR',
    'GL_PRIMARY_COLOR_ARB',
    'GL_PRIMARY_COLOR_EXT',
    'GL_PRIMARY_COLOR_NV',
    'GL_PRIMITIVE_RESTART_INDEX_NV',
    'GL_PRIMITIVE_RESTART_NV',
    'GL_PROGRAM_ADDRESS_REGISTERS_ARB',
    'GL_PROGRAM_ALU_INSTRUCTIONS_ARB',
    'GL_PROGRAM_ATTRIBS_ARB',
    'GL_PROGRAM_BINDING_ARB',
    'GL_PROGRAM_ERROR_POSITION_ARB',
    'GL_PROGRAM_ERROR_POSITION_NV',
    'GL_PROGRAM_ERROR_STRING_ARB',
    'GL_PROGRAM_ERROR_STRING_NV',
    'GL_PROGRAM_FORMAT_ARB',
    'GL_PROGRAM_FORMAT_ASCII_ARB',
    'GL_PROGRAM_INSTRUCTIONS_ARB',
    'GL_PROGRAM_LENGTH_ARB',
    'GL_PROGRAM_LENGTH_NV',
    'GL_PROGRAM_NATIVE_ADDRESS_REGISTERS_ARB',
    'GL_PROGRAM_NATIVE_ALU_INSTRUCTIONS_ARB',
    'GL_PROGRAM_NATIVE_ATTRIBS_ARB',
    'GL_PROGRAM_NATIVE_INSTRUCTIONS_ARB',
    'GL_PROGRAM_NATIVE_PARAMETERS_ARB',
    'GL_PROGRAM_NATIVE_TEMPORARIES_ARB',
    'GL_PROGRAM_NATIVE_TEX_INDIRECTIONS_ARB',
    'GL_PROGRAM_NATIVE_TEX_INSTRUCTIONS_ARB',
    'GL_PROGRAM_OBJECT_ARB',
    'GL_PROGRAM_PARAMETERS_ARB',
    'GL_PROGRAM_PARAMETER_NV',
    'GL_PROGRAM_RESIDENT_NV',
    'GL_PROGRAM_STRING_ARB',
    'GL_PROGRAM_STRING_NV',
    'GL_PROGRAM_TARGET_NV',
    'GL_PROGRAM_TEMPORARIES_ARB',
    'GL_PROGRAM_TEX_INDIRECTIONS_ARB',
    'GL_PROGRAM_TEX_INSTRUCTIONS_ARB',
    'GL_PROGRAM_UNDER_NATIVE_LIMITS_ARB',
    'GL_PROJECTION',
    'GL_PROJECTION_MATRIX',
    'GL_PROJECTION_STACK_DEPTH',
    'GL_PROXY_COLOR_TABLE',
    'GL_PROXY_COLOR_TABLE_SGI',
    'GL_PROXY_HISTOGRAM',
    'GL_PROXY_HISTOGRAM_EXT',
    'GL_PROXY_POST_COLOR_MATRIX_COLOR_TABLE',
    'GL_PROXY_POST_COLOR_MATRIX_COLOR_TABLE_SGI',
    'GL_PROXY_POST_CONVOLUTION_COLOR_TABLE',
    'GL_PROXY_POST_CONVOLUTION_COLOR_TABLE_SGI',
    'GL_PROXY_POST_IMAGE_TRANSFORM_COLOR_TABLE_HP',
    'GL_PROXY_TEXTURE_1D',
    'GL_PROXY_TEXTURE_1D_EXT',
    'GL_PROXY_TEXTURE_2D',
    'GL_PROXY_TEXTURE_2D_EXT',
    'GL_PROXY_TEXTURE_3D',
    'GL_PROXY_TEXTURE_3D_EXT',
    'GL_PROXY_TEXTURE_4D_SGIS',
    'GL_PROXY_TEXTURE_COLOR_TABLE_SGI',
    'GL_PROXY_TEXTURE_CUBE_MAP',
    'GL_PROXY_TEXTURE_CUBE_MAP_ARB',
    'GL_PROXY_TEXTURE_CUBE_MAP_EXT',
    'GL_PROXY_TEXTURE_RECTANGLE_ARB',
    'GL_PROXY_TEXTURE_RECTANGLE_NV',
    'GL_Q',
    'GL_QUADRATIC_ATTENUATION',
    'GL_QUADS',
    'GL_QUAD_ALPHA4_SGIS',
    'GL_QUAD_ALPHA8_SGIS',
    'GL_QUAD_INTENSITY4_SGIS',
    'GL_QUAD_INTENSITY8_SGIS',
    'GL_QUAD_LUMINANCE4_SGIS',
    'GL_QUAD_LUMINANCE8_SGIS',
    'GL_QUAD_MESH_SUN',
    'GL_QUAD_STRIP',
    'GL_QUAD_TEXTURE_SELECT_SGIS',
    'GL_QUARTER_BIT_ATI',
    'GL_QUERY_COUNTER_BITS',
    'GL_QUERY_COUNTER_BITS_ARB',
    'GL_QUERY_RESULT',
    'GL_QUERY_RESULT_ARB',
    'GL_QUERY_RESULT_AVAILABLE',
    'GL_QUERY_RESULT_AVAILABLE_ARB',
    'GL_R',
    'GL_R1UI_C3F_V3F_SUN',
    'GL_R1UI_C4F_N3F_V3F_SUN',
    'GL_R1UI_C4UB_V3F_SUN',
    'GL_R1UI_N3F_V3F_SUN',
    'GL_R1UI_T2F_C4F_N3F_V3F_SUN',
    'GL_R1UI_T2F_N3F_V3F_SUN',
    'GL_R1UI_T2F_V3F_SUN',
    'GL_R1UI_V3F_SUN',
    'GL_R3_G3_B2',
    'GL_RASTER_POSITION_UNCLIPPED_IBM',
    'GL_READ_BUFFER',
    'GL_READ_ONLY',
    'GL_READ_ONLY_ARB',
    'GL_READ_PIXEL_DATA_RANGE_LENGTH_NV',
    'GL_READ_PIXEL_DATA_RANGE_NV',
    'GL_READ_PIXEL_DATA_RANGE_POINTER_NV',
    'GL_READ_WRITE',
    'GL_READ_WRITE_ARB',
    'GL_RECLAIM_MEMORY_HINT_PGI',
    'GL_RED',
    'GL_REDUCE',
    'GL_REDUCE_EXT',
    'GL_RED_BIAS',
    'GL_RED_BITS',
    'GL_RED_BIT_ATI',
    'GL_RED_MAX_CLAMP_INGR',
    'GL_RED_MIN_CLAMP_INGR',
    'GL_RED_SCALE',
    'GL_REFERENCE_PLANE_EQUATION_SGIX',
    'GL_REFERENCE_PLANE_SGIX',
    'GL_REFLECTION_MAP',
    'GL_REFLECTION_MAP_ARB',
    'GL_REFLECTION_MAP_EXT',
    'GL_REFLECTION_MAP_NV',
    'GL_REGISTER_COMBINERS_NV',
    'GL_REG_0_ATI',
    'GL_REG_10_ATI',
    'GL_REG_11_ATI',
    'GL_REG_12_ATI',
    'GL_REG_13_ATI',
    'GL_REG_14_ATI',
    'GL_REG_15_ATI',
    'GL_REG_16_ATI',
    'GL_REG_17_ATI',
    'GL_REG_18_ATI',
    'GL_REG_19_ATI',
    'GL_REG_1_ATI',
    'GL_REG_20_ATI',
    'GL_REG_21_ATI',
    'GL_REG_22_ATI',
    'GL_REG_23_ATI',
    'GL_REG_24_ATI',
    'GL_REG_25_ATI',
    'GL_REG_26_ATI',
    'GL_REG_27_ATI',
    'GL_REG_28_ATI',
    'GL_REG_29_ATI',
    'GL_REG_2_ATI',
    'GL_REG_30_ATI',
    'GL_REG_31_ATI',
    'GL_REG_3_ATI',
    'GL_REG_4_ATI',
    'GL_REG_5_ATI',
    'GL_REG_6_ATI',
    'GL_REG_7_ATI',
    'GL_REG_8_ATI',
    'GL_REG_9_ATI',
    'GL_RENDER',
    'GL_RENDERBUFFER_ALPHA_SIZE_EXT',
    'GL_RENDERBUFFER_BINDING_EXT',
    'GL_RENDERBUFFER_BLUE_SIZE_EXT',
    'GL_RENDERBUFFER_DEPTH_SIZE_EXT',
    'GL_RENDERBUFFER_EXT',
    'GL_RENDERBUFFER_GREEN_SIZE_EXT',
    'GL_RENDERBUFFER_HEIGHT_EXT',
    'GL_RENDERBUFFER_INTERNAL_FORMAT_EXT',
    'GL_RENDERBUFFER_RED_SIZE_EXT',
    'GL_RENDERBUFFER_STENCIL_SIZE_EXT',
    'GL_RENDERBUFFER_WIDTH_EXT',
    'GL_RENDERER',
    'GL_RENDER_MODE',
    'GL_REPEAT',
    'GL_REPLACE',
    'GL_REPLACEMENT_CODE_ARRAY_POINTER_SUN',
    'GL_REPLACEMENT_CODE_ARRAY_STRIDE_SUN',
    'GL_REPLACEMENT_CODE_ARRAY_SUN',
    'GL_REPLACEMENT_CODE_ARRAY_TYPE_SUN',
    'GL_REPLACEMENT_CODE_SUN',
    'GL_REPLACE_EXT',
    'GL_REPLACE_MIDDLE_SUN',
    'GL_REPLACE_OLDEST_SUN',
    'GL_REPLICATE_BORDER',
    'GL_REPLICATE_BORDER_HP',
    'GL_RESAMPLE_AVERAGE_OML',
    'GL_RESAMPLE_DECIMATE_OML',
    'GL_RESAMPLE_DECIMATE_SGIX',
    'GL_RESAMPLE_REPLICATE_OML',
    'GL_RESAMPLE_REPLICATE_SGIX',
    'GL_RESAMPLE_ZERO_FILL_OML',
    'GL_RESAMPLE_ZERO_FILL_SGIX',
    'GL_RESCALE_NORMAL',
    'GL_RESCALE_NORMAL_EXT',
    'GL_RESTART_SUN',
    'GL_RETURN',
    'GL_RGB',
    'GL_RGB10',
    'GL_RGB10_A2',
    'GL_RGB10_A2_EXT',
    'GL_RGB10_EXT',
    'GL_RGB12',
    'GL_RGB12_EXT',
    'GL_RGB16',
    'GL_RGB16F_ARB',
    'GL_RGB16_EXT',
    'GL_RGB2_EXT',
    'GL_RGB32F_ARB',
    'GL_RGB4',
    'GL_RGB4_EXT',
    'GL_RGB4_S3TC',
    'GL_RGB5',
    'GL_RGB5_A1',
    'GL_RGB5_A1_EXT',
    'GL_RGB5_EXT',
    'GL_RGB8',
    'GL_RGB8_EXT',
    'GL_RGBA',
    'GL_RGBA12',
    'GL_RGBA12_EXT',
    'GL_RGBA16',
    'GL_RGBA16F_ARB',
    'GL_RGBA16_EXT',
    'GL_RGBA2',
    'GL_RGBA2_EXT',
    'GL_RGBA32F_ARB',
    'GL_RGBA4',
    'GL_RGBA4_EXT',
    'GL_RGBA4_S3TC',
    'GL_RGBA8',
    'GL_RGBA8_EXT',
    'GL_RGBA_FLOAT16_ATI',
    'GL_RGBA_FLOAT32_ATI',
    'GL_RGBA_FLOAT_MODE_ARB',
    'GL_RGBA_MODE',
    'GL_RGBA_S3TC',
    'GL_RGBA_UNSIGNED_DOT_PRODUCT_MAPPING_NV',
    'GL_RGB_FLOAT16_ATI',
    'GL_RGB_FLOAT32_ATI',
    'GL_RGB_S3TC',
    'GL_RGB_SCALE',
    'GL_RGB_SCALE_ARB',
    'GL_RGB_SCALE_EXT',
    'GL_RIGHT',
    'GL_S',
    'GL_SAMPLER_1D',
    'GL_SAMPLER_1D_ARB',
    'GL_SAMPLER_1D_SHADOW',
    'GL_SAMPLER_1D_SHADOW_ARB',
    'GL_SAMPLER_2D',
    'GL_SAMPLER_2D_ARB',
    'GL_SAMPLER_2D_RECT_ARB',
    'GL_SAMPLER_2D_RECT_SHADOW_ARB',
    'GL_SAMPLER_2D_SHADOW',
    'GL_SAMPLER_2D_SHADOW_ARB',
    'GL_SAMPLER_3D',
    'GL_SAMPLER_3D_ARB',
    'GL_SAMPLER_CUBE',
    'GL_SAMPLER_CUBE_ARB',
    'GL_SAMPLES',
    'GL_SAMPLES_3DFX',
    'GL_SAMPLES_ARB',
    'GL_SAMPLES_EXT',
    'GL_SAMPLES_PASSED',
    'GL_SAMPLES_PASSED_ARB',
    'GL_SAMPLES_SGIS',
    'GL_SAMPLE_ALPHA_TO_COVERAGE',
    'GL_SAMPLE_ALPHA_TO_COVERAGE_ARB',
    'GL_SAMPLE_ALPHA_TO_MASK_EXT',
    'GL_SAMPLE_ALPHA_TO_MASK_SGIS',
    'GL_SAMPLE_ALPHA_TO_ONE',
    'GL_SAMPLE_ALPHA_TO_ONE_ARB',
    'GL_SAMPLE_ALPHA_TO_ONE_EXT',
    'GL_SAMPLE_ALPHA_TO_ONE_SGIS',
    'GL_SAMPLE_BUFFERS',
    'GL_SAMPLE_BUFFERS_3DFX',
    'GL_SAMPLE_BUFFERS_ARB',
    'GL_SAMPLE_BUFFERS_EXT',
    'GL_SAMPLE_BUFFERS_SGIS',
    'GL_SAMPLE_COVERAGE',
    'GL_SAMPLE_COVERAGE_ARB',
    'GL_SAMPLE_COVERAGE_INVERT',
    'GL_SAMPLE_COVERAGE_INVERT_ARB',
    'GL_SAMPLE_COVERAGE_VALUE',
    'GL_SAMPLE_COVERAGE_VALUE_ARB',
    'GL_SAMPLE_MASK_EXT',
    'GL_SAMPLE_MASK_INVERT_EXT',
    'GL_SAMPLE_MASK_INVERT_SGIS',
    'GL_SAMPLE_MASK_SGIS',
    'GL_SAMPLE_MASK_VALUE_EXT',
    'GL_SAMPLE_MASK_VALUE_SGIS',
    'GL_SAMPLE_PATTERN_EXT',
    'GL_SAMPLE_PATTERN_SGIS',
    'GL_SATURATE_BIT_ATI',
    'GL_SCALAR_EXT',
    'GL_SCALEBIAS_HINT_SGIX',
    'GL_SCALE_BY_FOUR_NV',
    'GL_SCALE_BY_ONE_HALF_NV',
    'GL_SCALE_BY_TWO_NV',
    'GL_SCISSOR_BIT',
    'GL_SCISSOR_BOX',
    'GL_SCISSOR_TEST',
    'GL_SCREEN_COORDINATES_REND',
    'GL_SECONDARY_COLOR_ARRAY',
    'GL_SECONDARY_COLOR_ARRAY_BUFFER_BINDING',
    'GL_SECONDARY_COLOR_ARRAY_BUFFER_BINDING_ARB',
    'GL_SECONDARY_COLOR_ARRAY_EXT',
    'GL_SECONDARY_COLOR_ARRAY_LIST_IBM',
    'GL_SECONDARY_COLOR_ARRAY_LIST_STRIDE_IBM',
    'GL_SECONDARY_COLOR_ARRAY_POINTER',
    'GL_SECONDARY_COLOR_ARRAY_POINTER_EXT',
    'GL_SECONDARY_COLOR_ARRAY_SIZE',
    'GL_SECONDARY_COLOR_ARRAY_SIZE_EXT',
    'GL_SECONDARY_COLOR_ARRAY_STRIDE',
    'GL_SECONDARY_COLOR_ARRAY_STRIDE_EXT',
    'GL_SECONDARY_COLOR_ARRAY_TYPE',
    'GL_SECONDARY_COLOR_ARRAY_TYPE_EXT',
    'GL_SECONDARY_COLOR_NV',
    'GL_SECONDARY_INTERPOLATOR_ATI',
    'GL_SELECT',
    'GL_SELECTION_BUFFER_POINTER',
    'GL_SELECTION_BUFFER_SIZE',
    'GL_SEPARABLE_2D',
    'GL_SEPARABLE_2D_EXT',
    'GL_SEPARATE_SPECULAR_COLOR',
    'GL_SEPARATE_SPECULAR_COLOR_EXT',
    'GL_SET',
    'GL_SHADER_CONSISTENT_NV',
    'GL_SHADER_OBJECT_ARB',
    'GL_SHADER_OPERATION_NV',
    'GL_SHADER_SOURCE_LENGTH',
    'GL_SHADER_TYPE',
    'GL_SHADE_MODEL',
    'GL_SHADING_LANGUAGE_VERSION',
    'GL_SHADING_LANGUAGE_VERSION_ARB',
    'GL_SHADOW_AMBIENT_SGIX',
    'GL_SHADOW_ATTENUATION_EXT',
    'GL_SHARED_TEXTURE_PALETTE_EXT',
    'GL_SHARPEN_TEXTURE_FUNC_POINTS_SGIS',
    'GL_SHININESS',
    'GL_SHORT',
    'GL_SIGNED_ALPHA8_NV',
    'GL_SIGNED_ALPHA_NV',
    'GL_SIGNED_HILO16_NV',
    'GL_SIGNED_HILO8_NV',
    'GL_SIGNED_HILO_NV',
    'GL_SIGNED_IDENTITY_NV',
    'GL_SIGNED_INTENSITY8_NV',
    'GL_SIGNED_INTENSITY_NV',
    'GL_SIGNED_LUMINANCE8_ALPHA8_NV',
    'GL_SIGNED_LUMINANCE8_NV',
    'GL_SIGNED_LUMINANCE_ALPHA_NV',
    'GL_SIGNED_LUMINANCE_NV',
    'GL_SIGNED_NEGATE_NV',
    'GL_SIGNED_RGB8_NV',
    'GL_SIGNED_RGB8_UNSIGNED_ALPHA8_NV',
    'GL_SIGNED_RGBA8_NV',
    'GL_SIGNED_RGBA_NV',
    'GL_SIGNED_RGB_NV',
    'GL_SIGNED_RGB_UNSIGNED_ALPHA_NV',
    'GL_SINGLE_COLOR',
    'GL_SINGLE_COLOR_EXT',
    'GL_SLICE_ACCUM_SUN',
    'GL_SMOOTH',
    'GL_SMOOTH_LINE_WIDTH_GRANULARITY',
    'GL_SMOOTH_LINE_WIDTH_RANGE',
    'GL_SMOOTH_POINT_SIZE_GRANULARITY',
    'GL_SMOOTH_POINT_SIZE_RANGE',
    'GL_SOURCE0_ALPHA',
    'GL_SOURCE0_ALPHA_ARB',
    'GL_SOURCE0_ALPHA_EXT',
    'GL_SOURCE0_RGB',
    'GL_SOURCE0_RGB_ARB',
    'GL_SOURCE0_RGB_EXT',
    'GL_SOURCE1_ALPHA',
    'GL_SOURCE1_ALPHA_ARB',
    'GL_SOURCE1_ALPHA_EXT',
    'GL_SOURCE1_RGB',
    'GL_SOURCE1_RGB_ARB',
    'GL_SOURCE1_RGB_EXT',
    'GL_SOURCE2_ALPHA',
    'GL_SOURCE2_ALPHA_ARB',
    'GL_SOURCE2_ALPHA_EXT',
    'GL_SOURCE2_RGB',
    'GL_SOURCE2_RGB_ARB',
    'GL_SOURCE2_RGB_EXT',
    'GL_SOURCE3_ALPHA_NV',
    'GL_SOURCE3_RGB_NV',
    'GL_SPARE0_NV',
    'GL_SPARE0_PLUS_SECONDARY_COLOR_NV',
    'GL_SPARE1_NV',
    'GL_SPECULAR',
    'GL_SPHERE_MAP',
    'GL_SPOT_CUTOFF',
    'GL_SPOT_DIRECTION',
    'GL_SPOT_EXPONENT',
    'GL_SPRITE_AXIAL_SGIX',
    'GL_SPRITE_AXIS_SGIX',
    'GL_SPRITE_EYE_ALIGNED_SGIX',
    'GL_SPRITE_MODE_SGIX',
    'GL_SPRITE_OBJECT_ALIGNED_SGIX',
    'GL_SPRITE_SGIX',
    'GL_SPRITE_TRANSLATION_SGIX',
    'GL_SRC_ALPHA',
    'GL_SRC_ALPHA_SATURATE',
    'GL_SRC_COLOR',
    'GL_STACK_OVERFLOW',
    'GL_STACK_UNDERFLOW',
    'GL_STATIC_ATI',
    'GL_STATIC_COPY',
    'GL_STATIC_COPY_ARB',
    'GL_STATIC_DRAW',
    'GL_STATIC_DRAW_ARB',
    'GL_STATIC_READ',
    'GL_STATIC_READ_ARB',
    'GL_STENCIL',
    'GL_STENCIL_ATTACHMENT_EXT',
    'GL_STENCIL_BACK_FAIL',
    'GL_STENCIL_BACK_FAIL_ATI',
    'GL_STENCIL_BACK_FUNC',
    'GL_STENCIL_BACK_FUNC_ATI',
    'GL_STENCIL_BACK_PASS_DEPTH_FAIL',
    'GL_STENCIL_BACK_PASS_DEPTH_FAIL_ATI',
    'GL_STENCIL_BACK_PASS_DEPTH_PASS',
    'GL_STENCIL_BACK_PASS_DEPTH_PASS_ATI',
    'GL_STENCIL_BACK_REF',
    'GL_STENCIL_BACK_VALUE_MASK',
    'GL_STENCIL_BACK_WRITEMASK',
    'GL_STENCIL_BITS',
    'GL_STENCIL_BUFFER_BIT',
    'GL_STENCIL_CLEAR_VALUE',
    'GL_STENCIL_FAIL',
    'GL_STENCIL_FUNC',
    'GL_STENCIL_INDEX',
    'GL_STENCIL_INDEX16_EXT',
    'GL_STENCIL_INDEX1_EXT',
    'GL_STENCIL_INDEX4_EXT',
    'GL_STENCIL_INDEX8_EXT',
    'GL_STENCIL_PASS_DEPTH_FAIL',
    'GL_STENCIL_PASS_DEPTH_PASS',
    'GL_STENCIL_REF',
    'GL_STENCIL_TEST',
    'GL_STENCIL_TEST_TWO_SIDE_EXT',
    'GL_STENCIL_VALUE_MASK',
    'GL_STENCIL_WRITEMASK',
    'GL_STEREO',
    'GL_STORAGE_CACHED_APPLE',
    'GL_STORAGE_SHARED_APPLE',
    'GL_STREAM_COPY',
    'GL_STREAM_COPY_ARB',
    'GL_STREAM_DRAW',
    'GL_STREAM_DRAW_ARB',
    'GL_STREAM_READ',
    'GL_STREAM_READ_ARB',
    'GL_STRICT_DEPTHFUNC_HINT_PGI',
    'GL_STRICT_LIGHTING_HINT_PGI',
    'GL_STRICT_SCISSOR_HINT_PGI',
    'GL_SUBPIXEL_BITS',
    'GL_SUBTRACT',
    'GL_SUBTRACT_ARB',
    'GL_SUB_ATI',
    'GL_SWIZZLE_STQ_ATI',
    'GL_SWIZZLE_STQ_DQ_ATI',
    'GL_SWIZZLE_STRQ_ATI',
    'GL_SWIZZLE_STRQ_DQ_ATI',
    'GL_SWIZZLE_STR_ATI',
    'GL_SWIZZLE_STR_DR_ATI',
    'GL_T',
    'GL_T2F_C3F_V3F',
    'GL_T2F_C4F_N3F_V3F',
    'GL_T2F_C4UB_V3F',
    'GL_T2F_IUI_N3F_V2F_EXT',
    'GL_T2F_IUI_N3F_V3F_EXT',
    'GL_T2F_IUI_V2F_EXT',
    'GL_T2F_IUI_V3F_EXT',
    'GL_T2F_N3F_V3F',
    'GL_T2F_V3F',
    'GL_T4F_C4F_N3F_V4F',
    'GL_T4F_V4F',
    'GL_TABLE_TOO_LARGE',
    'GL_TABLE_TOO_LARGE_EXT',
    'GL_TANGENT_ARRAY_EXT',
    'GL_TANGENT_ARRAY_POINTER_EXT',
    'GL_TANGENT_ARRAY_STRIDE_EXT',
    'GL_TANGENT_ARRAY_TYPE_EXT',
    'GL_TEXCOORD1_BIT_PGI',
    'GL_TEXCOORD2_BIT_PGI',
    'GL_TEXCOORD3_BIT_PGI',
    'GL_TEXCOORD4_BIT_PGI',
    'GL_TEXTURE',
    'GL_TEXTURE0',
    'GL_TEXTURE0_ARB',
    'GL_TEXTURE1',
    'GL_TEXTURE10',
    'GL_TEXTURE10_ARB',
    'GL_TEXTURE11',
    'GL_TEXTURE11_ARB',
    'GL_TEXTURE12',
    'GL_TEXTURE12_ARB',
    'GL_TEXTURE13',
    'GL_TEXTURE13_ARB',
    'GL_TEXTURE14',
    'GL_TEXTURE14_ARB',
    'GL_TEXTURE15',
    'GL_TEXTURE15_ARB',
    'GL_TEXTURE16',
    'GL_TEXTURE16_ARB',
    'GL_TEXTURE17',
    'GL_TEXTURE17_ARB',
    'GL_TEXTURE18',
    'GL_TEXTURE18_ARB',
    'GL_TEXTURE19',
    'GL_TEXTURE19_ARB',
    'GL_TEXTURE1_ARB',
    'GL_TEXTURE2',
    'GL_TEXTURE20',
    'GL_TEXTURE20_ARB',
    'GL_TEXTURE21',
    'GL_TEXTURE21_ARB',
    'GL_TEXTURE22',
    'GL_TEXTURE22_ARB',
    'GL_TEXTURE23',
    'GL_TEXTURE23_ARB',
    'GL_TEXTURE24',
    'GL_TEXTURE24_ARB',
    'GL_TEXTURE25',
    'GL_TEXTURE25_ARB',
    'GL_TEXTURE26',
    'GL_TEXTURE26_ARB',
    'GL_TEXTURE27',
    'GL_TEXTURE27_ARB',
    'GL_TEXTURE28',
    'GL_TEXTURE28_ARB',
    'GL_TEXTURE29',
    'GL_TEXTURE29_ARB',
    'GL_TEXTURE2_ARB',
    'GL_TEXTURE3',
    'GL_TEXTURE30',
    'GL_TEXTURE30_ARB',
    'GL_TEXTURE31',
    'GL_TEXTURE31_ARB',
    'GL_TEXTURE3_ARB',
    'GL_TEXTURE4',
    'GL_TEXTURE4_ARB',
    'GL_TEXTURE5',
    'GL_TEXTURE5_ARB',
    'GL_TEXTURE6',
    'GL_TEXTURE6_ARB',
    'GL_TEXTURE7',
    'GL_TEXTURE7_ARB',
    'GL_TEXTURE8',
    'GL_TEXTURE8_ARB',
    'GL_TEXTURE9',
    'GL_TEXTURE9_ARB',
    'GL_TEXTURE_1D',
    'GL_TEXTURE_1D_BINDING_EXT',
    'GL_TEXTURE_2D',
    'GL_TEXTURE_2D_BINDING_EXT',
    'GL_TEXTURE_3D',
    'GL_TEXTURE_3D_BINDING_EXT',
    'GL_TEXTURE_3D_EXT',
    'GL_TEXTURE_4DSIZE_SGIS',
    'GL_TEXTURE_4D_BINDING_SGIS',
    'GL_TEXTURE_4D_SGIS',
    'GL_TEXTURE_ALPHA_SIZE',
    'GL_TEXTURE_ALPHA_SIZE_EXT',
    'GL_TEXTURE_ALPHA_TYPE_ARB',
    'GL_TEXTURE_APPLICATION_MODE_EXT',
    'GL_TEXTURE_BASE_LEVEL',
    'GL_TEXTURE_BASE_LEVEL_SGIS',
    'GL_TEXTURE_BINDING_1D',
    'GL_TEXTURE_BINDING_2D',
    'GL_TEXTURE_BINDING_3D',
    'GL_TEXTURE_BINDING_CUBE_MAP',
    'GL_TEXTURE_BINDING_CUBE_MAP_ARB',
    'GL_TEXTURE_BINDING_CUBE_MAP_EXT',
    'GL_TEXTURE_BINDING_RECTANGLE_ARB',
    'GL_TEXTURE_BINDING_RECTANGLE_NV',
    'GL_TEXTURE_BIT',
    'GL_TEXTURE_BLUE_SIZE',
    'GL_TEXTURE_BLUE_SIZE_EXT',
    'GL_TEXTURE_BLUE_TYPE_ARB',
    'GL_TEXTURE_BORDER',
    'GL_TEXTURE_BORDER_COLOR',
    'GL_TEXTURE_BORDER_VALUES_NV',
    'GL_TEXTURE_CLIPMAP_CENTER_SGIX',
    'GL_TEXTURE_CLIPMAP_DEPTH_SGIX',
    'GL_TEXTURE_CLIPMAP_FRAME_SGIX',
    'GL_TEXTURE_CLIPMAP_LOD_OFFSET_SGIX',
    'GL_TEXTURE_CLIPMAP_OFFSET_SGIX',
    'GL_TEXTURE_CLIPMAP_VIRTUAL_DEPTH_SGIX',
    'GL_TEXTURE_COLOR_TABLE_SGI',
    'GL_TEXTURE_COLOR_WRITEMASK_SGIS',
    'GL_TEXTURE_COMPARE_FAIL_VALUE_ARB',
    'GL_TEXTURE_COMPARE_FUNC',
    'GL_TEXTURE_COMPARE_FUNC_ARB',
    'GL_TEXTURE_COMPARE_MODE',
    'GL_TEXTURE_COMPARE_MODE_ARB',
    'GL_TEXTURE_COMPARE_OPERATOR_SGIX',
    'GL_TEXTURE_COMPARE_SGIX',
    'GL_TEXTURE_COMPRESSED',
    'GL_TEXTURE_COMPRESSED_ARB',
    'GL_TEXTURE_COMPRESSED_IMAGE_SIZE',
    'GL_TEXTURE_COMPRESSED_IMAGE_SIZE_ARB',
    'GL_TEXTURE_COMPRESSION_HINT',
    'GL_TEXTURE_COMPRESSION_HINT_ARB',
    'GL_TEXTURE_CONSTANT_DATA_SUNX',
    'GL_TEXTURE_COORD_ARRAY',
    'GL_TEXTURE_COORD_ARRAY_BUFFER_BINDING',
    'GL_TEXTURE_COORD_ARRAY_BUFFER_BINDING_ARB',
    'GL_TEXTURE_COORD_ARRAY_COUNT_EXT',
    'GL_TEXTURE_COORD_ARRAY_EXT',
    'GL_TEXTURE_COORD_ARRAY_LIST_IBM',
    'GL_TEXTURE_COORD_ARRAY_LIST_STRIDE_IBM',
    'GL_TEXTURE_COORD_ARRAY_PARALLEL_POINTERS_INTEL',
    'GL_TEXTURE_COORD_ARRAY_POINTER',
    'GL_TEXTURE_COORD_ARRAY_POINTER_EXT',
    'GL_TEXTURE_COORD_ARRAY_SIZE',
    'GL_TEXTURE_COORD_ARRAY_SIZE_EXT',
    'GL_TEXTURE_COORD_ARRAY_STRIDE',
    'GL_TEXTURE_COORD_ARRAY_STRIDE_EXT',
    'GL_TEXTURE_COORD_ARRAY_TYPE',
    'GL_TEXTURE_COORD_ARRAY_TYPE_EXT',
    'GL_TEXTURE_CUBE_MAP',
    'GL_TEXTURE_CUBE_MAP_ARB',
    'GL_TEXTURE_CUBE_MAP_EXT',
    'GL_TEXTURE_CUBE_MAP_NEGATIVE_X',
    'GL_TEXTURE_CUBE_MAP_NEGATIVE_X_ARB',
    'GL_TEXTURE_CUBE_MAP_NEGATIVE_X_EXT',
    'GL_TEXTURE_CUBE_MAP_NEGATIVE_Y',
    'GL_TEXTURE_CUBE_MAP_NEGATIVE_Y_ARB',
    'GL_TEXTURE_CUBE_MAP_NEGATIVE_Y_EXT',
    'GL_TEXTURE_CUBE_MAP_NEGATIVE_Z',
    'GL_TEXTURE_CUBE_MAP_NEGATIVE_Z_ARB',
    'GL_TEXTURE_CUBE_MAP_NEGATIVE_Z_EXT',
    'GL_TEXTURE_CUBE_MAP_POSITIVE_X',
    'GL_TEXTURE_CUBE_MAP_POSITIVE_X_ARB',
    'GL_TEXTURE_CUBE_MAP_POSITIVE_X_EXT',
    'GL_TEXTURE_CUBE_MAP_POSITIVE_Y',
    'GL_TEXTURE_CUBE_MAP_POSITIVE_Y_ARB',
    'GL_TEXTURE_CUBE_MAP_POSITIVE_Y_EXT',
    'GL_TEXTURE_CUBE_MAP_POSITIVE_Z',
    'GL_TEXTURE_CUBE_MAP_POSITIVE_Z_ARB',
    'GL_TEXTURE_CUBE_MAP_POSITIVE_Z_EXT',
    'GL_TEXTURE_DEFORMATION_BIT_SGIX',
    'GL_TEXTURE_DEFORMATION_SGIX',
    'GL_TEXTURE_DEPTH',
    'GL_TEXTURE_DEPTH_EXT',
    'GL_TEXTURE_DEPTH_SIZE',
    'GL_TEXTURE_DEPTH_SIZE_ARB',
    'GL_TEXTURE_DEPTH_TYPE_ARB',
    'GL_TEXTURE_DS_SIZE_NV',
    'GL_TEXTURE_DT_SIZE_NV',
    'GL_TEXTURE_ENV',
    'GL_TEXTURE_ENV_BIAS_SGIX',
    'GL_TEXTURE_ENV_COLOR',
    'GL_TEXTURE_ENV_MODE',
    'GL_TEXTURE_FILTER4_SIZE_SGIS',
    'GL_TEXTURE_FILTER_CONTROL',
    'GL_TEXTURE_FILTER_CONTROL_EXT',
    'GL_TEXTURE_FLOAT_COMPONENTS_NV',
    'GL_TEXTURE_GEN_MODE',
    'GL_TEXTURE_GEN_Q',
    'GL_TEXTURE_GEN_R',
    'GL_TEXTURE_GEN_S',
    'GL_TEXTURE_GEN_T',
    'GL_TEXTURE_GEQUAL_R_SGIX',
    'GL_TEXTURE_GREEN_SIZE',
    'GL_TEXTURE_GREEN_SIZE_EXT',
    'GL_TEXTURE_GREEN_TYPE_ARB',
    'GL_TEXTURE_HEIGHT',
    'GL_TEXTURE_HI_SIZE_NV',
    'GL_TEXTURE_INDEX_SIZE_EXT',
    'GL_TEXTURE_INTENSITY_SIZE',
    'GL_TEXTURE_INTENSITY_SIZE_EXT',
    'GL_TEXTURE_INTENSITY_TYPE_ARB',
    'GL_TEXTURE_INTERNAL_FORMAT',
    'GL_TEXTURE_LEQUAL_R_SGIX',
    'GL_TEXTURE_LIGHTING_MODE_HP',
    'GL_TEXTURE_LIGHT_EXT',
    'GL_TEXTURE_LOD_BIAS',
    'GL_TEXTURE_LOD_BIAS_EXT',
    'GL_TEXTURE_LOD_BIAS_R_SGIX',
    'GL_TEXTURE_LOD_BIAS_S_SGIX',
    'GL_TEXTURE_LOD_BIAS_T_SGIX',
    'GL_TEXTURE_LO_SIZE_NV',
    'GL_TEXTURE_LUMINANCE_SIZE',
    'GL_TEXTURE_LUMINANCE_SIZE_EXT',
    'GL_TEXTURE_LUMINANCE_TYPE_ARB',
    'GL_TEXTURE_MAG_FILTER',
    'GL_TEXTURE_MAG_SIZE_NV',
    'GL_TEXTURE_MATERIAL_FACE_EXT',
    'GL_TEXTURE_MATERIAL_PARAMETER_EXT',
    'GL_TEXTURE_MATRIX',
    'GL_TEXTURE_MAX_ANISOTROPY_EXT',
    'GL_TEXTURE_MAX_CLAMP_R_SGIX',
    'GL_TEXTURE_MAX_CLAMP_S_SGIX',
    'GL_TEXTURE_MAX_CLAMP_T_SGIX',
    'GL_TEXTURE_MAX_LEVEL',
    'GL_TEXTURE_MAX_LEVEL_SGIS',
    'GL_TEXTURE_MAX_LOD',
    'GL_TEXTURE_MAX_LOD_SGIS',
    'GL_TEXTURE_MIN_FILTER',
    'GL_TEXTURE_MIN_LOD',
    'GL_TEXTURE_MIN_LOD_SGIS',
    'GL_TEXTURE_MULTI_BUFFER_HINT_SGIX',
    'GL_TEXTURE_NORMAL_EXT',
    'GL_TEXTURE_POST_SPECULAR_HP',
    'GL_TEXTURE_PRE_SPECULAR_HP',
    'GL_TEXTURE_PRIORITY',
    'GL_TEXTURE_PRIORITY_EXT',
    'GL_TEXTURE_RECTANGLE_ARB',
    'GL_TEXTURE_RECTANGLE_NV',
    'GL_TEXTURE_RED_SIZE',
    'GL_TEXTURE_RED_SIZE_EXT',
    'GL_TEXTURE_RED_TYPE_ARB',
    'GL_TEXTURE_RESIDENT',
    'GL_TEXTURE_RESIDENT_EXT',
    'GL_TEXTURE_SHADER_NV',
    'GL_TEXTURE_STACK_DEPTH',
    'GL_TEXTURE_TOO_LARGE_EXT',
    'GL_TEXTURE_UNSIGNED_REMAP_MODE_NV',
    'GL_TEXTURE_WIDTH',
    'GL_TEXTURE_WRAP_Q_SGIS',
    'GL_TEXTURE_WRAP_R',
    'GL_TEXTURE_WRAP_R_EXT',
    'GL_TEXTURE_WRAP_S',
    'GL_TEXTURE_WRAP_T',
    'GL_TEXT_FRAGMENT_SHADER_ATI',
    'GL_TRACK_MATRIX_NV',
    'GL_TRACK_MATRIX_TRANSFORM_NV',
    'GL_TRANSFORM_BIT',
    'GL_TRANSFORM_HINT_APPLE',
    'GL_TRANSPOSE_COLOR_MATRIX',
    'GL_TRANSPOSE_COLOR_MATRIX_ARB',
    'GL_TRANSPOSE_CURRENT_MATRIX_ARB',
    'GL_TRANSPOSE_MODELVIEW_MATRIX',
    'GL_TRANSPOSE_MODELVIEW_MATRIX_ARB',
    'GL_TRANSPOSE_NV',
    'GL_TRANSPOSE_PROJECTION_MATRIX',
    'GL_TRANSPOSE_PROJECTION_MATRIX_ARB',
    'GL_TRANSPOSE_TEXTURE_MATRIX',
    'GL_TRANSPOSE_TEXTURE_MATRIX_ARB',
    'GL_TRIANGLES',
    'GL_TRIANGLE_FAN',
    'GL_TRIANGLE_LIST_SUN',
    'GL_TRIANGLE_MESH_SUN',
    'GL_TRIANGLE_STRIP',
    'GL_TRUE',
    'GL_TYPE_RGBA_FLOAT_ATI',
    'GL_UNPACK_ALIGNMENT',
    'GL_UNPACK_CLIENT_STORAGE_APPLE',
    'GL_UNPACK_CMYK_HINT_EXT',
    'GL_UNPACK_CONSTANT_DATA_SUNX',
    'GL_UNPACK_IMAGE_DEPTH_SGIS',
    'GL_UNPACK_IMAGE_HEIGHT',
    'GL_UNPACK_IMAGE_HEIGHT_EXT',
    'GL_UNPACK_LSB_FIRST',
    'GL_UNPACK_RESAMPLE_OML',
    'GL_UNPACK_RESAMPLE_SGIX',
    'GL_UNPACK_ROW_LENGTH',
    'GL_UNPACK_SKIP_IMAGES',
    'GL_UNPACK_SKIP_IMAGES_EXT',
    'GL_UNPACK_SKIP_PIXELS',
    'GL_UNPACK_SKIP_ROWS',
    'GL_UNPACK_SKIP_VOLUMES_SGIS',
    'GL_UNPACK_SUBSAMPLE_RATE_SGIX',
    'GL_UNPACK_SWAP_BYTES',
    'GL_UNSIGNED_BYTE',
    'GL_UNSIGNED_BYTE_2_3_3_REV',
    'GL_UNSIGNED_BYTE_3_3_2',
    'GL_UNSIGNED_BYTE_3_3_2_EXT',
    'GL_UNSIGNED_IDENTITY_NV',
    'GL_UNSIGNED_INT',
    'GL_UNSIGNED_INT_10_10_10_2',
    'GL_UNSIGNED_INT_10_10_10_2_EXT',
    'GL_UNSIGNED_INT_24_8_NV',
    'GL_UNSIGNED_INT_2_10_10_10_REV',
    'GL_UNSIGNED_INT_8_8_8_8',
    'GL_UNSIGNED_INT_8_8_8_8_EXT',
    'GL_UNSIGNED_INT_8_8_8_8_REV',
    'GL_UNSIGNED_INT_8_8_S8_S8_REV_NV',
    'GL_UNSIGNED_INT_S8_S8_8_8_NV',
    'GL_UNSIGNED_INVERT_NV',
    'GL_UNSIGNED_NORMALIZED_ARB',
    'GL_UNSIGNED_SHORT',
    'GL_UNSIGNED_SHORT_1_5_5_5_REV',
    'GL_UNSIGNED_SHORT_4_4_4_4',
    'GL_UNSIGNED_SHORT_4_4_4_4_EXT',
    'GL_UNSIGNED_SHORT_4_4_4_4_REV',
    'GL_UNSIGNED_SHORT_5_5_5_1',
    'GL_UNSIGNED_SHORT_5_5_5_1_EXT',
    'GL_UNSIGNED_SHORT_5_6_5',
    'GL_UNSIGNED_SHORT_5_6_5_REV',
    'GL_UNSIGNED_SHORT_8_8_APPLE',
    'GL_UNSIGNED_SHORT_8_8_MESA',
    'GL_UNSIGNED_SHORT_8_8_REV_APPLE',
    'GL_UNSIGNED_SHORT_8_8_REV_MESA',
    'GL_UPPER_LEFT',
    'GL_V2F',
    'GL_V3F',
    'GL_VALIDATE_STATUS',
    'GL_VARIABLE_A_NV',
    'GL_VARIABLE_B_NV',
    'GL_VARIABLE_C_NV',
    'GL_VARIABLE_D_NV',
    'GL_VARIABLE_E_NV',
    'GL_VARIABLE_F_NV',
    'GL_VARIABLE_G_NV',
    'GL_VARIANT_ARRAY_EXT',
    'GL_VARIANT_ARRAY_POINTER_EXT',
    'GL_VARIANT_ARRAY_STRIDE_EXT',
    'GL_VARIANT_ARRAY_TYPE_EXT',
    'GL_VARIANT_DATATYPE_EXT',
    'GL_VARIANT_EXT',
    'GL_VARIANT_VALUE_EXT',
    'GL_VECTOR_EXT',
    'GL_VENDOR',
    'GL_VERSION',
    'GL_VERSION_1_1',
    'GL_VERSION_1_2',
    'GL_VERSION_1_3',
    'GL_VERSION_1_4',
    'GL_VERSION_1_5',
    'GL_VERSION_2_0',
    'GL_VERTEX23_BIT_PGI',
    'GL_VERTEX4_BIT_PGI',
    'GL_VERTEX_ARRAY',
    'GL_VERTEX_ARRAY_BINDING_APPLE',
    'GL_VERTEX_ARRAY_BUFFER_BINDING',
    'GL_VERTEX_ARRAY_BUFFER_BINDING_ARB',
    'GL_VERTEX_ARRAY_COUNT_EXT',
    'GL_VERTEX_ARRAY_EXT',
    'GL_VERTEX_ARRAY_LIST_IBM',
    'GL_VERTEX_ARRAY_LIST_STRIDE_IBM',
    'GL_VERTEX_ARRAY_PARALLEL_POINTERS_INTEL',
    'GL_VERTEX_ARRAY_POINTER',
    'GL_VERTEX_ARRAY_POINTER_EXT',
    'GL_VERTEX_ARRAY_RANGE_APPLE',
    'GL_VERTEX_ARRAY_RANGE_LENGTH_APPLE',
    'GL_VERTEX_ARRAY_RANGE_LENGTH_NV',
    'GL_VERTEX_ARRAY_RANGE_NV',
    'GL_VERTEX_ARRAY_RANGE_POINTER_APPLE',
    'GL_VERTEX_ARRAY_RANGE_POINTER_NV',
    'GL_VERTEX_ARRAY_RANGE_VALID_NV',
    'GL_VERTEX_ARRAY_RANGE_WITHOUT_FLUSH_NV',
    'GL_VERTEX_ARRAY_SIZE',
    'GL_VERTEX_ARRAY_SIZE_EXT',
    'GL_VERTEX_ARRAY_STORAGE_HINT_APPLE',
    'GL_VERTEX_ARRAY_STRIDE',
    'GL_VERTEX_ARRAY_STRIDE_EXT',
    'GL_VERTEX_ARRAY_TYPE',
    'GL_VERTEX_ARRAY_TYPE_EXT',
    'GL_VERTEX_ATTRIB_ARRAY0_NV',
    'GL_VERTEX_ATTRIB_ARRAY10_NV',
    'GL_VERTEX_ATTRIB_ARRAY11_NV',
    'GL_VERTEX_ATTRIB_ARRAY12_NV',
    'GL_VERTEX_ATTRIB_ARRAY13_NV',
    'GL_VERTEX_ATTRIB_ARRAY14_NV',
    'GL_VERTEX_ATTRIB_ARRAY15_NV',
    'GL_VERTEX_ATTRIB_ARRAY1_NV',
    'GL_VERTEX_ATTRIB_ARRAY2_NV',
    'GL_VERTEX_ATTRIB_ARRAY3_NV',
    'GL_VERTEX_ATTRIB_ARRAY4_NV',
    'GL_VERTEX_ATTRIB_ARRAY5_NV',
    'GL_VERTEX_ATTRIB_ARRAY6_NV',
    'GL_VERTEX_ATTRIB_ARRAY7_NV',
    'GL_VERTEX_ATTRIB_ARRAY8_NV',
    'GL_VERTEX_ATTRIB_ARRAY9_NV',
    'GL_VERTEX_ATTRIB_ARRAY_BUFFER_BINDING',
    'GL_VERTEX_ATTRIB_ARRAY_BUFFER_BINDING_ARB',
    'GL_VERTEX_ATTRIB_ARRAY_ENABLED',
    'GL_VERTEX_ATTRIB_ARRAY_ENABLED_ARB',
    'GL_VERTEX_ATTRIB_ARRAY_NORMALIZED',
    'GL_VERTEX_ATTRIB_ARRAY_NORMALIZED_ARB',
    'GL_VERTEX_ATTRIB_ARRAY_POINTER',
    'GL_VERTEX_ATTRIB_ARRAY_POINTER_ARB',
    'GL_VERTEX_ATTRIB_ARRAY_SIZE',
    'GL_VERTEX_ATTRIB_ARRAY_SIZE_ARB',
    'GL_VERTEX_ATTRIB_ARRAY_STRIDE',
    'GL_VERTEX_ATTRIB_ARRAY_STRIDE_ARB',
    'GL_VERTEX_ATTRIB_ARRAY_TYPE',
    'GL_VERTEX_ATTRIB_ARRAY_TYPE_ARB',
    'GL_VERTEX_BLEND_ARB',
    'GL_VERTEX_CONSISTENT_HINT_PGI',
    'GL_VERTEX_DATA_HINT_PGI',
    'GL_VERTEX_PRECLIP_HINT_SGIX',
    'GL_VERTEX_PRECLIP_SGIX',
    'GL_VERTEX_PROGRAM_ARB',
    'GL_VERTEX_PROGRAM_BINDING_NV',
    'GL_VERTEX_PROGRAM_NV',
    'GL_VERTEX_PROGRAM_POINT_SIZE',
    'GL_VERTEX_PROGRAM_POINT_SIZE_ARB',
    'GL_VERTEX_PROGRAM_POINT_SIZE_NV',
    'GL_VERTEX_PROGRAM_TWO_SIDE',
    'GL_VERTEX_PROGRAM_TWO_SIDE_ARB',
    'GL_VERTEX_PROGRAM_TWO_SIDE_NV',
    'GL_VERTEX_SHADER',
    'GL_VERTEX_SHADER_ARB',
    'GL_VERTEX_SHADER_BINDING_EXT',
    'GL_VERTEX_SHADER_EXT',
    'GL_VERTEX_SHADER_INSTRUCTIONS_EXT',
    'GL_VERTEX_SHADER_INVARIANTS_EXT',
    'GL_VERTEX_SHADER_LOCALS_EXT',
    'GL_VERTEX_SHADER_LOCAL_CONSTANTS_EXT',
    'GL_VERTEX_SHADER_OPTIMIZED_EXT',
    'GL_VERTEX_SHADER_VARIANTS_EXT',
    'GL_VERTEX_SOURCE_ATI',
    'GL_VERTEX_STATE_PROGRAM_NV',
    'GL_VERTEX_STREAM0_ATI',
    'GL_VERTEX_STREAM1_ATI',
    'GL_VERTEX_STREAM2_ATI',
    'GL_VERTEX_STREAM3_ATI',
    'GL_VERTEX_STREAM4_ATI',
    'GL_VERTEX_STREAM5_ATI',
    'GL_VERTEX_STREAM6_ATI',
    'GL_VERTEX_STREAM7_ATI',
    'GL_VERTEX_WEIGHTING_EXT',
    'GL_VERTEX_WEIGHT_ARRAY_EXT',
    'GL_VERTEX_WEIGHT_ARRAY_POINTER_EXT',
    'GL_VERTEX_WEIGHT_ARRAY_SIZE_EXT',
    'GL_VERTEX_WEIGHT_ARRAY_STRIDE_EXT',
    'GL_VERTEX_WEIGHT_ARRAY_TYPE_EXT',
    'GL_VIBRANCE_BIAS_NV',
    'GL_VIBRANCE_SCALE_NV',
    'GL_VIEWPORT',
    'GL_VIEWPORT_BIT',
    'GL_WEIGHT_ARRAY_ARB',
    'GL_WEIGHT_ARRAY_BUFFER_BINDING',
    'GL_WEIGHT_ARRAY_BUFFER_BINDING_ARB',
    'GL_WEIGHT_ARRAY_POINTER_ARB',
    'GL_WEIGHT_ARRAY_SIZE_ARB',
    'GL_WEIGHT_ARRAY_STRIDE_ARB',
    'GL_WEIGHT_ARRAY_TYPE_ARB',
    'GL_WEIGHT_SUM_UNITY_ARB',
    'GL_WIDE_LINE_HINT_PGI',
    'GL_WRAP_BORDER_SUN',
    'GL_WRITE_ONLY',
    'GL_WRITE_ONLY_ARB',
    'GL_WRITE_PIXEL_DATA_RANGE_LENGTH_NV',
    'GL_WRITE_PIXEL_DATA_RANGE_NV',
    'GL_WRITE_PIXEL_DATA_RANGE_POINTER_NV',
    'GL_W_EXT',
    'GL_XOR',
    'GL_X_EXT',
    'GL_YCBCR_422_APPLE',
    'GL_YCBCR_MESA',
    'GL_YCRCBA_SGIX',
    'GL_YCRCB_422_SGIX',
    'GL_YCRCB_444_SGIX',
    'GL_YCRCB_SGIX',
    'GL_Y_EXT',
    'GL_ZERO',
    'GL_ZERO_EXT',
    'GL_ZOOM_X',
    'GL_ZOOM_Y',
    'GL_Z_EXT'
]
